-- MySQL dump 10.11
--
-- Host: localhost    Database: rainbowz_wp01
-- ------------------------------------------------------
-- Server version	5.0.67-community-log

/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8 */;
/*!40103 SET @OLD_TIME_ZONE=@@TIME_ZONE */;
/*!40103 SET TIME_ZONE='+00:00' */;
/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;
/*!40111 SET @OLD_SQL_NOTES=@@SQL_NOTES, SQL_NOTES=0 */;

--
-- Table structure for table `wp_comments`
--

DROP TABLE IF EXISTS `wp_comments`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `wp_comments` (
  `comment_ID` bigint(20) unsigned NOT NULL auto_increment,
  `comment_post_ID` int(11) NOT NULL default '0',
  `comment_author` tinytext NOT NULL,
  `comment_author_email` varchar(100) NOT NULL default '',
  `comment_author_url` varchar(200) NOT NULL default '',
  `comment_author_IP` varchar(100) NOT NULL default '',
  `comment_date` datetime NOT NULL default '0000-00-00 00:00:00',
  `comment_date_gmt` datetime NOT NULL default '0000-00-00 00:00:00',
  `comment_content` text NOT NULL,
  `comment_karma` int(11) NOT NULL default '0',
  `comment_approved` varchar(20) NOT NULL default '1',
  `comment_agent` varchar(255) NOT NULL default '',
  `comment_type` varchar(20) NOT NULL default '',
  `comment_parent` bigint(20) NOT NULL default '0',
  `user_id` bigint(20) NOT NULL default '0',
  PRIMARY KEY  (`comment_ID`),
  KEY `comment_approved` (`comment_approved`),
  KEY `comment_post_ID` (`comment_post_ID`),
  KEY `comment_approved_date_gmt` (`comment_approved`,`comment_date_gmt`),
  KEY `comment_date_gmt` (`comment_date_gmt`)
) ENGINE=MyISAM AUTO_INCREMENT=2 DEFAULT CHARSET=utf8;
SET character_set_client = @saved_cs_client;

--
-- Dumping data for table `wp_comments`
--

LOCK TABLES `wp_comments` WRITE;
/*!40000 ALTER TABLE `wp_comments` DISABLE KEYS */;
/*!40000 ALTER TABLE `wp_comments` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `wp_links`
--

DROP TABLE IF EXISTS `wp_links`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `wp_links` (
  `link_id` bigint(20) NOT NULL auto_increment,
  `link_url` varchar(255) NOT NULL default '',
  `link_name` varchar(255) NOT NULL default '',
  `link_image` varchar(255) NOT NULL default '',
  `link_target` varchar(25) NOT NULL default '',
  `link_category` bigint(20) NOT NULL default '0',
  `link_description` varchar(255) NOT NULL default '',
  `link_visible` varchar(20) NOT NULL default 'Y',
  `link_owner` int(11) NOT NULL default '1',
  `link_rating` int(11) NOT NULL default '0',
  `link_updated` datetime NOT NULL default '0000-00-00 00:00:00',
  `link_rel` varchar(255) NOT NULL default '',
  `link_notes` mediumtext NOT NULL,
  `link_rss` varchar(255) NOT NULL default '',
  PRIMARY KEY  (`link_id`),
  KEY `link_category` (`link_category`),
  KEY `link_visible` (`link_visible`)
) ENGINE=MyISAM AUTO_INCREMENT=9 DEFAULT CHARSET=utf8;
SET character_set_client = @saved_cs_client;

--
-- Dumping data for table `wp_links`
--

LOCK TABLES `wp_links` WRITE;
/*!40000 ALTER TABLE `wp_links` DISABLE KEYS */;
INSERT INTO `wp_links` VALUES (1,'http://codex.wordpress.org/','Documentation','','',0,'','Y',1,0,'0000-00-00 00:00:00','','',''),(2,'http://wordpress.org/development/','Development Blog','','',0,'','Y',1,0,'0000-00-00 00:00:00','','','http://wordpress.org/development/feed/'),(3,'http://wordpress.org/extend/ideas/','Suggest Ideas','','',0,'','Y',1,0,'0000-00-00 00:00:00','','',''),(4,'http://wordpress.org/support/','Support Forum','','',0,'','Y',1,0,'0000-00-00 00:00:00','','',''),(5,'http://wordpress.org/extend/plugins/','Plugins','','',0,'','Y',1,0,'0000-00-00 00:00:00','','',''),(6,'http://wordpress.org/extend/themes/','Themes','','',0,'','Y',1,0,'0000-00-00 00:00:00','','',''),(7,'http://planet.wordpress.org/','WordPress Planet','','',0,'','Y',1,0,'0000-00-00 00:00:00','','',''),(8,'http://www.simplescripts.com/','SimpleScripts','','',0,'','Y',1,0,'0000-00-00 00:00:00','','','');
/*!40000 ALTER TABLE `wp_links` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `wp_options`
--

DROP TABLE IF EXISTS `wp_options`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `wp_options` (
  `option_id` bigint(20) NOT NULL auto_increment,
  `blog_id` int(11) NOT NULL default '0',
  `option_name` varchar(64) NOT NULL default '',
  `option_value` longtext NOT NULL,
  `autoload` varchar(20) NOT NULL default 'yes',
  PRIMARY KEY  (`option_id`,`blog_id`,`option_name`),
  KEY `option_name` (`option_name`)
) ENGINE=MyISAM AUTO_INCREMENT=127 DEFAULT CHARSET=utf8;
SET character_set_client = @saved_cs_client;

--
-- Dumping data for table `wp_options`
--

LOCK TABLES `wp_options` WRITE;
/*!40000 ALTER TABLE `wp_options` DISABLE KEYS */;
INSERT INTO `wp_options` VALUES (1,0,'siteurl','http://www.rainbowzebra.net/wildwideweblog','yes'),(2,0,'blogname','The Wild Wide Weblog','yes'),(3,0,'blogdescription','Its All Out There...','yes'),(4,0,'users_can_register','1','yes'),(5,0,'admin_email','sol@rainbowzebra.com','yes'),(6,0,'start_of_week','1','yes'),(7,0,'use_balanceTags','0','yes'),(8,0,'use_smilies','1','yes'),(9,0,'require_name_email','1','yes'),(10,0,'comments_notify','1','yes'),(11,0,'posts_per_rss','10','yes'),(12,0,'rss_excerpt_length','50','yes'),(13,0,'rss_use_excerpt','0','yes'),(14,0,'mailserver_url','mail.example.com','yes'),(15,0,'mailserver_login','login@example.com','yes'),(16,0,'mailserver_pass','password','yes'),(17,0,'mailserver_port','110','yes'),(18,0,'default_category','1','yes'),(19,0,'default_comment_status','open','yes'),(20,0,'default_ping_status','closed','yes'),(21,0,'default_pingback_flag','','yes'),(22,0,'default_post_edit_rows','10','yes'),(23,0,'posts_per_page','10','yes'),(24,0,'what_to_show','posts','yes'),(25,0,'date_format','F j, Y','yes'),(26,0,'time_format','g:i A','yes'),(27,0,'links_updated_date_format','F j, Y g:i a','yes'),(28,0,'links_recently_updated_prepend','<em>','yes'),(29,0,'links_recently_updated_append','</em>','yes'),(30,0,'links_recently_updated_time','120','yes'),(31,0,'comment_moderation','1','yes'),(32,0,'moderation_notify','1','yes'),(33,0,'permalink_structure','/%year%/%monthnum%/%day%/%postname%/','yes'),(34,0,'gzipcompression','0','yes'),(35,0,'hack_file','1','yes'),(36,0,'blog_charset','UTF-8','yes'),(37,0,'moderation_keys','','no'),(38,0,'active_plugins','','yes'),(39,0,'home','http://www.rainbowzebra.net/wildwideweblog','yes'),(40,0,'category_base','','yes'),(41,0,'ping_sites','http://rpc.pingomatic.com/','yes'),(42,0,'advanced_edit','0','yes'),(43,0,'comment_max_links','2','yes'),(44,0,'gmt_offset','0','yes'),(45,0,'default_email_category','1','yes'),(46,0,'recently_edited','','no'),(47,0,'use_linksupdate','','yes'),(48,0,'template','default','yes'),(49,0,'stylesheet','default','yes'),(50,0,'comment_whitelist','1','yes'),(51,0,'page_uris','','yes'),(52,0,'blacklist_keys','','no'),(53,0,'comment_registration','1','yes'),(54,0,'rss_language','en','yes'),(55,0,'html_type','text/html','yes'),(56,0,'use_trackback','0','yes'),(57,0,'default_role','subscriber','yes'),(58,0,'db_version','9872','yes'),(59,0,'uploads_use_yearmonth_folders','1','yes'),(60,0,'upload_path','wp-content/uploads','yes'),(61,0,'random_seed','3867a52978d9310747a82337dfe7bed0','yes'),(62,0,'secret','tv&U10sZAE^8L0jYld4U7ob9*a%96lQUBzLi!91HaYShQtup)&K^d^a9s&$ymNV3','yes'),(63,0,'blog_public','1','yes'),(64,0,'default_link_category','2','yes'),(65,0,'show_on_front','posts','yes'),(66,0,'tag_base','','yes'),(67,0,'show_avatars','1','yes'),(68,0,'avatar_rating','G','yes'),(69,0,'upload_url_path','','yes'),(70,0,'thumbnail_size_w','150','yes'),(71,0,'thumbnail_size_h','150','yes'),(72,0,'thumbnail_crop','1','yes'),(73,0,'medium_size_w','300','yes'),(74,0,'medium_size_h','300','yes'),(75,0,'avatar_default','mystery','yes'),(76,0,'enable_app','0','yes'),(77,0,'enable_xmlrpc','0','yes'),(78,0,'large_size_w','1024','yes'),(79,0,'large_size_h','1024','yes'),(80,0,'image_default_link_type','file','yes'),(81,0,'image_default_size','','yes'),(82,0,'image_default_align','','yes'),(83,0,'close_comments_for_old_posts','','yes'),(84,0,'close_comments_days_old','14','yes'),(85,0,'thread_comments','','yes'),(86,0,'thread_comments_depth','5','yes'),(87,0,'page_comments','1','yes'),(88,0,'comments_per_page','50','yes'),(89,0,'default_comments_page','newest','yes'),(90,0,'comment_order','asc','yes'),(91,0,'use_ssl','0','yes'),(92,0,'sticky_posts','a:0:{}','yes'),(93,0,'widget_categories','a:0:{}','yes'),(94,0,'widget_text','a:0:{}','yes'),(95,0,'widget_rss','a:0:{}','yes'),(97,0,'dismissed_update_core','a:0:{}','yes'),(98,0,'wp_user_roles','a:5:{s:13:\"administrator\";a:2:{s:4:\"name\";s:23:\"Administrator|User role\";s:12:\"capabilities\";a:53:{s:13:\"switch_themes\";b:1;s:11:\"edit_themes\";b:1;s:16:\"activate_plugins\";b:1;s:12:\"edit_plugins\";b:1;s:10:\"edit_users\";b:1;s:10:\"edit_files\";b:1;s:14:\"manage_options\";b:1;s:17:\"moderate_comments\";b:1;s:17:\"manage_categories\";b:1;s:12:\"manage_links\";b:1;s:12:\"upload_files\";b:1;s:6:\"import\";b:1;s:15:\"unfiltered_html\";b:1;s:10:\"edit_posts\";b:1;s:17:\"edit_others_posts\";b:1;s:20:\"edit_published_posts\";b:1;s:13:\"publish_posts\";b:1;s:10:\"edit_pages\";b:1;s:4:\"read\";b:1;s:8:\"level_10\";b:1;s:7:\"level_9\";b:1;s:7:\"level_8\";b:1;s:7:\"level_7\";b:1;s:7:\"level_6\";b:1;s:7:\"level_5\";b:1;s:7:\"level_4\";b:1;s:7:\"level_3\";b:1;s:7:\"level_2\";b:1;s:7:\"level_1\";b:1;s:7:\"level_0\";b:1;s:17:\"edit_others_pages\";b:1;s:20:\"edit_published_pages\";b:1;s:13:\"publish_pages\";b:1;s:12:\"delete_pages\";b:1;s:19:\"delete_others_pages\";b:1;s:22:\"delete_published_pages\";b:1;s:12:\"delete_posts\";b:1;s:19:\"delete_others_posts\";b:1;s:22:\"delete_published_posts\";b:1;s:20:\"delete_private_posts\";b:1;s:18:\"edit_private_posts\";b:1;s:18:\"read_private_posts\";b:1;s:20:\"delete_private_pages\";b:1;s:18:\"edit_private_pages\";b:1;s:18:\"read_private_pages\";b:1;s:12:\"delete_users\";b:1;s:12:\"create_users\";b:1;s:17:\"unfiltered_upload\";b:1;s:14:\"edit_dashboard\";b:1;s:14:\"update_plugins\";b:1;s:14:\"delete_plugins\";b:1;s:15:\"install_plugins\";b:1;s:13:\"update_themes\";b:1;}}s:6:\"editor\";a:2:{s:4:\"name\";s:16:\"Editor|User role\";s:12:\"capabilities\";a:34:{s:17:\"moderate_comments\";b:1;s:17:\"manage_categories\";b:1;s:12:\"manage_links\";b:1;s:12:\"upload_files\";b:1;s:15:\"unfiltered_html\";b:1;s:10:\"edit_posts\";b:1;s:17:\"edit_others_posts\";b:1;s:20:\"edit_published_posts\";b:1;s:13:\"publish_posts\";b:1;s:10:\"edit_pages\";b:1;s:4:\"read\";b:1;s:7:\"level_7\";b:1;s:7:\"level_6\";b:1;s:7:\"level_5\";b:1;s:7:\"level_4\";b:1;s:7:\"level_3\";b:1;s:7:\"level_2\";b:1;s:7:\"level_1\";b:1;s:7:\"level_0\";b:1;s:17:\"edit_others_pages\";b:1;s:20:\"edit_published_pages\";b:1;s:13:\"publish_pages\";b:1;s:12:\"delete_pages\";b:1;s:19:\"delete_others_pages\";b:1;s:22:\"delete_published_pages\";b:1;s:12:\"delete_posts\";b:1;s:19:\"delete_others_posts\";b:1;s:22:\"delete_published_posts\";b:1;s:20:\"delete_private_posts\";b:1;s:18:\"edit_private_posts\";b:1;s:18:\"read_private_posts\";b:1;s:20:\"delete_private_pages\";b:1;s:18:\"edit_private_pages\";b:1;s:18:\"read_private_pages\";b:1;}}s:6:\"author\";a:2:{s:4:\"name\";s:16:\"Author|User role\";s:12:\"capabilities\";a:10:{s:12:\"upload_files\";b:1;s:10:\"edit_posts\";b:1;s:20:\"edit_published_posts\";b:1;s:13:\"publish_posts\";b:1;s:4:\"read\";b:1;s:7:\"level_2\";b:1;s:7:\"level_1\";b:1;s:7:\"level_0\";b:1;s:12:\"delete_posts\";b:1;s:22:\"delete_published_posts\";b:1;}}s:11:\"contributor\";a:2:{s:4:\"name\";s:21:\"Contributor|User role\";s:12:\"capabilities\";a:5:{s:10:\"edit_posts\";b:1;s:4:\"read\";b:1;s:7:\"level_1\";b:1;s:7:\"level_0\";b:1;s:12:\"delete_posts\";b:1;}}s:10:\"subscriber\";a:2:{s:4:\"name\";s:20:\"Subscriber|User role\";s:12:\"capabilities\";a:2:{s:4:\"read\";b:1;s:7:\"level_0\";b:1;}}}','yes'),(99,0,'cron','a:2:{i:1236166145;a:2:{s:17:\"wp_update_plugins\";a:1:{s:32:\"40cd750bba9870f18aada2478b24840a\";a:3:{s:8:\"schedule\";s:10:\"twicedaily\";s:4:\"args\";a:0:{}s:8:\"interval\";i:43200;}}s:16:\"wp_update_themes\";a:1:{s:32:\"40cd750bba9870f18aada2478b24840a\";a:3:{s:8:\"schedule\";s:10:\"twicedaily\";s:4:\"args\";a:0:{}s:8:\"interval\";i:43200;}}}s:7:\"version\";i:2;}','yes'),(100,0,'auth_salt','lclX#X7oic&2','yes'),(101,0,'doing_cron','0','yes'),(102,0,'update_plugins','O:8:\"stdClass\":3:{s:12:\"last_checked\";i:1236113232;s:7:\"checked\";a:2:{s:19:\"akismet/akismet.php\";s:5:\"2.2.3\";s:9:\"hello.php\";s:3:\"1.5\";}s:8:\"response\";a:0:{}}','yes'),(103,0,'update_themes','O:8:\"stdClass\":1:{s:12:\"last_checked\";i:1236113232;}','yes'),(104,0,'logged_in_salt','DvIDas1EUsI2','yes'),(105,0,'dashboard_widget_options','a:3:{s:24:\"dashboard_incoming_links\";a:5:{s:4:\"home\";s:42:\"http://www.rainbowzebra.net/wildwideweblog\";s:4:\"link\";s:124:\"http://blogsearch.google.com/blogsearch?hl=en&scoring=d&partner=wordpress&q=link:http://www.rainbowzebra.net/wildwideweblog/\";s:3:\"url\";s:157:\"http://blogsearch.google.com/blogsearch_feeds?hl=en&scoring=d&ie=utf-8&num=10&output=rss&partner=wordpress&q=link:http://www.rainbowzebra.net/wildwideweblog/\";s:5:\"items\";i:10;s:9:\"show_date\";b:0;}s:17:\"dashboard_primary\";a:7:{s:4:\"link\";s:33:\"http://wordpress.org/development/\";s:3:\"url\";s:38:\"http://wordpress.org/development/feed/\";s:5:\"title\";s:26:\"WordPress Development Blog\";s:5:\"items\";i:2;s:12:\"show_summary\";i:1;s:11:\"show_author\";i:0;s:9:\"show_date\";i:1;}s:19:\"dashboard_secondary\";a:4:{s:4:\"link\";s:28:\"http://planet.wordpress.org/\";s:3:\"url\";s:33:\"http://planet.wordpress.org/feed/\";s:5:\"title\";s:20:\"Other WordPress News\";s:5:\"items\";i:5;}}','yes'),(106,0,'nonce_salt','mk5NzV*quJvw','yes'),(107,0,'current_theme','WordPress Default','yes'),(108,0,'sidebars_widgets','a:1:{s:13:\"array_version\";i:3;}','yes'),(109,0,'rss_e90e6dfe4f411920bfc4710630e6612a','O:9:\"MagpieRSS\":17:{s:6:\"parser\";i:0;s:12:\"current_item\";a:0:{}s:5:\"items\";a:0:{}s:7:\"channel\";a:5:{s:5:\"title\";s:69:\"link:http://www.rainbowzebra.net/wildwideweblog/ - Google Blog Search\";s:4:\"link\";s:127:\"http://blogsearch.google.com/blogsearch?hl=en&scoring=d&ie=ISO-8859-1&num=10&q=link:http://www.rainbowzebra.net/wildwideweblog/\";s:11:\"description\";s:103:\"Your search - <b>link:http://www.rainbowzebra.net/wildwideweblog/</b> - did not match any documents.   \";s:10:\"opensearch\";a:3:{s:12:\"totalresults\";s:1:\"0\";s:10:\"startindex\";s:1:\"1\";s:12:\"itemsperpage\";s:2:\"10\";}s:7:\"tagline\";s:103:\"Your search - <b>link:http://www.rainbowzebra.net/wildwideweblog/</b> - did not match any documents.   \";}s:9:\"textinput\";a:0:{}s:5:\"image\";a:0:{}s:9:\"feed_type\";s:3:\"RSS\";s:12:\"feed_version\";s:3:\"2.0\";s:5:\"stack\";a:0:{}s:9:\"inchannel\";b:0;s:6:\"initem\";b:0;s:9:\"incontent\";b:0;s:11:\"intextinput\";b:0;s:7:\"inimage\";b:0;s:13:\"current_field\";s:0:\"\";s:17:\"current_namespace\";b:0;s:19:\"_CONTENT_CONSTRUCTS\";a:6:{i:0;s:7:\"content\";i:1;s:7:\"summary\";i:2;s:4:\"info\";i:3;s:5:\"title\";i:4;s:7:\"tagline\";i:5;s:9:\"copyright\";}}','no'),(110,0,'rss_e90e6dfe4f411920bfc4710630e6612a_ts','1236130594','no'),(111,0,'rss_a5420c83891a9c88ad2a4f04584a5efc','O:9:\"MagpieRSS\":17:{s:6:\"parser\";i:0;s:12:\"current_item\";a:0:{}s:5:\"items\";a:15:{i:0;a:7:{s:5:\"title\";s:33:\"uberdose on \"All in One SEO Pack\"\";s:4:\"link\";s:65:\"http://wordpress.org/extend/plugins/all-in-one-seo-pack/#post-753\";s:7:\"pubdate\";s:31:\"Fri, 30 Mar 2007 20:08:18 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:8:\"uberdose\";}s:4:\"guid\";s:40:\"753@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:92:\"Automatically optimizes your Wordpress blog for Search Engines (Search Engine Optimization).\";s:7:\"summary\";s:92:\"Automatically optimizes your Wordpress blog for Search Engines (Search Engine Optimization).\";}i:1;a:7:{s:5:\"title\";s:27:\"donncha on \"WP Super Cache\"\";s:4:\"link\";s:61:\"http://wordpress.org/extend/plugins/wp-super-cache/#post-2572\";s:7:\"pubdate\";s:31:\"Mon, 05 Nov 2007 11:40:04 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:7:\"donncha\";}s:4:\"guid\";s:41:\"2572@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:73:\"A very fast caching engine for WordPress that produces static html files.\";s:7:\"summary\";s:73:\"A very fast caching engine for WordPress that produces static html files.\";}i:2;a:7:{s:5:\"title\";s:30:\"arnee on \"Google XML Sitemaps\"\";s:4:\"link\";s:70:\"http://wordpress.org/extend/plugins/google-sitemap-generator/#post-132\";s:7:\"pubdate\";s:31:\"Fri, 09 Mar 2007 22:31:32 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:5:\"arnee\";}s:4:\"guid\";s:40:\"132@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:87:\"This plugin will create a Google sitemaps compliant XML-Sitemap of your WordPress blog.\";s:7:\"summary\";s:87:\"This plugin will create a Google sitemaps compliant XML-Sitemap of your WordPress blog.\";}i:3;a:7:{s:5:\"title\";s:32:\"takayukister on \"Contact Form 7\"\";s:4:\"link\";s:61:\"http://wordpress.org/extend/plugins/contact-form-7/#post-2141\";s:7:\"pubdate\";s:31:\"Thu, 02 Aug 2007 12:45:03 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:12:\"takayukister\";}s:4:\"guid\";s:41:\"2141@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:54:\"Just another contact form plugin. Simple but flexible.\";s:7:\"summary\";s:54:\"Just another contact form plugin. Simple but flexible.\";}i:4;a:7:{s:5:\"title\";s:44:\"keithdsouza on \"Wordpress Automatic upgrade\"\";s:4:\"link\";s:74:\"http://wordpress.org/extend/plugins/wordpress-automatic-upgrade/#post-2560\";s:7:\"pubdate\";s:31:\"Sat, 27 Oct 2007 20:55:05 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:11:\"keithdsouza\";}s:4:\"guid\";s:41:\"2560@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:112:\"Wordpress automatic upgrade allows a user to automatically upgrade the wordpress installation to the latest one.\";s:7:\"summary\";s:112:\"Wordpress automatic upgrade allows a user to automatically upgrade the wordpress installation to the latest one.\";}i:5;a:7:{s:5:\"title\";s:29:\"andy on \"WordPress.com Stats\"\";s:4:\"link\";s:52:\"http://wordpress.org/extend/plugins/stats/#post-1355\";s:7:\"pubdate\";s:31:\"Sun, 06 May 2007 02:15:03 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"andy\";}s:4:\"guid\";s:41:\"1355@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:119:\"You can have simple, concise stats with no additional load on your server by plugging into WordPress.com\'s stat system.\";s:7:\"summary\";s:119:\"You can have simple, concise stats with no additional load on your server by plugging into WordPress.com\'s stat system.\";}i:6;a:7:{s:5:\"title\";s:30:\"weefselkweekje on \"WP-Cumulus\"\";s:4:\"link\";s:57:\"http://wordpress.org/extend/plugins/wp-cumulus/#post-6499\";s:7:\"pubdate\";s:31:\"Thu, 31 Jul 2008 10:00:57 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:14:\"weefselkweekje\";}s:4:\"guid\";s:41:\"6499@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:91:\"WP-Cumulus displays your tags and/or categories in 3D by placing them on a rotating sphere.\";s:7:\"summary\";s:91:\"WP-Cumulus displays your tags and/or categories in 3D by placing them on a rotating sphere.\";}i:7;a:7:{s:5:\"title\";s:29:\"alexrabe on \"NextGEN Gallery\"\";s:4:\"link\";s:62:\"http://wordpress.org/extend/plugins/nextgen-gallery/#post-1169\";s:7:\"pubdate\";s:31:\"Mon, 23 Apr 2007 20:08:06 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:8:\"alexrabe\";}s:4:\"guid\";s:41:\"1169@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:102:\"NextGEN Gallery is a full integrated Image Gallery plugin for WordPress with a Flash slideshow option.\";s:7:\"summary\";s:102:\"NextGEN Gallery is a full integrated Image Gallery plugin for WordPress with a Flash slideshow option.\";}i:8;a:7:{s:5:\"title\";s:36:\"flipper on \"Page Flip Image Gallery\"\";s:4:\"link\";s:70:\"http://wordpress.org/extend/plugins/page-flip-image-gallery/#post-7590\";s:7:\"pubdate\";s:31:\"Fri, 07 Nov 2008 06:44:26 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:7:\"flipper\";}s:4:\"guid\";s:41:\"7590@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:108:\"FlippingBook Wordpress Gallery plugin helps you to create Image Gallery with Page Flip effects on your blog.\";s:7:\"summary\";s:108:\"FlippingBook Wordpress Gallery plugin helps you to create Image Gallery with Page Flip effects on your blog.\";}i:9;a:7:{s:5:\"title\";s:17:\"matt on \"Akismet\"\";s:4:\"link\";s:52:\"http://wordpress.org/extend/plugins/akismet/#post-15\";s:7:\"pubdate\";s:31:\"Fri, 09 Mar 2007 22:11:30 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"matt\";}s:4:\"guid\";s:39:\"15@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:98:\"Akismet checks your comments against the Akismet web service to see if they look like spam or not.\";s:7:\"summary\";s:98:\"Akismet checks your comments against the Akismet web service to see if they look like spam or not.\";}i:10;a:7:{s:5:\"title\";s:51:\"micropat on \"Add to Any Share/Save/Bookmark Button\"\";s:4:\"link\";s:56:\"http://wordpress.org/extend/plugins/add-to-any/#post-498\";s:7:\"pubdate\";s:31:\"Sat, 17 Mar 2007 23:08:16 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:8:\"micropat\";}s:4:\"guid\";s:40:\"498@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:149:\"Helps readers share, save, bookmark, and email your posts and pages using any service, such as Delicious, Digg, Facebook, Twitter, and over 100 more.\";s:7:\"summary\";s:149:\"Helps readers share, save, bookmark, and email your posts and pages using any service, such as Delicious, Digg, Facebook, Twitter, and over 100 more.\";}i:11;a:7:{s:5:\"title\";s:24:\"WebGeek on \"WP-SpamFree\"\";s:4:\"link\";s:58:\"http://wordpress.org/extend/plugins/wp-spamfree/#post-2654\";s:7:\"pubdate\";s:31:\"Sat, 15 Dec 2007 12:10:04 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:7:\"WebGeek\";}s:4:\"guid\";s:41:\"2654@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:139:\"Powerful anti-spam plugin that virtually eliminates comment spam. Finally, you can enjoy a spam-free WordPress blog! Includes contact form.\";s:7:\"summary\";s:139:\"Powerful anti-spam plugin that virtually eliminates comment spam. Finally, you can enjoy a spam-free WordPress blog! Includes contact form.\";}i:12;a:7:{s:5:\"title\";s:30:\"alexkingorg on \"Twitter Tools\"\";s:4:\"link\";s:59:\"http://wordpress.org/extend/plugins/twitter-tools/#post-313\";s:7:\"pubdate\";s:31:\"Fri, 09 Mar 2007 23:10:16 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:11:\"alexkingorg\";}s:4:\"guid\";s:40:\"313@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:115:\"Twitter Tools is a plugin that creates a complete integration between your WordPress blog and your Twitter account.\";s:7:\"summary\";s:115:\"Twitter Tools is a plugin that creates a complete integration between your WordPress blog and your Twitter account.\";}i:13;a:7:{s:5:\"title\";s:38:\"iePlexus on \"Featured Content Gallery\"\";s:4:\"link\";s:71:\"http://wordpress.org/extend/plugins/featured-content-gallery/#post-8733\";s:7:\"pubdate\";s:31:\"Thu, 22 Jan 2009 19:22:23 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:8:\"iePlexus\";}s:4:\"guid\";s:41:\"8733@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:89:\"Used to create a customizable rotating image gallery anywhere within your WordPress site.\";s:7:\"summary\";s:89:\"Used to create a customizable rotating image gallery anywhere within your WordPress site.\";}i:14;a:7:{s:5:\"title\";s:35:\"Utkarsh Kukreti on \"Plugin Manager\"\";s:4:\"link\";s:61:\"http://wordpress.org/extend/plugins/plugin-manager/#post-6737\";s:7:\"pubdate\";s:31:\"Fri, 22 Aug 2008 16:11:19 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:15:\"Utkarsh Kukreti\";}s:4:\"guid\";s:41:\"6737@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:129:\"View, download and install plugins from WordPress.org Plugin Database from an AJAX\'ed interface with a single click of the mouse.\";s:7:\"summary\";s:129:\"View, download and install plugins from WordPress.org Plugin Database from an AJAX\'ed interface with a single click of the mouse.\";}}s:7:\"channel\";a:6:{s:5:\"title\";s:12:\"Most Popular\";s:4:\"link\";s:36:\"http://wordpress.org/extend/plugins/\";s:11:\"description\";s:12:\"Most Popular\";s:8:\"language\";s:2:\"en\";s:7:\"pubdate\";s:31:\"Wed, 04 Mar 2009 01:36:36 +0000\";s:7:\"tagline\";s:12:\"Most Popular\";}s:9:\"textinput\";a:0:{}s:5:\"image\";a:0:{}s:9:\"feed_type\";s:3:\"RSS\";s:12:\"feed_version\";s:3:\"2.0\";s:5:\"stack\";a:0:{}s:9:\"inchannel\";b:0;s:6:\"initem\";b:0;s:9:\"incontent\";b:0;s:11:\"intextinput\";b:0;s:7:\"inimage\";b:0;s:13:\"current_field\";s:0:\"\";s:17:\"current_namespace\";b:0;s:19:\"_CONTENT_CONSTRUCTS\";a:6:{i:0;s:7:\"content\";i:1;s:7:\"summary\";i:2;s:4:\"info\";i:3;s:5:\"title\";i:4;s:7:\"tagline\";i:5;s:9:\"copyright\";}}','no'),(112,0,'rss_a5420c83891a9c88ad2a4f04584a5efc_ts','1236130596','no'),(113,0,'rss_0ff4b43bd116a9d8720d689c80e7dfd4','O:9:\"MagpieRSS\":17:{s:6:\"parser\";i:0;s:12:\"current_item\";a:0:{}s:5:\"items\";a:10:{i:0;a:12:{s:5:\"title\";s:24:\"Change the Web Challenge\";s:4:\"link\";s:66:\"http://wordpress.org/development/2009/02/change-the-web-challenge/\";s:8:\"comments\";s:75:\"http://wordpress.org/development/2009/02/change-the-web-challenge/#comments\";s:7:\"pubdate\";s:31:\"Thu, 26 Feb 2009 23:35:51 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:5:\"lloyd\";}s:8:\"category\";s:46:\"WidgetsChange the Web ChallengeContestsplugins\";s:4:\"guid\";s:39:\"http://wordpress.org/development/?p=563\";s:11:\"description\";s:326:\"We&#8217;re excited to be part of the Change the Web Challenge.\nBasically, the contest is to create a plugin, widget, mash up, hack, or other variety of web application that helps people find and share opportunities to take action. The grand prize is 50 benjis, and the best WordPress plugin will also be featured in the [...]\";s:7:\"content\";a:1:{s:7:\"encoded\";s:1585:\"<p><a href=\"http://www.socialactions.com/changetheweb\"><img class=\"alignleft\" align=\"left\" title=\"Change the Web Challenge Logo\" src=\"http://wpdotorg.wordpress.com/files/2009/02/change-the-web-challenge-logo-sm.gif\" alt=\"\" width=\"174\" height=\"240\" /></a>We&#8217;re excited to be part of the <a href=\"http://www.socialactions.com/changetheweb\">Change the Web Challenge</a>.</p>\n<p>Basically, the contest is to create a plugin, widget, mash up, hack, or other variety of web application that helps people find and share opportunities to take action. The grand prize is 50 benjis, and the best WordPress plugin will also be featured in the <a href=\"http://wordpress.org/extend/plugins/\">Plugin Directory</a>. But the real prize is spreading a little more love in the world.</p>\n<p><a href=\"http://www.socialactions.com/changetheweb\">Click here</a> for all the details.</p>\n<p>&#8220;<a href=\"http://codex.wordpress.org/Writing_a_Plugin\">Writing a Plugin</a>&#8221; in the WordPress Codex is where I got started when I needed to get hooked in to WordPress. Others might like to grab one of the over 4,000 <a href=\"http://wordpress.org/extend/plugins/\">open source WordPress plugins</a> and tweak the source. If in need of a little help, the <a href=\"http://wordpress.org/support/forum/10\">Plugins and Hacks</a> forum is full of friends to assist you wrap your head around the code or debug a problem. Social Actions also has provided some <a href=\"http://www.socialactions.com/developers\">developer resources</a>.</p>\n<p>Let&#8217;s show them how we change the web the WordPress way!</p>\n\";}s:3:\"wfw\";a:1:{s:10:\"commentrss\";s:71:\"http://wordpress.org/development/2009/02/change-the-web-challenge/feed/\";}s:7:\"summary\";s:326:\"We&#8217;re excited to be part of the Change the Web Challenge.\nBasically, the contest is to create a plugin, widget, mash up, hack, or other variety of web application that helps people find and share opportunities to take action. The grand prize is 50 benjis, and the best WordPress plugin will also be featured in the [...]\";s:12:\"atom_content\";s:1585:\"<p><a href=\"http://www.socialactions.com/changetheweb\"><img class=\"alignleft\" align=\"left\" title=\"Change the Web Challenge Logo\" src=\"http://wpdotorg.wordpress.com/files/2009/02/change-the-web-challenge-logo-sm.gif\" alt=\"\" width=\"174\" height=\"240\" /></a>We&#8217;re excited to be part of the <a href=\"http://www.socialactions.com/changetheweb\">Change the Web Challenge</a>.</p>\n<p>Basically, the contest is to create a plugin, widget, mash up, hack, or other variety of web application that helps people find and share opportunities to take action. The grand prize is 50 benjis, and the best WordPress plugin will also be featured in the <a href=\"http://wordpress.org/extend/plugins/\">Plugin Directory</a>. But the real prize is spreading a little more love in the world.</p>\n<p><a href=\"http://www.socialactions.com/changetheweb\">Click here</a> for all the details.</p>\n<p>&#8220;<a href=\"http://codex.wordpress.org/Writing_a_Plugin\">Writing a Plugin</a>&#8221; in the WordPress Codex is where I got started when I needed to get hooked in to WordPress. Others might like to grab one of the over 4,000 <a href=\"http://wordpress.org/extend/plugins/\">open source WordPress plugins</a> and tweak the source. If in need of a little help, the <a href=\"http://wordpress.org/support/forum/10\">Plugins and Hacks</a> forum is full of friends to assist you wrap your head around the code or debug a problem. Social Actions also has provided some <a href=\"http://www.socialactions.com/developers\">developer resources</a>.</p>\n<p>Let&#8217;s show them how we change the web the WordPress way!</p>\n\";}i:1;a:12:{s:5:\"title\";s:41:\"New and Improved Plugins Directory Search\";s:4:\"link\";s:83:\"http://wordpress.org/development/2009/02/new-and-improved-plugins-directory-search/\";s:8:\"comments\";s:92:\"http://wordpress.org/development/2009/02/new-and-improved-plugins-directory-search/#comments\";s:7:\"pubdate\";s:31:\"Thu, 19 Feb 2009 01:29:24 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:8:\"mdawaffe\";}s:8:\"category\";s:20:\"Generalpluginssearch\";s:4:\"guid\";s:39:\"http://wordpress.org/development/?p=544\";s:11:\"description\";s:399:\"One of the biggest problems and most frequent complaints we&#8217;ve had with the WordPress.org Plugins Directory is the horrible, horrible search results.\nNo longer.  We&#8217;re now using Sphinx (a &#8220;free open-source SQL full-text search engine&#8221;) to power search on the Plugins Directory both from the website and from within your blog&#8217;s admin (Plugins &#8594; Add New).\nIt [...]\";s:7:\"content\";a:1:{s:7:\"encoded\";s:1055:\"<p>One of the biggest problems and most frequent complaints we&#8217;ve had with the <a href=\"http://wordpress.org/extend/plugins/\">WordPress.org Plugins Directory</a> is the horrible, horrible search results.</p>\n<p>No longer.  We&#8217;re now using <a href=\"http://www.sphinxsearch.com/\">Sphinx</a> (a &#8220;free open-source SQL full-text search engine&#8221;) to power search on the Plugins Directory both from the website and from within your blog&#8217;s admin (Plugins &rarr; Add New).</p>\n<p>It works much better.  There are a few oddities floating around (our fault not sphinx&#8217;s) that we&#8217;ll be cleaning up shortly, but we&#8217;re happy enough with it on the whole to start letting everyone else use it <img src=\'http://wordpress.org/development/wp-includes/images/smilies/icon_smile.gif\' alt=\':)\' class=\'wp-smiley\' /> </p>\n<p>Currently, the search only indexes the plugin&#8217;s title and description/installation/FAQ/etc. (from the plugin&#8217;s readme.txt file), but we&#8217;ll be adding things like authors and tags soon.</p>\n\";}s:3:\"wfw\";a:1:{s:10:\"commentrss\";s:88:\"http://wordpress.org/development/2009/02/new-and-improved-plugins-directory-search/feed/\";}s:7:\"summary\";s:399:\"One of the biggest problems and most frequent complaints we&#8217;ve had with the WordPress.org Plugins Directory is the horrible, horrible search results.\nNo longer.  We&#8217;re now using Sphinx (a &#8220;free open-source SQL full-text search engine&#8221;) to power search on the Plugins Directory both from the website and from within your blog&#8217;s admin (Plugins &#8594; Add New).\nIt [...]\";s:12:\"atom_content\";s:1055:\"<p>One of the biggest problems and most frequent complaints we&#8217;ve had with the <a href=\"http://wordpress.org/extend/plugins/\">WordPress.org Plugins Directory</a> is the horrible, horrible search results.</p>\n<p>No longer.  We&#8217;re now using <a href=\"http://www.sphinxsearch.com/\">Sphinx</a> (a &#8220;free open-source SQL full-text search engine&#8221;) to power search on the Plugins Directory both from the website and from within your blog&#8217;s admin (Plugins &rarr; Add New).</p>\n<p>It works much better.  There are a few oddities floating around (our fault not sphinx&#8217;s) that we&#8217;ll be cleaning up shortly, but we&#8217;re happy enough with it on the whole to start letting everyone else use it <img src=\'http://wordpress.org/development/wp-includes/images/smilies/icon_smile.gif\' alt=\':)\' class=\'wp-smiley\' /> </p>\n<p>Currently, the search only indexes the plugin&#8217;s title and description/installation/FAQ/etc. (from the plugin&#8217;s readme.txt file), but we&#8217;ll be adding things like authors and tags soon.</p>\n\";}i:2;a:12:{s:5:\"title\";s:15:\"WordPress 2.7.1\";s:4:\"link\";s:55:\"http://wordpress.org/development/2009/02/wordpress-271/\";s:8:\"comments\";s:64:\"http://wordpress.org/development/2009/02/wordpress-271/#comments\";s:7:\"pubdate\";s:31:\"Tue, 10 Feb 2009 21:26:50 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:10:\"Ryan Boren\";}s:8:\"category\";s:8:\"Releases\";s:4:\"guid\";s:39:\"http://wordpress.org/development/?p=536\";s:11:\"description\";s:341:\"2.7.1, the first 2.7 maintenance release, is now available.  2.7.1 fixes 68 tickets.  You can automatically upgrade from 2.7 to 2.7.1 via the Tools &#8594; Upgrade menu, or you can download the package and upgrade manually.\nYou may have noticed that we went much longer than usual to release this .1 update. We&#8217;re very proud of [...]\";s:7:\"content\";a:1:{s:7:\"encoded\";s:1319:\"<p>2.7.1, the first 2.7 maintenance release, is now available.  2.7.1 fixes <a href=\"http://trac.wordpress.org/query?status=closed&amp;milestone=2.7.1&amp;resolution=fixed&amp;order=priority\">68 tickets</a>.  You can automatically upgrade from 2.7 to 2.7.1 via the Tools &rarr; Upgrade menu, or you can <a href=\"http://wordpress.org/download/\">download the package</a> and upgrade manually.</p>\n<p>You may have noticed that we went much longer than usual to release this .1 update. We&#8217;re very proud of this fact because it&#8217;s a testament to the testing all of you contributed prior to the release of 2.7 which helped make it the most bug-free release we&#8217;ve had.</p>\n<p>Consult the <a href=\"http://trac.wordpress.org/query?status=closed&amp;milestone=2.7.1&amp;resolution=fixed&amp;order=priority\">list of fixed tickets</a> and the  <a href=\"http://core.trac.wordpress.org/changeset?old_path=tags/2.7&#038;old=10539&#038;new_path=tags/2.7.1&#038;new=10539\">full set of changes between 2.7 and 2.7.1</a> for details.</p>\n<p>Finally partly due to the stability of the 2.7 we&#8217;ve decided to push back 2.8 a few more weeks so we can bring in a few more speed optimizations, taxonomy enhancements, and new theme features. We also need to figure out which jazz musician to name the release after.</p>\n\";}s:3:\"wfw\";a:1:{s:10:\"commentrss\";s:60:\"http://wordpress.org/development/2009/02/wordpress-271/feed/\";}s:7:\"summary\";s:341:\"2.7.1, the first 2.7 maintenance release, is now available.  2.7.1 fixes 68 tickets.  You can automatically upgrade from 2.7 to 2.7.1 via the Tools &#8594; Upgrade menu, or you can download the package and upgrade manually.\nYou may have noticed that we went much longer than usual to release this .1 update. We&#8217;re very proud of [...]\";s:12:\"atom_content\";s:1319:\"<p>2.7.1, the first 2.7 maintenance release, is now available.  2.7.1 fixes <a href=\"http://trac.wordpress.org/query?status=closed&amp;milestone=2.7.1&amp;resolution=fixed&amp;order=priority\">68 tickets</a>.  You can automatically upgrade from 2.7 to 2.7.1 via the Tools &rarr; Upgrade menu, or you can <a href=\"http://wordpress.org/download/\">download the package</a> and upgrade manually.</p>\n<p>You may have noticed that we went much longer than usual to release this .1 update. We&#8217;re very proud of this fact because it&#8217;s a testament to the testing all of you contributed prior to the release of 2.7 which helped make it the most bug-free release we&#8217;ve had.</p>\n<p>Consult the <a href=\"http://trac.wordpress.org/query?status=closed&amp;milestone=2.7.1&amp;resolution=fixed&amp;order=priority\">list of fixed tickets</a> and the  <a href=\"http://core.trac.wordpress.org/changeset?old_path=tags/2.7&#038;old=10539&#038;new_path=tags/2.7.1&#038;new=10539\">full set of changes between 2.7 and 2.7.1</a> for details.</p>\n<p>Finally partly due to the stability of the 2.7 we&#8217;ve decided to push back 2.8 a few more weeks so we can bring in a few more speed optimizations, taxonomy enhancements, and new theme features. We also need to figure out which jazz musician to name the release after.</p>\n\";}i:3;a:12:{s:5:\"title\";s:28:\"Thank a Plugin Developer Day\";s:4:\"link\";s:70:\"http://wordpress.org/development/2009/01/thank-a-plugin-developer-day/\";s:8:\"comments\";s:79:\"http://wordpress.org/development/2009/01/thank-a-plugin-developer-day/#comments\";s:7:\"pubdate\";s:31:\"Wed, 28 Jan 2009 21:55:51 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:8:\"category\";s:27:\"Developmentmilestoneplugins\";s:4:\"guid\";s:39:\"http://wordpress.org/development/?p=534\";s:11:\"description\";s:343:\"WordPress by itself is very simple &#8212; what makes it compelling for most of its users is the wide array of plugins (and themes) available for WP. The average WordPress blog has about 5 plugins installed! Today we just passed 4,000 plugins available in our plugin directory. (Which is also embedded into everyone&#8217;s WordPress 2.7 [...]\";s:7:\"content\";a:1:{s:7:\"encoded\";s:1037:\"<p>WordPress by itself is very simple &#8212; what makes it compelling for most of its users is the wide array of plugins (and themes) available for WP. The average WordPress blog has about 5 plugins installed! Today we just passed <a href=\"http://wordpress.org/extend/plugins/\">4,000 plugins available in our plugin directory</a>. (Which is also embedded into everyone&#8217;s WordPress 2.7 or above.)</p>\n<p>I declare January 28th our official &#8220;Thank a Plugin Developer&#8221; day. To celebrate take a look at the plugins you use and love, visit the author’s site, find their contact form, and drop them a note thanking them. (Or Paypal!) Look for the links in the plugin directory to &#8220;author homepage&#8221; and also to donate directly if they&#8217;ve specified a Paypal address.</p>\n<p>Thank you to everyone who has ever written a plugin for WordPress, and here&#8217;s to the next four thousand. <img src=\'http://wordpress.org/development/wp-includes/images/smilies/icon_smile.gif\' alt=\':)\' class=\'wp-smiley\' /> </p>\n\";}s:3:\"wfw\";a:1:{s:10:\"commentrss\";s:75:\"http://wordpress.org/development/2009/01/thank-a-plugin-developer-day/feed/\";}s:7:\"summary\";s:343:\"WordPress by itself is very simple &#8212; what makes it compelling for most of its users is the wide array of plugins (and themes) available for WP. The average WordPress blog has about 5 plugins installed! Today we just passed 4,000 plugins available in our plugin directory. (Which is also embedded into everyone&#8217;s WordPress 2.7 [...]\";s:12:\"atom_content\";s:1037:\"<p>WordPress by itself is very simple &#8212; what makes it compelling for most of its users is the wide array of plugins (and themes) available for WP. The average WordPress blog has about 5 plugins installed! Today we just passed <a href=\"http://wordpress.org/extend/plugins/\">4,000 plugins available in our plugin directory</a>. (Which is also embedded into everyone&#8217;s WordPress 2.7 or above.)</p>\n<p>I declare January 28th our official &#8220;Thank a Plugin Developer&#8221; day. To celebrate take a look at the plugins you use and love, visit the author’s site, find their contact form, and drop them a note thanking them. (Or Paypal!) Look for the links in the plugin directory to &#8220;author homepage&#8221; and also to donate directly if they&#8217;ve specified a Paypal address.</p>\n<p>Thank you to everyone who has ever written a plugin for WordPress, and here&#8217;s to the next four thousand. <img src=\'http://wordpress.org/development/wp-includes/images/smilies/icon_smile.gif\' alt=\':)\' class=\'wp-smiley\' /> </p>\n\";}i:4;a:12:{s:5:\"title\";s:12:\"WordPress.tv\";s:4:\"link\";s:53:\"http://wordpress.org/development/2009/01/wordpresstv/\";s:8:\"comments\";s:62:\"http://wordpress.org/development/2009/01/wordpresstv/#comments\";s:7:\"pubdate\";s:31:\"Sat, 17 Jan 2009 07:01:29 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:8:\"category\";s:23:\"WordCamptutorialsvideos\";s:4:\"guid\";s:39:\"http://wordpress.org/development/?p=513\";s:11:\"description\";s:366:\"Today we&#8217;ve switched on WordPress.tv, your visual resource for all things WordPress. \n\nOn WordPress.tv, you&#8217;ll find tutorials for both WordPress self-installs and WordPress.com to help you get blogging fast and hassle-free. We&#8217;ve kicked things off with the basics &#8212; now you can shape what comes next. Just drop us a line and let us know [...]\";s:7:\"content\";a:1:{s:7:\"encoded\";s:1655:\"<p>Today we&#8217;ve switched on <a href=\"http://wordpress.tv\">WordPress.tv</a>, your visual resource for all things WordPress. </p>\n<p><embed src=\"http://v.wordpress.com/DEesBAlR\" type=\"application/x-shockwave-flash\" width=\"640\" height=\"360\" allowscriptaccess=\"always\" allowfullscreen=\"true\"></embed></p>\n<p>On WordPress.tv, you&#8217;ll find <a href=\"http://wordpress.tv/category/how-to/\">tutorials</a> for both <a href=\"http://www.wordpress.org\">WordPress</a> self-installs and <a href=\"http://www.wordpress.com\">WordPress.com</a> to help you get blogging fast and hassle-free. We&#8217;ve kicked things off with the basics &#8212; now you can shape what comes next. Just <a href=\"http://wordpress.tv/contact/\">drop us a line</a> and let us know what you&#8217;d like to see added. </p>\n<p>WordPress.tv is also now <em>the</em> place to find all that awesome  <a href=\"http://central.wordcamp.org/\">WordCamp</a> footage that was floating around the web without a home. See the presentations you missed and get a peek at behind-the-scenes action. We call it <a href=\"http://wordpress.tv/category/wordcamptv/\">WordCampTV</a>. </p>\n<p>You&#8217;ll also find slideshows of presentations made by WordPress gurus, plus interviews I&#8217;ve done with the media and fellow bloggers. </p>\n<p>I hope you&#8217;ll consider WordPress.tv not just a <a href=\"http://www.wordpress.org/support\">support</a> resource, but also a place to hang out and keep up with all the geeky goodness going on in the WordPress community. Tune in regularly for fresh content and updates to the <a href=\"http://blog.wordpress.tv/\">WordPress.tv blog</a>. Lots more is on the way. </p>\n\";}s:3:\"wfw\";a:1:{s:10:\"commentrss\";s:58:\"http://wordpress.org/development/2009/01/wordpresstv/feed/\";}s:7:\"summary\";s:366:\"Today we&#8217;ve switched on WordPress.tv, your visual resource for all things WordPress. \n\nOn WordPress.tv, you&#8217;ll find tutorials for both WordPress self-installs and WordPress.com to help you get blogging fast and hassle-free. We&#8217;ve kicked things off with the basics &#8212; now you can shape what comes next. Just drop us a line and let us know [...]\";s:12:\"atom_content\";s:1655:\"<p>Today we&#8217;ve switched on <a href=\"http://wordpress.tv\">WordPress.tv</a>, your visual resource for all things WordPress. </p>\n<p><embed src=\"http://v.wordpress.com/DEesBAlR\" type=\"application/x-shockwave-flash\" width=\"640\" height=\"360\" allowscriptaccess=\"always\" allowfullscreen=\"true\"></embed></p>\n<p>On WordPress.tv, you&#8217;ll find <a href=\"http://wordpress.tv/category/how-to/\">tutorials</a> for both <a href=\"http://www.wordpress.org\">WordPress</a> self-installs and <a href=\"http://www.wordpress.com\">WordPress.com</a> to help you get blogging fast and hassle-free. We&#8217;ve kicked things off with the basics &#8212; now you can shape what comes next. Just <a href=\"http://wordpress.tv/contact/\">drop us a line</a> and let us know what you&#8217;d like to see added. </p>\n<p>WordPress.tv is also now <em>the</em> place to find all that awesome  <a href=\"http://central.wordcamp.org/\">WordCamp</a> footage that was floating around the web without a home. See the presentations you missed and get a peek at behind-the-scenes action. We call it <a href=\"http://wordpress.tv/category/wordcamptv/\">WordCampTV</a>. </p>\n<p>You&#8217;ll also find slideshows of presentations made by WordPress gurus, plus interviews I&#8217;ve done with the media and fellow bloggers. </p>\n<p>I hope you&#8217;ll consider WordPress.tv not just a <a href=\"http://www.wordpress.org/support\">support</a> resource, but also a place to hang out and keep up with all the geeky goodness going on in the WordPress community. Tune in regularly for fresh content and updates to the <a href=\"http://blog.wordpress.tv/\">WordPress.tv blog</a>. Lots more is on the way. </p>\n\";}i:5;a:12:{s:5:\"title\";s:39:\"Prioritizing Features for WordPress 2.8\";s:4:\"link\";s:80:\"http://wordpress.org/development/2008/12/prioritizing-features-for-wordpress-28/\";s:8:\"comments\";s:89:\"http://wordpress.org/development/2008/12/prioritizing-features-for-wordpress-28/#comments\";s:7:\"pubdate\";s:31:\"Wed, 24 Dec 2008 00:17:58 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:10:\"Jane Wells\";}s:8:\"category\";s:32:\"DevelopmentFeatures2.8surveytrac\";s:4:\"guid\";s:39:\"http://wordpress.org/development/?p=491\";s:11:\"description\";s:327:\"Everyone knows by now that WordPress 2.7 is packed with new features. Now that it&#8217;s available (almost 600,000 downloads as I write this!), it&#8217;s time to start working on 2.8. There were dozens of things that got tabled during 2.7 due to time constraints, and there are a lot of high-rated features in the Ideas [...]\";s:7:\"content\";a:1:{s:7:\"encoded\";s:2977:\"<p>Everyone knows by now that WordPress 2.7 is packed with new features. Now that it&#8217;s available (almost <a href=\"http://wordpress.org/download/counter/\">600,000 downloads</a> as I write this!), it&#8217;s time to start working on 2.8. There were dozens of things that got tabled during 2.7 due to time constraints, and there are a lot of high-rated features in the <a href=\"http://wordpress.org/extend/ideas\">Ideas forum</a>, so there are a lot of potential features under consideration.</p>\n<p>Right now, the lead developers are thinking the top priorities for 2.8 will be widget management, theme browser/installer and performance upgrades. The rest of the development time will be taken up with bug tickets and additional features/enhancements from a prioritized list. To that end, we&#8217;ve posted <a href=\"http://www.polldaddy.com/s/6FC3E15CDE20B5B5/\">a new survey</a> for you to help us prioritize features for 2.8. The list pulls from the developers&#8217; &#8220;2.7 leftovers&#8221; list as well as the most popular features from the Ideas forum. Just rank each feature and tell us your top pick (up to three). You also have the option of adding comments or additional suggestions, but this is not mandatory. For your response to count, you must rank all of the features in the list. The survey has only one page.  </p>\n<p>Note that media features are not included in this list as we will be posting a separate survey for media-specific features soon. </p>\n<p><a href=\"http://www.polldaddy.com/s/6FC3E15CDE20B5B5/\">Cast your votes</a> any time this week, but as always the sooner the better. This survey will close at noon on December 31, 2008 UTC.</p>\n<p>In the new year, we will be reviving scheduled IRC developer chats, where the lead developers will discuss the week&#8217;s progress on feature development, providing opportunities for people to ask questions or make suggestions. These will be held early in the day on Wednesdays (U.S. Wednesday), and the specific time will be posted here on the development blog once it&#8217;s been finalized. </p>\n<p>As a related aside, we spent a significant amount of time during 2.7 development sifting through Trac tickets that really shouldn&#8217;t have been there. Feature ideas and requests do not belong in Trac, they belong in the Ideas forum. Please reserve Trac for reporting bugs and things that need fixing (typos, code enhancements, etc.). If you are asking for a new UI, a new feature, or a new approach to coding something, that&#8217;s not an enhancement, it&#8217;s a new feature. New features will be entered into Trac by developers once it has been determined that the feature should be included in core. To help speed up development, moving forward we will close Trac tickets that are actually feature requests, with the comment that they should be posted in the Ideas forum instead. Please help the developers maximize their time by following this guideline. </p>\n<p>Thanks for your help!</p>\n\";}s:3:\"wfw\";a:1:{s:10:\"commentrss\";s:85:\"http://wordpress.org/development/2008/12/prioritizing-features-for-wordpress-28/feed/\";}s:7:\"summary\";s:327:\"Everyone knows by now that WordPress 2.7 is packed with new features. Now that it&#8217;s available (almost 600,000 downloads as I write this!), it&#8217;s time to start working on 2.8. There were dozens of things that got tabled during 2.7 due to time constraints, and there are a lot of high-rated features in the Ideas [...]\";s:12:\"atom_content\";s:2977:\"<p>Everyone knows by now that WordPress 2.7 is packed with new features. Now that it&#8217;s available (almost <a href=\"http://wordpress.org/download/counter/\">600,000 downloads</a> as I write this!), it&#8217;s time to start working on 2.8. There were dozens of things that got tabled during 2.7 due to time constraints, and there are a lot of high-rated features in the <a href=\"http://wordpress.org/extend/ideas\">Ideas forum</a>, so there are a lot of potential features under consideration.</p>\n<p>Right now, the lead developers are thinking the top priorities for 2.8 will be widget management, theme browser/installer and performance upgrades. The rest of the development time will be taken up with bug tickets and additional features/enhancements from a prioritized list. To that end, we&#8217;ve posted <a href=\"http://www.polldaddy.com/s/6FC3E15CDE20B5B5/\">a new survey</a> for you to help us prioritize features for 2.8. The list pulls from the developers&#8217; &#8220;2.7 leftovers&#8221; list as well as the most popular features from the Ideas forum. Just rank each feature and tell us your top pick (up to three). You also have the option of adding comments or additional suggestions, but this is not mandatory. For your response to count, you must rank all of the features in the list. The survey has only one page.  </p>\n<p>Note that media features are not included in this list as we will be posting a separate survey for media-specific features soon. </p>\n<p><a href=\"http://www.polldaddy.com/s/6FC3E15CDE20B5B5/\">Cast your votes</a> any time this week, but as always the sooner the better. This survey will close at noon on December 31, 2008 UTC.</p>\n<p>In the new year, we will be reviving scheduled IRC developer chats, where the lead developers will discuss the week&#8217;s progress on feature development, providing opportunities for people to ask questions or make suggestions. These will be held early in the day on Wednesdays (U.S. Wednesday), and the specific time will be posted here on the development blog once it&#8217;s been finalized. </p>\n<p>As a related aside, we spent a significant amount of time during 2.7 development sifting through Trac tickets that really shouldn&#8217;t have been there. Feature ideas and requests do not belong in Trac, they belong in the Ideas forum. Please reserve Trac for reporting bugs and things that need fixing (typos, code enhancements, etc.). If you are asking for a new UI, a new feature, or a new approach to coding something, that&#8217;s not an enhancement, it&#8217;s a new feature. New features will be entered into Trac by developers once it has been determined that the feature should be included in core. To help speed up development, moving forward we will close Trac tickets that are actually feature requests, with the comment that they should be posted in the Ideas forum instead. Please help the developers maximize their time by following this guideline. </p>\n<p>Thanks for your help!</p>\n\";}i:6;a:12:{s:5:\"title\";s:28:\"WordPress 2.7 “Coltrane”\";s:4:\"link\";s:50:\"http://wordpress.org/development/2008/12/coltrane/\";s:8:\"comments\";s:59:\"http://wordpress.org/development/2008/12/coltrane/#comments\";s:7:\"pubdate\";s:31:\"Thu, 11 Dec 2008 02:28:57 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:8:\"category\";s:19:\"DevelopmentReleases\";s:4:\"guid\";s:39:\"http://wordpress.org/development/?p=477\";s:11:\"description\";s:318:\"The first thing you&#8217;ll notice about 2.7 is its new interface. From the top down, we&#8217;ve listened to your feedback and thought deeply about the design and the result is a WordPress that&#8217;s just plain faster. Nearly every task you do on your blog will take fewer clicks and be faster in 2.7 than it [...]\";s:7:\"content\";a:1:{s:7:\"encoded\";s:11933:\"<p>The first thing you&#8217;ll notice about 2.7 is its new interface. From the top down, we&#8217;ve listened to your feedback and thought deeply about the design and the result is a WordPress that&#8217;s just plain faster. Nearly every task you do on your blog will <strong>take fewer clicks and be faster</strong> in 2.7 than it did in a previous version. (<a href=\"http://wordpress.org/download/\">Download it now</a>, or read on for more.)</p>\n<p>Next you&#8217;ll begin to notice the new features subtly sprinkled through the new interface: the new dashboard that you can arrange with drag and drop to put the things most important to you on top, QuickPress, comment threading, paging, and the ability to reply to comments from your dashboard, the ability to install any plugin directly from WordPress.org with a single click, and sticky posts.</p>\n<p>Digging in further you might notice that every screen is customizable. Let&#8217;s say you never care about author on your post listings &#8212; just click &#8220;Screen Options&#8221; and uncheck it and it&#8217;s instantly gone from the page. The same for any module on the dashboard or write screen. If your screen is narrow and the menu is taking up too much horizontal room, click the arrow to minimize it to be icon-only, and then go to the write page and drag and drop everything from the right column into the main one, so your posting area is full-screen. (For example I like hiding everything except categories, tags, and publish. I put categories and tags on the right, and publish under the post box.)</p>\n<p>For a visual introduction to what 2.7 is, check out this video (available in HD, and full screen):</p>\n<p><object width=\"640\" height=\"360\" data=\"http://v.wordpress.com/hFr8Nyar\" type=\"application/x-shockwave-flash\"><param name=\"src\" value=\"http://v.wordpress.com/hFr8Nyar\" /><param name=\"allowfullscreen\" value=\"true\" /></object></p>\n<p>It&#8217;s all about you. It&#8217;s the next generation of WordPress, which is why we&#8217;ve bestowed it with the honor of being named for <a href=\"http://en.wikipedia.org/wiki/John_Coltrane\">John Coltrane</a>. <a href=\"http://wordpress.org/download/\">And you can download it today</a>.</p>\n<p>Last, but certainly not least, this may be the <strong>last time you ever have to manually upgrade WordPress again</strong>. We heard how tired you were of doing upgrades for yourself and your friends, so now WordPress includes a built-in upgrade that will automatically notify you of new releases, and when you&#8217;re ready it will download them, install them, and upgrade your blog with a single click.</p>\n<p>(As with any interface change it may take a little bit of time to acclimate yourself but soon you&#8217;ll find yourself whizzing through the screens. Even people who have hated it at first tell us after a few days they wonder how they got by before.)</p>\n<h3>The Story Behind 2.7</h3>\n<p>The real reason Coltrane is such a huge leap forward is because the community was so involved with every step of the process. <strong>Over 150 people contributed code directly to the release</strong>, our highest ever, with many tens of thousands more participating in the polls, surveys, tests, mailing lists, and other feedback mechanisms the WordPress dev team used in putting this release together.</p>\n<p>For some of the back story in the development of 2.7, check out these blog posts (thanks to <a href=\"http://weblogtoolscollection.com/\">WeblogToolsCollection</a> for the list):</p>\n<ul>\n<li><a href=\"http://wordpress.org/development/2008/10/usability-testing-report-25-and-crazyhorse/\">Usability Testing Report: 2.5 and CrazyHorse</a></li>\n<li><a href=\"http://wordpress.org/development/2008/10/the-new-27-dashboard/\">The New 2.7 Dashboard</a></li>\n<li><a href=\"http://wordpress.org/development/2008/10/the-visual-design-of-27/\">The Visual Design of 2.7</a></li>\n<li><a href=\"http://wordpress.org/development/2008/10/wordpress-27-wireframes/\">WordPress 2.7 wireframes</a></li>\n<li><a href=\"http://codex.wordpress.org/Version_2.7\">Comprehensive Codex Article on WordPress 2.7</a></li>\n<li><a href=\"http://wpdevel.wordpress.com/author/jane/\">WordPress Development Updates from Jane Wells</a></li>\n<li><a href=\"http://en.blog.wordpress.com/2008/05/20/new-york-usability-testing/\">WordPress Usability Testing in New York</a></li>\n<li><a href=\"http://boren.nu/archives/2008/10/31/wordpress-27-ui-configurability/\">WordPress 2.7 UI Configurability from Ryan Boren</a></li>\n<li><a href=\"http://markjaquith.wordpress.com/2008/11/06/wordpress-27-feature-preview-customizable-post-editing-screen/\">Customizable Post Editing Screen from Mark Jaquith</a></li>\n<li><a href=\"http://jane.wordpress.com/2008/09/15/wordpress-27-navigation-survey/\">WordPress 2.7 Navigation Survey from Jane Wells</a></li>\n<li><a href=\"http://jane.wordpress.com/2008/10/16/shortcutsfavorites-menu/\">Shortcuts/Favorites Menu from Jane Wells</a></li>\n<li><a href=\"http://www.slideshare.net/edanzico/riding-the-crazyhorse-future-generation-wordpress-presentation\">CrazyHorse Presentation at WordCamp SF</a></li>\n<li><a href=\"http://www.centernetworks.com/wordpress-27-demo\">WordPress 2.7 Walkthrough by Matt</a></li>\n<li><a href=\"http://www.idratherbewriting.com/2008/09/27/wordpress-27-and-beyond-%E2%80%93-keynote-by-matt-mullenweg-at-wordcamp-utah-2008/\">WordPress 2.7 and beyond from Matt at WordCamp Utah</a></li>\n</ul>\n<p>This was interesting to us, a blogging software release we actually blogged about, but the process was hugely informative. Prior to its release today Crazyhorse and 2.7 had been tested by tens of thousands of people on their blogs, hundreds of thousands of you count .com. The volume of feedback was so high that we decided to push back the release date a month to take time to incorporate it all and do more revisions based on what you guys said.</p>\n<p>For those of you wondering why we didn&#8217;t call this release 3.0, it&#8217;s because we abhor version number inflation. 3.0 will just be the next release after 2.9. The major features in new point releases approach also works well for products like OS X, with huge changes between a 10.3 and 10.4.</p>\n<h3>The Future</h3>\n<p>Those of you following along at home might have noticed this was our second major redesign of WordPress this year. Whoa nelly! While that wasn&#8217;t ideal, and I especially sympathize with those of you creating books or tutorials around WordPress, there&#8217;s good news. The changes to WordPress in 2.5 and 2.7 were necessary for us to break free of much of the legacy cruft and interface bloat that had built up over the years (gradually) and more importantly provide us with a UI framework and interface language we can use at the foundation to build tomorrow&#8217;s WordPress on, to express ideas we haven&#8217;t been able to before. So at the end of 2009 I expect, interface-wise, WordPress to look largely the same as it does now.</p>\n<p>That said, we couldn&#8217;t be more excited about the future with regards to features. Now that we&#8217;ve cleared out more basic things, we are looking forward in the coming year to really tackling media handling including audio and video, better tools for plugin and theme developers, widgets, theme updates, more integrated and contextual help, and easier integration with projects like <a href=\"http://buddypress.org/\">BuddyPress</a> and <a href=\"http://bbpress.org/\">bbPress</a>.</p>\n<h3>Thank Yous</h3>\n<p>We would like to take a moment to thank the following WordPress.org users for being a part of 2.7: <a href=\"http://segert.net/\">Verena Segert</a>, <a href=\"http://www.fieldii.com/\">Ben Dunkle</a>, 082net, <a href=\"http://ckon.wordpress.com/\">_ck_</a>, <a href=\"http://technosailor.com/\">Aaron Brazell</a>, Aaron Campbell, Aaron Harp, aaron_guitar, abackstrom, <a href=\"http://alexrabe.boelinger.com/\">Alex Rabe</a>, <a href=\"http://flightpathblog.com/\">Alex Shiels</a>, anderswc, andr, <a href=\"http://azaozz.wordpress.com/\">Andrew Ozz</a>, andy, <a href=\"http://apeatling.wordpress.com/\">Andy Peatling</a>, <a href=\"http://ilfilosofo.com/\">Austin Matzko</a>, axelseaa, bendalton, <a href=\"http://extralogical.net/\">Benedict Eastaugh</a>, <a href=\"http://www.umaitech.com/\">Betsy Kimak</a>, <a href=\"http://www.burobjorn.nl/\">Björn Wijers</a>, <a href=\"http://bobrik.name/\">bobrik</a>, brianwhite, bubel, <a href=\"http://www.majordojo.com/\">Byrne Reese</a>, caesarsgrunt, capripot, <a href=\"http://maisonbisson.com/blog/\">Casey Bisson</a>, <a href=\"http://www.cefm.ca/\">Charles E. Frees-Melvin</a>, <a href=\"http://chrisjohnston.org\">Chris Johnston</a>, codestyling, corischlegel, count_0, <a href=\"http://www.red-sweater.com/blog/\">Daniel Jalkut</a>, Daniel Torreblanca, <a href=\"http://www.misthaven.org.uk/blog/\">David McFarlane</a>, dbuser123, <a href=\"http://op111.net/\">Demetris Kikizas</a>, <a href=\"http://dd32.id.au/\">Dion Hulse</a>, docwhat, <a href=\"http://ocaoimh.ie\">Donncha O Caoimh</a>, <a href=\"http://literalbarrage.org/blog/\">Doug Stewart</a>, <a href=\"http://dougal.gunters.org\">Dougal Campbell</a>, dsader, dtsn, dwc, g30rg3x, guillep2k, <a href=\"http://hailin.wordpress.com/\">Hailin Wu</a>, <a href=\"http://engel.uk.to/\">Hans Engel</a>, <a href=\"http://santosj.name/\">Jacob Santos</a>, <a href=\"http://jamierumbelow.net/\">Jamie Rumbelow</a>, <a href=\"http://www.janbrasna.com/\">Jan Brasna</a>, <a href=\"http://jane.wordpress.com/\">Jane Wells</a>, Jean-LucfromBrussels, <a href=\"http://poplarware.com/HodgBlog/\">Jennifer Hodgdon</a>, <a href=\"http://simianuprising.com/\">Jeremy Clarke</a>, <a href=\"http://jmini.fr/\">Jérémie Bresson</a>, jick, <a href=\"http://www.joetek.ca/\">Joe Taiabjee</a>, <a href=\"http://johnblackbourn.com/\">John Blackbourn</a>, John Conners, John Lamansky, johnhennmacc, <a href=\"http://yoast.com/\">Joost de Valk</a>, <a href=\"http://josephscott.org/\">Joseph Scott</a>, kashani, <a href=\"http://www.kpdesign.net/\">Kim Parsell</a>, <a href=\"http://foolswisdom.com/\">Lloyd Budd</a>, <a href=\"http://elektroelch.de/blog\">Lutz Schröer</a>, <a href=\"http://www.malaiac.net\">Malaiac</a>, <a href=\"http://markjaquith.com/\">Mark Jaquith</a>, <a href=\"http://www.blogitude.com/\">Mark Steel</a>, <a href=\"http://mattsblog.ca/\">Matt Freedman</a>, <a href=\"http://ma.tt/\">Matt Mullenweg</a>, <a href=\"htttp://iammattthomas.com/\">Matt Thomas</a>, matthewh84, mattyrob, mcs_trekkie, <a href=\"http://blogwaffe.com/\">Michael Adams</a>, <a href=\"http://www.ioerror.us/\">Michael Hampton</a>, <a href=\"http://codex.wordpress.org/User:MichaelH\">MichaelH</a>, mictasm, <a href=\"http://mikeschinkel.com/\">Mike Schinkel</a>, msi08, msw0418, mtekk, <a href=\"http://mtdewvirus.com/\">Nick Momrik</a>, <a href=\"http://nikolay.bg/\">Nikolay Bachiyski</a>, <a href=\"http://jcksn.com/\">Noel Jackson</a>, <a href=\"http://ottodestruct.com/\">Otto</a>, <a href=\"http://planetozh.com/\">Ozh</a>, paddya, paul, pedrop, pishmishy, Po0ky, RanYanivHartstein, raychampagne, rdworth, reinkim, rickoman, rm53, rnt, <a href=\"http://robert.accettura.com/\">Robert Accettura</a>, roganty, <a href=\"http://boren.nu/\">Ryan Boren</a>, <a href=\"http://cubegames.net/\">Ryan McCue</a>, <a href=\"http://unlettered.com/\">Sam Bauers</a>, Sam_a, schiller, <a href=\"http://www.scott-h.com/\">Scott Houst</a>, sekundek, <a href=\"http://bugssite.org/\">Shane</a>, Simek, <a href=\"http://www.simonwheatley.co.uk/\">Simon Wheatley</a>, <a href=\"http://sivel.net/\">sivel</a>, st_falcon, stefano, strider72, tai, takayukister, techcookies, Terragg, thinlight, tott, <a href=\"http://www.trevorfitzgerald.com/\">Trevor Fitzgerald</a>, tschai, Txanny, <a href=\"http://www.manionline.org/\">Valiallah (Mani) Monajjemi</a>, <a href=\"http://viper007bond.com/\">Viper007Bond</a>, <a href=\"http://wordpress.org/support/profile/1064655\">Vladimir Kolesnikov</a>, wasp, wet, wfrantz, x11tech, xknown, xorax, <a href=\"http://ydekproductions.com/\">ydekproductions</a>, yoavf, yonosoytu, yoshi, zedlander</p>\n\";}s:3:\"wfw\";a:1:{s:10:\"commentrss\";s:55:\"http://wordpress.org/development/2008/12/coltrane/feed/\";}s:7:\"summary\";s:318:\"The first thing you&#8217;ll notice about 2.7 is its new interface. From the top down, we&#8217;ve listened to your feedback and thought deeply about the design and the result is a WordPress that&#8217;s just plain faster. Nearly every task you do on your blog will take fewer clicks and be faster in 2.7 than it [...]\";s:12:\"atom_content\";s:11933:\"<p>The first thing you&#8217;ll notice about 2.7 is its new interface. From the top down, we&#8217;ve listened to your feedback and thought deeply about the design and the result is a WordPress that&#8217;s just plain faster. Nearly every task you do on your blog will <strong>take fewer clicks and be faster</strong> in 2.7 than it did in a previous version. (<a href=\"http://wordpress.org/download/\">Download it now</a>, or read on for more.)</p>\n<p>Next you&#8217;ll begin to notice the new features subtly sprinkled through the new interface: the new dashboard that you can arrange with drag and drop to put the things most important to you on top, QuickPress, comment threading, paging, and the ability to reply to comments from your dashboard, the ability to install any plugin directly from WordPress.org with a single click, and sticky posts.</p>\n<p>Digging in further you might notice that every screen is customizable. Let&#8217;s say you never care about author on your post listings &#8212; just click &#8220;Screen Options&#8221; and uncheck it and it&#8217;s instantly gone from the page. The same for any module on the dashboard or write screen. If your screen is narrow and the menu is taking up too much horizontal room, click the arrow to minimize it to be icon-only, and then go to the write page and drag and drop everything from the right column into the main one, so your posting area is full-screen. (For example I like hiding everything except categories, tags, and publish. I put categories and tags on the right, and publish under the post box.)</p>\n<p>For a visual introduction to what 2.7 is, check out this video (available in HD, and full screen):</p>\n<p><object width=\"640\" height=\"360\" data=\"http://v.wordpress.com/hFr8Nyar\" type=\"application/x-shockwave-flash\"><param name=\"src\" value=\"http://v.wordpress.com/hFr8Nyar\" /><param name=\"allowfullscreen\" value=\"true\" /></object></p>\n<p>It&#8217;s all about you. It&#8217;s the next generation of WordPress, which is why we&#8217;ve bestowed it with the honor of being named for <a href=\"http://en.wikipedia.org/wiki/John_Coltrane\">John Coltrane</a>. <a href=\"http://wordpress.org/download/\">And you can download it today</a>.</p>\n<p>Last, but certainly not least, this may be the <strong>last time you ever have to manually upgrade WordPress again</strong>. We heard how tired you were of doing upgrades for yourself and your friends, so now WordPress includes a built-in upgrade that will automatically notify you of new releases, and when you&#8217;re ready it will download them, install them, and upgrade your blog with a single click.</p>\n<p>(As with any interface change it may take a little bit of time to acclimate yourself but soon you&#8217;ll find yourself whizzing through the screens. Even people who have hated it at first tell us after a few days they wonder how they got by before.)</p>\n<h3>The Story Behind 2.7</h3>\n<p>The real reason Coltrane is such a huge leap forward is because the community was so involved with every step of the process. <strong>Over 150 people contributed code directly to the release</strong>, our highest ever, with many tens of thousands more participating in the polls, surveys, tests, mailing lists, and other feedback mechanisms the WordPress dev team used in putting this release together.</p>\n<p>For some of the back story in the development of 2.7, check out these blog posts (thanks to <a href=\"http://weblogtoolscollection.com/\">WeblogToolsCollection</a> for the list):</p>\n<ul>\n<li><a href=\"http://wordpress.org/development/2008/10/usability-testing-report-25-and-crazyhorse/\">Usability Testing Report: 2.5 and CrazyHorse</a></li>\n<li><a href=\"http://wordpress.org/development/2008/10/the-new-27-dashboard/\">The New 2.7 Dashboard</a></li>\n<li><a href=\"http://wordpress.org/development/2008/10/the-visual-design-of-27/\">The Visual Design of 2.7</a></li>\n<li><a href=\"http://wordpress.org/development/2008/10/wordpress-27-wireframes/\">WordPress 2.7 wireframes</a></li>\n<li><a href=\"http://codex.wordpress.org/Version_2.7\">Comprehensive Codex Article on WordPress 2.7</a></li>\n<li><a href=\"http://wpdevel.wordpress.com/author/jane/\">WordPress Development Updates from Jane Wells</a></li>\n<li><a href=\"http://en.blog.wordpress.com/2008/05/20/new-york-usability-testing/\">WordPress Usability Testing in New York</a></li>\n<li><a href=\"http://boren.nu/archives/2008/10/31/wordpress-27-ui-configurability/\">WordPress 2.7 UI Configurability from Ryan Boren</a></li>\n<li><a href=\"http://markjaquith.wordpress.com/2008/11/06/wordpress-27-feature-preview-customizable-post-editing-screen/\">Customizable Post Editing Screen from Mark Jaquith</a></li>\n<li><a href=\"http://jane.wordpress.com/2008/09/15/wordpress-27-navigation-survey/\">WordPress 2.7 Navigation Survey from Jane Wells</a></li>\n<li><a href=\"http://jane.wordpress.com/2008/10/16/shortcutsfavorites-menu/\">Shortcuts/Favorites Menu from Jane Wells</a></li>\n<li><a href=\"http://www.slideshare.net/edanzico/riding-the-crazyhorse-future-generation-wordpress-presentation\">CrazyHorse Presentation at WordCamp SF</a></li>\n<li><a href=\"http://www.centernetworks.com/wordpress-27-demo\">WordPress 2.7 Walkthrough by Matt</a></li>\n<li><a href=\"http://www.idratherbewriting.com/2008/09/27/wordpress-27-and-beyond-%E2%80%93-keynote-by-matt-mullenweg-at-wordcamp-utah-2008/\">WordPress 2.7 and beyond from Matt at WordCamp Utah</a></li>\n</ul>\n<p>This was interesting to us, a blogging software release we actually blogged about, but the process was hugely informative. Prior to its release today Crazyhorse and 2.7 had been tested by tens of thousands of people on their blogs, hundreds of thousands of you count .com. The volume of feedback was so high that we decided to push back the release date a month to take time to incorporate it all and do more revisions based on what you guys said.</p>\n<p>For those of you wondering why we didn&#8217;t call this release 3.0, it&#8217;s because we abhor version number inflation. 3.0 will just be the next release after 2.9. The major features in new point releases approach also works well for products like OS X, with huge changes between a 10.3 and 10.4.</p>\n<h3>The Future</h3>\n<p>Those of you following along at home might have noticed this was our second major redesign of WordPress this year. Whoa nelly! While that wasn&#8217;t ideal, and I especially sympathize with those of you creating books or tutorials around WordPress, there&#8217;s good news. The changes to WordPress in 2.5 and 2.7 were necessary for us to break free of much of the legacy cruft and interface bloat that had built up over the years (gradually) and more importantly provide us with a UI framework and interface language we can use at the foundation to build tomorrow&#8217;s WordPress on, to express ideas we haven&#8217;t been able to before. So at the end of 2009 I expect, interface-wise, WordPress to look largely the same as it does now.</p>\n<p>That said, we couldn&#8217;t be more excited about the future with regards to features. Now that we&#8217;ve cleared out more basic things, we are looking forward in the coming year to really tackling media handling including audio and video, better tools for plugin and theme developers, widgets, theme updates, more integrated and contextual help, and easier integration with projects like <a href=\"http://buddypress.org/\">BuddyPress</a> and <a href=\"http://bbpress.org/\">bbPress</a>.</p>\n<h3>Thank Yous</h3>\n<p>We would like to take a moment to thank the following WordPress.org users for being a part of 2.7: <a href=\"http://segert.net/\">Verena Segert</a>, <a href=\"http://www.fieldii.com/\">Ben Dunkle</a>, 082net, <a href=\"http://ckon.wordpress.com/\">_ck_</a>, <a href=\"http://technosailor.com/\">Aaron Brazell</a>, Aaron Campbell, Aaron Harp, aaron_guitar, abackstrom, <a href=\"http://alexrabe.boelinger.com/\">Alex Rabe</a>, <a href=\"http://flightpathblog.com/\">Alex Shiels</a>, anderswc, andr, <a href=\"http://azaozz.wordpress.com/\">Andrew Ozz</a>, andy, <a href=\"http://apeatling.wordpress.com/\">Andy Peatling</a>, <a href=\"http://ilfilosofo.com/\">Austin Matzko</a>, axelseaa, bendalton, <a href=\"http://extralogical.net/\">Benedict Eastaugh</a>, <a href=\"http://www.umaitech.com/\">Betsy Kimak</a>, <a href=\"http://www.burobjorn.nl/\">Björn Wijers</a>, <a href=\"http://bobrik.name/\">bobrik</a>, brianwhite, bubel, <a href=\"http://www.majordojo.com/\">Byrne Reese</a>, caesarsgrunt, capripot, <a href=\"http://maisonbisson.com/blog/\">Casey Bisson</a>, <a href=\"http://www.cefm.ca/\">Charles E. Frees-Melvin</a>, <a href=\"http://chrisjohnston.org\">Chris Johnston</a>, codestyling, corischlegel, count_0, <a href=\"http://www.red-sweater.com/blog/\">Daniel Jalkut</a>, Daniel Torreblanca, <a href=\"http://www.misthaven.org.uk/blog/\">David McFarlane</a>, dbuser123, <a href=\"http://op111.net/\">Demetris Kikizas</a>, <a href=\"http://dd32.id.au/\">Dion Hulse</a>, docwhat, <a href=\"http://ocaoimh.ie\">Donncha O Caoimh</a>, <a href=\"http://literalbarrage.org/blog/\">Doug Stewart</a>, <a href=\"http://dougal.gunters.org\">Dougal Campbell</a>, dsader, dtsn, dwc, g30rg3x, guillep2k, <a href=\"http://hailin.wordpress.com/\">Hailin Wu</a>, <a href=\"http://engel.uk.to/\">Hans Engel</a>, <a href=\"http://santosj.name/\">Jacob Santos</a>, <a href=\"http://jamierumbelow.net/\">Jamie Rumbelow</a>, <a href=\"http://www.janbrasna.com/\">Jan Brasna</a>, <a href=\"http://jane.wordpress.com/\">Jane Wells</a>, Jean-LucfromBrussels, <a href=\"http://poplarware.com/HodgBlog/\">Jennifer Hodgdon</a>, <a href=\"http://simianuprising.com/\">Jeremy Clarke</a>, <a href=\"http://jmini.fr/\">Jérémie Bresson</a>, jick, <a href=\"http://www.joetek.ca/\">Joe Taiabjee</a>, <a href=\"http://johnblackbourn.com/\">John Blackbourn</a>, John Conners, John Lamansky, johnhennmacc, <a href=\"http://yoast.com/\">Joost de Valk</a>, <a href=\"http://josephscott.org/\">Joseph Scott</a>, kashani, <a href=\"http://www.kpdesign.net/\">Kim Parsell</a>, <a href=\"http://foolswisdom.com/\">Lloyd Budd</a>, <a href=\"http://elektroelch.de/blog\">Lutz Schröer</a>, <a href=\"http://www.malaiac.net\">Malaiac</a>, <a href=\"http://markjaquith.com/\">Mark Jaquith</a>, <a href=\"http://www.blogitude.com/\">Mark Steel</a>, <a href=\"http://mattsblog.ca/\">Matt Freedman</a>, <a href=\"http://ma.tt/\">Matt Mullenweg</a>, <a href=\"htttp://iammattthomas.com/\">Matt Thomas</a>, matthewh84, mattyrob, mcs_trekkie, <a href=\"http://blogwaffe.com/\">Michael Adams</a>, <a href=\"http://www.ioerror.us/\">Michael Hampton</a>, <a href=\"http://codex.wordpress.org/User:MichaelH\">MichaelH</a>, mictasm, <a href=\"http://mikeschinkel.com/\">Mike Schinkel</a>, msi08, msw0418, mtekk, <a href=\"http://mtdewvirus.com/\">Nick Momrik</a>, <a href=\"http://nikolay.bg/\">Nikolay Bachiyski</a>, <a href=\"http://jcksn.com/\">Noel Jackson</a>, <a href=\"http://ottodestruct.com/\">Otto</a>, <a href=\"http://planetozh.com/\">Ozh</a>, paddya, paul, pedrop, pishmishy, Po0ky, RanYanivHartstein, raychampagne, rdworth, reinkim, rickoman, rm53, rnt, <a href=\"http://robert.accettura.com/\">Robert Accettura</a>, roganty, <a href=\"http://boren.nu/\">Ryan Boren</a>, <a href=\"http://cubegames.net/\">Ryan McCue</a>, <a href=\"http://unlettered.com/\">Sam Bauers</a>, Sam_a, schiller, <a href=\"http://www.scott-h.com/\">Scott Houst</a>, sekundek, <a href=\"http://bugssite.org/\">Shane</a>, Simek, <a href=\"http://www.simonwheatley.co.uk/\">Simon Wheatley</a>, <a href=\"http://sivel.net/\">sivel</a>, st_falcon, stefano, strider72, tai, takayukister, techcookies, Terragg, thinlight, tott, <a href=\"http://www.trevorfitzgerald.com/\">Trevor Fitzgerald</a>, tschai, Txanny, <a href=\"http://www.manionline.org/\">Valiallah (Mani) Monajjemi</a>, <a href=\"http://viper007bond.com/\">Viper007Bond</a>, <a href=\"http://wordpress.org/support/profile/1064655\">Vladimir Kolesnikov</a>, wasp, wet, wfrantz, x11tech, xknown, xorax, <a href=\"http://ydekproductions.com/\">ydekproductions</a>, yoavf, yonosoytu, yoshi, zedlander</p>\n\";}i:7;a:12:{s:5:\"title\";s:25:\"2.7 Release Candidate Two\";s:4:\"link\";s:66:\"http://wordpress.org/development/2008/12/27-release-candidate-two/\";s:8:\"comments\";s:75:\"http://wordpress.org/development/2008/12/27-release-candidate-two/#comments\";s:7:\"pubdate\";s:31:\"Wed, 10 Dec 2008 00:55:33 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:8:\"category\";s:11:\"Development\";s:4:\"guid\";s:39:\"http://wordpress.org/development/?p=474\";s:11:\"description\";s:315:\"There comes a time in every WordPress release when it&#8217;s ready for the world , to come out of its cocoon and feel the light of the world on its wings for the first time.\nIt&#8217;s not quite that time yet, but we&#8217;re as close as we&#8217;ve ever been, hence the immediate availability of 2.7 Release [...]\";s:7:\"content\";a:1:{s:7:\"encoded\";s:836:\"<p>There comes a time in every WordPress release when it&#8217;s ready for the world , to come out of its cocoon and feel the light of the world on its wings for the first time.</p>\n<p>It&#8217;s not quite that time yet, but we&#8217;re as close as we&#8217;ve ever been, hence the <a href=\"http://wordpress.org/wordpress-2.7-RC2.zip\">immediate availability of 2.7 Release Candidate 2, or RC2 for short</a>.</p>\n<p>Of course if you were already testing 2.7, you can just use the built-in core updater (Tools > Upgrade) to download and install RC2 for you (and later upgrade you to the final release when it&#8217;s available) but if not you can use the download link above.</p>\n<p>We feel this release is pretty much exactly what we&#8217;re going to ship as 2.7, barring any final bugs or polish tweaks that you report or we find.</p>\n\";}s:3:\"wfw\";a:1:{s:10:\"commentrss\";s:71:\"http://wordpress.org/development/2008/12/27-release-candidate-two/feed/\";}s:7:\"summary\";s:315:\"There comes a time in every WordPress release when it&#8217;s ready for the world , to come out of its cocoon and feel the light of the world on its wings for the first time.\nIt&#8217;s not quite that time yet, but we&#8217;re as close as we&#8217;ve ever been, hence the immediate availability of 2.7 Release [...]\";s:12:\"atom_content\";s:836:\"<p>There comes a time in every WordPress release when it&#8217;s ready for the world , to come out of its cocoon and feel the light of the world on its wings for the first time.</p>\n<p>It&#8217;s not quite that time yet, but we&#8217;re as close as we&#8217;ve ever been, hence the <a href=\"http://wordpress.org/wordpress-2.7-RC2.zip\">immediate availability of 2.7 Release Candidate 2, or RC2 for short</a>.</p>\n<p>Of course if you were already testing 2.7, you can just use the built-in core updater (Tools > Upgrade) to download and install RC2 for you (and later upgrade you to the final release when it&#8217;s available) but if not you can use the download link above.</p>\n<p>We feel this release is pretty much exactly what we&#8217;re going to ship as 2.7, barring any final bugs or polish tweaks that you report or we find.</p>\n\";}i:8;a:12:{s:5:\"title\";s:33:\"WordPress 2.7 Release Candidate 1\";s:4:\"link\";s:74:\"http://wordpress.org/development/2008/12/wordpress-27-release-candidate-1/\";s:8:\"comments\";s:83:\"http://wordpress.org/development/2008/12/wordpress-27-release-candidate-1/#comments\";s:7:\"pubdate\";s:31:\"Mon, 01 Dec 2008 22:26:14 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:10:\"Ryan Boren\";}s:8:\"category\";s:8:\"Releases\";s:4:\"guid\";s:39:\"http://wordpress.org/development/?p=467\";s:11:\"description\";s:312:\"With the release of RC1, we&#8217;re in the final leg of development before the release of 2.7.  280 commits since beta 3 have polished the new admin UI (including new menu icons created by the winners of our icon design contest) and fixed all known blocker bugs.\nWe think RC1 is ready for everyone to try [...]\";s:7:\"content\";a:1:{s:7:\"encoded\";s:843:\"<p>With the release of RC1, we&#8217;re in the final leg of development before the release of 2.7.  <a href=\"http://trac.wordpress.org/timeline?from=12%2F01%2F08&amp;daysback=16&amp;changeset=on&amp;update=Update\">280 commits</a> since beta 3 have polished the new admin UI (including new menu icons created by the <a href=\"http://wordpress.org/development/2008/11/the-results-of-project-icon/\">winners of our icon design contest</a>) and fixed all known blocker bugs.</p>\n<p>We think RC1 is ready for everyone to try out.  Please <a href=\"http://wordpress.org/wordpress-2.7-RC1.zip\">download RC1</a> and help us make the final release the best it can be.  As always, <a href=\"http://codex.wordpress.org/WordPress_Backups\">back up your blog</a> before upgrading.</p>\n<p><a href=\"http://wordpress.org/wordpress-2.7-RC1.zip\">Get RC1</a>.</p>\n\";}s:3:\"wfw\";a:1:{s:10:\"commentrss\";s:79:\"http://wordpress.org/development/2008/12/wordpress-27-release-candidate-1/feed/\";}s:7:\"summary\";s:312:\"With the release of RC1, we&#8217;re in the final leg of development before the release of 2.7.  280 commits since beta 3 have polished the new admin UI (including new menu icons created by the winners of our icon design contest) and fixed all known blocker bugs.\nWe think RC1 is ready for everyone to try [...]\";s:12:\"atom_content\";s:843:\"<p>With the release of RC1, we&#8217;re in the final leg of development before the release of 2.7.  <a href=\"http://trac.wordpress.org/timeline?from=12%2F01%2F08&amp;daysback=16&amp;changeset=on&amp;update=Update\">280 commits</a> since beta 3 have polished the new admin UI (including new menu icons created by the <a href=\"http://wordpress.org/development/2008/11/the-results-of-project-icon/\">winners of our icon design contest</a>) and fixed all known blocker bugs.</p>\n<p>We think RC1 is ready for everyone to try out.  Please <a href=\"http://wordpress.org/wordpress-2.7-RC1.zip\">download RC1</a> and help us make the final release the best it can be.  As always, <a href=\"http://codex.wordpress.org/WordPress_Backups\">back up your blog</a> before upgrading.</p>\n<p><a href=\"http://wordpress.org/wordpress-2.7-RC1.zip\">Get RC1</a>.</p>\n\";}i:9;a:12:{s:5:\"title\";s:15:\"WordPress 2.6.5\";s:4:\"link\";s:55:\"http://wordpress.org/development/2008/11/wordpress-265/\";s:8:\"comments\";s:64:\"http://wordpress.org/development/2008/11/wordpress-265/#comments\";s:7:\"pubdate\";s:31:\"Tue, 25 Nov 2008 17:33:56 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:10:\"Ryan Boren\";}s:8:\"category\";s:11:\"Development\";s:4:\"guid\";s:39:\"http://wordpress.org/development/?p=462\";s:11:\"description\";s:391:\"WordPress 2.6.5 is immediately available and fixes one security problem and three bugs. We recommend everyone upgrade to this release.\nThe security issue is an XSS exploit discovered by Jeremias Reith that fortunately only affects IP-based virtual servers running on Apache 2.x. If you are interested only in the security fix, copy wp-includes/feed.php and wp-includes/version.php from [...]\";s:7:\"content\";a:1:{s:7:\"encoded\";s:1251:\"<p><a href=\"http://wordpress.org/download/\">WordPress 2.6.5 is immediately available and fixes one security problem and three bugs</a>. We recommend everyone upgrade to this release.</p>\n<p>The security issue is an XSS exploit discovered by Jeremias Reith that fortunately only affects IP-based virtual servers running on Apache 2.x. If you are interested only in the security fix, copy <code>wp-includes/feed.php</code> and <code>wp-includes/version.php</code> from the 2.6.5 release package.</p>\n<p>2.6.5 contains three other small fixes in addition to the XSS fix. The first prevents accidentally saving post meta information to a revision. The second prevents XML-RPC from fetching incorrect post types. The third adds some user ID sanitization during bulk delete requests. For a list of changed files, consult the <a href=\"http://trac.wordpress.org/changeset?old_path=tags%2F2.6.3&amp;old=&amp;new_path=tags%2F2.6.5&amp;new=\">full changeset</a> between 2.6.3 and 2.6.5.</p>\n<p>Note that we are skipping version 2.6.4 and jumping from 2.6.3 to 2.6.5 to avoid confusion with a fake 2.6.4 release that made the rounds. There is not and never will be a version 2.6.4.</p>\n<p><a href=\"http://wordpress.org/download/\">Get WordPress 2.6.5</a>.</p>\n\";}s:3:\"wfw\";a:1:{s:10:\"commentrss\";s:60:\"http://wordpress.org/development/2008/11/wordpress-265/feed/\";}s:7:\"summary\";s:391:\"WordPress 2.6.5 is immediately available and fixes one security problem and three bugs. We recommend everyone upgrade to this release.\nThe security issue is an XSS exploit discovered by Jeremias Reith that fortunately only affects IP-based virtual servers running on Apache 2.x. If you are interested only in the security fix, copy wp-includes/feed.php and wp-includes/version.php from [...]\";s:12:\"atom_content\";s:1251:\"<p><a href=\"http://wordpress.org/download/\">WordPress 2.6.5 is immediately available and fixes one security problem and three bugs</a>. We recommend everyone upgrade to this release.</p>\n<p>The security issue is an XSS exploit discovered by Jeremias Reith that fortunately only affects IP-based virtual servers running on Apache 2.x. If you are interested only in the security fix, copy <code>wp-includes/feed.php</code> and <code>wp-includes/version.php</code> from the 2.6.5 release package.</p>\n<p>2.6.5 contains three other small fixes in addition to the XSS fix. The first prevents accidentally saving post meta information to a revision. The second prevents XML-RPC from fetching incorrect post types. The third adds some user ID sanitization during bulk delete requests. For a list of changed files, consult the <a href=\"http://trac.wordpress.org/changeset?old_path=tags%2F2.6.3&amp;old=&amp;new_path=tags%2F2.6.5&amp;new=\">full changeset</a> between 2.6.3 and 2.6.5.</p>\n<p>Note that we are skipping version 2.6.4 and jumping from 2.6.3 to 2.6.5 to avoid confusion with a fake 2.6.4 release that made the rounds. There is not and never will be a version 2.6.4.</p>\n<p><a href=\"http://wordpress.org/download/\">Get WordPress 2.6.5</a>.</p>\n\";}}s:7:\"channel\";a:8:{s:5:\"title\";s:26:\"WordPress Development Blog\";s:4:\"link\";s:32:\"http://wordpress.org/development\";s:11:\"description\";s:33:\"WordPress development and updates\";s:7:\"pubdate\";s:31:\"Thu, 26 Feb 2009 23:38:06 +0000\";s:9:\"generator\";s:41:\"http://wordpress.org/?v=2.8-bleeding-edge\";s:8:\"language\";s:2:\"en\";s:2:\"sy\";a:2:{s:12:\"updateperiod\";s:6:\"hourly\";s:15:\"updatefrequency\";s:1:\"1\";}s:7:\"tagline\";s:33:\"WordPress development and updates\";}s:9:\"textinput\";a:0:{}s:5:\"image\";a:0:{}s:9:\"feed_type\";s:3:\"RSS\";s:12:\"feed_version\";s:3:\"2.0\";s:5:\"stack\";a:0:{}s:9:\"inchannel\";b:0;s:6:\"initem\";b:0;s:9:\"incontent\";b:0;s:11:\"intextinput\";b:0;s:7:\"inimage\";b:0;s:13:\"current_field\";s:0:\"\";s:17:\"current_namespace\";b:0;s:19:\"_CONTENT_CONSTRUCTS\";a:6:{i:0;s:7:\"content\";i:1;s:7:\"summary\";i:2;s:4:\"info\";i:3;s:5:\"title\";i:4;s:7:\"tagline\";i:5;s:9:\"copyright\";}}','no'),(114,0,'rss_0ff4b43bd116a9d8720d689c80e7dfd4_ts','1236130596','no'),(115,0,'rss_57bc725ad6568758915363af670fd8bc','O:9:\"MagpieRSS\":17:{s:6:\"parser\";i:0;s:12:\"current_item\";a:0:{}s:5:\"items\";a:15:{i:0;a:7:{s:5:\"title\";s:32:\"dartiss on \"Simple Twitter Link\"\";s:4:\"link\";s:66:\"http://wordpress.org/extend/plugins/simple-twitter-link/#post-9432\";s:7:\"pubdate\";s:31:\"Tue, 03 Mar 2009 08:42:46 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:7:\"dartiss\";}s:4:\"guid\";s:41:\"9432@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:120:\"Simple Twitter Link displays a link allowing Twitter users to update their status with a link back to your post or page.\";s:7:\"summary\";s:120:\"Simple Twitter Link displays a link allowing Twitter users to update their status with a link back to your post or page.\";}i:1;a:7:{s:5:\"title\";s:21:\"Gorkfu on \"HLogoZ-WP\"\";s:4:\"link\";s:56:\"http://wordpress.org/extend/plugins/hlogoz-wp/#post-9424\";s:7:\"pubdate\";s:31:\"Mon, 02 Mar 2009 22:08:16 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:6:\"Gorkfu\";}s:4:\"guid\";s:41:\"9424@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:90:\"Automatically changes your logo based on the date. Images and flash (swf files) supported.\";s:7:\"summary\";s:90:\"Automatically changes your logo based on the date. Images and flash (swf files) supported.\";}i:2;a:7:{s:5:\"title\";s:26:\"gfazioli on \"WP-BANNERIZE\"\";s:4:\"link\";s:59:\"http://wordpress.org/extend/plugins/wp-bannerize/#post-9423\";s:7:\"pubdate\";s:31:\"Mon, 02 Mar 2009 21:30:41 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:8:\"gfazioli\";}s:4:\"guid\";s:41:\"9423@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:35:\"WP_BANNERIZE, banner-image manager.\";s:7:\"summary\";s:35:\"WP_BANNERIZE, banner-image manager.\";}i:3;a:7:{s:5:\"title\";s:28:\"simonwheatley on \"Cron View\"\";s:4:\"link\";s:56:\"http://wordpress.org/extend/plugins/cron-view/#post-9421\";s:7:\"pubdate\";s:31:\"Mon, 02 Mar 2009 16:19:53 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:13:\"simonwheatley\";}s:4:\"guid\";s:41:\"9421@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:61:\"Allows you to view all WP Cron events. Handy for development.\";s:7:\"summary\";s:61:\"Allows you to view all WP Cron events. Handy for development.\";}i:4;a:7:{s:5:\"title\";s:23:\"iamntz on \"NtzAntispam\"\";s:4:\"link\";s:58:\"http://wordpress.org/extend/plugins/ntzantispam/#post-9420\";s:7:\"pubdate\";s:31:\"Mon, 02 Mar 2009 15:05:19 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:6:\"iamntz\";}s:4:\"guid\";s:41:\"9420@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:150:\"This plugin will remove your spam comments. You don\'t need Akismet anymore but you can keep that too if you are not sure what to pick. Anyhow, this is\";s:7:\"summary\";s:150:\"This plugin will remove your spam comments. You don\'t need Akismet anymore but you can keep that too if you are not sure what to pick. Anyhow, this is\";}i:5;a:7:{s:5:\"title\";s:29:\"alexkingorg on \"Zannel Tools\"\";s:4:\"link\";s:59:\"http://wordpress.org/extend/plugins/zannel-tools/#post-9411\";s:7:\"pubdate\";s:31:\"Mon, 02 Mar 2009 06:16:46 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:11:\"alexkingorg\";}s:4:\"guid\";s:41:\"9411@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:144:\"A complete integration between your WordPress blog and Zannel. Bring your Zannel Updates into your blog and pass your blog posts back to Zannel.\";s:7:\"summary\";s:144:\"A complete integration between your WordPress blog and Zannel. Bring your Zannel Updates into your blog and pass your blog posts back to Zannel.\";}i:6;a:7:{s:5:\"title\";s:32:\"eight7teen on \"Upgrade Else DIE\"\";s:4:\"link\";s:63:\"http://wordpress.org/extend/plugins/upgrade-else-die/#post-9408\";s:7:\"pubdate\";s:31:\"Mon, 02 Mar 2009 02:29:01 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:10:\"eight7teen\";}s:4:\"guid\";s:41:\"9408@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:51:\"Aggresive way to tell IE6 users to upgrade OR ELSE!\";s:7:\"summary\";s:51:\"Aggresive way to tell IE6 users to upgrade OR ELSE!\";}i:7;a:7:{s:5:\"title\";s:34:\"gregory80 on \"Recently on Last.fm\"\";s:4:\"link\";s:74:\"http://wordpress.org/extend/plugins/lastfm-recent-tracks-widget/#post-9407\";s:7:\"pubdate\";s:31:\"Mon, 02 Mar 2009 02:05:21 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:9:\"gregory80\";}s:4:\"guid\";s:41:\"9407@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:66:\"Fast, flash free, non-cached view of your Recent Tracks on Last.fm\";s:7:\"summary\";s:66:\"Fast, flash free, non-cached view of your Recent Tracks on Last.fm\";}i:8;a:7:{s:5:\"title\";s:19:\"holooli on \"WP-RTL\"\";s:4:\"link\";s:53:\"http://wordpress.org/extend/plugins/ar-php/#post-9406\";s:7:\"pubdate\";s:31:\"Sun, 01 Mar 2009 19:16:25 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:7:\"holooli\";}s:4:\"guid\";s:41:\"9406@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:52:\"Adds Ar-PHP project functionality in TinyMCE editor.\";s:7:\"summary\";s:52:\"Adds Ar-PHP project functionality in TinyMCE editor.\";}i:9;a:7:{s:5:\"title\";s:27:\"a-scripts.com on \"Tooltips\"\";s:4:\"link\";s:55:\"http://wordpress.org/extend/plugins/tooltips/#post-9405\";s:7:\"pubdate\";s:31:\"Sun, 01 Mar 2009 18:16:10 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:13:\"a-scripts.com\";}s:4:\"guid\";s:41:\"9405@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:73:\"Simple filter plugin that allows you to use tooltips for words / phrases.\";s:7:\"summary\";s:73:\"Simple filter plugin that allows you to use tooltips for words / phrases.\";}i:10;a:7:{s:5:\"title\";s:74:\"amummey on \"cSprites - Speed Up Page Load Time with Dynamic Image Sprites\"\";s:4:\"link\";s:69:\"http://wordpress.org/extend/plugins/csprites-for-wordpress/#post-9388\";s:7:\"pubdate\";s:31:\"Sun, 01 Mar 2009 09:48:40 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:7:\"amummey\";}s:4:\"guid\";s:41:\"9388@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:91:\"Automatically compress you content images into a big sprite, decreasing web page load time.\";s:7:\"summary\";s:91:\"Automatically compress you content images into a big sprite, decreasing web page load time.\";}i:11;a:7:{s:5:\"title\";s:24:\"yejun on \"Parallel Load\"\";s:4:\"link\";s:60:\"http://wordpress.org/extend/plugins/parallel-load/#post-9387\";s:7:\"pubdate\";s:31:\"Sun, 01 Mar 2009 06:16:31 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:5:\"yejun\";}s:4:\"guid\";s:41:\"9387@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:137:\"Load Javascript files in parallel by using document.write tag.\n\nChange Log: 1.1 Fix a bug, hope it will have better plugin compatibility.\";s:7:\"summary\";s:137:\"Load Javascript files in parallel by using document.write tag.\n\nChange Log: 1.1 Fix a bug, hope it will have better plugin compatibility.\";}i:12;a:7:{s:5:\"title\";s:20:\"anukit on \"WP Hooks\"\";s:4:\"link\";s:55:\"http://wordpress.org/extend/plugins/wp-hooks/#post-9386\";s:7:\"pubdate\";s:31:\"Sun, 01 Mar 2009 06:15:18 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:6:\"anukit\";}s:4:\"guid\";s:41:\"9386@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:145:\"WP Hooks is a plugin for WordPress that allows you to add JavaScript, HTML, or other code to your\nheader and footer without modifying your theme.\";s:7:\"summary\";s:145:\"WP Hooks is a plugin for WordPress that allows you to add JavaScript, HTML, or other code to your\nheader and footer without modifying your theme.\";}i:13;a:7:{s:5:\"title\";s:27:\"flyingdev on \"WP_Reactions\"\";s:4:\"link\";s:59:\"http://wordpress.org/extend/plugins/wp-reactions/#post-9385\";s:7:\"pubdate\";s:31:\"Sun, 01 Mar 2009 03:51:46 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:9:\"flyingdev\";}s:4:\"guid\";s:41:\"9385@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:105:\"WP_Reactions is a plugin that allows blog authors to gather a reader\'s gut reaction after reading a post.\";s:7:\"summary\";s:105:\"WP_Reactions is a plugin that allows blog authors to gather a reader\'s gut reaction after reading a post.\";}i:14;a:7:{s:5:\"title\";s:27:\"jameswberry on \"WP-Tracker\"\";s:4:\"link\";s:57:\"http://wordpress.org/extend/plugins/wp-tracker/#post-9381\";s:7:\"pubdate\";s:31:\"Sat, 28 Feb 2009 23:20:37 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:11:\"jameswberry\";}s:4:\"guid\";s:41:\"9381@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:105:\"Adds the ability to track and chart basic personal statistics along with, or as individual, blog entries.\";s:7:\"summary\";s:105:\"Adds the ability to track and chart basic personal statistics along with, or as individual, blog entries.\";}}s:7:\"channel\";a:6:{s:5:\"title\";s:6:\"Newest\";s:4:\"link\";s:36:\"http://wordpress.org/extend/plugins/\";s:11:\"description\";s:6:\"Newest\";s:8:\"language\";s:2:\"en\";s:7:\"pubdate\";s:31:\"Wed, 04 Mar 2009 01:36:36 +0000\";s:7:\"tagline\";s:6:\"Newest\";}s:9:\"textinput\";a:0:{}s:5:\"image\";a:0:{}s:9:\"feed_type\";s:3:\"RSS\";s:12:\"feed_version\";s:3:\"2.0\";s:5:\"stack\";a:0:{}s:9:\"inchannel\";b:0;s:6:\"initem\";b:0;s:9:\"incontent\";b:0;s:11:\"intextinput\";b:0;s:7:\"inimage\";b:0;s:13:\"current_field\";s:0:\"\";s:17:\"current_namespace\";b:0;s:19:\"_CONTENT_CONSTRUCTS\";a:6:{i:0;s:7:\"content\";i:1;s:7:\"summary\";i:2;s:4:\"info\";i:3;s:5:\"title\";i:4;s:7:\"tagline\";i:5;s:9:\"copyright\";}}','no'),(116,0,'rss_57bc725ad6568758915363af670fd8bc_ts','1236130596','no'),(117,0,'rss_1a5f760f2e2b48827d4974a60857e7c2','O:9:\"MagpieRSS\":17:{s:6:\"parser\";i:0;s:12:\"current_item\";a:0:{}s:5:\"items\";a:15:{i:0;a:7:{s:5:\"title\";s:28:\"storyday on \"cos-html-cache\"\";s:4:\"link\";s:61:\"http://wordpress.org/extend/plugins/cos-html-cache/#post-2105\";s:7:\"pubdate\";s:31:\"Sun, 15 Jul 2007 01:30:05 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:8:\"storyday\";}s:4:\"guid\";s:41:\"2105@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:149:\"cos-html-cache is an extremely efficient WordPress page caching plugin designed to make your WordPress site much faster and more responsive. Based on\";s:7:\"summary\";s:149:\"cos-html-cache is an extremely efficient WordPress page caching plugin designed to make your WordPress site much faster and more responsive. Based on\";}i:1;a:7:{s:5:\"title\";s:32:\"videoguy916 on \"History Manager\"\";s:4:\"link\";s:62:\"http://wordpress.org/extend/plugins/history-manager/#post-8799\";s:7:\"pubdate\";s:31:\"Tue, 27 Jan 2009 03:03:40 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:11:\"videoguy916\";}s:4:\"guid\";s:41:\"8799@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:130:\"History manager is a widget that shows archives, categories, recent posts, and recent categories all in one widget on the sidebar.\";s:7:\"summary\";s:130:\"History manager is a widget that shows archives, categories, recent posts, and recent categories all in one widget on the sidebar.\";}i:2;a:7:{s:5:\"title\";s:29:\"gwycon on \"WP Content Filter\"\";s:4:\"link\";s:64:\"http://wordpress.org/extend/plugins/wp-content-filter/#post-9339\";s:7:\"pubdate\";s:31:\"Fri, 27 Feb 2009 00:56:30 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:6:\"gwycon\";}s:4:\"guid\";s:41:\"9339@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:149:\"Filter out unwanted profanity, swearing, and any other keywords specified on the Plugin options page. Various settings are available to customise the\";s:7:\"summary\";s:149:\"Filter out unwanted profanity, swearing, and any other keywords specified on the Plugin options page. Various settings are available to customise the\";}i:3;a:7:{s:5:\"title\";s:29:\"eight7teen on \"SexyBookmarks\"\";s:4:\"link\";s:60:\"http://wordpress.org/extend/plugins/sexybookmarks/#post-9249\";s:7:\"pubdate\";s:31:\"Sun, 22 Feb 2009 11:30:11 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:10:\"eight7teen\";}s:4:\"guid\";s:41:\"9249@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:57:\"Adds a social bookmarking menu to your posts and/or pages\";s:7:\"summary\";s:57:\"Adds a social bookmarking menu to your posts and/or pages\";}i:4;a:7:{s:5:\"title\";s:20:\"rduffy on \"Glossary\"\";s:4:\"link\";s:65:\"http://wordpress.org/extend/plugins/automatic-glossary/#post-9193\";s:7:\"pubdate\";s:31:\"Wed, 18 Feb 2009 22:35:00 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:6:\"rduffy\";}s:4:\"guid\";s:41:\"9193@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:150:\"Given a collection of glossary definition pages, automatically creates links in your page and post content for the words in your glossary. Is smart en\";s:7:\"summary\";s:150:\"Given a collection of glossary definition pages, automatically creates links in your page and post content for the words in your glossary. Is smart en\";}i:5;a:7:{s:5:\"title\";s:35:\"christopherross on \"No More Frames\"\";s:4:\"link\";s:61:\"http://wordpress.org/extend/plugins/no-more-frames/#post-8774\";s:7:\"pubdate\";s:31:\"Sun, 25 Jan 2009 17:46:20 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:15:\"christopherross\";}s:4:\"guid\";s:41:\"8774@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:150:\"Many web sites try to load your content into their own frame, to help sell ads on their sites. This simple plugin ensure your site is protect from thi\";s:7:\"summary\";s:150:\"Many web sites try to load your content into their own frame, to help sell ads on their sites. This simple plugin ensure your site is protect from thi\";}i:6;a:7:{s:5:\"title\";s:32:\"ccb23 on \"All in One Qype Suite\"\";s:4:\"link\";s:68:\"http://wordpress.org/extend/plugins/all-in-one-qype-suite/#post-9259\";s:7:\"pubdate\";s:31:\"Sun, 22 Feb 2009 17:24:48 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:5:\"ccb23\";}s:4:\"guid\";s:41:\"9259@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:146:\"All-in-one-Qype-Suite &quot;Qype-ifys&quot; your Blog! Add beautiful tooltip-links to Qype Places &amp; pimp sidebar with 3 different Qype Widgets\";s:7:\"summary\";s:146:\"All-in-one-Qype-Suite &quot;Qype-ifys&quot; your Blog! Add beautiful tooltip-links to Qype Places &amp; pimp sidebar with 3 different Qype Widgets\";}i:7;a:7:{s:5:\"title\";s:21:\"Txanny on \"DailyTube\"\";s:4:\"link\";s:56:\"http://wordpress.org/extend/plugins/dailytube/#post-5839\";s:7:\"pubdate\";s:31:\"Wed, 04 Jun 2008 02:07:44 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:6:\"Txanny\";}s:4:\"guid\";s:41:\"5839@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:141:\"Simple WordPress filter to post DailyMotion, YouTube or Google videos. DailyMotion videos can have two formats: Wide (16:9) and Square (4:3).\";s:7:\"summary\";s:141:\"Simple WordPress filter to post DailyMotion, YouTube or Google videos. DailyMotion videos can have two formats: Wide (16:9) and Square (4:3).\";}i:8;a:7:{s:5:\"title\";s:35:\"christopherross on \"Auto Copyright\"\";s:4:\"link\";s:63:\"http://wordpress.org/extend/plugins/auto-copyright-1/#post-8743\";s:7:\"pubdate\";s:31:\"Fri, 23 Jan 2009 13:30:28 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:15:\"christopherross\";}s:4:\"guid\";s:41:\"8743@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:149:\"Automatically generates a copyright notice based on the first and last post published in the WordPress database. The notice can be placed anywhere in\";s:7:\"summary\";s:149:\"Automatically generates a copyright notice based on the first and last post published in the WordPress database. The notice can be placed anywhere in\";}i:9;a:7:{s:5:\"title\";s:39:\"christopherross on \"WordPress PHP Info\"\";s:4:\"link\";s:65:\"http://wordpress.org/extend/plugins/wordpress-php-info/#post-8814\";s:7:\"pubdate\";s:31:\"Tue, 27 Jan 2009 18:16:17 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:15:\"christopherross\";}s:4:\"guid\";s:41:\"8814@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:150:\"It\'s important for a non technical administrator to be able to diagnose server related problems in WordPress but also rapidly retrieve feedback regard\";s:7:\"summary\";s:150:\"It\'s important for a non technical administrator to be able to diagnose server related problems in WordPress but also rapidly retrieve feedback regard\";}i:10;a:7:{s:5:\"title\";s:21:\"Gorkfu on \"HLogoZ-WP\"\";s:4:\"link\";s:56:\"http://wordpress.org/extend/plugins/hlogoz-wp/#post-9424\";s:7:\"pubdate\";s:31:\"Mon, 02 Mar 2009 22:08:16 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:6:\"Gorkfu\";}s:4:\"guid\";s:41:\"9424@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:90:\"Automatically changes your logo based on the date. Images and flash (swf files) supported.\";s:7:\"summary\";s:90:\"Automatically changes your logo based on the date. Images and flash (swf files) supported.\";}i:11;a:7:{s:5:\"title\";s:19:\"e2b on \"Hyphenator\"\";s:4:\"link\";s:57:\"http://wordpress.org/extend/plugins/hyphenator/#post-7366\";s:7:\"pubdate\";s:31:\"Sat, 18 Oct 2008 15:31:49 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:3:\"e2b\";}s:4:\"guid\";s:41:\"7366@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:142:\"Soft hyphen are automatically added in the content for nicer automatic word wrap. Particularly suitable for justification. Uses Hyphenator.js.\";s:7:\"summary\";s:142:\"Soft hyphen are automatically added in the content for nicer automatic word wrap. Particularly suitable for justification. Uses Hyphenator.js.\";}i:12;a:7:{s:5:\"title\";s:34:\"simonwheatley on \"Twitter Tracker\"\";s:4:\"link\";s:62:\"http://wordpress.org/extend/plugins/twitter-tracker/#post-9190\";s:7:\"pubdate\";s:31:\"Wed, 18 Feb 2009 15:54:21 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:13:\"simonwheatley\";}s:4:\"guid\";s:41:\"9190@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:71:\"Tracks Twitter search results or a Twitter hashtag in a sidebar widget.\";s:7:\"summary\";s:71:\"Tracks Twitter search results or a Twitter hashtag in a sidebar widget.\";}i:13;a:7:{s:5:\"title\";s:49:\"SocialMind on \"Google Friend Connect Integration\"\";s:4:\"link\";s:80:\"http://wordpress.org/extend/plugins/google-friend-connect-integration/#post-8263\";s:7:\"pubdate\";s:31:\"Sun, 28 Dec 2008 01:34:51 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:10:\"SocialMind\";}s:4:\"guid\";s:41:\"8263@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:89:\"Create a social community using Google Friend Connect. Easily add many different gadgets.\";s:7:\"summary\";s:89:\"Create a social community using Google Friend Connect. Easily add many different gadgets.\";}i:14;a:7:{s:5:\"title\";s:33:\"christopherross on \"Our Progress\"\";s:4:\"link\";s:91:\"http://wordpress.org/extend/plugins/fundraising-thermometer-plugin-for-wordpress/#post-8744\";s:7:\"pubdate\";s:31:\"Fri, 23 Jan 2009 13:32:10 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:15:\"christopherross\";}s:4:\"guid\";s:41:\"8744@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:95:\"Our Progress allows WordPress to display a thermometer to measure progress such as fundraising.\";s:7:\"summary\";s:95:\"Our Progress allows WordPress to display a thermometer to measure progress such as fundraising.\";}}s:7:\"channel\";a:6:{s:5:\"title\";s:16:\"Recently Updated\";s:4:\"link\";s:36:\"http://wordpress.org/extend/plugins/\";s:11:\"description\";s:16:\"Recently Updated\";s:8:\"language\";s:2:\"en\";s:7:\"pubdate\";s:31:\"Wed, 04 Mar 2009 01:36:36 +0000\";s:7:\"tagline\";s:16:\"Recently Updated\";}s:9:\"textinput\";a:0:{}s:5:\"image\";a:0:{}s:9:\"feed_type\";s:3:\"RSS\";s:12:\"feed_version\";s:3:\"2.0\";s:5:\"stack\";a:0:{}s:9:\"inchannel\";b:0;s:6:\"initem\";b:0;s:9:\"incontent\";b:0;s:11:\"intextinput\";b:0;s:7:\"inimage\";b:0;s:13:\"current_field\";s:0:\"\";s:17:\"current_namespace\";b:0;s:19:\"_CONTENT_CONSTRUCTS\";a:6:{i:0;s:7:\"content\";i:1;s:7:\"summary\";i:2;s:4:\"info\";i:3;s:5:\"title\";i:4;s:7:\"tagline\";i:5;s:9:\"copyright\";}}','no'),(118,0,'rss_1a5f760f2e2b48827d4974a60857e7c2_ts','1236130596','no'),(119,0,'rss_867bd5c64f85878d03a060509cd2f92c','O:9:\"MagpieRSS\":17:{s:6:\"parser\";i:0;s:12:\"current_item\";a:0:{}s:5:\"items\";a:50:{i:0;a:7:{s:5:\"title\";s:27:\"Matt: Open Source Usability\";s:4:\"guid\";s:21:\"http://ma.tt/?p=12057\";s:4:\"link\";s:45:\"http://ma.tt/2009/03/open-source-usability-3/\";s:11:\"description\";s:372:\"<p><a href=\"http://developers.slashdot.org/article.pl?sid=09/03/03/0152241&amp;from=rss\">Open Source Usability — Joomla! Vs. WordPress</a>. We&#8217;re on Slashdot again, with of course the predictable comments somehow ending up in an argument about Vim and Emacs. <img src=\"http://ma.tt/blog/wp-includes/images/smilies/icon_smile.gif\" alt=\":)\" class=\"wp-smiley\" /> </p>\";s:7:\"pubdate\";s:31:\"Tue, 03 Mar 2009 22:28:22 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:7:\"summary\";s:372:\"<p><a href=\"http://developers.slashdot.org/article.pl?sid=09/03/03/0152241&amp;from=rss\">Open Source Usability — Joomla! Vs. WordPress</a>. We&#8217;re on Slashdot again, with of course the predictable comments somehow ending up in an argument about Vim and Emacs. <img src=\"http://ma.tt/blog/wp-includes/images/smilies/icon_smile.gif\" alt=\":)\" class=\"wp-smiley\" /> </p>\";}i:1;a:7:{s:5:\"title\";s:59:\"Weblog Tools Collection: WordPress Theme Releases for 03/03\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=5250\";s:4:\"link\";s:87:\"http://weblogtoolscollection.com/archives/2009/03/03/wordpress-theme-releases-for-0303/\";s:11:\"description\";s:1631:\"<p><a href=\"http://www.harrr.org/rrr/admiral-theme/\">Admiral</a></p>\n<p><a href=\"http://www.harrr.org/rrr/admiral-theme/\"><img title=\"Admiral\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/admiral.jpg\" alt=\"Admiral\" width=\"150\" height=\"150\" /></a></p>\n<p>Two column, widget and gravatar ready theme, with detection of visitors from search engines</p>\n<p><a href=\"http://copacetix.com/\">Copacetix</a></p>\n<p><img title=\"Copacetix\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/copacetix.gif\" alt=\"Copacetix\" width=\"150\" height=\"95\" /></p>\n<p>This theme features Widgets, a clean readable css file, and printer friendly style sheet, variable title tags, multiple layouts, random homepage photos, minimal images to load, h1 titles on pages and posts, and many other specific things that I think make up a usable WordPress theme.</p>\n<p><a href=\"http://themeshaper.com/thematic-for-wordpress/\">The Thematic Theme Framework</a></p>\n<p><img title=\"Thematic\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/thematic.jpg\" alt=\"Thematic\" width=\"150\" height=\"92\" /></p>\n<p>Thematic is a WordPress Theme Framework perfect for the beginner blogger and experienced developers looking for a solid design platform. Version 0.9 is a complete re-think of the front end and a major refinement of the back end. 13 Widget ready areas (with options for more). It supports gravatars, threaded comments, and sticky posts. There’s a simple Theme Options page. And layout possibilities for 1, 2 or 3-column layouts.</p>\n<p>Are you a theme author? <a href=\"http://weblogtoolscollection.com/submit-news/\">Submit your theme</a> to us.</p>\";s:7:\"pubdate\";s:31:\"Tue, 03 Mar 2009 18:27:17 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:1631:\"<p><a href=\"http://www.harrr.org/rrr/admiral-theme/\">Admiral</a></p>\n<p><a href=\"http://www.harrr.org/rrr/admiral-theme/\"><img title=\"Admiral\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/admiral.jpg\" alt=\"Admiral\" width=\"150\" height=\"150\" /></a></p>\n<p>Two column, widget and gravatar ready theme, with detection of visitors from search engines</p>\n<p><a href=\"http://copacetix.com/\">Copacetix</a></p>\n<p><img title=\"Copacetix\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/copacetix.gif\" alt=\"Copacetix\" width=\"150\" height=\"95\" /></p>\n<p>This theme features Widgets, a clean readable css file, and printer friendly style sheet, variable title tags, multiple layouts, random homepage photos, minimal images to load, h1 titles on pages and posts, and many other specific things that I think make up a usable WordPress theme.</p>\n<p><a href=\"http://themeshaper.com/thematic-for-wordpress/\">The Thematic Theme Framework</a></p>\n<p><img title=\"Thematic\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/thematic.jpg\" alt=\"Thematic\" width=\"150\" height=\"92\" /></p>\n<p>Thematic is a WordPress Theme Framework perfect for the beginner blogger and experienced developers looking for a solid design platform. Version 0.9 is a complete re-think of the front end and a major refinement of the back end. 13 Widget ready areas (with options for more). It supports gravatars, threaded comments, and sticky posts. There’s a simple Theme Options page. And layout possibilities for 1, 2 or 3-column layouts.</p>\n<p>Are you a theme author? <a href=\"http://weblogtoolscollection.com/submit-news/\">Submit your theme</a> to us.</p>\";}i:2;a:7:{s:5:\"title\";s:51:\"Ping-O-Matic: Ping-o-matic has received a makeover!\";s:4:\"guid\";s:32:\"http://blog.pingomatic.com/?p=15\";s:4:\"link\";s:75:\"http://blog.pingomatic.com/2009/03/03/ping-o-matic-has-received-a-makeover/\";s:11:\"description\";s:3023:\"<div class=\"snap_preview\"><br /><p>Dear Ping-o-matic users, I&#8217;m Isaac from Automattic. It was a while since anyone wrote on this blog, and I thought I&#8217;d fill you in on what&#8217;s been going on lately.</p>\n<p>I&#8217;ve just performed a redesign on the Ping-o-matic website. The new look was launched a few weeks ago, and is meant to increase the usability of the service and make it look a bit more modern and well fitted for the WordPress/Automattic family.</p>\n<p>For newcomers, there&#8217;s now a welcome message on top of the front page which gives you a Ping-o-matic crash course. Below this, you&#8217;ll find the familiar pinging form where you supply your blog details and select the services you want ping. The whole form has been redesigned to stand out more from the rest of the content on the page, making it easier to see how it all fits together. The vertical space for the services list has been compressed. This list took up a big chunk of the screen before, but has now been compressed to 4 columns which saves a lot of space. &#8230;And the action button is now bigger than ever, so you can&#8217;t possibly miss it!</p>\n<p>As for the Stats page, it&#8217;s received a minor update. The graph has been modified to fit with the new color scheme of Ping-o-matic.</p>\n<p>The spirit behind the redesign was to give Ping-o-matic a graphical profile on it&#8217;s own, with bold colors that makes the service memorable. I also wanted to make it better tied in to the WordPress/Automattic family&#8217;s graphical profile and user interface ideas. You&#8217;ll notice similar fonts, navigation solutions and a fancy looking footer, as well as a good deal of &#8220;under the hood&#8221; similarities. Among those are the uses of CSS3 rules like border-radius, which gives people browsing Ping-o-matic in modern browsers a richer (and rounder!) experience.</p>\n  <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gocomments/pingomatic.wordpress.com/15/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/comments/pingomatic.wordpress.com/15/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godelicious/pingomatic.wordpress.com/15/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/delicious/pingomatic.wordpress.com/15/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gostumble/pingomatic.wordpress.com/15/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/stumble/pingomatic.wordpress.com/15/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godigg/pingomatic.wordpress.com/15/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/digg/pingomatic.wordpress.com/15/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/goreddit/pingomatic.wordpress.com/15/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/reddit/pingomatic.wordpress.com/15/\" /></a> <img alt=\"\" border=\"0\" src=\"http://stats.wordpress.com/b.gif?host=blog.pingomatic.com&blog=68432&post=15&subd=pingomatic&ref=&feed=1\" /></div>\";s:7:\"pubdate\";s:31:\"Tue, 03 Mar 2009 12:00:20 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:5:\"Isaac\";}s:7:\"summary\";s:3023:\"<div class=\"snap_preview\"><br /><p>Dear Ping-o-matic users, I&#8217;m Isaac from Automattic. It was a while since anyone wrote on this blog, and I thought I&#8217;d fill you in on what&#8217;s been going on lately.</p>\n<p>I&#8217;ve just performed a redesign on the Ping-o-matic website. The new look was launched a few weeks ago, and is meant to increase the usability of the service and make it look a bit more modern and well fitted for the WordPress/Automattic family.</p>\n<p>For newcomers, there&#8217;s now a welcome message on top of the front page which gives you a Ping-o-matic crash course. Below this, you&#8217;ll find the familiar pinging form where you supply your blog details and select the services you want ping. The whole form has been redesigned to stand out more from the rest of the content on the page, making it easier to see how it all fits together. The vertical space for the services list has been compressed. This list took up a big chunk of the screen before, but has now been compressed to 4 columns which saves a lot of space. &#8230;And the action button is now bigger than ever, so you can&#8217;t possibly miss it!</p>\n<p>As for the Stats page, it&#8217;s received a minor update. The graph has been modified to fit with the new color scheme of Ping-o-matic.</p>\n<p>The spirit behind the redesign was to give Ping-o-matic a graphical profile on it&#8217;s own, with bold colors that makes the service memorable. I also wanted to make it better tied in to the WordPress/Automattic family&#8217;s graphical profile and user interface ideas. You&#8217;ll notice similar fonts, navigation solutions and a fancy looking footer, as well as a good deal of &#8220;under the hood&#8221; similarities. Among those are the uses of CSS3 rules like border-radius, which gives people browsing Ping-o-matic in modern browsers a richer (and rounder!) experience.</p>\n  <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gocomments/pingomatic.wordpress.com/15/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/comments/pingomatic.wordpress.com/15/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godelicious/pingomatic.wordpress.com/15/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/delicious/pingomatic.wordpress.com/15/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gostumble/pingomatic.wordpress.com/15/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/stumble/pingomatic.wordpress.com/15/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godigg/pingomatic.wordpress.com/15/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/digg/pingomatic.wordpress.com/15/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/goreddit/pingomatic.wordpress.com/15/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/reddit/pingomatic.wordpress.com/15/\" /></a> <img alt=\"\" border=\"0\" src=\"http://stats.wordpress.com/b.gif?host=blog.pingomatic.com&blog=68432&post=15&subd=pingomatic&ref=&feed=1\" /></div>\";}i:3;a:7:{s:5:\"title\";s:47:\"Dougal Campbell: The Future of WordPress Themes\";s:4:\"guid\";s:33:\"http://dougal.gunters.org/?p=1468\";s:4:\"link\";s:72:\"http://dougal.gunters.org/blog/2009/03/02/the-future-of-wordpress-themes\";s:11:\"description\";s:942:\"<p><img class=\"alignright size-thumbnail wp-image-1222\" title=\"WordPress\" src=\"http://dougal.gunters.org/wordpress/wp-content/uploads/2008/11/wplogo-notext-rgb-150x150.png\" alt=\"WordPress\" width=\"150\" height=\"150\" /></p>\n<p>A couple of months ago, Ian Stewart asked me to be one of the voices for this year&#8217;s roundup on <a href=\"http://themeshaper.com/future-wordpress-themes-2009/\">The Future of WordPress Themes 2009</a>. There were a variety of angles from which to look at the subject, so it&#8217;s interesting to see how everyone interpreted the question.</p>\n<p>There are discussions about &#8220;Premium&#8221; themes and the <acronym title=\"Gnu General Public License\"><span class=\"caps\">GPL</span></acronym>, about whether plugin functionality belongs in themes, and about seperation of presentation and content, among other things. Give it a read to learn what I (and 14 other WordPress community influencers) had to say.</p>\";s:7:\"pubdate\";s:31:\"Mon, 02 Mar 2009 21:21:04 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:6:\"Dougal\";}s:7:\"summary\";s:942:\"<p><img class=\"alignright size-thumbnail wp-image-1222\" title=\"WordPress\" src=\"http://dougal.gunters.org/wordpress/wp-content/uploads/2008/11/wplogo-notext-rgb-150x150.png\" alt=\"WordPress\" width=\"150\" height=\"150\" /></p>\n<p>A couple of months ago, Ian Stewart asked me to be one of the voices for this year&#8217;s roundup on <a href=\"http://themeshaper.com/future-wordpress-themes-2009/\">The Future of WordPress Themes 2009</a>. There were a variety of angles from which to look at the subject, so it&#8217;s interesting to see how everyone interpreted the question.</p>\n<p>There are discussions about &#8220;Premium&#8221; themes and the <acronym title=\"Gnu General Public License\"><span class=\"caps\">GPL</span></acronym>, about whether plugin functionality belongs in themes, and about seperation of presentation and content, among other things. Give it a read to learn what I (and 14 other WordPress community influencers) had to say.</p>\";}i:4;a:7:{s:5:\"title\";s:60:\"Weblog Tools Collection: WordPress Plugin Releases for 03/02\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=5245\";s:4:\"link\";s:88:\"http://weblogtoolscollection.com/archives/2009/03/02/wordpress-plugin-releases-for-0302/\";s:11:\"description\";s:3896:\"<h3>New Plugins</h3>\n<p><a href=\"http://gwycon.com/products/wordpress-plugins/wp-content-filter/\">WP Content Filter</a></p>\n<p>Filter out any profanity and any other keywords specified on the Plugin options page.</p>\n<p><a href=\"http://www.a-scripts.com/wordpress-plugins/tooltips-for-wordpress/\">Tooltips</a></p>\n<p>Simple filter plugin that allows you to use tooltips for words / phrases.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/parallel-load/\">Parallel Load</a></p>\n<p>Load Javascript files in parallel by using document.write tag.</p>\n<p><a href=\"http://amwhalen.com/blog/projects/wp-hooks\">WP Hooks</a></p>\n<p>WP Hooks is a plugin for WordPress that allows you to add JavaScript, HTML, or other code to your header and footer without modifying your theme.</p>\n<p><a href=\"http://theflyingdeveloper.com/wordpress-plugins/wp_reactions/\">WP_Reactions</a></p>\n<p>WP_Reactions is a plugin that allows blog authors to gather a reader&#8217;s gut reaction after reading a post.</p>\n<p><a href=\"http://www.lukti.com/2009/03/posts-reminder-recordatorio-de-posts.html\">Posts reminder</a></p>\n<p>Posts reminder notifies you when you forget to write a post on the current day.</p>\n<p><a href=\"http://www.a-scripts.com/wordpress-plugins/social-actions-wp-plugin/\">Social Actions For Posts</a></p>\n<p>A plugin conntecting your blog with Social Actions displaying related social actions as widget for each post.</p>\n<h3>Updated Plugins</h3>\n<p><a href=\"http://dnhints.com/plus/\">TwitPlusNNNF</a></p>\n<p>This plugin allows you to twit your newly published / edited wordpress posts. &#8220;Post to twitter&#8221; form is embedded into &#8220;Add/Edit Post&#8221; page, thus you can easily create customized twitter posts. You can also shorten your post&#8217;s urls for twitter &#8220;on the fly&#8221; with <a href=\"http://nn.nf\">http://nn.nf</a> url shortener service.</p>\n<p><a href=\"http://omninoggin.com/wordpress-plugins/wp-greet-box-wordpress-plugin/\">WP Greet Box</a></p>\n<p>This plugin lets you show a different greeting message to your new visitors depending on their referrer url.</p>\n<p><a href=\"http://omninoggin.com/wordpress-plugins/buy-sell-ads-wordpress-plugin/\">Buy Sell Ads</a></p>\n<p>This simple plugin helps you easily integrate your Buy Sell Ads zones and includes anti-AdBlock measures to prevent AdBlock (and other similar softwares) from blocking Buy Sell Ads advertisements on your site.</p>\n<p><a href=\"http://ajaydsouza.com/wordpress/plugins/contextual-related-posts/\">Contextual Related Posts</a></p>\n<p>Display a list of contextually related posts for the current post. You can select the number of posts to display and if you want to automatically display the related posts in your content / feed.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/csprites-for-wordpress/\">cSprites - Speed Up Page Load Time with Dynamic Image Sprites</a></p>\n<p>Automatically compress you content images into a big sprite, decreasing web page load time.</p>\n<p><a href=\"http://www.drunkadmin.com/projects/plugin-manager\">Plugin Manager</a></p>\n<p>View, download and install plugins from WordPress.org Plugin Database from an AJAX&#8217;ed interface with a single click of the mouse.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/flash-feed-scroll-reader/\">Flash Feed Scroll Reader</a></p>\n<p>Flash Feed Scroll Reader is a Flash Feed Reader with horizontal scrolling.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/tweetbacks/\">Tweetbacks</a></p>\n<p>Show tweets that mention your post as &#8220;tweetbacks&#8221; in your comments section.</p>\n<p><a href=\"http://www.emmanuelgeorjon.com/en/eg-attachments-plugin-1233\">EG-Attachments</a></p>\n<p>This plugin add a shortcode to display the list of attachments of a post, with icon and details.</p>\n<p><a href=\"http://www.thulasidas.com/adsense\">AdSense Now!</a></p>\n<p>AdSense Now! gets you started with Google AdSense.</p>\";s:7:\"pubdate\";s:31:\"Mon, 02 Mar 2009 19:56:21 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:3896:\"<h3>New Plugins</h3>\n<p><a href=\"http://gwycon.com/products/wordpress-plugins/wp-content-filter/\">WP Content Filter</a></p>\n<p>Filter out any profanity and any other keywords specified on the Plugin options page.</p>\n<p><a href=\"http://www.a-scripts.com/wordpress-plugins/tooltips-for-wordpress/\">Tooltips</a></p>\n<p>Simple filter plugin that allows you to use tooltips for words / phrases.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/parallel-load/\">Parallel Load</a></p>\n<p>Load Javascript files in parallel by using document.write tag.</p>\n<p><a href=\"http://amwhalen.com/blog/projects/wp-hooks\">WP Hooks</a></p>\n<p>WP Hooks is a plugin for WordPress that allows you to add JavaScript, HTML, or other code to your header and footer without modifying your theme.</p>\n<p><a href=\"http://theflyingdeveloper.com/wordpress-plugins/wp_reactions/\">WP_Reactions</a></p>\n<p>WP_Reactions is a plugin that allows blog authors to gather a reader&#8217;s gut reaction after reading a post.</p>\n<p><a href=\"http://www.lukti.com/2009/03/posts-reminder-recordatorio-de-posts.html\">Posts reminder</a></p>\n<p>Posts reminder notifies you when you forget to write a post on the current day.</p>\n<p><a href=\"http://www.a-scripts.com/wordpress-plugins/social-actions-wp-plugin/\">Social Actions For Posts</a></p>\n<p>A plugin conntecting your blog with Social Actions displaying related social actions as widget for each post.</p>\n<h3>Updated Plugins</h3>\n<p><a href=\"http://dnhints.com/plus/\">TwitPlusNNNF</a></p>\n<p>This plugin allows you to twit your newly published / edited wordpress posts. &#8220;Post to twitter&#8221; form is embedded into &#8220;Add/Edit Post&#8221; page, thus you can easily create customized twitter posts. You can also shorten your post&#8217;s urls for twitter &#8220;on the fly&#8221; with <a href=\"http://nn.nf\">http://nn.nf</a> url shortener service.</p>\n<p><a href=\"http://omninoggin.com/wordpress-plugins/wp-greet-box-wordpress-plugin/\">WP Greet Box</a></p>\n<p>This plugin lets you show a different greeting message to your new visitors depending on their referrer url.</p>\n<p><a href=\"http://omninoggin.com/wordpress-plugins/buy-sell-ads-wordpress-plugin/\">Buy Sell Ads</a></p>\n<p>This simple plugin helps you easily integrate your Buy Sell Ads zones and includes anti-AdBlock measures to prevent AdBlock (and other similar softwares) from blocking Buy Sell Ads advertisements on your site.</p>\n<p><a href=\"http://ajaydsouza.com/wordpress/plugins/contextual-related-posts/\">Contextual Related Posts</a></p>\n<p>Display a list of contextually related posts for the current post. You can select the number of posts to display and if you want to automatically display the related posts in your content / feed.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/csprites-for-wordpress/\">cSprites - Speed Up Page Load Time with Dynamic Image Sprites</a></p>\n<p>Automatically compress you content images into a big sprite, decreasing web page load time.</p>\n<p><a href=\"http://www.drunkadmin.com/projects/plugin-manager\">Plugin Manager</a></p>\n<p>View, download and install plugins from WordPress.org Plugin Database from an AJAX&#8217;ed interface with a single click of the mouse.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/flash-feed-scroll-reader/\">Flash Feed Scroll Reader</a></p>\n<p>Flash Feed Scroll Reader is a Flash Feed Reader with horizontal scrolling.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/tweetbacks/\">Tweetbacks</a></p>\n<p>Show tweets that mention your post as &#8220;tweetbacks&#8221; in your comments section.</p>\n<p><a href=\"http://www.emmanuelgeorjon.com/en/eg-attachments-plugin-1233\">EG-Attachments</a></p>\n<p>This plugin add a shortcode to display the list of attachments of a post, with icon and details.</p>\n<p><a href=\"http://www.thulasidas.com/adsense\">AdSense Now!</a></p>\n<p>AdSense Now! gets you started with Google AdSense.</p>\";}i:5;a:7:{s:5:\"title\";s:102:\"WordPress Podcast: Episode 50: WordPress 2.7.1 released, WordPress.tv, How much do YOU love WordPress?\";s:4:\"guid\";s:30:\"http://wp-community.org/?p=321\";s:4:\"link\";s:112:\"http://wp-community.org/2009/03/02/episode-50-wordpress-271-released-wordpresstv-how-much-do-you-love-wordpress/\";s:11:\"description\";s:698:\"Episode 50 of The WordPress Podcast is made possible by Mozy- the world&#8217;s most popular backup service, proving simple, automatic and secure backups for your important files, and GoDaddy - world&#8217;s largest domain name registrar and provider of shared, dedicated and virtual dedicated hosting plans.\nIncluded in this episode:\n\nFrederick Ding asks about saving changes he&#8217;s made [...]<p>Published at: <a href=\"http://wp-community.org\">The WordPress Community</a></p>\n<p><a href=\"http://wp-community.org/2009/03/02/episode-50-wordpress-271-released-wordpresstv-how-much-do-you-love-wordpress/\">Episode 50: WordPress 2.7.1 released, WordPress.tv, How much do YOU love WordPress?</a></p>\";s:7:\"pubdate\";s:31:\"Mon, 02 Mar 2009 15:07:05 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:37:\"Charles Stricklin and Jonathan Bailey\";}s:7:\"summary\";s:698:\"Episode 50 of The WordPress Podcast is made possible by Mozy- the world&#8217;s most popular backup service, proving simple, automatic and secure backups for your important files, and GoDaddy - world&#8217;s largest domain name registrar and provider of shared, dedicated and virtual dedicated hosting plans.\nIncluded in this episode:\n\nFrederick Ding asks about saving changes he&#8217;s made [...]<p>Published at: <a href=\"http://wp-community.org\">The WordPress Community</a></p>\n<p><a href=\"http://wp-community.org/2009/03/02/episode-50-wordpress-271-released-wordpresstv-how-much-do-you-love-wordpress/\">Episode 50: WordPress 2.7.1 released, WordPress.tv, How much do YOU love WordPress?</a></p>\";}i:6;a:7:{s:5:\"title\";s:68:\"Weblog Tools Collection: Plugin Review: Improved Plugin Installation\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=5243\";s:4:\"link\";s:96:\"http://weblogtoolscollection.com/archives/2009/03/01/plugin-review-improved-plugin-installation/\";s:11:\"description\";s:3034:\"<p>One thing I&#8217;ve loved about WordPress 2.7.x is the ability to install plugins directly from the WordPress Plugin Repository. You don&#8217;t need to visit the individual site and instead just search for the plugin you want and then download, install and activate it.</p>\n<p>However, even now, you need to go to your WP-Admin to install your plugins.</p>\n<p><a href=\"http://www.improvingtheweb.com/wordpress-plugins/improved-plugin-installation/\">Improved Plugin Installation</a> helps overcome this problem.</p>\n<h3>Description:</h3>\n<p>This plugin is an improvement to the current WP 2.7 plugin installation methods. It allows you to install one or more plugins simply by typing the names of the plugins or the download URLs in a textarea. This means you can install all your favorite wordpress plugins in one go!</p>\n<p>Furthermore, a bookmarklet is included which lets you install plugins directly from an external site. </p>\n<h3>Review:</h3>\n<p>Firstly, I love <a href=\"http://www.improvingtheweb.com/wordpress-plugins/improved-plugin-installation/\">the plugin page</a>. I&#8217;ve always encouraged authors to write detailed plugin pages on their blogs as these ensure that your reader easily understands what your plugin has to offer as well what exactly do they need to do to use it. And, Improved Plugin Installation has the necessary details.</p>\n<p>The plugin can be used in two main ways. One is from within WordPress Admin and the second is the bookmarklet.</p>\n<p>From within the WordPress Admin, you can navigate to Add New Plugin page as usual and scroll down to find a textarea at the bottom. In this you can enter plugin names, plugin page URLS or even direct URLs to the zip files.</p>\n<p><img title=\"install-multiple-plugins\" alt=\"install-multiple-plugins\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/installmultipleplugins.png\" width=\"457\" height=\"200\" /> </p>\n<p>Improved Plugin Installation will then download these plugins and install them on your WordPress blog.</p>\n<p>The second feature is the bookmarklet. You can install the bookmarklet by navigating to the Add Plugin page and install it from there.</p>\n<p>Visit a plugin page, even on external sites and hit the bookmarklet to initiate the installation dialog. You may be asked to login to your blog. This is a necessary security measure and you&#8217;ll be able to quickly install yet another plugin.</p>\n<p>Without doubt this plugin really enhances the WordPress interface. But, the question remains how often will you use it. For one, it&#8217;s excellent when you setup a fresh blog and know you have a certain set of plugins that need to be installed.</p>\n<p>Another is if you are in the habit of trying out different plugins, or are a tester.</p>\n<p>One feature I would like to see is the ability to mass upgrade plugins. Right now if new versions of two or more plugins are released, I need to update each individually, which can be a pain.</p>\n<p>Are you currently using this plugin? What would you like to see in the future?</p>\";s:7:\"pubdate\";s:31:\"Sun, 01 Mar 2009 17:15:07 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:3034:\"<p>One thing I&#8217;ve loved about WordPress 2.7.x is the ability to install plugins directly from the WordPress Plugin Repository. You don&#8217;t need to visit the individual site and instead just search for the plugin you want and then download, install and activate it.</p>\n<p>However, even now, you need to go to your WP-Admin to install your plugins.</p>\n<p><a href=\"http://www.improvingtheweb.com/wordpress-plugins/improved-plugin-installation/\">Improved Plugin Installation</a> helps overcome this problem.</p>\n<h3>Description:</h3>\n<p>This plugin is an improvement to the current WP 2.7 plugin installation methods. It allows you to install one or more plugins simply by typing the names of the plugins or the download URLs in a textarea. This means you can install all your favorite wordpress plugins in one go!</p>\n<p>Furthermore, a bookmarklet is included which lets you install plugins directly from an external site. </p>\n<h3>Review:</h3>\n<p>Firstly, I love <a href=\"http://www.improvingtheweb.com/wordpress-plugins/improved-plugin-installation/\">the plugin page</a>. I&#8217;ve always encouraged authors to write detailed plugin pages on their blogs as these ensure that your reader easily understands what your plugin has to offer as well what exactly do they need to do to use it. And, Improved Plugin Installation has the necessary details.</p>\n<p>The plugin can be used in two main ways. One is from within WordPress Admin and the second is the bookmarklet.</p>\n<p>From within the WordPress Admin, you can navigate to Add New Plugin page as usual and scroll down to find a textarea at the bottom. In this you can enter plugin names, plugin page URLS or even direct URLs to the zip files.</p>\n<p><img title=\"install-multiple-plugins\" alt=\"install-multiple-plugins\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/installmultipleplugins.png\" width=\"457\" height=\"200\" /> </p>\n<p>Improved Plugin Installation will then download these plugins and install them on your WordPress blog.</p>\n<p>The second feature is the bookmarklet. You can install the bookmarklet by navigating to the Add Plugin page and install it from there.</p>\n<p>Visit a plugin page, even on external sites and hit the bookmarklet to initiate the installation dialog. You may be asked to login to your blog. This is a necessary security measure and you&#8217;ll be able to quickly install yet another plugin.</p>\n<p>Without doubt this plugin really enhances the WordPress interface. But, the question remains how often will you use it. For one, it&#8217;s excellent when you setup a fresh blog and know you have a certain set of plugins that need to be installed.</p>\n<p>Another is if you are in the habit of trying out different plugins, or are a tester.</p>\n<p>One feature I would like to see is the ability to mass upgrade plugins. Right now if new versions of two or more plugins are released, I need to update each individually, which can be a pain.</p>\n<p>Are you currently using this plugin? What would you like to see in the future?</p>\";}i:7;a:7:{s:5:\"title\";s:60:\"Weblog Tools Collection: WordPress Plugin Releases for 02/27\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=5238\";s:4:\"link\";s:88:\"http://weblogtoolscollection.com/archives/2009/02/27/wordpress-plugin-releases-for-0227/\";s:11:\"description\";s:4638:\"<h3>New Plugins</h3>\n<p><a href=\"http://www.cyberblog.net/our-works/cb-featured-plugin-featured-posts/\">CB-Featured</a></p>\n<p>CB-Featured is a highly customizable featured content plugin which will display your selected posts with a nice scrolling and bouncing effect anywhere within your Wordpress theme. The plugin was created from jCarousel and developed by CyberBlog.net</p>\n<p><a href=\"http://eight7teen.com/sexy-bookmarks\">SexyBookmarks</a></p>\n<p>WP Social Bookmark Menu (aka: SexyBookmarks) is a Wordpress plugin that inserts menu of social bookmarking site icons in each of your blog post to make it easier for your reader to bookmarks your blog. You can watch this plugin in action in this blog.</p>\n<p><a href=\"http://sivel.net/2009/02/admin-show-sticky/\">Admin Show Sticky</a></p>\n<p>Adds a new column to the posts table in the admin to display if a post is sticky or not. Determining what posts are sticky or not should be easier than editing each post or comparing a list of posts displayed on your site to the list in the Edit Posts table in the admin. This plugin will add a new column titled `Sticky` and place a check mark in this column if the post is &#8216;Sticky&#8217;.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/belindes-bricks-box/\">Belinde&#8217;s Bricks Box</a></p>\n<p>Belinde&#8217;s Brick Box is a collation of common tools useful in plugin&#8217;s developing. It provides an highly configurable CRUD (Create - Read - Update - Delete) for database tables and others data structures, AJAX grids features, options management and so on.</p>\n<p><a href=\"http://fabrizio.zellini.org/picgrab-a-wordpress-plugin#english\">Picture grabber, resizer and cropper</a></p>\n<p>Picgrab is a plugin that download, resize and crop an image on the fly. It also stores resized and cropped images in local cache. <em>Page not in English</em></p>\n<p><a href=\"http://wordpress.org/extend/plugins/random-post-list/\">random post list</a></p>\n<p>Make random post list and feeling lucky link</p>\n<p><a href=\"http://www.stoplivinginthepast.com/get-the-code/\">Stop Living in the Past</a></p>\n<p>Adds a box to the top of the page when a user visits it using Internet Explorer 6 or older telling the visitor to upgrade to a newer version</p>\n<p><a href=\"http://www.philmcdonnell.com/projects/wp-categories-and-posts/\">WP Categories and Posts</a></p>\n<p>This plugin adds in a template tag you can use to display categories and sub categories and the posts underneath those categories.</p>\n<h3>Updated Plugins</h3>\n<p><a href=\"http://ajaydsouza.com/wordpress/plugins/contextual-related-posts/\">Contextual Related Posts</a></p>\n<p>Display a list of contextually related posts for the current post. You can select the number of posts to display and if you want to automatically display the related posts in your content / feed. Now, you can choose to exclude posts from certain categories as well as exclude pages.</p>\n<p><a href=\"http://ajaydsouza.com/wordpress/plugins/open-browser-window-plugin/\">Open Browser Window</a></p>\n<p>Open Browser Window opens a new browser window with the URL of the page that you specified using JavaScript.</p>\n<p><a href=\"http://www.instinct.co.nz/e-commerce\">WP e-commerce</a></p>\n<p>The WordPress e-Commerce plugin is a state-of-the-art e-Commerce platform with a focus on aesthetics, web standards and usability. It is both free and priceless at the same time.</p>\n<p><a href=\"http://ocaoimh.ie/wp-super-cache/\">WP Super Cache</a></p>\n<p>WP Super Cache is a page caching plugin for WordPress that will significantly speed up your website.</p>\n<p><a href=\"http://flutter.freshout.us/\">Flutter</a></p>\n<p>Flutter is a feature rich WordPress CMS plugin by Freshout.</p>\n<p><a href=\"http://sivel.net/2008/09/possibly-related-recent-posts/\">Possibly Related Recent Posts</a></p>\n<p>Automatically displays possibly related posts at the end of each post.</p>\n<p><a href=\"http://52good.skylast.com/statpresscn-info\">StatPressCN</a></p>\n<p>Manage visitor statistics of realtime, hot articles, random articles, feed subscriber&#8217;s count, etc; can be used by your blog through widget.</p>\n<p><a href=\"http://www.freecharity.org.uk/wordpress-petition-plugin/\">WordPress Petition Plugin</a></p>\n<p>Run simple web and e-mail based petitions through WordPress.</p>\n<p><a href=\"http://neppe.no/wordpress/wp-opt-in/\">WP Opt-in</a></p>\n<p>Collect e-mail addresses from users with a simple form. Send them an e-mail automagically.</p>\n<p><a href=\"http://sivel.net/2008/08/moderate-selected-posts/\">Moderate Selected Posts</a></p>\n<p>Force comment moderation on selected posts but allow others to remain open.</p>\";s:7:\"pubdate\";s:31:\"Fri, 27 Feb 2009 18:47:07 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:4638:\"<h3>New Plugins</h3>\n<p><a href=\"http://www.cyberblog.net/our-works/cb-featured-plugin-featured-posts/\">CB-Featured</a></p>\n<p>CB-Featured is a highly customizable featured content plugin which will display your selected posts with a nice scrolling and bouncing effect anywhere within your Wordpress theme. The plugin was created from jCarousel and developed by CyberBlog.net</p>\n<p><a href=\"http://eight7teen.com/sexy-bookmarks\">SexyBookmarks</a></p>\n<p>WP Social Bookmark Menu (aka: SexyBookmarks) is a Wordpress plugin that inserts menu of social bookmarking site icons in each of your blog post to make it easier for your reader to bookmarks your blog. You can watch this plugin in action in this blog.</p>\n<p><a href=\"http://sivel.net/2009/02/admin-show-sticky/\">Admin Show Sticky</a></p>\n<p>Adds a new column to the posts table in the admin to display if a post is sticky or not. Determining what posts are sticky or not should be easier than editing each post or comparing a list of posts displayed on your site to the list in the Edit Posts table in the admin. This plugin will add a new column titled `Sticky` and place a check mark in this column if the post is &#8216;Sticky&#8217;.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/belindes-bricks-box/\">Belinde&#8217;s Bricks Box</a></p>\n<p>Belinde&#8217;s Brick Box is a collation of common tools useful in plugin&#8217;s developing. It provides an highly configurable CRUD (Create - Read - Update - Delete) for database tables and others data structures, AJAX grids features, options management and so on.</p>\n<p><a href=\"http://fabrizio.zellini.org/picgrab-a-wordpress-plugin#english\">Picture grabber, resizer and cropper</a></p>\n<p>Picgrab is a plugin that download, resize and crop an image on the fly. It also stores resized and cropped images in local cache. <em>Page not in English</em></p>\n<p><a href=\"http://wordpress.org/extend/plugins/random-post-list/\">random post list</a></p>\n<p>Make random post list and feeling lucky link</p>\n<p><a href=\"http://www.stoplivinginthepast.com/get-the-code/\">Stop Living in the Past</a></p>\n<p>Adds a box to the top of the page when a user visits it using Internet Explorer 6 or older telling the visitor to upgrade to a newer version</p>\n<p><a href=\"http://www.philmcdonnell.com/projects/wp-categories-and-posts/\">WP Categories and Posts</a></p>\n<p>This plugin adds in a template tag you can use to display categories and sub categories and the posts underneath those categories.</p>\n<h3>Updated Plugins</h3>\n<p><a href=\"http://ajaydsouza.com/wordpress/plugins/contextual-related-posts/\">Contextual Related Posts</a></p>\n<p>Display a list of contextually related posts for the current post. You can select the number of posts to display and if you want to automatically display the related posts in your content / feed. Now, you can choose to exclude posts from certain categories as well as exclude pages.</p>\n<p><a href=\"http://ajaydsouza.com/wordpress/plugins/open-browser-window-plugin/\">Open Browser Window</a></p>\n<p>Open Browser Window opens a new browser window with the URL of the page that you specified using JavaScript.</p>\n<p><a href=\"http://www.instinct.co.nz/e-commerce\">WP e-commerce</a></p>\n<p>The WordPress e-Commerce plugin is a state-of-the-art e-Commerce platform with a focus on aesthetics, web standards and usability. It is both free and priceless at the same time.</p>\n<p><a href=\"http://ocaoimh.ie/wp-super-cache/\">WP Super Cache</a></p>\n<p>WP Super Cache is a page caching plugin for WordPress that will significantly speed up your website.</p>\n<p><a href=\"http://flutter.freshout.us/\">Flutter</a></p>\n<p>Flutter is a feature rich WordPress CMS plugin by Freshout.</p>\n<p><a href=\"http://sivel.net/2008/09/possibly-related-recent-posts/\">Possibly Related Recent Posts</a></p>\n<p>Automatically displays possibly related posts at the end of each post.</p>\n<p><a href=\"http://52good.skylast.com/statpresscn-info\">StatPressCN</a></p>\n<p>Manage visitor statistics of realtime, hot articles, random articles, feed subscriber&#8217;s count, etc; can be used by your blog through widget.</p>\n<p><a href=\"http://www.freecharity.org.uk/wordpress-petition-plugin/\">WordPress Petition Plugin</a></p>\n<p>Run simple web and e-mail based petitions through WordPress.</p>\n<p><a href=\"http://neppe.no/wordpress/wp-opt-in/\">WP Opt-in</a></p>\n<p>Collect e-mail addresses from users with a simple form. Send them an e-mail automagically.</p>\n<p><a href=\"http://sivel.net/2008/08/moderate-selected-posts/\">Moderate Selected Posts</a></p>\n<p>Force comment moderation on selected posts but allow others to remain open.</p>\";}i:8;a:7:{s:5:\"title\";s:20:\"Matt: Magazine Theme\";s:4:\"guid\";s:21:\"http://ma.tt/?p=12038\";s:4:\"link\";s:36:\"http://ma.tt/2009/02/magazine-theme/\";s:11:\"description\";s:222:\"<p><a href=\"http://www.smashingmagazine.com/2009/02/23/magazeen-free-magazine-look-wordpress-theme/#comment-326692\">Check out &#8220;Magazeen&#8221;: Free Magazine-Look WordPress Theme</a>. Even better: it&#8217;s GPL.</p>\";s:7:\"pubdate\";s:31:\"Fri, 27 Feb 2009 11:45:42 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:7:\"summary\";s:222:\"<p><a href=\"http://www.smashingmagazine.com/2009/02/23/magazeen-free-magazine-look-wordpress-theme/#comment-326692\">Check out &#8220;Magazeen&#8221;: Free Magazine-Look WordPress Theme</a>. Even better: it&#8217;s GPL.</p>\";}i:9;a:7:{s:5:\"title\";s:120:\"Lorelle on WP: WordPress News Summary: WordCamps, WordPress Meetups, WordPress PowerPoint, FeedBurner and Flash Warnings\";s:4:\"guid\";s:36:\"http://lorelle.wordpress.com/?p=3919\";s:4:\"link\";s:142:\"http://lorelle.wordpress.com/2009/02/26/wordpress-news-summary-wordcamps-wordpress-meetups-wordpress-powerpoint-feedburner-and-flash-warnings/\";s:11:\"description\";s:13503:\"<div class=\"snap_preview\"><br /><p><a href=\"http://lorelle.wordpress.com/tag/wordpress-news/\" title=\"WordPress News\"><img src=\"http://lorelle.files.wordpress.com/2007/01/wpnews1.png\" alt=\"WordPress News\" align=\"right\" /></a>This week&#8217;s <a href=\"http://www.blogherald.com/tag/wordpress-news/\" title=\"Articles on WordPress News on the Blog Herald\" rel=\"tag\">Blog Herald WordPress News</a> covers &#8220;<a href=\"http://www.blogherald.com/2009/02/20/wordpress-news-can-you-spot-a-wordpress-blog-wordpress-28-news-plugin-directory-searchable-iphone-app-tested-and-more/\" title=\"WordPress News: Can You Spot a WordPress Blog? WordPress 2.8 News, Plugin Directory Searchable, iPhone App Tested, and More\">Can You Spot a WordPress Blog? WordPress 2.8 News, Plugin Directory Searchable, iPhone App Tested, and More</a>&#8221; including:</p>\n<blockquote><p>March is WordPress month with more WordCamps and WordPress Meetups than ever. Will April beat it? Lester Chan makes a WordPress PowerPoint Template for presentations. WordPress wins the Best Irish Blogs Awards. FeedBurner transfer deadline is this weekend. Adobe Flash security vulnerability found, impacting many Plugins and WordPress blogs. And a lot more WordPress news coming your way.</p></blockquote>\n<p>The following are a few of the highlights and the WordPress news you can use.</p>\n<h4>FeedBurner Transfer to Google FeedBurner Deadline is Now</h4>\n<p>As <a href=\"http://weblogtoolscollection.com/archives/2009/02/12/feedburner-is-dead-long-live-feedburner/\" title=\"FeedBurner is Dead, Long Live Feedburner\">reported by Weblog Tools Collection&#8217;s Mark Ghosh</a>, FeedBurner has been taken over by Google and FeedBurner users are required to transfer their FeedBurner feeds, or check to ensure they have indeed been transferred, as he found out recently that his weren&#8217;t. <a href=\"http://adsenseforfeeds.blogspot.com/2009/02/more-details-on-moving-to-google.html\" title=\"More details on moving to a Google Account\">Feed must be transferred</a> as of February 28, this weekend, to the &#8220;new&#8221; version of Google FeedBurner. </p>\n<h4>WordPress 2.7.1 Released</h4>\n<p><a href=\"http://wordpress.org/development/2009/02/wordpress-271/\" title=\"WordPress 2.7.1\">WordPress 2.7.1</a>, a maintenance release, is out. If you are using WordPress 2.7, take advantage of the automatic built-in upgrade. If you are not, then consider <a href=\"http://lorelle.wordpress.com/2008/12/11/wordpress-27-upgrade-tips/\" title=\"WordPress 2.7 Upgrade Tips « Lorelle on WordPress\">upgrading to WordPress 2.7</a>. Sixty-five files were modified with 68 bug and feature fixes and improvements, and I covered more details <a href=\"http://lorelle.wordpress.com/2009/02/11/wordpress-271-released/\" title=\"WordPress 2.7.1\">about the release on my blog</a>. </p>\n<h4>WordPress 2.8 News</h4>\n<p><a href=\"http://boren.nu/archives/2009/02/17/wordpress-bits/\" title=\"WordPress Bits\">Ryan Boren reports</a> that development for WordPress 2.8 is underway. Articles worth noting on WordPress 2.8 development include: </p>\n<ul>\n<li><a href=\"http://wpdevel.wordpress.com/2008/12/27/optimizing-script-loading/\" title=\"Optimizing script loading\">Optimizing Script Loading</a></li>\n<li><a href=\"http://wpdevel.wordpress.com/2009/01/07/optimizing-script-loading-part-2/\" title=\"Optimizing script loading part 2\">Optimizing script loading part 2</a></li>\n<li><a href=\"http://wpdevel.wordpress.com/2009/01/15/optimizing-script-loading-implementation/\" title=\"Optimizing script loading, implementation\">Optimizing script loading, implementation</a></li>\n<li><a href=\"http://lesterchan.net/wordpress/2009/01/15/javascript-in-my-plugins/\" title=\"JavaScript In My Plugins\">Preparing for WordPress 2.8: Using JavaScript in WordPress Plugins</a></li>\n<li><a href=\"http://wpengineer.com/change-your-wordpress-theme-on/\" title=\"Change your WordPress Theme on …\">Change your WordPress Theme on …</a></li>\n<li><a href=\"http://wpengineer.com/wordpress-28-body_class-automatic_feed_links/\" title=\"WordPress 2.8 body_class, automatic_feed_links\">WordPress 2.8 body_class, automatic_feed_links</a></li>\n<li><a href=\"http://www.wp-fun.co.uk/2009/02/09/what-a-body/\" title=\"What a body!\">What a body!</a></li>\n</ul>\n<h4>Flash Security Vulnerability Warning</h4>\n<p><a href=\"http://www.f-secure.com/weblog/archives/00001613.html\" title=\"Adobe Flash Vulnerability\">F-Secure reports there is a security vulnerability</a> with Adobe Flash, specifically a <a href=\"http://www.f-secure.com/vulnerabilities/SA200900917\" title=\"Adobe Flash Player remote code execution vulnerability\">Adobe Flash Player remote code execution vulnerability</a> which impacts several versions. Many WordPress Plugins rely upon Flash, as do many WordPress blog. It is recommended you upgrade Adobe Flash accordingly.</p>\n<h3>WordPress Events</h3>\n<p><a href=\"http://lorelle.wordpress.com/?s=wordpress+events\" title=\"WordPress Events\"><img src=\"http://lorelle.files.wordpress.com/2007/01/wpevents.png\" alt=\"WordPress Events\" align=\"right\" /></a>I report on a lot of various WordPress events including WordCamps and WordPress Meetups around the world. Check the <a href=\"http://www.blogherald.com/tag/wordpress-news/\" title=\"Articles on WordPress News on the Blog Herald\" rel=\"tag\">Blog Herald WordPress News</a> for a WordPress event near you. </p>\n<h4>WordCamp Denver News</h4>\n<p><a href=\"http://denver.wordcamp.org/\" title=\"WordCamp Denver\">WordCamp Denver</a> is this weekend and for the most part, is sold out. I&#8217;ll be attending and working with Dave Moyer of the WordCast Podcast to do live podcasting and video interviews during the event. Hope to see you there!</p>\n<h4>WordCamp Toronto Logo Design Contest Winner</h4>\n<p><a href=\"http://phug.ca/wordcamptoronto/index.php/updates/logo-design-contest-winner\" title=\"Toronto WordCamp design contest winner\"><img alt=\"\" src=\"http://phug.ca/wordcamptoronto/wp-content/uploads/2009/02/logo01.png\" title=\"WordCamp Toronto Logo contest winner design\" class=\"alignright\" width=\"290\" height=\"309\" /></a>The <a href=\"http://phug.ca/wordcamptoronto/index.php/updates/logo-design-contest-winner\" title=\"Logo Design Contest Winner\">Logo Design Contest Winner</a> for WordCamp Toronto 2009 is <a href=\"http://iamunr.com/\" title=\"Paul Morrison\">Paul Morrison</a>, a student at Seneca College Digital Media Arts student. This is a great way to involve the community in a WordPress event.</p>\n<h4>WordPress Meetup or WordCamp Near You?</h4>\n<p><strong>February 2009</strong></p>\n<ul>\n<li><a href=\"http://denver.wordcamp.org\" title=\"WordCamp Denver\">WordCamp Denver 2009 - February 28, 2009</a> (<a href=\"http://http//www.facebook.com/profile.php?id=779828054#/group.php?gid=22086243642\" title=\"WordCamp Denver 2009\">Facebook</a>)</li>\n<li><a href=\"http://www.meetup.com/dfwwordpress/calendar/9593871/\" title=\"February Meetup of the DFW WordPress Group\">Dallas/Fort Worth WordPress Meetup - Dallas, Texas - February 28, 2009</a></li>\n<li><a href=\"http://wordpress.meetup.com/184/calendar/9615427/\" title=\"Atlanta WordPress Users Group February Meetup\">Atlanta WordPress Users Group Meetup - Learning WordPress 2.7 - Atlanta, Georgia - February 28, 2009</a></li>\n<li><a href=\"http://www.meetup.com/mywplife/calendar/9593848/\" title=\"The Chicago WordPress February Meetup\">The Chicago WordPress February Meetup - February 28, 2009</a></li>\n</ul>\n<p><strong>March 2009</strong></p>\n<ul>\n<li><a href=\"http://wordpress.meetup.com/173/calendar/9823503/\" title=\"So I want to install WordPress on my own domain—what do I do?\">Austin, Texas - Installing Full Version of WordPress - March 3, 2009</a></li>\n<li><a href=\"http://www.meetup.com/The-New-Jersey-WordPress-Meetup-Group/calendar/9675967/\" title=\"The New Jersey WordPress March Meetup\">New Jersey - The New Jersey WordPress March Meetup - March 4, 2009</a></li>\n<li><a href=\"http://www.meetup.com/gulf-coast-wordpress/calendar/9684749/\" title=\"Gulf Coast WordPress/Blogger March Meetup\">Mobile, Alabama - Gulf Coast WordPress/Blogger WordPress Meetup - March 5, 2009</a></li>\n<li><a href=\"http://www.meetup.com/LasVegasWordPress/calendar/9678813/\" title=\"Las Vegas WordPress Meetup\">Las Vegas WordPress Meetup - March 5, 2009</a></li>\n<li><a href=\"http://upcoming.yahoo.com/event/1808383/\" title=\"Mar 8, 2009: Los Angeles WordPress Users Group at Philippe\'s French Dip\">Los Angeles WordPress Users Group - March 8, 2009</a></li>\n<li><a href=\"http://upcoming.yahoo.com/event/1897209/\" title=\"Mar 15, 2009: Southern California WordPress Meetup - Long Beach at The Grounds Bakery Cafe\">Southern California WordPress Meetup - Long Beach - March 15, 2009</a></li>\n<li><a href=\"http://www.meetup.com/SF-WordPress-Users/calendar/9716946/\" title=\"South Florida WordPress March Meetup User Group\">Ft Lauderdale - South Florida WordPress March Meetup User Group - March 11, 2009</a></li>\n<li><a href=\"http://www.meetup.com/LasVegasWordPress/calendar/9678814/\" title=\"Las Vegas WordPress Meetup\">Las Vegas WordPress Meetup - March 12, 2009</a></li>\n<li><a title=\"SXSWeek 2009\" href=\"http://sxsw.com/\">Austin, Texas - SXSW 2009 - March 13-22, 2009</a></li>\n<li><a href=\"http://www.meetup.com/The-Scottsdale-WordPress-Meetup-Group/calendar/9815224/\" title=\"The Scottsdale WordPress March Meetup\">Arizona - The Scottsdale WordPress March Meetup - March 15, 2009</a></li>\n</ul>\n<p>If you are putting together a WordPress event, please <a href=\"mailto:&#x6c;&#111;&#114;&#x65;&#x6c;&#108;&#101;&#x6f;&#x6e;&#119;&#111;&#114;&#100;&#112;&#x72;&#101;&#x73;&#x73;&#64;&#103;&#109;&#x61;&#x69;&#x6c;&#46;&#x63;&#111;&#x6d;\">email</a> me so I can publicize it here. If there is a WordCamp near you, go. If you are interested in setting up a WordCamp, stay tuned for news and information on to bring a WordCamp event near you.</p>\n<p><img src=\"http://lorelle.files.wordpress.com/2006/08/sig.gif\" alt=\"\" /><br />\n<hr />\n<p><font size=\"-1\"><b>Site Search Tags:</b> <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+news\" rel=\"tag\">wordpress news</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+events\" rel=\"tag\">wordpress events</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+announcements\" rel=\"tag\">wordpress announcements</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+releases\" rel=\"tag\">wordpress releases</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+plugins\" rel=\"tag\">wordpress plugins</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+themes\" rel=\"tag\">wordpress themes</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+community\" rel=\"tag\">wordpress community</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordcamp\" rel=\"tag\">wordcamp</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+meetup\" rel=\"tag\">wordpress meetup</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=help+with+wordpress\" rel=\"tag\">help with wordpress</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+tips\" rel=\"tag\">wordpress tips</a> </p>\n<p><a href=\"http://lorelle.wordpress.com/feed/\" title=\"Feed on Lorelle on WordPress\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/02/rss.png\" alt=\"Feed on Lorelle on WordPress\" /></a> <a href=\"http://lorelle.wordpress.com/feed/\" title=\"Feed on Lorelle on WordPress\">Subscribe</a>  <a href=\"http://feeds.feedburner.com/LorelleOnWordPress\" title=\"Feedburner Lorelle on WordPress Feed\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/04/feedburnericon.gif\" alt=\"Feedburner icon\" />Via Feedburner</a>  <a href=\"http://www.feedblitz.com/f/?Sub=182399\" title=\"Lorelle on WordPress - full site feed email subscription\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/03/email.gif\" alt=\"\" />Subscribe by Email</a> <a href=\"http://lorelle.wordpress.com/\" title=\"Visit Lorelle on WordPress\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2008/03/pointer.gif\" alt=\"\" />Visit</a><br /><a href=\"http://lorelle.wordpress.com/about/\" title=\"Copyright Protected by Brent and Lorelle VanFossen\">Copyright Lorelle VanFossen</a>, the author of <a href=\"http://lorelle.wordpress.com/books/blogging-tips/\" title=\"Blogging Tips Book By Lorelle VanFossen\"><em>Blogging Tips, What Bloggers Won\'t Tell You About Blogging</em></a>.</font></p>\nPosted in WordPress News, WordPress Tips  <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gocomments/lorelle.wordpress.com/3919/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/comments/lorelle.wordpress.com/3919/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godelicious/lorelle.wordpress.com/3919/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/delicious/lorelle.wordpress.com/3919/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gostumble/lorelle.wordpress.com/3919/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/stumble/lorelle.wordpress.com/3919/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godigg/lorelle.wordpress.com/3919/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/digg/lorelle.wordpress.com/3919/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/goreddit/lorelle.wordpress.com/3919/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/reddit/lorelle.wordpress.com/3919/\" /></a> <img alt=\"\" border=\"0\" src=\"http://stats.wordpress.com/b.gif?host=lorelle.wordpress.com&blog=72&post=3919&subd=lorelle&ref=&feed=1\" /></div>\";s:7:\"pubdate\";s:31:\"Fri, 27 Feb 2009 00:37:31 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:17:\"Lorelle VanFossen\";}s:7:\"summary\";s:13503:\"<div class=\"snap_preview\"><br /><p><a href=\"http://lorelle.wordpress.com/tag/wordpress-news/\" title=\"WordPress News\"><img src=\"http://lorelle.files.wordpress.com/2007/01/wpnews1.png\" alt=\"WordPress News\" align=\"right\" /></a>This week&#8217;s <a href=\"http://www.blogherald.com/tag/wordpress-news/\" title=\"Articles on WordPress News on the Blog Herald\" rel=\"tag\">Blog Herald WordPress News</a> covers &#8220;<a href=\"http://www.blogherald.com/2009/02/20/wordpress-news-can-you-spot-a-wordpress-blog-wordpress-28-news-plugin-directory-searchable-iphone-app-tested-and-more/\" title=\"WordPress News: Can You Spot a WordPress Blog? WordPress 2.8 News, Plugin Directory Searchable, iPhone App Tested, and More\">Can You Spot a WordPress Blog? WordPress 2.8 News, Plugin Directory Searchable, iPhone App Tested, and More</a>&#8221; including:</p>\n<blockquote><p>March is WordPress month with more WordCamps and WordPress Meetups than ever. Will April beat it? Lester Chan makes a WordPress PowerPoint Template for presentations. WordPress wins the Best Irish Blogs Awards. FeedBurner transfer deadline is this weekend. Adobe Flash security vulnerability found, impacting many Plugins and WordPress blogs. And a lot more WordPress news coming your way.</p></blockquote>\n<p>The following are a few of the highlights and the WordPress news you can use.</p>\n<h4>FeedBurner Transfer to Google FeedBurner Deadline is Now</h4>\n<p>As <a href=\"http://weblogtoolscollection.com/archives/2009/02/12/feedburner-is-dead-long-live-feedburner/\" title=\"FeedBurner is Dead, Long Live Feedburner\">reported by Weblog Tools Collection&#8217;s Mark Ghosh</a>, FeedBurner has been taken over by Google and FeedBurner users are required to transfer their FeedBurner feeds, or check to ensure they have indeed been transferred, as he found out recently that his weren&#8217;t. <a href=\"http://adsenseforfeeds.blogspot.com/2009/02/more-details-on-moving-to-google.html\" title=\"More details on moving to a Google Account\">Feed must be transferred</a> as of February 28, this weekend, to the &#8220;new&#8221; version of Google FeedBurner. </p>\n<h4>WordPress 2.7.1 Released</h4>\n<p><a href=\"http://wordpress.org/development/2009/02/wordpress-271/\" title=\"WordPress 2.7.1\">WordPress 2.7.1</a>, a maintenance release, is out. If you are using WordPress 2.7, take advantage of the automatic built-in upgrade. If you are not, then consider <a href=\"http://lorelle.wordpress.com/2008/12/11/wordpress-27-upgrade-tips/\" title=\"WordPress 2.7 Upgrade Tips « Lorelle on WordPress\">upgrading to WordPress 2.7</a>. Sixty-five files were modified with 68 bug and feature fixes and improvements, and I covered more details <a href=\"http://lorelle.wordpress.com/2009/02/11/wordpress-271-released/\" title=\"WordPress 2.7.1\">about the release on my blog</a>. </p>\n<h4>WordPress 2.8 News</h4>\n<p><a href=\"http://boren.nu/archives/2009/02/17/wordpress-bits/\" title=\"WordPress Bits\">Ryan Boren reports</a> that development for WordPress 2.8 is underway. Articles worth noting on WordPress 2.8 development include: </p>\n<ul>\n<li><a href=\"http://wpdevel.wordpress.com/2008/12/27/optimizing-script-loading/\" title=\"Optimizing script loading\">Optimizing Script Loading</a></li>\n<li><a href=\"http://wpdevel.wordpress.com/2009/01/07/optimizing-script-loading-part-2/\" title=\"Optimizing script loading part 2\">Optimizing script loading part 2</a></li>\n<li><a href=\"http://wpdevel.wordpress.com/2009/01/15/optimizing-script-loading-implementation/\" title=\"Optimizing script loading, implementation\">Optimizing script loading, implementation</a></li>\n<li><a href=\"http://lesterchan.net/wordpress/2009/01/15/javascript-in-my-plugins/\" title=\"JavaScript In My Plugins\">Preparing for WordPress 2.8: Using JavaScript in WordPress Plugins</a></li>\n<li><a href=\"http://wpengineer.com/change-your-wordpress-theme-on/\" title=\"Change your WordPress Theme on …\">Change your WordPress Theme on …</a></li>\n<li><a href=\"http://wpengineer.com/wordpress-28-body_class-automatic_feed_links/\" title=\"WordPress 2.8 body_class, automatic_feed_links\">WordPress 2.8 body_class, automatic_feed_links</a></li>\n<li><a href=\"http://www.wp-fun.co.uk/2009/02/09/what-a-body/\" title=\"What a body!\">What a body!</a></li>\n</ul>\n<h4>Flash Security Vulnerability Warning</h4>\n<p><a href=\"http://www.f-secure.com/weblog/archives/00001613.html\" title=\"Adobe Flash Vulnerability\">F-Secure reports there is a security vulnerability</a> with Adobe Flash, specifically a <a href=\"http://www.f-secure.com/vulnerabilities/SA200900917\" title=\"Adobe Flash Player remote code execution vulnerability\">Adobe Flash Player remote code execution vulnerability</a> which impacts several versions. Many WordPress Plugins rely upon Flash, as do many WordPress blog. It is recommended you upgrade Adobe Flash accordingly.</p>\n<h3>WordPress Events</h3>\n<p><a href=\"http://lorelle.wordpress.com/?s=wordpress+events\" title=\"WordPress Events\"><img src=\"http://lorelle.files.wordpress.com/2007/01/wpevents.png\" alt=\"WordPress Events\" align=\"right\" /></a>I report on a lot of various WordPress events including WordCamps and WordPress Meetups around the world. Check the <a href=\"http://www.blogherald.com/tag/wordpress-news/\" title=\"Articles on WordPress News on the Blog Herald\" rel=\"tag\">Blog Herald WordPress News</a> for a WordPress event near you. </p>\n<h4>WordCamp Denver News</h4>\n<p><a href=\"http://denver.wordcamp.org/\" title=\"WordCamp Denver\">WordCamp Denver</a> is this weekend and for the most part, is sold out. I&#8217;ll be attending and working with Dave Moyer of the WordCast Podcast to do live podcasting and video interviews during the event. Hope to see you there!</p>\n<h4>WordCamp Toronto Logo Design Contest Winner</h4>\n<p><a href=\"http://phug.ca/wordcamptoronto/index.php/updates/logo-design-contest-winner\" title=\"Toronto WordCamp design contest winner\"><img alt=\"\" src=\"http://phug.ca/wordcamptoronto/wp-content/uploads/2009/02/logo01.png\" title=\"WordCamp Toronto Logo contest winner design\" class=\"alignright\" width=\"290\" height=\"309\" /></a>The <a href=\"http://phug.ca/wordcamptoronto/index.php/updates/logo-design-contest-winner\" title=\"Logo Design Contest Winner\">Logo Design Contest Winner</a> for WordCamp Toronto 2009 is <a href=\"http://iamunr.com/\" title=\"Paul Morrison\">Paul Morrison</a>, a student at Seneca College Digital Media Arts student. This is a great way to involve the community in a WordPress event.</p>\n<h4>WordPress Meetup or WordCamp Near You?</h4>\n<p><strong>February 2009</strong></p>\n<ul>\n<li><a href=\"http://denver.wordcamp.org\" title=\"WordCamp Denver\">WordCamp Denver 2009 - February 28, 2009</a> (<a href=\"http://http//www.facebook.com/profile.php?id=779828054#/group.php?gid=22086243642\" title=\"WordCamp Denver 2009\">Facebook</a>)</li>\n<li><a href=\"http://www.meetup.com/dfwwordpress/calendar/9593871/\" title=\"February Meetup of the DFW WordPress Group\">Dallas/Fort Worth WordPress Meetup - Dallas, Texas - February 28, 2009</a></li>\n<li><a href=\"http://wordpress.meetup.com/184/calendar/9615427/\" title=\"Atlanta WordPress Users Group February Meetup\">Atlanta WordPress Users Group Meetup - Learning WordPress 2.7 - Atlanta, Georgia - February 28, 2009</a></li>\n<li><a href=\"http://www.meetup.com/mywplife/calendar/9593848/\" title=\"The Chicago WordPress February Meetup\">The Chicago WordPress February Meetup - February 28, 2009</a></li>\n</ul>\n<p><strong>March 2009</strong></p>\n<ul>\n<li><a href=\"http://wordpress.meetup.com/173/calendar/9823503/\" title=\"So I want to install WordPress on my own domain—what do I do?\">Austin, Texas - Installing Full Version of WordPress - March 3, 2009</a></li>\n<li><a href=\"http://www.meetup.com/The-New-Jersey-WordPress-Meetup-Group/calendar/9675967/\" title=\"The New Jersey WordPress March Meetup\">New Jersey - The New Jersey WordPress March Meetup - March 4, 2009</a></li>\n<li><a href=\"http://www.meetup.com/gulf-coast-wordpress/calendar/9684749/\" title=\"Gulf Coast WordPress/Blogger March Meetup\">Mobile, Alabama - Gulf Coast WordPress/Blogger WordPress Meetup - March 5, 2009</a></li>\n<li><a href=\"http://www.meetup.com/LasVegasWordPress/calendar/9678813/\" title=\"Las Vegas WordPress Meetup\">Las Vegas WordPress Meetup - March 5, 2009</a></li>\n<li><a href=\"http://upcoming.yahoo.com/event/1808383/\" title=\"Mar 8, 2009: Los Angeles WordPress Users Group at Philippe\'s French Dip\">Los Angeles WordPress Users Group - March 8, 2009</a></li>\n<li><a href=\"http://upcoming.yahoo.com/event/1897209/\" title=\"Mar 15, 2009: Southern California WordPress Meetup - Long Beach at The Grounds Bakery Cafe\">Southern California WordPress Meetup - Long Beach - March 15, 2009</a></li>\n<li><a href=\"http://www.meetup.com/SF-WordPress-Users/calendar/9716946/\" title=\"South Florida WordPress March Meetup User Group\">Ft Lauderdale - South Florida WordPress March Meetup User Group - March 11, 2009</a></li>\n<li><a href=\"http://www.meetup.com/LasVegasWordPress/calendar/9678814/\" title=\"Las Vegas WordPress Meetup\">Las Vegas WordPress Meetup - March 12, 2009</a></li>\n<li><a title=\"SXSWeek 2009\" href=\"http://sxsw.com/\">Austin, Texas - SXSW 2009 - March 13-22, 2009</a></li>\n<li><a href=\"http://www.meetup.com/The-Scottsdale-WordPress-Meetup-Group/calendar/9815224/\" title=\"The Scottsdale WordPress March Meetup\">Arizona - The Scottsdale WordPress March Meetup - March 15, 2009</a></li>\n</ul>\n<p>If you are putting together a WordPress event, please <a href=\"mailto:&#x6c;&#111;&#114;&#x65;&#x6c;&#108;&#101;&#x6f;&#x6e;&#119;&#111;&#114;&#100;&#112;&#x72;&#101;&#x73;&#x73;&#64;&#103;&#109;&#x61;&#x69;&#x6c;&#46;&#x63;&#111;&#x6d;\">email</a> me so I can publicize it here. If there is a WordCamp near you, go. If you are interested in setting up a WordCamp, stay tuned for news and information on to bring a WordCamp event near you.</p>\n<p><img src=\"http://lorelle.files.wordpress.com/2006/08/sig.gif\" alt=\"\" /><br />\n<hr />\n<p><font size=\"-1\"><b>Site Search Tags:</b> <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+news\" rel=\"tag\">wordpress news</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+events\" rel=\"tag\">wordpress events</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+announcements\" rel=\"tag\">wordpress announcements</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+releases\" rel=\"tag\">wordpress releases</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+plugins\" rel=\"tag\">wordpress plugins</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+themes\" rel=\"tag\">wordpress themes</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+community\" rel=\"tag\">wordpress community</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordcamp\" rel=\"tag\">wordcamp</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+meetup\" rel=\"tag\">wordpress meetup</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=help+with+wordpress\" rel=\"tag\">help with wordpress</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+tips\" rel=\"tag\">wordpress tips</a> </p>\n<p><a href=\"http://lorelle.wordpress.com/feed/\" title=\"Feed on Lorelle on WordPress\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/02/rss.png\" alt=\"Feed on Lorelle on WordPress\" /></a> <a href=\"http://lorelle.wordpress.com/feed/\" title=\"Feed on Lorelle on WordPress\">Subscribe</a>  <a href=\"http://feeds.feedburner.com/LorelleOnWordPress\" title=\"Feedburner Lorelle on WordPress Feed\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/04/feedburnericon.gif\" alt=\"Feedburner icon\" />Via Feedburner</a>  <a href=\"http://www.feedblitz.com/f/?Sub=182399\" title=\"Lorelle on WordPress - full site feed email subscription\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/03/email.gif\" alt=\"\" />Subscribe by Email</a> <a href=\"http://lorelle.wordpress.com/\" title=\"Visit Lorelle on WordPress\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2008/03/pointer.gif\" alt=\"\" />Visit</a><br /><a href=\"http://lorelle.wordpress.com/about/\" title=\"Copyright Protected by Brent and Lorelle VanFossen\">Copyright Lorelle VanFossen</a>, the author of <a href=\"http://lorelle.wordpress.com/books/blogging-tips/\" title=\"Blogging Tips Book By Lorelle VanFossen\"><em>Blogging Tips, What Bloggers Won\'t Tell You About Blogging</em></a>.</font></p>\nPosted in WordPress News, WordPress Tips  <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gocomments/lorelle.wordpress.com/3919/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/comments/lorelle.wordpress.com/3919/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godelicious/lorelle.wordpress.com/3919/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/delicious/lorelle.wordpress.com/3919/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gostumble/lorelle.wordpress.com/3919/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/stumble/lorelle.wordpress.com/3919/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godigg/lorelle.wordpress.com/3919/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/digg/lorelle.wordpress.com/3919/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/goreddit/lorelle.wordpress.com/3919/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/reddit/lorelle.wordpress.com/3919/\" /></a> <img alt=\"\" border=\"0\" src=\"http://stats.wordpress.com/b.gif?host=lorelle.wordpress.com&blog=72&post=3919&subd=lorelle&ref=&feed=1\" /></div>\";}i:10;a:7:{s:5:\"title\";s:34:\"Dev Blog: Change the Web Challenge\";s:4:\"guid\";s:39:\"http://wordpress.org/development/?p=563\";s:4:\"link\";s:66:\"http://wordpress.org/development/2009/02/change-the-web-challenge/\";s:11:\"description\";s:1584:\"<p><a href=\"http://www.socialactions.com/changetheweb\"><img class=\"alignleft\" align=\"left\" title=\"Change the Web Challenge Logo\" src=\"http://wpdotorg.wordpress.com/files/2009/02/change-the-web-challenge-logo-sm.gif\" alt=\"\" width=\"174\" height=\"240\" /></a>We&#8217;re excited to be part of the <a href=\"http://www.socialactions.com/changetheweb\">Change the Web Challenge</a>.</p>\n<p>Basically, the contest is to create a plugin, widget, mash up, hack, or other variety of web application that helps people find and share opportunities to take action. The grand prize is 50 benjis, and the best WordPress plugin will also be featured in the <a href=\"http://wordpress.org/extend/plugins/\">Plugin Directory</a>. But the real prize is spreading a little more love in the world.</p>\n<p><a href=\"http://www.socialactions.com/changetheweb\">Click here</a> for all the details.</p>\n<p>&#8220;<a href=\"http://codex.wordpress.org/Writing_a_Plugin\">Writing a Plugin</a>&#8221; in the WordPress Codex is where I got started when I needed to get hooked in to WordPress. Others might like to grab one of the over 4,000 <a href=\"http://wordpress.org/extend/plugins/\">open source WordPress plugins</a> and tweak the source. If in need of a little help, the <a href=\"http://wordpress.org/support/forum/10\">Plugins and Hacks</a> forum is full of friends to assist you wrap your head around the code or debug a problem. Social Actions also has provided some <a href=\"http://www.socialactions.com/developers\">developer resources</a>.</p>\n<p>Let&#8217;s show them how we change the web the WordPress way!</p>\";s:7:\"pubdate\";s:31:\"Thu, 26 Feb 2009 23:35:51 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:5:\"lloyd\";}s:7:\"summary\";s:1584:\"<p><a href=\"http://www.socialactions.com/changetheweb\"><img class=\"alignleft\" align=\"left\" title=\"Change the Web Challenge Logo\" src=\"http://wpdotorg.wordpress.com/files/2009/02/change-the-web-challenge-logo-sm.gif\" alt=\"\" width=\"174\" height=\"240\" /></a>We&#8217;re excited to be part of the <a href=\"http://www.socialactions.com/changetheweb\">Change the Web Challenge</a>.</p>\n<p>Basically, the contest is to create a plugin, widget, mash up, hack, or other variety of web application that helps people find and share opportunities to take action. The grand prize is 50 benjis, and the best WordPress plugin will also be featured in the <a href=\"http://wordpress.org/extend/plugins/\">Plugin Directory</a>. But the real prize is spreading a little more love in the world.</p>\n<p><a href=\"http://www.socialactions.com/changetheweb\">Click here</a> for all the details.</p>\n<p>&#8220;<a href=\"http://codex.wordpress.org/Writing_a_Plugin\">Writing a Plugin</a>&#8221; in the WordPress Codex is where I got started when I needed to get hooked in to WordPress. Others might like to grab one of the over 4,000 <a href=\"http://wordpress.org/extend/plugins/\">open source WordPress plugins</a> and tweak the source. If in need of a little help, the <a href=\"http://wordpress.org/support/forum/10\">Plugins and Hacks</a> forum is full of friends to assist you wrap your head around the code or debug a problem. Social Actions also has provided some <a href=\"http://www.socialactions.com/developers\">developer resources</a>.</p>\n<p>Let&#8217;s show them how we change the web the WordPress way!</p>\";}i:11;a:7:{s:5:\"title\";s:59:\"Weblog Tools Collection: WordPress Theme Releases for 02/26\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=5234\";s:4:\"link\";s:87:\"http://weblogtoolscollection.com/archives/2009/02/26/wordpress-theme-releases-for-0226/\";s:11:\"description\";s:2057:\"<p><a href=\"http://the-cloisters.net/blog/wordpress-themes/soho-serenity-theme/\"><strong>Soho Serenity</strong></a></p>\n<p><a href=\"http://the-cloisters.net/themedemos/?SelectedTheme=Soho+Serenity\"><img title=\"Soho Serenity\" src=\"http://weblogtoolscollection.com/b2-img/2009/02/sohoserenity.jpg\" alt=\"Soho Serenity\" width=\"150\" height=\"89\" /></a></p>\n<p>It&#8217;s a Multi Column (1 sidebar, 2 main content colums, 2 right hand sections and 3 footer sections all widgetized) fixed width theme loosely inspired by the art galleries of Soho New York and is perfect for a showcase/portfolio or scrapbook type site. It features an author info page and gravatars along with Custom Archives, Sitemap, Blog Post and full width No Sidebars page templates.</p>\n<p><a href=\"http://3oneseven.com/29/newspaper-style/\"><strong>BlogTimes</strong></a></p>\n<p><img title=\"Blog Times\" src=\"http://weblogtoolscollection.com/b2-img/2009/02/blogtimes.png\" alt=\"Blog Times\" width=\"150\" height=\"127\" /></p>\n<p>The BlogTimes WP theme includes an magazine style layout, twelve recent posts and an options panel for the front area, that gives you full control over the frontpage content.</p>\n<p><a href=\"http://www.wpcontempo.com/new-free-wordpress-theme-angley-theme/\"><strong>Angley</strong></a></p>\n<p><img title=\"Angley\" src=\"http://weblogtoolscollection.com/b2-img/2009/02/angley.gif\" alt=\"Angley\" width=\"150\" height=\"112\" /></p>\n<p>2 Column, advertisement ready theme with dynamic page navigation and included PSD.</p>\n<p><a href=\"http://www.wppro.org/2009/01/10/aligned-theme-for-wordpress/\"><strong>Aligned</strong></a></p>\n<p><a href=\"http://www.wppro.org/demo/?wptheme=Aligned\"><img title=\"Aligned\" src=\"http://weblogtoolscollection.com/b2-img/2009/02/aligned.jpg\" alt=\"Aligned\" width=\"100\" height=\"150\" /></a></p>\n<p>Fixed width, Two column, Widget ready theme with rotating headers, placement for Google Adsense and 125&#215;125 ads in sidebar</p>\n<p>Theme author? <a href=\"http://weblogtoolscollection.com/submit-news/\">Submit your theme</a> for our daily releases.</p>\";s:7:\"pubdate\";s:31:\"Thu, 26 Feb 2009 17:39:08 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:2057:\"<p><a href=\"http://the-cloisters.net/blog/wordpress-themes/soho-serenity-theme/\"><strong>Soho Serenity</strong></a></p>\n<p><a href=\"http://the-cloisters.net/themedemos/?SelectedTheme=Soho+Serenity\"><img title=\"Soho Serenity\" src=\"http://weblogtoolscollection.com/b2-img/2009/02/sohoserenity.jpg\" alt=\"Soho Serenity\" width=\"150\" height=\"89\" /></a></p>\n<p>It&#8217;s a Multi Column (1 sidebar, 2 main content colums, 2 right hand sections and 3 footer sections all widgetized) fixed width theme loosely inspired by the art galleries of Soho New York and is perfect for a showcase/portfolio or scrapbook type site. It features an author info page and gravatars along with Custom Archives, Sitemap, Blog Post and full width No Sidebars page templates.</p>\n<p><a href=\"http://3oneseven.com/29/newspaper-style/\"><strong>BlogTimes</strong></a></p>\n<p><img title=\"Blog Times\" src=\"http://weblogtoolscollection.com/b2-img/2009/02/blogtimes.png\" alt=\"Blog Times\" width=\"150\" height=\"127\" /></p>\n<p>The BlogTimes WP theme includes an magazine style layout, twelve recent posts and an options panel for the front area, that gives you full control over the frontpage content.</p>\n<p><a href=\"http://www.wpcontempo.com/new-free-wordpress-theme-angley-theme/\"><strong>Angley</strong></a></p>\n<p><img title=\"Angley\" src=\"http://weblogtoolscollection.com/b2-img/2009/02/angley.gif\" alt=\"Angley\" width=\"150\" height=\"112\" /></p>\n<p>2 Column, advertisement ready theme with dynamic page navigation and included PSD.</p>\n<p><a href=\"http://www.wppro.org/2009/01/10/aligned-theme-for-wordpress/\"><strong>Aligned</strong></a></p>\n<p><a href=\"http://www.wppro.org/demo/?wptheme=Aligned\"><img title=\"Aligned\" src=\"http://weblogtoolscollection.com/b2-img/2009/02/aligned.jpg\" alt=\"Aligned\" width=\"100\" height=\"150\" /></a></p>\n<p>Fixed width, Two column, Widget ready theme with rotating headers, placement for Google Adsense and 125&#215;125 ads in sidebar</p>\n<p>Theme author? <a href=\"http://weblogtoolscollection.com/submit-news/\">Submit your theme</a> for our daily releases.</p>\";}i:12;a:7:{s:5:\"title\";s:29:\"Donncha: WP Super Cache 0.9.1\";s:4:\"guid\";s:29:\"http://ocaoimh.ie/?p=89494613\";s:4:\"link\";s:48:\"http://ocaoimh.ie/2009/02/26/wp-super-cache-091/\";s:11:\"description\";s:3847:\"<p><a href=\"http://ocaoimh.ie/wp-super-cache/\">WP Super Cache</a> version 0.9.1 is now <a href=\"http://wordpress.org/extend/plugins/wp-super-cache/\">available</a>. WP Super Cache is a page caching plugin for WordPress that will significantly speed up your website.</p>\n<p>Major changes under the hood in this release, and many bugfixes:</p>\n<ul>\n<li> If your blog is installed in a folder then compare the mod_rewrite rules in your .htaccess with those on the admin page. I fixed a bug in how those are generated.</li>\n<li>Out goes the shutdown function the plugin relied on for years (going back to the days of wp-cache), and in comes plain old output buffering on it&#8217;s own.</li>\n<li> If you&#8217;ve had problems clearing the cache on your blog it could be because wp-cron isn&#8217;t firing. I&#8217;ve added checks for that. Joost helped me debug that and he <a href=\"http://yoast.com/wp-cron-issues/\">blogged about it</a> too. You&#8217;ll get a nice warning message if those checks fail.</li>\n<li> If after all that, your cache still doesn&#8217;t clear, add <code>$wp_cache_shutdown_gc = 1;</code> to wp-content/wp-cache-config.php to clear the cache at the end of pageload instead of by wp-cron. It will slow down page generation for a tiny number of your users though.</li>\n<li> The Last and Next garbage collection times are now in the timezone selected for your blog.</li>\n<li>Added an admin notice on the plugin page to warn that caching has to be enabled. A warning is shown below the plugin activation row too.</li>\n<li> If your site runs on a Windows server, I fixed a small problem with slashes and creating the config file.</li>\n<li> The plugin created empty supercache folders, but that&#8217;s fixed now.</li>\n<li>Bad Behaviour support seems to work nicely now!</li>\n<li> You can now relocate the supercache plugins folder. See $wp_cache_plugins_dir in wp-cache-config-sample.php.</li>\n<li> I added 2 new filters: wp_cache_served_cache_file in wp-cache-phase1.php (BB uses this) and wp_cache_file_contents in wp-cache-phase2.php where you can filter the contents of the newly created cache before it&#8217;s written out to a file.</li>\n<li> The readme.txt has been updated too warning about using NFS to store the cache folder, solving wp-cron problems, added the list of Apache modules required for expired pages to really expire in the browser cache.</li>\n</ul>\n<p>I also added a donation link in the readme.txt and on the admin page. You can hide it with the click of a button but if you&#8217;re feeling generous, I&#8217;d appreciate a donation.<br />\nI don&#8217;t expect many donations, that&#8217;s how these things work, but if you tell me your site does 100,000 page views a day and you couldn&#8217;t live without caching I might be slightly annoyed if you come looking for free support.</p>\n<p>PS. Looks like Bad Behavior support is broken because the docs on the BB site were a little misleading and I don&#8217;t use the plugin. Grab <a href=\"http://svn.wp-plugins.org/wp-super-cache/trunk/plugins/badbehaviour.php\">badbehaviour.php</a> and copy into plugins/wp-super-cache/plugins/ overwriting the file of the same name in that folder.</p>\n<p><img src=\"http://ocaoimh.ie/?voyeur=1\" /></p><p><strong>Related Posts</strong><ul><li><a href=\"http://ocaoimh.ie/2008/10/24/wp-super-cache-084-the-garbage-collector/\" rel=\"bookmark\" title=\"Permanent Link: WP Super Cache 0.8.4, the garbage collector\">WP Super Cache 0.8.4, the garbage collector</a></li><li><a href=\"http://ocaoimh.ie/2009/01/09/wp-super-cache-087/\" rel=\"bookmark\" title=\"Permanent Link: WP Super Cache 0.8.7\">WP Super Cache 0.8.7</a></li><li><a href=\"http://ocaoimh.ie/2008/10/08/wp-super-cache-083-speedy/\" rel=\"bookmark\" title=\"Permanent Link: WP Super Cache 0.8.3 &#8220;Speedy&#8221;\">WP Super Cache 0.8.3 &#8220;Speedy&#8221;</a></li></ul></p>\";s:7:\"pubdate\";s:31:\"Thu, 26 Feb 2009 13:13:57 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:7:\"Donncha\";}s:7:\"summary\";s:3847:\"<p><a href=\"http://ocaoimh.ie/wp-super-cache/\">WP Super Cache</a> version 0.9.1 is now <a href=\"http://wordpress.org/extend/plugins/wp-super-cache/\">available</a>. WP Super Cache is a page caching plugin for WordPress that will significantly speed up your website.</p>\n<p>Major changes under the hood in this release, and many bugfixes:</p>\n<ul>\n<li> If your blog is installed in a folder then compare the mod_rewrite rules in your .htaccess with those on the admin page. I fixed a bug in how those are generated.</li>\n<li>Out goes the shutdown function the plugin relied on for years (going back to the days of wp-cache), and in comes plain old output buffering on it&#8217;s own.</li>\n<li> If you&#8217;ve had problems clearing the cache on your blog it could be because wp-cron isn&#8217;t firing. I&#8217;ve added checks for that. Joost helped me debug that and he <a href=\"http://yoast.com/wp-cron-issues/\">blogged about it</a> too. You&#8217;ll get a nice warning message if those checks fail.</li>\n<li> If after all that, your cache still doesn&#8217;t clear, add <code>$wp_cache_shutdown_gc = 1;</code> to wp-content/wp-cache-config.php to clear the cache at the end of pageload instead of by wp-cron. It will slow down page generation for a tiny number of your users though.</li>\n<li> The Last and Next garbage collection times are now in the timezone selected for your blog.</li>\n<li>Added an admin notice on the plugin page to warn that caching has to be enabled. A warning is shown below the plugin activation row too.</li>\n<li> If your site runs on a Windows server, I fixed a small problem with slashes and creating the config file.</li>\n<li> The plugin created empty supercache folders, but that&#8217;s fixed now.</li>\n<li>Bad Behaviour support seems to work nicely now!</li>\n<li> You can now relocate the supercache plugins folder. See $wp_cache_plugins_dir in wp-cache-config-sample.php.</li>\n<li> I added 2 new filters: wp_cache_served_cache_file in wp-cache-phase1.php (BB uses this) and wp_cache_file_contents in wp-cache-phase2.php where you can filter the contents of the newly created cache before it&#8217;s written out to a file.</li>\n<li> The readme.txt has been updated too warning about using NFS to store the cache folder, solving wp-cron problems, added the list of Apache modules required for expired pages to really expire in the browser cache.</li>\n</ul>\n<p>I also added a donation link in the readme.txt and on the admin page. You can hide it with the click of a button but if you&#8217;re feeling generous, I&#8217;d appreciate a donation.<br />\nI don&#8217;t expect many donations, that&#8217;s how these things work, but if you tell me your site does 100,000 page views a day and you couldn&#8217;t live without caching I might be slightly annoyed if you come looking for free support.</p>\n<p>PS. Looks like Bad Behavior support is broken because the docs on the BB site were a little misleading and I don&#8217;t use the plugin. Grab <a href=\"http://svn.wp-plugins.org/wp-super-cache/trunk/plugins/badbehaviour.php\">badbehaviour.php</a> and copy into plugins/wp-super-cache/plugins/ overwriting the file of the same name in that folder.</p>\n<p><img src=\"http://ocaoimh.ie/?voyeur=1\" /></p><p><strong>Related Posts</strong><ul><li><a href=\"http://ocaoimh.ie/2008/10/24/wp-super-cache-084-the-garbage-collector/\" rel=\"bookmark\" title=\"Permanent Link: WP Super Cache 0.8.4, the garbage collector\">WP Super Cache 0.8.4, the garbage collector</a></li><li><a href=\"http://ocaoimh.ie/2009/01/09/wp-super-cache-087/\" rel=\"bookmark\" title=\"Permanent Link: WP Super Cache 0.8.7\">WP Super Cache 0.8.7</a></li><li><a href=\"http://ocaoimh.ie/2008/10/08/wp-super-cache-083-speedy/\" rel=\"bookmark\" title=\"Permanent Link: WP Super Cache 0.8.3 &#8220;Speedy&#8221;\">WP Super Cache 0.8.3 &#8220;Speedy&#8221;</a></li></ul></p>\";}i:13;a:7:{s:5:\"title\";s:47:\"Alex King: Carrington JAM (Just Add Markup) 1.0\";s:4:\"guid\";s:53:\"http://alexking.org/blog/2009/02/25/carrington-jam-10\";s:4:\"link\";s:53:\"http://alexking.org/blog/2009/02/25/carrington-jam-10\";s:11:\"description\";s:1862:\"<p>We&#8217;ve released a new <a href=\"http://carringtontheme.com\">Carrington</a> theme: <a href=\"http://carringtontheme.com/2009/02/carrington-jam-10/\">Carrington JAM</a></p>\n<p>JAM stands for Just Add Markup. We created JAM as a &#8220;developer outline&#8221; for building a theme on the Carrington CMS theme framework.</p>\n<p>It&#8217;s basically a completely stripped down skeleton (doesn&#8217;t even have XHTML) with placeholder <a href=\"http://wordpress.org/\" rel=\"external\">WordPress</a> template tags where appropriate. It functions enough that you can see it working, but is obviously not intended for use in it&#8217;s current state. Instead, you can take your site design/markup and add it in where appropriate to take advantage of the Carrington CMS theme framework features.<sup><a href=\"http://alexking.org/blog/feed?cat=16#fn1235584274567n\" id=\"fn1235584274567\" class=\"footnote\">1</a></sup></p>\n<p>This might be something you want to download and bring with you if you are going to be attending my presentation at <a href=\"http://denver.wordcamp.org\" rel=\"external\">WordCamp Denver</a> this weekend (and want to code along with the examples).</p>\n<p>Get more details and stay up with the latest Carrington news on the <a href=\"http://carringtontheme.com\">Carrington CMS Theme Framework for WordPress</a> web site.</p>\n<ol class=\"footnotes\">\n<li id=\"fn1235584274567n\">The Carrington CMS theme framework auto-selects templates based on naming conventions, etc. - drastically reducing the logic needed in your theme. [<a href=\"http://alexking.org/blog/feed?cat=16#fn1235584274567\">back</a>]</li>\n</ol>\n<p><a href=\"http://sharethis.com/item?&wp=2.2.3&amp;publisher=a1583af8-28eb-4210-97bd-2bb5c02bc265&amp;title=Carrington+JAM+%28Just+Add+Markup%29+1.0&amp;url=http%3A%2F%2Falexking.org%2Fblog%2F2009%2F02%2F25%2Fcarrington-jam-10\">ShareThis</a></p>\";s:7:\"pubdate\";s:31:\"Wed, 25 Feb 2009 17:51:50 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Alex\";}s:7:\"summary\";s:1862:\"<p>We&#8217;ve released a new <a href=\"http://carringtontheme.com\">Carrington</a> theme: <a href=\"http://carringtontheme.com/2009/02/carrington-jam-10/\">Carrington JAM</a></p>\n<p>JAM stands for Just Add Markup. We created JAM as a &#8220;developer outline&#8221; for building a theme on the Carrington CMS theme framework.</p>\n<p>It&#8217;s basically a completely stripped down skeleton (doesn&#8217;t even have XHTML) with placeholder <a href=\"http://wordpress.org/\" rel=\"external\">WordPress</a> template tags where appropriate. It functions enough that you can see it working, but is obviously not intended for use in it&#8217;s current state. Instead, you can take your site design/markup and add it in where appropriate to take advantage of the Carrington CMS theme framework features.<sup><a href=\"http://alexking.org/blog/feed?cat=16#fn1235584274567n\" id=\"fn1235584274567\" class=\"footnote\">1</a></sup></p>\n<p>This might be something you want to download and bring with you if you are going to be attending my presentation at <a href=\"http://denver.wordcamp.org\" rel=\"external\">WordCamp Denver</a> this weekend (and want to code along with the examples).</p>\n<p>Get more details and stay up with the latest Carrington news on the <a href=\"http://carringtontheme.com\">Carrington CMS Theme Framework for WordPress</a> web site.</p>\n<ol class=\"footnotes\">\n<li id=\"fn1235584274567n\">The Carrington CMS theme framework auto-selects templates based on naming conventions, etc. - drastically reducing the logic needed in your theme. [<a href=\"http://alexking.org/blog/feed?cat=16#fn1235584274567\">back</a>]</li>\n</ol>\n<p><a href=\"http://sharethis.com/item?&wp=2.2.3&amp;publisher=a1583af8-28eb-4210-97bd-2bb5c02bc265&amp;title=Carrington+JAM+%28Just+Add+Markup%29+1.0&amp;url=http%3A%2F%2Falexking.org%2Fblog%2F2009%2F02%2F25%2Fcarrington-jam-10\">ShareThis</a></p>\";}i:14;a:7:{s:5:\"title\";s:60:\"Weblog Tools Collection: WordPress Plugin Releases for 02/25\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=5226\";s:4:\"link\";s:88:\"http://weblogtoolscollection.com/archives/2009/02/25/wordpress-plugin-releases-for-0225/\";s:11:\"description\";s:3782:\"<h3>New Plugins</h3>\n<p><a href=\"http://blog.ftwr.co.uk/wordpress/query-child-of-page/\">PJW Query Child Of</a></p>\n<p>Allows you to use query_posts to list the children of a page.</p>\n<p><a href=\"http://www.christian-jokes.net/tools/wordpress.aspx\">Christian Jokes</a></p>\n<p>Christian Jokes widget will fetch the latest or random joke from christian-jokes.net website, and display them on your blog.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/starbox-voting/\">wp-starbox</a></p>\n<p>This plugin adds voting functionality for posts. Visitors can vote for the post and against.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/my-cdn/\">My CDN</a></p>\n<p>Helps you offloading javascript, css and theme files to your own CDN network. This plugin only handles url rewriting not actual file transferring.</p>\n<p><a href=\"http://www.ericjohnolson.com/blog/2009/2/23/wordpress-eastimated-reading-time-plugin/\">Estimated Reading Time</a></p>\n<p>This plugin estimates the time it would take for a slightly below average reader to a slightly above average reader to read your post.</p>\n<p><a href=\"http://blog.ftwr.co.uk/wordpress/page-excerpt/\">PJW Page Excerpt</a></p>\n<p>Allows you to edit excerpts for Pages.</p>\n<p><a href=\"http://w-shadow.com/blog/2008/12/31/aligning-images-in-rss-feeds/\">Align RSS Images</a></p>\n<p>Scans your RSS feed and ensures that every image has the correct alignment and margin settings.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/30boxes-calendar-widget-shortcode/\">30bwidget</a></p>\n<p>A simple plugin that provides shortcodes and sidebar widgets to integrate 30Boxes.com calendars within your Blog.</p>\n<p><a href=\"http://playground.ebiene.de/1577/antivirus-wordpress-plugin/\">AntiVirus</a></p>\n<p>AntiVirus for WordPress is a smart and effective solution to protect your blog against exploits and spam injections. <em>Page in German</em></p>\n<h3>Updated Plugins</h3>\n<p><a href=\"http://kempwire.com/wordpress-users-plugin\">WordPress Users</a></p>\n<p>Display your WordPress users and their profiles in an index on your site.</p>\n<p><a href=\"http://wordpress.softwud.com/\">Page Blocks</a></p>\n<p>This plugin extends WordPress pages by allowing widgets to be placed above and below the page content reducing the need to code custom page templates.</p>\n<p><a href=\"http://kempwire.com/wordpress-ultimate-noindex-nofollow-plugin\">Ultimate Noindex Nofollow Tool</a></p>\n<p>Improves your blog&#8217;s search engine optimization by &#8220;noindexing&#8221; pages you choose.</p>\n<p><a href=\"http://www.bebl.eu/zeug/hyphenator\">Hyphenator</a></p>\n<p>Soft hyphen are automatically added in the content for nicer automatic word wrap. Particularly suitable for justification. Uses Hyphenator.js.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/wp-favorite-posts/\">WP Favorite Posts</a></p>\n<p>Allows visitors to add favorite posts. This plugin uses cookies for saving data so unregistered users can favorite a post.</p>\n<p><a href=\"http://kaltura.org/community/viewtopic.php?f=4&amp;t=3\">All in One Video Pack</a></p>\n<p>Easily add full video capabilities to your blog.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/disqus-comment-system/\">DISQUS Comment System</a></p>\n<p>The DISQUS comment system replaces your WordPress comment system with your comments hosted and powered by DISQUS.</p>\n<p><a href=\"http://co.deme.me/projects/flickr-gallery/\">Flickr Gallery</a></p>\n<p>Quickly and easily add Flickr galleries, photos, and even custom search results into your WordPress pages and posts.</p>\n<p><a href=\"http://kmorey.net/downloads/advanced-tagline-wordpress-plugin/\">Advanced Tagline</a></p>\n<p>Advanced Tagline gives the option to have multiple taglines for your blog and display them at random or sequentially with each page view</p>\";s:7:\"pubdate\";s:31:\"Wed, 25 Feb 2009 13:19:48 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:3782:\"<h3>New Plugins</h3>\n<p><a href=\"http://blog.ftwr.co.uk/wordpress/query-child-of-page/\">PJW Query Child Of</a></p>\n<p>Allows you to use query_posts to list the children of a page.</p>\n<p><a href=\"http://www.christian-jokes.net/tools/wordpress.aspx\">Christian Jokes</a></p>\n<p>Christian Jokes widget will fetch the latest or random joke from christian-jokes.net website, and display them on your blog.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/starbox-voting/\">wp-starbox</a></p>\n<p>This plugin adds voting functionality for posts. Visitors can vote for the post and against.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/my-cdn/\">My CDN</a></p>\n<p>Helps you offloading javascript, css and theme files to your own CDN network. This plugin only handles url rewriting not actual file transferring.</p>\n<p><a href=\"http://www.ericjohnolson.com/blog/2009/2/23/wordpress-eastimated-reading-time-plugin/\">Estimated Reading Time</a></p>\n<p>This plugin estimates the time it would take for a slightly below average reader to a slightly above average reader to read your post.</p>\n<p><a href=\"http://blog.ftwr.co.uk/wordpress/page-excerpt/\">PJW Page Excerpt</a></p>\n<p>Allows you to edit excerpts for Pages.</p>\n<p><a href=\"http://w-shadow.com/blog/2008/12/31/aligning-images-in-rss-feeds/\">Align RSS Images</a></p>\n<p>Scans your RSS feed and ensures that every image has the correct alignment and margin settings.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/30boxes-calendar-widget-shortcode/\">30bwidget</a></p>\n<p>A simple plugin that provides shortcodes and sidebar widgets to integrate 30Boxes.com calendars within your Blog.</p>\n<p><a href=\"http://playground.ebiene.de/1577/antivirus-wordpress-plugin/\">AntiVirus</a></p>\n<p>AntiVirus for WordPress is a smart and effective solution to protect your blog against exploits and spam injections. <em>Page in German</em></p>\n<h3>Updated Plugins</h3>\n<p><a href=\"http://kempwire.com/wordpress-users-plugin\">WordPress Users</a></p>\n<p>Display your WordPress users and their profiles in an index on your site.</p>\n<p><a href=\"http://wordpress.softwud.com/\">Page Blocks</a></p>\n<p>This plugin extends WordPress pages by allowing widgets to be placed above and below the page content reducing the need to code custom page templates.</p>\n<p><a href=\"http://kempwire.com/wordpress-ultimate-noindex-nofollow-plugin\">Ultimate Noindex Nofollow Tool</a></p>\n<p>Improves your blog&#8217;s search engine optimization by &#8220;noindexing&#8221; pages you choose.</p>\n<p><a href=\"http://www.bebl.eu/zeug/hyphenator\">Hyphenator</a></p>\n<p>Soft hyphen are automatically added in the content for nicer automatic word wrap. Particularly suitable for justification. Uses Hyphenator.js.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/wp-favorite-posts/\">WP Favorite Posts</a></p>\n<p>Allows visitors to add favorite posts. This plugin uses cookies for saving data so unregistered users can favorite a post.</p>\n<p><a href=\"http://kaltura.org/community/viewtopic.php?f=4&amp;t=3\">All in One Video Pack</a></p>\n<p>Easily add full video capabilities to your blog.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/disqus-comment-system/\">DISQUS Comment System</a></p>\n<p>The DISQUS comment system replaces your WordPress comment system with your comments hosted and powered by DISQUS.</p>\n<p><a href=\"http://co.deme.me/projects/flickr-gallery/\">Flickr Gallery</a></p>\n<p>Quickly and easily add Flickr galleries, photos, and even custom search results into your WordPress pages and posts.</p>\n<p><a href=\"http://kmorey.net/downloads/advanced-tagline-wordpress-plugin/\">Advanced Tagline</a></p>\n<p>Advanced Tagline gives the option to have multiple taglines for your blog and display them at random or sequentially with each page view</p>\";}i:15;a:7:{s:5:\"title\";s:39:\"Lloyd: Learning by doing something else\";s:4:\"guid\";s:30:\"http://foolswisdom.com/?p=1644\";s:4:\"link\";s:56:\"http://foolswisdom.com/learning-by-doing-something-else/\";s:11:\"description\";s:1406:\"<div class=\"wp-caption alignright\"><a href=\"http://flickr.com/photos/bootbearwdc/515399703/\"><img title=\"Dr. Andrei Dmitrievich Sakharov\" src=\"http://farm1.static.flickr.com/211/515399703_72ece0c2d1_m.jpg\" alt=\"Dr. Andrei Dmitrievich Sakharov\" width=\"171\" height=\"240\" /></a><p class=\"wp-caption-text\">Dr. Andrei Dmitrievich Sakharov Sculpture photo by Flickr user dbking. Andrei Dmitrievich Sakharov (May 21, 1921 – December 14, 1989) was an eminent Soviet nuclear physicist, dissident and human rights activist. Sakharov was an advocate of civil liberties and reforms in the Soviet Union. He was awarded the Nobel Peace Prize in 1975. (wikipedia)</p></div>\n<p>There is a small project that I&#8217;m working on with a friend, and since for years I&#8217;ve wanted to try Python&#8230;</p>\n<p>I find two of the greatest assistants in learning and developing expertise in something are:</p>\n<ul>\n<li>Helping someone else (teaching).</li>\n<li>Using something else (compare).</li>\n</ul>\n<p>Experimenting with something else helps me take the emotions and religion out of what I&#8217;m developing expertise in. It lends to a pragmatic foundation and helps be able to speak to another audience.</p>\n<p>So while I work on this Python project, I won&#8217;t feel like I&#8217;m cheating on PHP and WordPress. Instead I&#8217;m continuing my learning about both and will be a better representative of both.</p>\";s:7:\"pubdate\";s:31:\"Tue, 24 Feb 2009 21:28:36 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:5:\"Lloyd\";}s:7:\"summary\";s:1406:\"<div class=\"wp-caption alignright\"><a href=\"http://flickr.com/photos/bootbearwdc/515399703/\"><img title=\"Dr. Andrei Dmitrievich Sakharov\" src=\"http://farm1.static.flickr.com/211/515399703_72ece0c2d1_m.jpg\" alt=\"Dr. Andrei Dmitrievich Sakharov\" width=\"171\" height=\"240\" /></a><p class=\"wp-caption-text\">Dr. Andrei Dmitrievich Sakharov Sculpture photo by Flickr user dbking. Andrei Dmitrievich Sakharov (May 21, 1921 – December 14, 1989) was an eminent Soviet nuclear physicist, dissident and human rights activist. Sakharov was an advocate of civil liberties and reforms in the Soviet Union. He was awarded the Nobel Peace Prize in 1975. (wikipedia)</p></div>\n<p>There is a small project that I&#8217;m working on with a friend, and since for years I&#8217;ve wanted to try Python&#8230;</p>\n<p>I find two of the greatest assistants in learning and developing expertise in something are:</p>\n<ul>\n<li>Helping someone else (teaching).</li>\n<li>Using something else (compare).</li>\n</ul>\n<p>Experimenting with something else helps me take the emotions and religion out of what I&#8217;m developing expertise in. It lends to a pragmatic foundation and helps be able to speak to another audience.</p>\n<p>So while I work on this Python project, I won&#8217;t feel like I&#8217;m cheating on PHP and WordPress. Instead I&#8217;m continuing my learning about both and will be a better representative of both.</p>\";}i:16;a:7:{s:5:\"title\";s:59:\"Weblog Tools Collection: WordPress Theme Releases for 24/02\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=5224\";s:4:\"link\";s:87:\"http://weblogtoolscollection.com/archives/2009/02/24/wordpress-theme-releases-for-2402/\";s:11:\"description\";s:2184:\"<p><a href=\"http://wpgpl.com/themes/yashfa/\">Yashfa</a></p>\n<p><img title=\"Yashfa\" src=\"http://weblogtoolscollection.com/b2-img/2009/02/yashfa.png\" alt=\"Yashfa\" width=\"115\" height=\"83\" /></p>\n<p>Yashfa is 2 columns layout and created with simplicity and grid based design with a lot of featured and good looking layout. Widget and gravatar ready with support for threaded and paged comments, separated trackbacks and comments and custom header support.</p>\n<p><a href=\"http://code.google.com/p/whitebeans/wiki/Documentation\">WhiteBeans</a></p>\n<p><img title=\"WhiteBeans\" src=\"http://weblogtoolscollection.com/b2-img/2009/02/whitebeans.gif\" alt=\"WhiteBeans\" width=\"120\" height=\"83\" /></p>\n<p>WhiteBeans is simply a Wordpress theme framework. Currently is a simple white and orange two column theme. Actively being developed.</p>\n<p><a href=\"http://techblissonline.com/indy-premium-wordpress-theme/\">Indy Premium</a></p>\n<p><a href=\"http://free-wp-themes.techblissonline.com/index.php?wptheme=Indy%20Premium\"><img title=\"Indy Premium\" src=\"http://weblogtoolscollection.com/b2-img/2009/02/indypremium.jpg\" alt=\"Indy Premium\" width=\"120\" height=\"83\" /></a></p>\n<p>Indy Premium is SEO-optimized, 3-column, ad-ready, WordPress 2.7 compatible with widgetized sidebars and footer.</p>\n<p><a href=\"http://www.smashingmagazine.com/2009/02/23/magazeen-free-magazine-look-wordpress-theme/\">Magazeen</a></p>\n<p><a href=\"http://demo.wefunction.com/?wptheme=Magazeen\"><img title=\"magazeen\" src=\"http://weblogtoolscollection.com/b2-img/2009/02/magazeen.jpg\" alt=\"magazeen\" width=\"128\" height=\"83\" /></a></p>\n<p>Two column, feature rich magazine style theme</p>\n<p><a href=\"http://andreamignolo.com/zack-990/\">Zack 990</a></p>\n<p><img title=\"Zack 990\" src=\"http://weblogtoolscollection.com/b2-img/2009/02/zack990.gif\" alt=\"Zack 990\" width=\"55\" height=\"83\" /></p>\n<p>Zack 990 is a variation on Ocular Professor. Inspired by the Boston Globe&#8217;s <a href=\"http://www.boston.com/bigpicture/\">Big Picture</a>, Zack 990 is designed exclusively for photo and video bloggers.</p>\n<p> </p>\n<p>Are you a theme author? <a href=\"http://weblogtoolscollection.com/submit-news/\">Submit your theme to us</a>.</p>\";s:7:\"pubdate\";s:31:\"Tue, 24 Feb 2009 20:11:44 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:2184:\"<p><a href=\"http://wpgpl.com/themes/yashfa/\">Yashfa</a></p>\n<p><img title=\"Yashfa\" src=\"http://weblogtoolscollection.com/b2-img/2009/02/yashfa.png\" alt=\"Yashfa\" width=\"115\" height=\"83\" /></p>\n<p>Yashfa is 2 columns layout and created with simplicity and grid based design with a lot of featured and good looking layout. Widget and gravatar ready with support for threaded and paged comments, separated trackbacks and comments and custom header support.</p>\n<p><a href=\"http://code.google.com/p/whitebeans/wiki/Documentation\">WhiteBeans</a></p>\n<p><img title=\"WhiteBeans\" src=\"http://weblogtoolscollection.com/b2-img/2009/02/whitebeans.gif\" alt=\"WhiteBeans\" width=\"120\" height=\"83\" /></p>\n<p>WhiteBeans is simply a Wordpress theme framework. Currently is a simple white and orange two column theme. Actively being developed.</p>\n<p><a href=\"http://techblissonline.com/indy-premium-wordpress-theme/\">Indy Premium</a></p>\n<p><a href=\"http://free-wp-themes.techblissonline.com/index.php?wptheme=Indy%20Premium\"><img title=\"Indy Premium\" src=\"http://weblogtoolscollection.com/b2-img/2009/02/indypremium.jpg\" alt=\"Indy Premium\" width=\"120\" height=\"83\" /></a></p>\n<p>Indy Premium is SEO-optimized, 3-column, ad-ready, WordPress 2.7 compatible with widgetized sidebars and footer.</p>\n<p><a href=\"http://www.smashingmagazine.com/2009/02/23/magazeen-free-magazine-look-wordpress-theme/\">Magazeen</a></p>\n<p><a href=\"http://demo.wefunction.com/?wptheme=Magazeen\"><img title=\"magazeen\" src=\"http://weblogtoolscollection.com/b2-img/2009/02/magazeen.jpg\" alt=\"magazeen\" width=\"128\" height=\"83\" /></a></p>\n<p>Two column, feature rich magazine style theme</p>\n<p><a href=\"http://andreamignolo.com/zack-990/\">Zack 990</a></p>\n<p><img title=\"Zack 990\" src=\"http://weblogtoolscollection.com/b2-img/2009/02/zack990.gif\" alt=\"Zack 990\" width=\"55\" height=\"83\" /></p>\n<p>Zack 990 is a variation on Ocular Professor. Inspired by the Boston Globe&#8217;s <a href=\"http://www.boston.com/bigpicture/\">Big Picture</a>, Zack 990 is designed exclusively for photo and video bloggers.</p>\n<p> </p>\n<p>Are you a theme author? <a href=\"http://weblogtoolscollection.com/submit-news/\">Submit your theme to us</a>.</p>\";}i:17;a:7:{s:5:\"title\";s:90:\"Weblog Tools Collection: The manual Excerpt in WordPress. What, why, how, tips and plugins\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=5217\";s:4:\"link\";s:115:\"http://weblogtoolscollection.com/archives/2009/02/24/the-manual-excerpt-in-wordpress-what-why-how-tips-and-plugins/\";s:11:\"description\";s:891:\"<p><a href=\"http://op111.net/67\">The manual Excerpt in WordPress. What, why, how, tips and plugins</a>.: Demetris has a written a very nice, well illustrated and explained tutorial on the WordPress excerpt and how to manipulate it to take full advantage of it.</p>\n<p><em>WordPress excerpts, which are not excerpts, make a WordPress site easier to browse and its content easier to discover. In addition, when also used as META descriptions, good excerpts bring more and better traffic from search engines.</em></p>\n<p><!--CONTENTS-->Topics discussed include:</p>\n<ol>\n<li>What is the WordPress excerpt</li>\n<li>Why write excerpts in WordPress</li>\n<li>How to write excerpts</li>\n<li>WordPress Excerpt Editor</li>\n<li>Excerpts as META descriptions</li>\n<li>Notes, Miscellaneous</li>\n<li>Links</li>\n</ol>\n<p>In Demetris&#8217; style, the tutorial is very well written and well fleshed out.</p>\";s:7:\"pubdate\";s:31:\"Tue, 24 Feb 2009 14:38:16 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:10:\"Mark Ghosh\";}s:7:\"summary\";s:891:\"<p><a href=\"http://op111.net/67\">The manual Excerpt in WordPress. What, why, how, tips and plugins</a>.: Demetris has a written a very nice, well illustrated and explained tutorial on the WordPress excerpt and how to manipulate it to take full advantage of it.</p>\n<p><em>WordPress excerpts, which are not excerpts, make a WordPress site easier to browse and its content easier to discover. In addition, when also used as META descriptions, good excerpts bring more and better traffic from search engines.</em></p>\n<p><!--CONTENTS-->Topics discussed include:</p>\n<ol>\n<li>What is the WordPress excerpt</li>\n<li>Why write excerpts in WordPress</li>\n<li>How to write excerpts</li>\n<li>WordPress Excerpt Editor</li>\n<li>Excerpts as META descriptions</li>\n<li>Notes, Miscellaneous</li>\n<li>Links</li>\n</ol>\n<p>In Demetris&#8217; style, the tutorial is very well written and well fleshed out.</p>\";}i:18;a:7:{s:5:\"title\";s:56:\"Alex King: WordCamp Denver - Afternoon Tickets Available\";s:4:\"guid\";s:79:\"http://alexking.org/blog/2009/02/23/wordcamp-denver-afternoon-tickets-available\";s:4:\"link\";s:79:\"http://alexking.org/blog/2009/02/23/wordcamp-denver-afternoon-tickets-available\";s:11:\"description\";s:2421:\"<p>Response for <a href=\"http://denver.wordcamp.org\" rel=\"external\">WordCamp Denver</a> has been overwhelming. We sold out last week, but thanks to some thoughtful people letting us know they won&#8217;t be able to attend, we have <del>5</del>4 more full tickets <a href=\"http://wordcampdenver.eventbrite.com\" rel=\"external\">available</a>. Based on the e-mail requests we&#8217;ve received since we sold out, I expect they will go quickly.</p>\n<p class=\"center\"><a href=\"http://denver.wordcamp.org/\"><img title=\"Attending WordCamp Denver\" src=\"http://denver.wordcamp.org/files/2008/10/attending-badge.png\" alt=\"I\'m Attending WordCamp Denver 2009\" width=\"125\" height=\"125\" /></a></p>\n<p>Our morning venue space is limited (by fire codes) to 276 people. However, we&#8217;ll be splitting up into two locations for the separate blogger and technical sessions in the afternoon. We still have space in both of these areas, so we&#8217;ve created the &#8220;afternoon only&#8221; tickets. These are available immediately, and I believe we&#8217;ll be able to make as many of these available as necessary. Please note, these tickets do not include a t-shirt or access to the morning sessions.</p>\n<p>A couple of notes:</p>\n<ul>\n<li>There will be an after-party at the <a href=\"http://www.paramountcafe.com/\" rel=\"external\">Paramount Cafe</a> - should be a good chance to socialize and network after a long day of &#8220;camping&#8221;.</li>\n<li>We&#8217;ve opened up a <a href=\"http://moderator.appspot.com/#16/e=20794\" rel=\"external\">Moderator instance</a> so that you can post questions for the presenters to consider. You can also vote on questions people have already posted. I&#8217;m curious to see how this works.</li>\n<li>We are still looking for folks to record the event (in HD please). Get in touch if you are interested.</li>\n<li>There are tickets still available for the VIP (speakers/sponsors) dinner on Friday night - looking forward to seeing some folks there.</li>\n</ul>\n<p>It&#8217;s great to see so much interest in WordPress here in the Denver/Boulder area. We&#8217;ll be sure to book a larger venue for WordCamp Denver 2010.</p>\n<p><a href=\"http://sharethis.com/item?&wp=2.2.3&amp;publisher=a1583af8-28eb-4210-97bd-2bb5c02bc265&amp;title=WordCamp+Denver+-+Afternoon+Tickets+Available&amp;url=http%3A%2F%2Falexking.org%2Fblog%2F2009%2F02%2F23%2Fwordcamp-denver-afternoon-tickets-available\">ShareThis</a></p>\";s:7:\"pubdate\";s:31:\"Mon, 23 Feb 2009 22:39:24 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Alex\";}s:7:\"summary\";s:2421:\"<p>Response for <a href=\"http://denver.wordcamp.org\" rel=\"external\">WordCamp Denver</a> has been overwhelming. We sold out last week, but thanks to some thoughtful people letting us know they won&#8217;t be able to attend, we have <del>5</del>4 more full tickets <a href=\"http://wordcampdenver.eventbrite.com\" rel=\"external\">available</a>. Based on the e-mail requests we&#8217;ve received since we sold out, I expect they will go quickly.</p>\n<p class=\"center\"><a href=\"http://denver.wordcamp.org/\"><img title=\"Attending WordCamp Denver\" src=\"http://denver.wordcamp.org/files/2008/10/attending-badge.png\" alt=\"I\'m Attending WordCamp Denver 2009\" width=\"125\" height=\"125\" /></a></p>\n<p>Our morning venue space is limited (by fire codes) to 276 people. However, we&#8217;ll be splitting up into two locations for the separate blogger and technical sessions in the afternoon. We still have space in both of these areas, so we&#8217;ve created the &#8220;afternoon only&#8221; tickets. These are available immediately, and I believe we&#8217;ll be able to make as many of these available as necessary. Please note, these tickets do not include a t-shirt or access to the morning sessions.</p>\n<p>A couple of notes:</p>\n<ul>\n<li>There will be an after-party at the <a href=\"http://www.paramountcafe.com/\" rel=\"external\">Paramount Cafe</a> - should be a good chance to socialize and network after a long day of &#8220;camping&#8221;.</li>\n<li>We&#8217;ve opened up a <a href=\"http://moderator.appspot.com/#16/e=20794\" rel=\"external\">Moderator instance</a> so that you can post questions for the presenters to consider. You can also vote on questions people have already posted. I&#8217;m curious to see how this works.</li>\n<li>We are still looking for folks to record the event (in HD please). Get in touch if you are interested.</li>\n<li>There are tickets still available for the VIP (speakers/sponsors) dinner on Friday night - looking forward to seeing some folks there.</li>\n</ul>\n<p>It&#8217;s great to see so much interest in WordPress here in the Denver/Boulder area. We&#8217;ll be sure to book a larger venue for WordCamp Denver 2010.</p>\n<p><a href=\"http://sharethis.com/item?&wp=2.2.3&amp;publisher=a1583af8-28eb-4210-97bd-2bb5c02bc265&amp;title=WordCamp+Denver+-+Afternoon+Tickets+Available&amp;url=http%3A%2F%2Falexking.org%2Fblog%2F2009%2F02%2F23%2Fwordcamp-denver-afternoon-tickets-available\">ShareThis</a></p>\";}i:19;a:7:{s:5:\"title\";s:60:\"Weblog Tools Collection: WordPress Plugin Releases for 02/23\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=5214\";s:4:\"link\";s:88:\"http://weblogtoolscollection.com/archives/2009/02/23/wordpress-plugin-releases-for-0223/\";s:11:\"description\";s:4191:\"<h3>New Plugins</h3>\n<p><a href=\"http://sivel.net/2009/02/public-post-preview/\">Public Post Preview</a></p>\n<p>Enables you to give a link to anonymous users for public preview of a post before it is published.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/add-twitter-rss/\">Add Twitter RSS</a></p>\n<p>Adds a link to your Twitter feed in the header of your WordPress Blog.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/favicon-generator/\">Favicon Generator</a></p>\n<p>This plugin will allow you to upload an image file of your choosing to be converted to a favicon for your WordPress site.</p>\n<p><a href=\"http://dound.com/projects/word-press/ajax-login-widget/\">AJAX Login Widget++</a></p>\n<p>A clean AJAX-based login, registration and lost password retrieval widget.</p>\n<p><a href=\"http://felixker.com/wp-timeout-plugin/\">Wordpress/Plugin Upgrade Time Out Plugin</a></p>\n<p>Wordpress/Plugin Upgrade Time Out Plugin allows you to modify the files download time out value (mainly used for upgrade of Wordpress and Plugins).</p>\n<p><a href=\"http://wordpress.org/extend/plugins/wow-character-display/\">WoW-Character-Display</a></p>\n<p>The WoW-Character-Display plugin shows many informations from the WoW armory in a widget or post. Highly configurable and for multiple characters!</p>\n<p><a href=\"http://wordpress.org/extend/plugins/oxyxml/\">oxyXML generator</a></p>\n<p>This plugin creates a XML file from your last posts.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/wp-favorite-posts/\">WP Favorite Posts</a></p>\n<p>Allows users to add favorite posts. This plugin use cookies for saving data so unregistered users can favorite a post.</p>\n<h3>Updated Plugins</h3>\n<p><a href=\"http://kerrywebster.com/my-current-plugins/branded-admin/\">Branded Admin</a> </p>\n<p>A WordPress plugin designed to give a blog author or designer the ability to change the WordPress Administration section by adding a unique - branded - header and footer. Branding may be important depending on how prevalent the WordPress logo &amp; native branding are to the owner or designer of a site. This plugin is now fully WordPress 2.7.x compliant and recently converted to us jQuery. jQuery was used so that others could extend the plugin to fit their own needs.</p>\n<p><a href=\"http://scribu.net/wordpress/custom-field-taxonomies\">Custom Field Taxonomies</a></p>\n<p>A WordPress plugin that let’s you use custom fields as ad-hoc taxonomies.</p>\n<p><a href=\"http://www.stuartconover.com/2009/02/23/lifestream-plugin-updated-94beta/\">Lifestream</a></p>\n<p>Lifestream displays your social feeds and photos much like you would see it on many of the social networking sites.</p>\n<p><a href=\"http://rickbeckman.org/thesis-openhook/\">Thesis OpenHook</a></p>\n<p>This plugin allows you to insert arbitrary content into the many hooks that the Thesis Theme Framework provides. Never again edit a file!</p>\n<p><a href=\"http://wordpress.org/extend/plugins/statpress-reloaded/\">StatPress Reloaded</a></p>\n<p>This plugin shows you real time statistics about your blog. It collects information about visitors, spiders, search keywords, feeds, browsers, OS etc.</p>\n<p><a href=\"http://gigpress.com/\">GigPress</a></p>\n<p>GigPress provides an easy way for bands to list and manage their concerts and tours on their WordPress-powered website.</p>\n<p><a href=\"http://www.ultimateidx.com/menu-manager/\">WordPress Menu Creator</a></p>\n<p>WordPress Menu Creator ( Menu Manager ) is developed to provide website owners with truly easy to manage easy to configure menu solution.</p>\n<p><a href=\"http://www.viadat.com/store-locator/\">Store Locator</a></p>\n<p>A store locator plugin for developers who create sites in Wordpress &amp; web site owners who want to quickly show important locations.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/connect2site/\">Connect2site</a></p>\n<p>This plugin can be used to connect to another wordpress blog located in a subdomain on the same server. It provides various ways to display posts.</p>\n<p><a href=\"http://pageflipgallery.com/\">Page Flip Image Gallery</a></p>\n<p>FlippingBook Wordpress Gallery plugin helps you to create Image Gallery with Page Flip effects on your blog.</p>\";s:7:\"pubdate\";s:31:\"Mon, 23 Feb 2009 19:30:51 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:4191:\"<h3>New Plugins</h3>\n<p><a href=\"http://sivel.net/2009/02/public-post-preview/\">Public Post Preview</a></p>\n<p>Enables you to give a link to anonymous users for public preview of a post before it is published.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/add-twitter-rss/\">Add Twitter RSS</a></p>\n<p>Adds a link to your Twitter feed in the header of your WordPress Blog.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/favicon-generator/\">Favicon Generator</a></p>\n<p>This plugin will allow you to upload an image file of your choosing to be converted to a favicon for your WordPress site.</p>\n<p><a href=\"http://dound.com/projects/word-press/ajax-login-widget/\">AJAX Login Widget++</a></p>\n<p>A clean AJAX-based login, registration and lost password retrieval widget.</p>\n<p><a href=\"http://felixker.com/wp-timeout-plugin/\">Wordpress/Plugin Upgrade Time Out Plugin</a></p>\n<p>Wordpress/Plugin Upgrade Time Out Plugin allows you to modify the files download time out value (mainly used for upgrade of Wordpress and Plugins).</p>\n<p><a href=\"http://wordpress.org/extend/plugins/wow-character-display/\">WoW-Character-Display</a></p>\n<p>The WoW-Character-Display plugin shows many informations from the WoW armory in a widget or post. Highly configurable and for multiple characters!</p>\n<p><a href=\"http://wordpress.org/extend/plugins/oxyxml/\">oxyXML generator</a></p>\n<p>This plugin creates a XML file from your last posts.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/wp-favorite-posts/\">WP Favorite Posts</a></p>\n<p>Allows users to add favorite posts. This plugin use cookies for saving data so unregistered users can favorite a post.</p>\n<h3>Updated Plugins</h3>\n<p><a href=\"http://kerrywebster.com/my-current-plugins/branded-admin/\">Branded Admin</a> </p>\n<p>A WordPress plugin designed to give a blog author or designer the ability to change the WordPress Administration section by adding a unique - branded - header and footer. Branding may be important depending on how prevalent the WordPress logo &amp; native branding are to the owner or designer of a site. This plugin is now fully WordPress 2.7.x compliant and recently converted to us jQuery. jQuery was used so that others could extend the plugin to fit their own needs.</p>\n<p><a href=\"http://scribu.net/wordpress/custom-field-taxonomies\">Custom Field Taxonomies</a></p>\n<p>A WordPress plugin that let’s you use custom fields as ad-hoc taxonomies.</p>\n<p><a href=\"http://www.stuartconover.com/2009/02/23/lifestream-plugin-updated-94beta/\">Lifestream</a></p>\n<p>Lifestream displays your social feeds and photos much like you would see it on many of the social networking sites.</p>\n<p><a href=\"http://rickbeckman.org/thesis-openhook/\">Thesis OpenHook</a></p>\n<p>This plugin allows you to insert arbitrary content into the many hooks that the Thesis Theme Framework provides. Never again edit a file!</p>\n<p><a href=\"http://wordpress.org/extend/plugins/statpress-reloaded/\">StatPress Reloaded</a></p>\n<p>This plugin shows you real time statistics about your blog. It collects information about visitors, spiders, search keywords, feeds, browsers, OS etc.</p>\n<p><a href=\"http://gigpress.com/\">GigPress</a></p>\n<p>GigPress provides an easy way for bands to list and manage their concerts and tours on their WordPress-powered website.</p>\n<p><a href=\"http://www.ultimateidx.com/menu-manager/\">WordPress Menu Creator</a></p>\n<p>WordPress Menu Creator ( Menu Manager ) is developed to provide website owners with truly easy to manage easy to configure menu solution.</p>\n<p><a href=\"http://www.viadat.com/store-locator/\">Store Locator</a></p>\n<p>A store locator plugin for developers who create sites in Wordpress &amp; web site owners who want to quickly show important locations.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/connect2site/\">Connect2site</a></p>\n<p>This plugin can be used to connect to another wordpress blog located in a subdomain on the same server. It provides various ways to display posts.</p>\n<p><a href=\"http://pageflipgallery.com/\">Page Flip Image Gallery</a></p>\n<p>FlippingBook Wordpress Gallery plugin helps you to create Image Gallery with Page Flip effects on your blog.</p>\";}i:20;a:7:{s:5:\"title\";s:18:\"Matt: Ryanair Diss\";s:4:\"guid\";s:21:\"http://ma.tt/?p=12035\";s:4:\"link\";s:34:\"http://ma.tt/2009/02/ryanair-diss/\";s:11:\"description\";s:251:\"<p>In a relatively bizarre case an employee of Ryanair <a href=\"http://ocaoimh.ie/2009/02/19/ryanair-staff-give-wordpress-some-lovin/\">left disparaging remarks about WordPress on someone&#8217;s blog</a>. Someone with the airline should apologize.</p>\";s:7:\"pubdate\";s:31:\"Mon, 23 Feb 2009 14:12:51 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:7:\"summary\";s:251:\"<p>In a relatively bizarre case an employee of Ryanair <a href=\"http://ocaoimh.ie/2009/02/19/ryanair-staff-give-wordpress-some-lovin/\">left disparaging remarks about WordPress on someone&#8217;s blog</a>. Someone with the airline should apologize.</p>\";}i:21;a:7:{s:5:\"title\";s:60:\"Donncha: WordPress and Blacknight power the best Irish blogs\";s:4:\"guid\";s:29:\"http://ocaoimh.ie/?p=89494517\";s:4:\"link\";s:81:\"http://ocaoimh.ie/2009/02/23/wordpress-and-blacknight-power-the-best-irish-blogs/\";s:11:\"description\";s:4570:\"<div align=\"center\"><img src=\"http://ocaoimh.ie/wp-content/uploads/2009/02/grandad.jpg\" alt=\"grandad\" title=\"grandad\" width=\"500\" height=\"334\" class=\"aligncenter size-full wp-image-89494519\" /></div>\n<p>Last Saturday night many of the Irish blogging community got together in The Cork International Airport Hotel for the <a href=\"http://awards.ie/blogawards/\">Irish Blog Awards</a>. <a href=\"http://ocaoimh.ie/2009/02/22/back-from-the-irish-blog-awards-2009/\">I was there</a> with my wife Jacinta, it was a great night and <a href=\"http://twitter.com/donncha/status/1235359350\">I was delighted</a> to see so many WordPress powered blogs. Both WordPress.org and WordPress.com blogs were represented again and again among the top bloggers in Ireland.</p>\n<p>I had planned on writing a post analysing the breakdown of WordPress vs Blogspot vs MT vs everyone else but lucky for me, Cathal Garvey <a href=\"http://cgarvey.ie/blog/archive/2009/02/22/blog-software-of-choice-of-the-irish-blog-awards-09-short-listed/\">already did the hard work</a>! </p>\n<p><img src=\"http://ocaoimh.ie/wp-content/uploads/2009/02/pub.png\" alt=\"pub\" title=\"pub\" width=\"500\" height=\"330\" class=\"aligncenter size-full wp-image-89494524\" /></p>\n<p>He has some very interesting stats on version numbers, and I&#8217;m shocked that &#8220;Best Technology Blog&#8221; (sponsored by <a href=\"http://www.bitbuzz.com/\">Bitbuzz</a>) has the worst record for upgrading WordPress. Hopefully this attention will encourage those bloggers to upgrade.</p>\n<p><a href=\"http://wordpress.org/\">WordPress</a> is the most popular blogging software among the Blog Awards nominees and <a href=\"http://www.blacknight.com/\">Blacknight</a> is by far the most popular hosting service. I don&#8217;t think you can get a better recommendation than that for either WordPress or Blacknight.</p>\n<p>BTW - That&#8217;s Grandad in the photo above. Go read his blog, <a href=\"http://www.headrambles.com/\">Head Rambles</a>. You&#8217;ll love it!<br />\nPS. Here are the <a href=\"http://awards.ie/blogawards/2009/02/22/the-2009-irish-blog-awards-winners-are/\">results</a> of the Awards, read more by <a href=\"http://redmum.blogspot.com/2009/02/irish-blog-awards-2009_22.html\">Red Mum</a>, <a href=\"http://blog.sweetnam.eu/2009/02/22/great-night-but-a-nasty-hangover/\">Robert</a>, <a href=\"http://blog.niallok.com/index.php/2009/02/22/irish-blog-awards-2009-the-interviews/\">Niall</a> and <a href=\"http://www.jason-roe.com/blog/cork-international-airport-hotel-a-big-thanks/\">Jason</a> who reminds us <a href=\"http://www.tripadvisor.com/Hotel_Review-g186600-d650792-Reviews-Cork_International_Airport_Hotel-Cork_County_Cork.html\">we should vote</a> for the excellent <a href=\"http://www.corkinternationalairporthotel.com/\">Cork International Airport Hotel</a>. TheChrisD has a <a href=\"http://www.thechrisd.com/blog/2009/02/23/random-iba-shit\">massive post</a> listing everyone in his feedreader who posted about the Awards, a few pics, and some of the videos shown on the night.<br />\nI&#8217;ll be uploading photos from the night in a post here and to <a href=\"http://pix.ie/\">Pixie</a> later.</p>\n<p>PPS. Alan Burke got in touch and asked me to give <a href=\"http://groups.drupal.org/node/18452\">Drupalcamp Galway</a> a plug. He added, &#8220;Maybe we could convert a few Wordpress users ;-)&#8221; but of course that&#8217;ll never happen!</p>\n<blockquote><p>On Saturday 4th and Sunday 5th of April 2009 in Galway, 2 groups of Drupal developers will work on building 2 real working Drupal sites for 2 good causes. They will have 24 hours to complete their website. We are calling organizations, charities and NGOs from Ireland to submit their site proposal. Any organisation can register as long as they are not-for-profit and do not have a Drupal site already running. (A few static HTML pages is the limit for being accepted).</p></blockquote>\n<p>Sounds like a great idea and a worthy one too.</p>\n<p><img src=\"http://ocaoimh.ie/?voyeur=1\" /></p><p><strong>Related Posts</strong><ul><li><a href=\"http://ocaoimh.ie/2005/11/24/top-25-irish-blogs/\" rel=\"bookmark\" title=\"Permanent Link: Top 25 Irish Blogs\">Top 25 Irish Blogs</a></li><li><a href=\"http://ocaoimh.ie/2005/03/24/irish-blogs-and-bloggers/\" rel=\"bookmark\" title=\"Permanent Link: Irish Blogs and Bloggers\">Irish Blogs and Bloggers</a></li><li><a href=\"http://ocaoimh.ie/2005/05/25/irish-blogs-directory-the-new-boggersphere/\" rel=\"bookmark\" title=\"Permanent Link: Irish Blogs Directory, the new boggersphere!\">Irish Blogs Directory, the new boggersphere!</a></li></ul></p>\";s:7:\"pubdate\";s:31:\"Mon, 23 Feb 2009 10:15:17 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:7:\"Donncha\";}s:7:\"summary\";s:4570:\"<div align=\"center\"><img src=\"http://ocaoimh.ie/wp-content/uploads/2009/02/grandad.jpg\" alt=\"grandad\" title=\"grandad\" width=\"500\" height=\"334\" class=\"aligncenter size-full wp-image-89494519\" /></div>\n<p>Last Saturday night many of the Irish blogging community got together in The Cork International Airport Hotel for the <a href=\"http://awards.ie/blogawards/\">Irish Blog Awards</a>. <a href=\"http://ocaoimh.ie/2009/02/22/back-from-the-irish-blog-awards-2009/\">I was there</a> with my wife Jacinta, it was a great night and <a href=\"http://twitter.com/donncha/status/1235359350\">I was delighted</a> to see so many WordPress powered blogs. Both WordPress.org and WordPress.com blogs were represented again and again among the top bloggers in Ireland.</p>\n<p>I had planned on writing a post analysing the breakdown of WordPress vs Blogspot vs MT vs everyone else but lucky for me, Cathal Garvey <a href=\"http://cgarvey.ie/blog/archive/2009/02/22/blog-software-of-choice-of-the-irish-blog-awards-09-short-listed/\">already did the hard work</a>! </p>\n<p><img src=\"http://ocaoimh.ie/wp-content/uploads/2009/02/pub.png\" alt=\"pub\" title=\"pub\" width=\"500\" height=\"330\" class=\"aligncenter size-full wp-image-89494524\" /></p>\n<p>He has some very interesting stats on version numbers, and I&#8217;m shocked that &#8220;Best Technology Blog&#8221; (sponsored by <a href=\"http://www.bitbuzz.com/\">Bitbuzz</a>) has the worst record for upgrading WordPress. Hopefully this attention will encourage those bloggers to upgrade.</p>\n<p><a href=\"http://wordpress.org/\">WordPress</a> is the most popular blogging software among the Blog Awards nominees and <a href=\"http://www.blacknight.com/\">Blacknight</a> is by far the most popular hosting service. I don&#8217;t think you can get a better recommendation than that for either WordPress or Blacknight.</p>\n<p>BTW - That&#8217;s Grandad in the photo above. Go read his blog, <a href=\"http://www.headrambles.com/\">Head Rambles</a>. You&#8217;ll love it!<br />\nPS. Here are the <a href=\"http://awards.ie/blogawards/2009/02/22/the-2009-irish-blog-awards-winners-are/\">results</a> of the Awards, read more by <a href=\"http://redmum.blogspot.com/2009/02/irish-blog-awards-2009_22.html\">Red Mum</a>, <a href=\"http://blog.sweetnam.eu/2009/02/22/great-night-but-a-nasty-hangover/\">Robert</a>, <a href=\"http://blog.niallok.com/index.php/2009/02/22/irish-blog-awards-2009-the-interviews/\">Niall</a> and <a href=\"http://www.jason-roe.com/blog/cork-international-airport-hotel-a-big-thanks/\">Jason</a> who reminds us <a href=\"http://www.tripadvisor.com/Hotel_Review-g186600-d650792-Reviews-Cork_International_Airport_Hotel-Cork_County_Cork.html\">we should vote</a> for the excellent <a href=\"http://www.corkinternationalairporthotel.com/\">Cork International Airport Hotel</a>. TheChrisD has a <a href=\"http://www.thechrisd.com/blog/2009/02/23/random-iba-shit\">massive post</a> listing everyone in his feedreader who posted about the Awards, a few pics, and some of the videos shown on the night.<br />\nI&#8217;ll be uploading photos from the night in a post here and to <a href=\"http://pix.ie/\">Pixie</a> later.</p>\n<p>PPS. Alan Burke got in touch and asked me to give <a href=\"http://groups.drupal.org/node/18452\">Drupalcamp Galway</a> a plug. He added, &#8220;Maybe we could convert a few Wordpress users ;-)&#8221; but of course that&#8217;ll never happen!</p>\n<blockquote><p>On Saturday 4th and Sunday 5th of April 2009 in Galway, 2 groups of Drupal developers will work on building 2 real working Drupal sites for 2 good causes. They will have 24 hours to complete their website. We are calling organizations, charities and NGOs from Ireland to submit their site proposal. Any organisation can register as long as they are not-for-profit and do not have a Drupal site already running. (A few static HTML pages is the limit for being accepted).</p></blockquote>\n<p>Sounds like a great idea and a worthy one too.</p>\n<p><img src=\"http://ocaoimh.ie/?voyeur=1\" /></p><p><strong>Related Posts</strong><ul><li><a href=\"http://ocaoimh.ie/2005/11/24/top-25-irish-blogs/\" rel=\"bookmark\" title=\"Permanent Link: Top 25 Irish Blogs\">Top 25 Irish Blogs</a></li><li><a href=\"http://ocaoimh.ie/2005/03/24/irish-blogs-and-bloggers/\" rel=\"bookmark\" title=\"Permanent Link: Irish Blogs and Bloggers\">Irish Blogs and Bloggers</a></li><li><a href=\"http://ocaoimh.ie/2005/05/25/irish-blogs-directory-the-new-boggersphere/\" rel=\"bookmark\" title=\"Permanent Link: Irish Blogs Directory, the new boggersphere!\">Irish Blogs Directory, the new boggersphere!</a></li></ul></p>\";}i:22;a:7:{s:5:\"title\";s:122:\"Lorelle on WP: WordPress News: LiveJournal Migration Improved, WordPress Plugin Search Improved, bbPress Updated, and More\";s:4:\"guid\";s:36:\"http://lorelle.wordpress.com/?p=3909\";s:4:\"link\";s:144:\"http://lorelle.wordpress.com/2009/02/22/wordpress-news-livejournal-migration-improved-wordpress-plugin-search-improved-bbpress-updated-and-more/\";s:11:\"description\";s:14052:\"<div class=\"snap_preview\"><br /><p><a href=\"http://lorelle.wordpress.com/tag/wordpress-news/\" title=\"WordPress News\"><img src=\"http://lorelle.files.wordpress.com/2007/01/wpnews1.png\" alt=\"WordPress News\" align=\"right\" /></a>I&#8217;ve just posted this week&#8217;s <a href=\"http://www.blogherald.com/2009/02/20/wordpress-news-can-you-spot-a-wordpress-blog-wordpress-28-news-plugin-directory-searchable-iphone-app-tested-and-more/\" title=\"WordPress News: Can You Spot a WordPress Blog? WordPress 2.8 News, Plugin Directory Searchable, iPhone App Tested, and More\">WordPress News: Can You Spot a WordPress Blog? WordPress 2.8 News, Plugin Directory Searchable, iPhone App Tested, and More</a> on the <a href=\"http://www.blogherald.com/\" title=\"Blog Herald\" rel=\"tag\">Blog Herald</a>.</p>\n<blockquote><p>Can you spot a WordPress blog? Are you sure? WordPress 2.7.1 released. Improvements on the WordPress Plugin Directory search functions. Help for those transferring from LiveJournal to WordPress.com, and WordPress in the future. WordPress 2.8 development on track. WordPress iPhone app in testing for next release. WordPress.com gets a new data center. More WordPress Tattoo news. WordCamps in Miami and India this weekend, Denver next. Singapore starts its first blogger meetup, including WordPress fans. WordPress jobs, and tips for WordPress Plugin and Theme authors. </p></blockquote>\n<p>Here are some highlights of the WordPress news you can use.</p>\n<h4>Improvements in the WordPress Plugin Directory</h4>\n<p>At long last, the <a href=\"http://wordpress.org/extend/plugins/\" title=\"WordPress Plugins Extends\">WordPress Plugin Directory</a> now has a <a href=\"http://wordpress.org/development/2009/02/new-and-improved-plugins-directory-search/\" title=\"New and Improved Plugins Directory Search\">new and improved search function</a> using <a href=\"http://www.sphinxsearch.com/\" title=\"Sphinx\">Sphinx</a> open source SQL full-text search engine to help you find the Plugins you need in the directory from the site as well as the WordPress Plugins panel. </p>\n<h4>Improved LiveJournal Migration</h4>\n<p>For those looking to migrate from LiveJournal to <a href=\"http://www.wordpress.com/\" title=\"WordPress.com free blogs\" rel=\"tag\">WordPress.com</a>, there is now an <a href=\"http://en.blog.wordpress.com/2009/02/18/even-easier-livejournal-migration/\" title=\"Even Easier LiveJournal Migration\">even easier LiveJournal migration</a> process that the WordPress.com team has come up with to help the ever increasing number of people moving to WordPress.com from one of the oldest blogging platforms in the world.</p>\n<p>The new technique is a step by step approach that improves the importing from importing by the month without comments to now include comments, handle &#8220;friends only&#8221; posts, private posts, improvements in tagging, link back to LiveJournal blogs, and connection to the LiveJournal API to download all posts and comments in one pass. One LiveJournal users helped test the importer which handled over 3,700 posts and nearly 200,000 comments. That&#8217;s impressive.</p>\n<p>The new importer will be included in the next major release of the full version of WordPress.<span id=\"more-3909\"></span></p>\n<h4>iPhone WordPress App in Testing Mode</h4>\n<p>The latest version of the <a href=\"http://iphone.wordpress.org/2009/02/17/looking-for-a-few-good-hardware-testers/\" title=\"Looking For a Few Good Hardware Testers\">WordPress iPhone app is underway and they are looking for hardware testers</a> for the next version. </p>\n<p>The changes in the iPhones operating system delayed this new update, but now they are nearly ready for the release to the Apple store. The upcoming version includes landscape mode with the extra wide keyboard, link creation help, editing and creating Pages, comment moderation, asynchronous publishing, photo resizing, and a few more goodies. </p>\n<h4>bbPress On Fire</h4>\n<p><a href=\"http://ma.tt/\" title=\"Matt Mullenweg\" rel=\"tag\">Matt Mullenweg</a> has announced that this is going to be a very active year for development of <a href=\"http://www.bbpress.org/\" title=\"bbPress forum software\" rel=\"tag\">bbPress</a>, the open source forum software that drives the WordPress forums. It begins the year with some new announcements and activities including <a href=\"http://bbpress.org/blog/2009/01/two-new-bbpress-releases/\" title=\"Two new bbPress releases\">two new bbPress releases</a>. One is a security fix to prevent XSS attacks on login pages for Internet Explorer 6, which is highly recommend, and the second includes code improvements that increase the speed at which bbPress interacts with MySQL and integration with WordPress. </p>\n<p>I&#8217;m working on an article for <a href=\"http://lorelle.wordpress.com/\" title=\"Lorelle on WordPress\" rel=\"tag\">Lorelle on WordPress</a> on bbPress, so stay tuned.</p>\n<h4>Help The WordPress Support Forum, Please</h4>\n<p>As a long time volunteer on the <a href=\"http://www.wordpress.org/support\" title=\"WordPress Support Forums\" rel=\"tag\">WordPress Support Forums</a>, I join MichaelH in his request to improve the <a href=\"http://www.wordpress.org/support\" title=\"WordPress Support Forums\" rel=\"tag\">WordPress Support Forums</a> and applaud his recent post on Weblog Tools Collection called &#8220;<a href=\"http://weblogtoolscollection.com/news/topic/wish-list-for-the-wordpress-support-forums-software\" title=\"Wish list for the WordPress Support Forums software\">Wish list for the WordPress Support Forums software</a>.&#8221; </p>\n<p>Run on <a href=\"http://www.bbpress.org/\" title=\"bbPress forum software\" rel=\"tag\">bbPress</a> with a ton of customizations, there are a lot of limitations and problems on the Forums that could easily be fixed, and MichaelH joins a growing voice requesting the Forum be upgraded for increased functionality both by the users and the volunteers and staff who spend a lot of time helping others fix and use WordPress. </p>\n<h4>New Theme on WordPress.com</h4>\n<p>WordPress.com announced the <a href=\"http://en.blog.wordpress.com/2009/02/19/new-theme-vigilance/\" title=\"New Theme: Vigilance\">Vigilance WordPress Theme</a> has been added to the collection which includes customizable colors, alert boxes that appear at the top of the page for announcements, hidden pages from the main menu, custom image header, and special sidebar WordPress Widget functions. </p>\n<h4>Comment Threading on WordPress.com</h4>\n<p><a href=\"http://www.wordpress.com/\" title=\"WordPress.com free blogs\" rel=\"tag\">WordPress.com</a> announced <a href=\"http://en.blog.wordpress.com/2009/02/19/comment-threading-is-here-plus-other-cool-comment-settings/\" title=\"Comment Threading is Here! (Plus Other Cool Comment Settings)\">comment threading and other cool comment features</a> for their free blog hosting service. </p>\n<p>All WordPress Themes are now set up to enable threaded comments, breaking comments into pages, and changing the comment order from the oldest comments on top to the newest comments at the top and the oldest ones at the bottom of the list. Comment threads are allowed up to ten levels. </p>\n<p>To enable this on your WordPress.com blog, go to  <strong>Settings &gt; Discussion &gt; Other Comment Settings</strong> and mark the appropriate boxes. It is disabled by default.</p>\n<h4>WordPress on Your Calendar</h4>\n<p>Some upcoming WordPress events include:</p>\n<ul>\n<li><a href=\"http://india.wordcamp.org/\" title=\"WordCamp India\">Delhi - WordCamp India - February 21-22, 2009</a></li>\n<li><a href=\"http://wordcampmiami.com/\" title=\"WordCamp Miami 2009\">Miami, Florida - WordCamp Miami 2009 - February 22, 2009</a></li>\n<li><a href=\"http://www.meetup.com/wordpress-sf/calendar/9713860/\" title=\"WordPress Surf and Turf (or newb and geeky)\">San Francisco - WordPress Surf and Turf - February 24, 2009</a></li>\n<li><a href=\"http://wordpress.meetup.com/173/calendar/9749800/\" title=\"Almost Everyone is a WordPress Expert\">Austin WordPress Meetup Group - Almost Everyone is a WordPress Expert - February 24, 2009</a></li>\n<li><a href=\"http://www.meetup.com/LasVegasWordPress/calendar/9678812/\" title=\"Las Vegas WordPress Meetup\">Las Vegas WordPress Meetup - February 26, 2009</a></li>\n<li><a href=\"http://wordpress.meetup.com/188/calendar/9763830/\" title=\"Singapore Blogger Meetup\">Singapore Blogger Meetup Froup - February 27, 2009</a></li>\n<li><a href=\"http://denver.wordcamp.org\" title=\"WordCamp Denver\">WordCamp Denver 2009 - February 28, 2009</a> (<a href=\"http://http//www.facebook.com/profile.php?id=779828054#/group.php?gid=22086243642\" title=\"WordCamp Denver 2009\">Facebook</a>)</li>\n<li><a href=\"http://www.meetup.com/dfwwordpress/calendar/9593871/\" title=\"February Meetup of the DFW WordPress Group\">Dallas/Fort Worth WordPress Meetup - Dallas, Texas - February 28, 2009</a></li>\n<li><a href=\"http://wordpress.meetup.com/184/calendar/9615427/\" title=\"Atlanta WordPress Users Group February Meetup\">Atlanta WordPress Users Group Meetup - Learning WordPress 2.7 - Atlanta, Georgia - February 28, 2009</a></li>\n<li><a href=\"http://www.meetup.com/mywplife/calendar/9593848/\" title=\"The Chicago WordPress February Meetup\">The Chicago WordPress February Meetup - February 28, 2009</a></li>\n<li><a href=\"http://www.meetup.com/The-New-Jersey-WordPress-Meetup-Group/calendar/9675967/\" title=\"The New Jersey WordPress March Meetup\">New Jersey - The New Jersey WordPress March Meetup - March 4, 2009</a></li>\n<li><a href=\"http://www.meetup.com/gulf-coast-wordpress/calendar/9684749/\" title=\"Gulf Coast WordPress/Blogger March Meetup\">Mobile, Alabama - Gulf Coast WordPress/Blogger WordPress Meetup - March 5, 2009</a></li>\n<li><a href=\"http://www.meetup.com/LasVegasWordPress/calendar/9678813/\" title=\"Las Vegas WordPress Meetup\">Las Vegas WordPress Meetup - March 5, 2009</a></li>\n<li><a href=\"http://upcoming.yahoo.com/event/1808383/\" title=\"Mar 8, 2009: Los Angeles WordPress Users Group at Philippe\'s French Dip\">Los Angeles WordPress Users Group - March 8, 2009</a></li>\n</ul>\n<p>The last issue of my WordPress News on the <a href=\"http://www.blogherald.com/\" title=\"Blog Herald\" rel=\"tag\">Blog Herald</a> was <a href=\"http://www.blogherald.com/2009/02/05/wordpress-news-release-week-news-wordpress-271-buddypress-wordpress-mu-and-more-releases/\" title=\"WordPress News: Release Week News, WordPress 2.7.1, BuddyPress, WordPress MU, and More Releases\">WordPress News: Release Week News, WordPress 2.7.1, BuddyPress, WordPress MU, and More Releases</a>.</p>\n<p>For more WordPress news, check out my weekly <a href=\"http://www.blogherald.com/tag/wordpress-news/\" title=\"Articles on WordPress News on the Blog Herald\" rel=\"tag\">Blog Herald WordPress News</a>. For more WordCamp news, check out the <a href=\"http://wordcamp.info/\" title=\"The WordCamp Report\">The WordCamp Report</a>.</p>\n<p><img src=\"http://lorelle.files.wordpress.com/2006/08/sig.gif\" alt=\"\" /><br />\n<hr />\n<p><font size=\"-1\"><b>Site Search Tags:</b> <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+news\" rel=\"tag\">wordpress news</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress\" rel=\"tag\">wordpress</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+themes\" rel=\"tag\">wordpress themes</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+plugins\" rel=\"tag\">wordpress plugins</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+logo\" rel=\"tag\">wordpress logo</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+tips\" rel=\"tag\">wordpress tips</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+help\" rel=\"tag\">wordpress help</a> </p>\n<p><a href=\"http://lorelle.wordpress.com/feed/\" title=\"Feed on Lorelle on WordPress\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/02/rss.png\" alt=\"Feed on Lorelle on WordPress\" /></a> <a href=\"http://lorelle.wordpress.com/feed/\" title=\"Feed on Lorelle on WordPress\">Subscribe</a>  <a href=\"http://feeds.feedburner.com/LorelleOnWordPress\" title=\"Feedburner Lorelle on WordPress Feed\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/04/feedburnericon.gif\" alt=\"Feedburner icon\" />Via Feedburner</a>  <a href=\"http://www.feedblitz.com/f/?Sub=182399\" title=\"Lorelle on WordPress - full site feed email subscription\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/03/email.gif\" alt=\"\" />Subscribe by Email</a> <a href=\"http://lorelle.wordpress.com/\" title=\"Visit Lorelle on WordPress\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2008/03/pointer.gif\" alt=\"\" />Visit</a><br /><a href=\"http://lorelle.wordpress.com/about/\" title=\"Copyright Protected by Brent and Lorelle VanFossen\">Copyright Lorelle VanFossen</a>, the author of <a href=\"http://lorelle.wordpress.com/books/blogging-tips/\" title=\"Blogging Tips Book By Lorelle VanFossen\"><em>Blogging Tips, What Bloggers Won\'t Tell You About Blogging</em></a>.</font></p>\nPosted in WordPress News  <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gocomments/lorelle.wordpress.com/3909/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/comments/lorelle.wordpress.com/3909/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godelicious/lorelle.wordpress.com/3909/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/delicious/lorelle.wordpress.com/3909/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gostumble/lorelle.wordpress.com/3909/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/stumble/lorelle.wordpress.com/3909/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godigg/lorelle.wordpress.com/3909/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/digg/lorelle.wordpress.com/3909/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/goreddit/lorelle.wordpress.com/3909/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/reddit/lorelle.wordpress.com/3909/\" /></a> <img alt=\"\" border=\"0\" src=\"http://stats.wordpress.com/b.gif?host=lorelle.wordpress.com&blog=72&post=3909&subd=lorelle&ref=&feed=1\" /></div>\";s:7:\"pubdate\";s:31:\"Mon, 23 Feb 2009 02:21:10 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:17:\"Lorelle VanFossen\";}s:7:\"summary\";s:14052:\"<div class=\"snap_preview\"><br /><p><a href=\"http://lorelle.wordpress.com/tag/wordpress-news/\" title=\"WordPress News\"><img src=\"http://lorelle.files.wordpress.com/2007/01/wpnews1.png\" alt=\"WordPress News\" align=\"right\" /></a>I&#8217;ve just posted this week&#8217;s <a href=\"http://www.blogherald.com/2009/02/20/wordpress-news-can-you-spot-a-wordpress-blog-wordpress-28-news-plugin-directory-searchable-iphone-app-tested-and-more/\" title=\"WordPress News: Can You Spot a WordPress Blog? WordPress 2.8 News, Plugin Directory Searchable, iPhone App Tested, and More\">WordPress News: Can You Spot a WordPress Blog? WordPress 2.8 News, Plugin Directory Searchable, iPhone App Tested, and More</a> on the <a href=\"http://www.blogherald.com/\" title=\"Blog Herald\" rel=\"tag\">Blog Herald</a>.</p>\n<blockquote><p>Can you spot a WordPress blog? Are you sure? WordPress 2.7.1 released. Improvements on the WordPress Plugin Directory search functions. Help for those transferring from LiveJournal to WordPress.com, and WordPress in the future. WordPress 2.8 development on track. WordPress iPhone app in testing for next release. WordPress.com gets a new data center. More WordPress Tattoo news. WordCamps in Miami and India this weekend, Denver next. Singapore starts its first blogger meetup, including WordPress fans. WordPress jobs, and tips for WordPress Plugin and Theme authors. </p></blockquote>\n<p>Here are some highlights of the WordPress news you can use.</p>\n<h4>Improvements in the WordPress Plugin Directory</h4>\n<p>At long last, the <a href=\"http://wordpress.org/extend/plugins/\" title=\"WordPress Plugins Extends\">WordPress Plugin Directory</a> now has a <a href=\"http://wordpress.org/development/2009/02/new-and-improved-plugins-directory-search/\" title=\"New and Improved Plugins Directory Search\">new and improved search function</a> using <a href=\"http://www.sphinxsearch.com/\" title=\"Sphinx\">Sphinx</a> open source SQL full-text search engine to help you find the Plugins you need in the directory from the site as well as the WordPress Plugins panel. </p>\n<h4>Improved LiveJournal Migration</h4>\n<p>For those looking to migrate from LiveJournal to <a href=\"http://www.wordpress.com/\" title=\"WordPress.com free blogs\" rel=\"tag\">WordPress.com</a>, there is now an <a href=\"http://en.blog.wordpress.com/2009/02/18/even-easier-livejournal-migration/\" title=\"Even Easier LiveJournal Migration\">even easier LiveJournal migration</a> process that the WordPress.com team has come up with to help the ever increasing number of people moving to WordPress.com from one of the oldest blogging platforms in the world.</p>\n<p>The new technique is a step by step approach that improves the importing from importing by the month without comments to now include comments, handle &#8220;friends only&#8221; posts, private posts, improvements in tagging, link back to LiveJournal blogs, and connection to the LiveJournal API to download all posts and comments in one pass. One LiveJournal users helped test the importer which handled over 3,700 posts and nearly 200,000 comments. That&#8217;s impressive.</p>\n<p>The new importer will be included in the next major release of the full version of WordPress.<span id=\"more-3909\"></span></p>\n<h4>iPhone WordPress App in Testing Mode</h4>\n<p>The latest version of the <a href=\"http://iphone.wordpress.org/2009/02/17/looking-for-a-few-good-hardware-testers/\" title=\"Looking For a Few Good Hardware Testers\">WordPress iPhone app is underway and they are looking for hardware testers</a> for the next version. </p>\n<p>The changes in the iPhones operating system delayed this new update, but now they are nearly ready for the release to the Apple store. The upcoming version includes landscape mode with the extra wide keyboard, link creation help, editing and creating Pages, comment moderation, asynchronous publishing, photo resizing, and a few more goodies. </p>\n<h4>bbPress On Fire</h4>\n<p><a href=\"http://ma.tt/\" title=\"Matt Mullenweg\" rel=\"tag\">Matt Mullenweg</a> has announced that this is going to be a very active year for development of <a href=\"http://www.bbpress.org/\" title=\"bbPress forum software\" rel=\"tag\">bbPress</a>, the open source forum software that drives the WordPress forums. It begins the year with some new announcements and activities including <a href=\"http://bbpress.org/blog/2009/01/two-new-bbpress-releases/\" title=\"Two new bbPress releases\">two new bbPress releases</a>. One is a security fix to prevent XSS attacks on login pages for Internet Explorer 6, which is highly recommend, and the second includes code improvements that increase the speed at which bbPress interacts with MySQL and integration with WordPress. </p>\n<p>I&#8217;m working on an article for <a href=\"http://lorelle.wordpress.com/\" title=\"Lorelle on WordPress\" rel=\"tag\">Lorelle on WordPress</a> on bbPress, so stay tuned.</p>\n<h4>Help The WordPress Support Forum, Please</h4>\n<p>As a long time volunteer on the <a href=\"http://www.wordpress.org/support\" title=\"WordPress Support Forums\" rel=\"tag\">WordPress Support Forums</a>, I join MichaelH in his request to improve the <a href=\"http://www.wordpress.org/support\" title=\"WordPress Support Forums\" rel=\"tag\">WordPress Support Forums</a> and applaud his recent post on Weblog Tools Collection called &#8220;<a href=\"http://weblogtoolscollection.com/news/topic/wish-list-for-the-wordpress-support-forums-software\" title=\"Wish list for the WordPress Support Forums software\">Wish list for the WordPress Support Forums software</a>.&#8221; </p>\n<p>Run on <a href=\"http://www.bbpress.org/\" title=\"bbPress forum software\" rel=\"tag\">bbPress</a> with a ton of customizations, there are a lot of limitations and problems on the Forums that could easily be fixed, and MichaelH joins a growing voice requesting the Forum be upgraded for increased functionality both by the users and the volunteers and staff who spend a lot of time helping others fix and use WordPress. </p>\n<h4>New Theme on WordPress.com</h4>\n<p>WordPress.com announced the <a href=\"http://en.blog.wordpress.com/2009/02/19/new-theme-vigilance/\" title=\"New Theme: Vigilance\">Vigilance WordPress Theme</a> has been added to the collection which includes customizable colors, alert boxes that appear at the top of the page for announcements, hidden pages from the main menu, custom image header, and special sidebar WordPress Widget functions. </p>\n<h4>Comment Threading on WordPress.com</h4>\n<p><a href=\"http://www.wordpress.com/\" title=\"WordPress.com free blogs\" rel=\"tag\">WordPress.com</a> announced <a href=\"http://en.blog.wordpress.com/2009/02/19/comment-threading-is-here-plus-other-cool-comment-settings/\" title=\"Comment Threading is Here! (Plus Other Cool Comment Settings)\">comment threading and other cool comment features</a> for their free blog hosting service. </p>\n<p>All WordPress Themes are now set up to enable threaded comments, breaking comments into pages, and changing the comment order from the oldest comments on top to the newest comments at the top and the oldest ones at the bottom of the list. Comment threads are allowed up to ten levels. </p>\n<p>To enable this on your WordPress.com blog, go to  <strong>Settings &gt; Discussion &gt; Other Comment Settings</strong> and mark the appropriate boxes. It is disabled by default.</p>\n<h4>WordPress on Your Calendar</h4>\n<p>Some upcoming WordPress events include:</p>\n<ul>\n<li><a href=\"http://india.wordcamp.org/\" title=\"WordCamp India\">Delhi - WordCamp India - February 21-22, 2009</a></li>\n<li><a href=\"http://wordcampmiami.com/\" title=\"WordCamp Miami 2009\">Miami, Florida - WordCamp Miami 2009 - February 22, 2009</a></li>\n<li><a href=\"http://www.meetup.com/wordpress-sf/calendar/9713860/\" title=\"WordPress Surf and Turf (or newb and geeky)\">San Francisco - WordPress Surf and Turf - February 24, 2009</a></li>\n<li><a href=\"http://wordpress.meetup.com/173/calendar/9749800/\" title=\"Almost Everyone is a WordPress Expert\">Austin WordPress Meetup Group - Almost Everyone is a WordPress Expert - February 24, 2009</a></li>\n<li><a href=\"http://www.meetup.com/LasVegasWordPress/calendar/9678812/\" title=\"Las Vegas WordPress Meetup\">Las Vegas WordPress Meetup - February 26, 2009</a></li>\n<li><a href=\"http://wordpress.meetup.com/188/calendar/9763830/\" title=\"Singapore Blogger Meetup\">Singapore Blogger Meetup Froup - February 27, 2009</a></li>\n<li><a href=\"http://denver.wordcamp.org\" title=\"WordCamp Denver\">WordCamp Denver 2009 - February 28, 2009</a> (<a href=\"http://http//www.facebook.com/profile.php?id=779828054#/group.php?gid=22086243642\" title=\"WordCamp Denver 2009\">Facebook</a>)</li>\n<li><a href=\"http://www.meetup.com/dfwwordpress/calendar/9593871/\" title=\"February Meetup of the DFW WordPress Group\">Dallas/Fort Worth WordPress Meetup - Dallas, Texas - February 28, 2009</a></li>\n<li><a href=\"http://wordpress.meetup.com/184/calendar/9615427/\" title=\"Atlanta WordPress Users Group February Meetup\">Atlanta WordPress Users Group Meetup - Learning WordPress 2.7 - Atlanta, Georgia - February 28, 2009</a></li>\n<li><a href=\"http://www.meetup.com/mywplife/calendar/9593848/\" title=\"The Chicago WordPress February Meetup\">The Chicago WordPress February Meetup - February 28, 2009</a></li>\n<li><a href=\"http://www.meetup.com/The-New-Jersey-WordPress-Meetup-Group/calendar/9675967/\" title=\"The New Jersey WordPress March Meetup\">New Jersey - The New Jersey WordPress March Meetup - March 4, 2009</a></li>\n<li><a href=\"http://www.meetup.com/gulf-coast-wordpress/calendar/9684749/\" title=\"Gulf Coast WordPress/Blogger March Meetup\">Mobile, Alabama - Gulf Coast WordPress/Blogger WordPress Meetup - March 5, 2009</a></li>\n<li><a href=\"http://www.meetup.com/LasVegasWordPress/calendar/9678813/\" title=\"Las Vegas WordPress Meetup\">Las Vegas WordPress Meetup - March 5, 2009</a></li>\n<li><a href=\"http://upcoming.yahoo.com/event/1808383/\" title=\"Mar 8, 2009: Los Angeles WordPress Users Group at Philippe\'s French Dip\">Los Angeles WordPress Users Group - March 8, 2009</a></li>\n</ul>\n<p>The last issue of my WordPress News on the <a href=\"http://www.blogherald.com/\" title=\"Blog Herald\" rel=\"tag\">Blog Herald</a> was <a href=\"http://www.blogherald.com/2009/02/05/wordpress-news-release-week-news-wordpress-271-buddypress-wordpress-mu-and-more-releases/\" title=\"WordPress News: Release Week News, WordPress 2.7.1, BuddyPress, WordPress MU, and More Releases\">WordPress News: Release Week News, WordPress 2.7.1, BuddyPress, WordPress MU, and More Releases</a>.</p>\n<p>For more WordPress news, check out my weekly <a href=\"http://www.blogherald.com/tag/wordpress-news/\" title=\"Articles on WordPress News on the Blog Herald\" rel=\"tag\">Blog Herald WordPress News</a>. For more WordCamp news, check out the <a href=\"http://wordcamp.info/\" title=\"The WordCamp Report\">The WordCamp Report</a>.</p>\n<p><img src=\"http://lorelle.files.wordpress.com/2006/08/sig.gif\" alt=\"\" /><br />\n<hr />\n<p><font size=\"-1\"><b>Site Search Tags:</b> <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+news\" rel=\"tag\">wordpress news</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress\" rel=\"tag\">wordpress</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+themes\" rel=\"tag\">wordpress themes</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+plugins\" rel=\"tag\">wordpress plugins</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+logo\" rel=\"tag\">wordpress logo</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+tips\" rel=\"tag\">wordpress tips</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+help\" rel=\"tag\">wordpress help</a> </p>\n<p><a href=\"http://lorelle.wordpress.com/feed/\" title=\"Feed on Lorelle on WordPress\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/02/rss.png\" alt=\"Feed on Lorelle on WordPress\" /></a> <a href=\"http://lorelle.wordpress.com/feed/\" title=\"Feed on Lorelle on WordPress\">Subscribe</a>  <a href=\"http://feeds.feedburner.com/LorelleOnWordPress\" title=\"Feedburner Lorelle on WordPress Feed\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/04/feedburnericon.gif\" alt=\"Feedburner icon\" />Via Feedburner</a>  <a href=\"http://www.feedblitz.com/f/?Sub=182399\" title=\"Lorelle on WordPress - full site feed email subscription\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/03/email.gif\" alt=\"\" />Subscribe by Email</a> <a href=\"http://lorelle.wordpress.com/\" title=\"Visit Lorelle on WordPress\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2008/03/pointer.gif\" alt=\"\" />Visit</a><br /><a href=\"http://lorelle.wordpress.com/about/\" title=\"Copyright Protected by Brent and Lorelle VanFossen\">Copyright Lorelle VanFossen</a>, the author of <a href=\"http://lorelle.wordpress.com/books/blogging-tips/\" title=\"Blogging Tips Book By Lorelle VanFossen\"><em>Blogging Tips, What Bloggers Won\'t Tell You About Blogging</em></a>.</font></p>\nPosted in WordPress News  <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gocomments/lorelle.wordpress.com/3909/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/comments/lorelle.wordpress.com/3909/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godelicious/lorelle.wordpress.com/3909/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/delicious/lorelle.wordpress.com/3909/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gostumble/lorelle.wordpress.com/3909/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/stumble/lorelle.wordpress.com/3909/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godigg/lorelle.wordpress.com/3909/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/digg/lorelle.wordpress.com/3909/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/goreddit/lorelle.wordpress.com/3909/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/reddit/lorelle.wordpress.com/3909/\" /></a> <img alt=\"\" border=\"0\" src=\"http://stats.wordpress.com/b.gif?host=lorelle.wordpress.com&blog=72&post=3909&subd=lorelle&ref=&feed=1\" /></div>\";}i:23;a:7:{s:5:\"title\";s:51:\"Weblog Tools Collection: Plugin Review: Post Avatar\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=5212\";s:4:\"link\";s:79:\"http://weblogtoolscollection.com/archives/2009/02/22/plugin-review-post-avatar/\";s:11:\"description\";s:2386:\"<p>I always thought that I was the only one who had a problem with the WordPress Upload manager. Seems like, I&#8217;m not alone. The author of <a href=\"http://garinungkadol.com/downloads/post-avatar/\">Post Avatar</a> plugin for WordPress also had similar feelings, which was one of the reasons he wrote this plugin.</p>\n<h3>Description</h3>\n<p>This plugin simplifies including a picture when writing posts by allowing the user to choose from a predefined list of images. The image can be automatically shown on the page or output customized with the use of a template tag in themes.</p>\n<h3>Features</h3>\n<ul>\n<li>Easy selection of images in the Write Post screen.</li>\n<li>Scans images in sub-directories of the image option folder.</li>\n<li>Allows the following file types: .jpg, .jpeg, .gif and .png.</li>\n<li>Settings display avatars automatically or through the use of template tags.</li>\n<li>Customize html output of avatars.</li>\n<li>Does not display missing images.</li>\n</ul>\n<h3>Demo</h3>\n<p>For an example of what this looks like you can check out the author&#8217;s site and notice the 100&#215;100px size images before each post.</p>\n<h3>Review</h3>\n<p>The plugin includes detailed installation and usage instructions which is exactly how plugin packages should come.</p>\n<p>Using the plugin is extremely simple. You&#8217;ll need to first set some default options mainly the directory that is to be used to find the post avatars.</p>\n<p>You need to upload these images to this folder in order to use them in your posts. The plugin still doesn&#8217;t support this feature, but this is on the charts and hopefully, you&#8217;ll see it in a later version.</p>\n<p>You can then choose to automatically display the avatars in your posts and / or feeds or you can manually add the code to your template file. I prefer the latter options simply because it gives you more control on where and how exactly you wish to display the avatars.</p>\n<p>The main trick after using this avatars is the styling. The plugin allows you to either use the default styles or customize the class you wish to use as well as the HTML that will be used to display the same. IMO, you don&#8217;t really need to do this as you can use the default styles and then customize the CSS for their display in your theme.</p>\n<p>So, are you using this plugin? Do you like it? What would you like improved?</p>\";s:7:\"pubdate\";s:31:\"Sun, 22 Feb 2009 13:21:51 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:2386:\"<p>I always thought that I was the only one who had a problem with the WordPress Upload manager. Seems like, I&#8217;m not alone. The author of <a href=\"http://garinungkadol.com/downloads/post-avatar/\">Post Avatar</a> plugin for WordPress also had similar feelings, which was one of the reasons he wrote this plugin.</p>\n<h3>Description</h3>\n<p>This plugin simplifies including a picture when writing posts by allowing the user to choose from a predefined list of images. The image can be automatically shown on the page or output customized with the use of a template tag in themes.</p>\n<h3>Features</h3>\n<ul>\n<li>Easy selection of images in the Write Post screen.</li>\n<li>Scans images in sub-directories of the image option folder.</li>\n<li>Allows the following file types: .jpg, .jpeg, .gif and .png.</li>\n<li>Settings display avatars automatically or through the use of template tags.</li>\n<li>Customize html output of avatars.</li>\n<li>Does not display missing images.</li>\n</ul>\n<h3>Demo</h3>\n<p>For an example of what this looks like you can check out the author&#8217;s site and notice the 100&#215;100px size images before each post.</p>\n<h3>Review</h3>\n<p>The plugin includes detailed installation and usage instructions which is exactly how plugin packages should come.</p>\n<p>Using the plugin is extremely simple. You&#8217;ll need to first set some default options mainly the directory that is to be used to find the post avatars.</p>\n<p>You need to upload these images to this folder in order to use them in your posts. The plugin still doesn&#8217;t support this feature, but this is on the charts and hopefully, you&#8217;ll see it in a later version.</p>\n<p>You can then choose to automatically display the avatars in your posts and / or feeds or you can manually add the code to your template file. I prefer the latter options simply because it gives you more control on where and how exactly you wish to display the avatars.</p>\n<p>The main trick after using this avatars is the styling. The plugin allows you to either use the default styles or customize the class you wish to use as well as the HTML that will be used to display the same. IMO, you don&#8217;t really need to do this as you can use the default styles and then customize the CSS for their display in your theme.</p>\n<p>So, are you using this plugin? Do you like it? What would you like improved?</p>\";}i:24;a:7:{s:5:\"title\";s:46:\"Weblog Tools Collection: WordCamp India is On!\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=5201\";s:4:\"link\";s:74:\"http://weblogtoolscollection.com/archives/2009/02/21/wordcamp-india-is-on/\";s:11:\"description\";s:1658:\"<p><a href=\"http://wci.eventbrite.com/\">WordCamp India is On!</a>. The list of speakers is quite impressive and includes both <a href=\"http://ma.tt\">Matt</a> and <a href=\"http://omis.me/\">Om</a> for various talks including Matt&#8217;s famous &#8220;<a href=\"http://www.google.com/search?hl=en&amp;q=%22state+of+the+word%22&amp;btnG=Search\">State of the Word</a>&#8220;. It looks to be a fun and information filled event with quite interesting fare such as SEO, IP rights and other both techie and non-techie topics. As luck would have it, I am going to be traveling though Dubai and India next weekend (days late, dollars short) and will not be able to attend.</p>\n<p>From the list of sponsors, the list of attendees and the list of speakers, the enthusiasm for blogging and WordPress in India is not lost on me. If you have not checked out the <a href=\"http://www.delhibloggersbloc.com/\">Delhi Bloggers Group</a> or one of the many other blogging groups and partnerships mentioned and you are an Indian blogger, you might be missing out. I am hopeful that the turnout will be fantastic and I hope to see some of the presentations on <a href=\"http://wordpress.tv/category/wordcamptv/\">WordPress.tv</a></p>\n<p>I am jealous that Matt and Om were able to visit the Taj Mahal because it appears that <a href=\"http://www.zeenews.com/Nation/2007-02-20/355367news.html\">parts of the Taj might be restricted to visitors</a>. Om has an <a href=\"http://gigaom.com/2009/02/19/what-the-taj-mahal-and-apple-have-in-common/\">interesting take on the Taj and Apple Computers</a> and <a href=\"http://ma.tt/2009/02/taj-mahal-agra/\">Matt has some nice pictures posted</a>.</p>\";s:7:\"pubdate\";s:31:\"Sat, 21 Feb 2009 20:47:47 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:10:\"Mark Ghosh\";}s:7:\"summary\";s:1658:\"<p><a href=\"http://wci.eventbrite.com/\">WordCamp India is On!</a>. The list of speakers is quite impressive and includes both <a href=\"http://ma.tt\">Matt</a> and <a href=\"http://omis.me/\">Om</a> for various talks including Matt&#8217;s famous &#8220;<a href=\"http://www.google.com/search?hl=en&amp;q=%22state+of+the+word%22&amp;btnG=Search\">State of the Word</a>&#8220;. It looks to be a fun and information filled event with quite interesting fare such as SEO, IP rights and other both techie and non-techie topics. As luck would have it, I am going to be traveling though Dubai and India next weekend (days late, dollars short) and will not be able to attend.</p>\n<p>From the list of sponsors, the list of attendees and the list of speakers, the enthusiasm for blogging and WordPress in India is not lost on me. If you have not checked out the <a href=\"http://www.delhibloggersbloc.com/\">Delhi Bloggers Group</a> or one of the many other blogging groups and partnerships mentioned and you are an Indian blogger, you might be missing out. I am hopeful that the turnout will be fantastic and I hope to see some of the presentations on <a href=\"http://wordpress.tv/category/wordcamptv/\">WordPress.tv</a></p>\n<p>I am jealous that Matt and Om were able to visit the Taj Mahal because it appears that <a href=\"http://www.zeenews.com/Nation/2007-02-20/355367news.html\">parts of the Taj might be restricted to visitors</a>. Om has an <a href=\"http://gigaom.com/2009/02/19/what-the-taj-mahal-and-apple-have-in-common/\">interesting take on the Taj and Apple Computers</a> and <a href=\"http://ma.tt/2009/02/taj-mahal-agra/\">Matt has some nice pictures posted</a>.</p>\";}i:25;a:7:{s:5:\"title\";s:60:\"Weblog Tools Collection: WordPress Plugin Releases for 02/20\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=5208\";s:4:\"link\";s:88:\"http://weblogtoolscollection.com/archives/2009/02/20/wordpress-plugin-releases-for-0220/\";s:11:\"description\";s:3784:\"<h3>New Plugins</h3>\n<p><a href=\"http://wordpress.org/extend/plugins/wordpress-twitterbot/\">Wordpress Twitter Bot</a></p>\n<p>Post your Wordpress blog updates to your Twitter account</p>\n<p><a href=\"http://wordpresswiki.org/community-documentation/\">WordPress Wiki Plugin</a></p>\n<p>The WordPress Wiki Plugin adds Wiki functionality to your WordPress powered website.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/plugin-list/\">Plugin List</a></p>\n<p>Lists current WordPress plugins used inside of page/post content.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/custom-logo/\">Custom Logo</a></p>\n<p>Replace WordPress default login/register page logo with custom one.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/wp-imagemation/\">WP_ImageMation</a></p>\n<p>ImageMation lets you put a set of sliding images with captions on any of your WordPress page.</p>\n<p><a href=\"http://kempwire.com/wordpress-ultimate-noindex-nofollow-plugin\">Ultimate Noindex Nofollow Tool</a></p>\n<p>Improves your blog&#8217;s search engine optimization by &#8220;noindexing&#8221; pages you choose.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/faster-image-insert/\">Faster Image Insert</a></p>\n<p>Integrates media manager into edit panel meta-box, avoid having to reload it separately in thickbox pop-up, suitable for precise image control.</p>\n<p><a href=\"http://blogtap.net/custom_post_background_plugin.shtml\">Custom Post Background</a></p>\n<p>Create custom backgrounds or styles for your posts and pages.</p>\n<p><a href=\"http://nothing.golddave.com/?page_id=680\">Share On Facebook</a></p>\n<p>This plugin adds a footer link to add the current post or page as a Facebook link.</p>\n<p><a href=\"http://blog.caspie.net/2009/02/19/fast-tube-wordpress-plugin/\">Fast Tube</a></p>\n<p>Fast and easy way to insert videos from YouTube right into your WordPress blog posts or pages.</p>\n<h3>Updated Plugins</h3>\n<p><a href=\"http://wordpress.org/extend/plugins/plugin-wonderful/\">Plugin Wonderful</a></p>\n<p>An easy way to place your <a href=\"http://www.projectwonderful.com/\">Project Wonderful</a> ads into your Website. Downloads your adbox information and allows you to post your ads as sidebar widgets, template tags, or straight in your RSS feed.</p>\n<p><a href=\"http://skyphe.org/code/wordpress/decategorizer/\">Decategorizer</a></p>\n<p>&#8220;Decategorizer&#8221; removes &#8216;category base&#8217; from your permalinks. Quick setup and no editing required. 301 redirections are added automatically.</p>\n<p><a href=\"http://www.dyasonhat.com/wp-smart-sort/\">WP Smart Sort</a></p>\n<p>WP Smart sort offers advanced sorting of posts in your blog. Sort posts by Title, Date, Comment count, Custom Fields and more.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/addquicktag/\">AddQuicktag</a></p>\n<p>This plugin make it easy, Quicktags add to the editor. It is possible to ex- and import your Quicktags.</p>\n<p><a href=\"http://www.viper007bond.com/wordpress-plugins/vipers-video-quicktags/\">Viper&#8217;s Video Quicktags</a></p>\n<p>Allows easy and XHTML valid posting of videos from various websites such as YouTube, DailyMotion, Vimeo, and more.</p>\n<p><a href=\"http://noscope.com/journal/2008/12/quote-comments-javascript-plugin-for-wordpress\">Quote Comments</a></p>\n<p>Creates a little quote icon in comment boxes which, when clicked, copies that comment to the comment box wrapped in blockquotes.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/secure-wordpress/\">Secure WordPress</a></p>\n<p>Secure your WordPress Installation with small functions.</p>\n<p><a href=\"http://www.hybrid6.com/webgeek/plugins/wp-spamfree\">WP-SpamFree</a></p>\n<p>Powerful anti-spam plugin that virtually eliminates comment spam. Finally, you can enjoy a spam-free WordPress blog! Includes contact form.</p>\";s:7:\"pubdate\";s:31:\"Fri, 20 Feb 2009 19:42:46 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:3784:\"<h3>New Plugins</h3>\n<p><a href=\"http://wordpress.org/extend/plugins/wordpress-twitterbot/\">Wordpress Twitter Bot</a></p>\n<p>Post your Wordpress blog updates to your Twitter account</p>\n<p><a href=\"http://wordpresswiki.org/community-documentation/\">WordPress Wiki Plugin</a></p>\n<p>The WordPress Wiki Plugin adds Wiki functionality to your WordPress powered website.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/plugin-list/\">Plugin List</a></p>\n<p>Lists current WordPress plugins used inside of page/post content.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/custom-logo/\">Custom Logo</a></p>\n<p>Replace WordPress default login/register page logo with custom one.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/wp-imagemation/\">WP_ImageMation</a></p>\n<p>ImageMation lets you put a set of sliding images with captions on any of your WordPress page.</p>\n<p><a href=\"http://kempwire.com/wordpress-ultimate-noindex-nofollow-plugin\">Ultimate Noindex Nofollow Tool</a></p>\n<p>Improves your blog&#8217;s search engine optimization by &#8220;noindexing&#8221; pages you choose.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/faster-image-insert/\">Faster Image Insert</a></p>\n<p>Integrates media manager into edit panel meta-box, avoid having to reload it separately in thickbox pop-up, suitable for precise image control.</p>\n<p><a href=\"http://blogtap.net/custom_post_background_plugin.shtml\">Custom Post Background</a></p>\n<p>Create custom backgrounds or styles for your posts and pages.</p>\n<p><a href=\"http://nothing.golddave.com/?page_id=680\">Share On Facebook</a></p>\n<p>This plugin adds a footer link to add the current post or page as a Facebook link.</p>\n<p><a href=\"http://blog.caspie.net/2009/02/19/fast-tube-wordpress-plugin/\">Fast Tube</a></p>\n<p>Fast and easy way to insert videos from YouTube right into your WordPress blog posts or pages.</p>\n<h3>Updated Plugins</h3>\n<p><a href=\"http://wordpress.org/extend/plugins/plugin-wonderful/\">Plugin Wonderful</a></p>\n<p>An easy way to place your <a href=\"http://www.projectwonderful.com/\">Project Wonderful</a> ads into your Website. Downloads your adbox information and allows you to post your ads as sidebar widgets, template tags, or straight in your RSS feed.</p>\n<p><a href=\"http://skyphe.org/code/wordpress/decategorizer/\">Decategorizer</a></p>\n<p>&#8220;Decategorizer&#8221; removes &#8216;category base&#8217; from your permalinks. Quick setup and no editing required. 301 redirections are added automatically.</p>\n<p><a href=\"http://www.dyasonhat.com/wp-smart-sort/\">WP Smart Sort</a></p>\n<p>WP Smart sort offers advanced sorting of posts in your blog. Sort posts by Title, Date, Comment count, Custom Fields and more.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/addquicktag/\">AddQuicktag</a></p>\n<p>This plugin make it easy, Quicktags add to the editor. It is possible to ex- and import your Quicktags.</p>\n<p><a href=\"http://www.viper007bond.com/wordpress-plugins/vipers-video-quicktags/\">Viper&#8217;s Video Quicktags</a></p>\n<p>Allows easy and XHTML valid posting of videos from various websites such as YouTube, DailyMotion, Vimeo, and more.</p>\n<p><a href=\"http://noscope.com/journal/2008/12/quote-comments-javascript-plugin-for-wordpress\">Quote Comments</a></p>\n<p>Creates a little quote icon in comment boxes which, when clicked, copies that comment to the comment box wrapped in blockquotes.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/secure-wordpress/\">Secure WordPress</a></p>\n<p>Secure your WordPress Installation with small functions.</p>\n<p><a href=\"http://www.hybrid6.com/webgeek/plugins/wp-spamfree\">WP-SpamFree</a></p>\n<p>Powerful anti-spam plugin that virtually eliminates comment spam. Finally, you can enjoy a spam-free WordPress blog! Includes contact form.</p>\";}i:26;a:7:{s:5:\"title\";s:21:\"Matt: Taj Mahal, Agra\";s:4:\"guid\";s:21:\"http://ma.tt/?p=11876\";s:4:\"link\";s:36:\"http://ma.tt/2009/02/taj-mahal-agra/\";s:11:\"description\";s:29405:\"<p>Visiting Agra and the Taj Mahal with <a href=\"http://omis.me/\">Om</a>.</p>\n<p><span id=\"more-11876\"></span></p>\n\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9393/\" title=\"mcm_9393\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9393-195x151.jpg\" width=\"195\" height=\"151\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9394/\" title=\"mcm_9394\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9394-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9396/\" title=\"mcm_9396\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9396-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9397/\" title=\"mcm_9397\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9397-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9399/\" title=\"mcm_9399\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9399-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9400/\" title=\"mcm_9400\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9400-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9401/\" title=\"mcm_9401\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9401-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9403/\" title=\"mcm_9403\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9403-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9405/\" title=\"mcm_9405\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9405-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9406/\" title=\"mcm_9406\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9406-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9409/\" title=\"mcm_9409\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9409-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9413/\" title=\"mcm_9413\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9413-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9414/\" title=\"mcm_9414\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9414-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9416/\" title=\"mcm_9416\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9416-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9419/\" title=\"mcm_9419\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9419-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9423/\" title=\"mcm_9423\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9423-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9424/\" title=\"mcm_9424\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9424-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9425/\" title=\"mcm_9425\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9425-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9426/\" title=\"mcm_9426\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9426-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9427/\" title=\"mcm_9427\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9427-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9429/\" title=\"mcm_9429\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9429-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9430/\" title=\"mcm_9430\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9430-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9433/\" title=\"mcm_9433\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9433-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9434/\" title=\"mcm_9434\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9434-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9435/\" title=\"mcm_9435\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9435-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9437/\" title=\"mcm_9437\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9437-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9439/\" title=\"mcm_9439\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9439-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9441/\" title=\"mcm_9441\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9441-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9443/\" title=\"mcm_9443\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9443-195x130.jpg\" width=\"195\" height=\"130\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9444/\" title=\"mcm_9444\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9444-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9447/\" title=\"mcm_9447\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9447-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9449/\" title=\"mcm_9449\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9449-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9460/\" title=\"mcm_9460\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9460-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9463/\" title=\"mcm_9463\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9463-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9466/\" title=\"mcm_9466\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9466-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9467/\" title=\"mcm_9467\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9467-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9469/\" title=\"mcm_9469\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9469-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9470/\" title=\"mcm_9470\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9470-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9471/\" title=\"mcm_9471\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9471-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9474/\" title=\"mcm_9474\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9474-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9475/\" title=\"mcm_9475\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9475-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9476/\" title=\"mcm_9476\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9476-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9477/\" title=\"mcm_9477\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9477-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9480/\" title=\"mcm_9480\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9480-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9482/\" title=\"mcm_9482\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9482-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9485/\" title=\"mcm_9485\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9485-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9492/\" title=\"mcm_9492\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9492-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9495/\" title=\"mcm_9495\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9495-140x210.jpg\" width=\"140\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9496/\" title=\"mcm_9496\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9496-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9497/\" title=\"mcm_9497\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9497-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9498/\" title=\"mcm_9498\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9498-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9499/\" title=\"mcm_9499\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9499-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9500/\" title=\"mcm_9500\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9500-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9503/\" title=\"mcm_9503\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9503-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9509/\" title=\"mcm_9509\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9509-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9510/\" title=\"mcm_9510\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9510-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9512/\" title=\"mcm_9512\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9512-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9513/\" title=\"mcm_9513\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9513-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/p1000501/\" title=\"p1000501\"><img src=\"http://s.ma.tt/files/2009/02/p1000501-195x109.jpg\" width=\"195\" height=\"109\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9515/\" title=\"mcm_9515\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9515-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9518/\" title=\"mcm_9518\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9518-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/p1000506/\" title=\"p1000506\"><img src=\"http://s.ma.tt/files/2009/02/p1000506-195x109.jpg\" width=\"195\" height=\"109\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9519/\" title=\"mcm_9519\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9519-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9520/\" title=\"mcm_9520\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9520-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/p1000505/\" title=\"p1000505\"><img src=\"http://s.ma.tt/files/2009/02/p1000505-195x109.jpg\" width=\"195\" height=\"109\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9521/\" title=\"mcm_9521\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9521-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9524/\" title=\"mcm_9524\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9524-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9526/\" title=\"mcm_9526\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9526-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9527/\" title=\"mcm_9527\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9527-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9529/\" title=\"mcm_9529\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9529-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9532/\" title=\"mcm_9532\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9532-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9533/\" title=\"mcm_9533\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9533-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9535/\" title=\"mcm_9535\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9535-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9536/\" title=\"mcm_9536\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9536-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9539/\" title=\"mcm_9539\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9539-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9540/\" title=\"mcm_9540\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9540-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9541/\" title=\"mcm_9541\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9541-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9542/\" title=\"mcm_9542\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9542-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9543/\" title=\"mcm_9543\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9543-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9544/\" title=\"mcm_9544\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9544-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9545/\" title=\"mcm_9545\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9545-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9546/\" title=\"mcm_9546\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9546-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9547/\" title=\"mcm_9547\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9547-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9548/\" title=\"mcm_9548\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9548-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9550/\" title=\"mcm_9550\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9550-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9551/\" title=\"mcm_9551\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9551-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9553/\" title=\"mcm_9553\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9553-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9555/\" title=\"mcm_9555\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9555-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9556/\" title=\"mcm_9556\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9556-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9558/\" title=\"mcm_9558\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9558-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9561/\" title=\"mcm_9561\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9561-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9566/\" title=\"mcm_9566\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9566-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9568/\" title=\"mcm_9568\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9568-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9570/\" title=\"mcm_9570\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9570-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9572/\" title=\"mcm_9572\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9572-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9573/\" title=\"mcm_9573\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9573-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9574/\" title=\"mcm_9574\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9574-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9578/\" title=\"mcm_9578\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9578-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9579/\" title=\"mcm_9579\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9579-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9581/\" title=\"mcm_9581\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9581-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9582/\" title=\"mcm_9582\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9582-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9583/\" title=\"mcm_9583\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9583-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9585/\" title=\"mcm_9585\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9585-195x128.jpg\" width=\"195\" height=\"128\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9587/\" title=\"mcm_9587\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9587-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9588/\" title=\"mcm_9588\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9588-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9589/\" title=\"mcm_9589\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9589-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9590/\" title=\"mcm_9590\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9590-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9591/\" title=\"mcm_9591\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9591-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/p1000542/\" title=\"p1000542\"><img src=\"http://s.ma.tt/files/2009/02/p1000542-195x109.jpg\" width=\"195\" height=\"109\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9596/\" title=\"mcm_9596\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9596-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9598/\" title=\"mcm_9598\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9598-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/p1000538/\" title=\"p1000538\"><img src=\"http://s.ma.tt/files/2009/02/p1000538-118x209.jpg\" width=\"118\" height=\"209\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9600/\" title=\"mcm_9600\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9600-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9601/\" title=\"mcm_9601\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9601-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9606/\" title=\"mcm_9606\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9606-195x130.jpg\" width=\"195\" height=\"130\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9607/\" title=\"mcm_9607\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9607-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9608/\" title=\"mcm_9608\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9608-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9609/\" title=\"mcm_9609\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9609-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9614/\" title=\"mcm_9614\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9614-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9615/\" title=\"mcm_9615\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9615-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9616/\" title=\"mcm_9616\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9616-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9617/\" title=\"mcm_9617\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9617-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9618/\" title=\"mcm_9618\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9618-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9619/\" title=\"mcm_9619\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9619-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9620/\" title=\"mcm_9620\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9620-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9621/\" title=\"mcm_9621\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9621-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9624/\" title=\"mcm_9624\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9624-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9626/\" title=\"mcm_9626\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9626-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9629/\" title=\"mcm_9629\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9629-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9630/\" title=\"mcm_9630\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9630-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9632/\" title=\"mcm_9632\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9632-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9633/\" title=\"mcm_9633\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9633-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9634/\" title=\"mcm_9634\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9634-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9638/\" title=\"mcm_9638\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9638-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9640/\" title=\"mcm_9640\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9640-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9651/\" title=\"mcm_9651\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9651-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9653/\" title=\"mcm_9653\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9653-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9656/\" title=\"mcm_9656\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9656-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9661/\" title=\"mcm_9661\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9661-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9664/\" title=\"mcm_9664\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9664-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9669/\" title=\"mcm_9669\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9669-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9674/\" title=\"mcm_9674\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9674-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9675/\" title=\"mcm_9675\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9675-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9676/\" title=\"mcm_9676\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9676-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9677/\" title=\"mcm_9677\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9677-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\";s:7:\"pubdate\";s:31:\"Fri, 20 Feb 2009 08:15:50 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:7:\"summary\";s:29405:\"<p>Visiting Agra and the Taj Mahal with <a href=\"http://omis.me/\">Om</a>.</p>\n<p><span id=\"more-11876\"></span></p>\n\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9393/\" title=\"mcm_9393\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9393-195x151.jpg\" width=\"195\" height=\"151\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9394/\" title=\"mcm_9394\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9394-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9396/\" title=\"mcm_9396\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9396-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9397/\" title=\"mcm_9397\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9397-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9399/\" title=\"mcm_9399\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9399-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9400/\" title=\"mcm_9400\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9400-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9401/\" title=\"mcm_9401\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9401-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9403/\" title=\"mcm_9403\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9403-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9405/\" title=\"mcm_9405\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9405-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9406/\" title=\"mcm_9406\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9406-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9409/\" title=\"mcm_9409\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9409-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9413/\" title=\"mcm_9413\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9413-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9414/\" title=\"mcm_9414\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9414-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9416/\" title=\"mcm_9416\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9416-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9419/\" title=\"mcm_9419\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9419-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9423/\" title=\"mcm_9423\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9423-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9424/\" title=\"mcm_9424\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9424-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9425/\" title=\"mcm_9425\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9425-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9426/\" title=\"mcm_9426\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9426-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9427/\" title=\"mcm_9427\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9427-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9429/\" title=\"mcm_9429\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9429-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9430/\" title=\"mcm_9430\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9430-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9433/\" title=\"mcm_9433\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9433-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9434/\" title=\"mcm_9434\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9434-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9435/\" title=\"mcm_9435\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9435-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9437/\" title=\"mcm_9437\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9437-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9439/\" title=\"mcm_9439\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9439-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9441/\" title=\"mcm_9441\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9441-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9443/\" title=\"mcm_9443\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9443-195x130.jpg\" width=\"195\" height=\"130\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9444/\" title=\"mcm_9444\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9444-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9447/\" title=\"mcm_9447\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9447-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9449/\" title=\"mcm_9449\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9449-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9460/\" title=\"mcm_9460\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9460-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9463/\" title=\"mcm_9463\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9463-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9466/\" title=\"mcm_9466\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9466-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9467/\" title=\"mcm_9467\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9467-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9469/\" title=\"mcm_9469\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9469-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9470/\" title=\"mcm_9470\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9470-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9471/\" title=\"mcm_9471\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9471-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9474/\" title=\"mcm_9474\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9474-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9475/\" title=\"mcm_9475\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9475-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9476/\" title=\"mcm_9476\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9476-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9477/\" title=\"mcm_9477\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9477-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9480/\" title=\"mcm_9480\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9480-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9482/\" title=\"mcm_9482\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9482-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9485/\" title=\"mcm_9485\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9485-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9492/\" title=\"mcm_9492\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9492-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9495/\" title=\"mcm_9495\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9495-140x210.jpg\" width=\"140\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9496/\" title=\"mcm_9496\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9496-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9497/\" title=\"mcm_9497\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9497-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9498/\" title=\"mcm_9498\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9498-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9499/\" title=\"mcm_9499\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9499-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9500/\" title=\"mcm_9500\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9500-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9503/\" title=\"mcm_9503\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9503-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9509/\" title=\"mcm_9509\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9509-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9510/\" title=\"mcm_9510\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9510-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9512/\" title=\"mcm_9512\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9512-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9513/\" title=\"mcm_9513\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9513-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/p1000501/\" title=\"p1000501\"><img src=\"http://s.ma.tt/files/2009/02/p1000501-195x109.jpg\" width=\"195\" height=\"109\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9515/\" title=\"mcm_9515\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9515-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9518/\" title=\"mcm_9518\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9518-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/p1000506/\" title=\"p1000506\"><img src=\"http://s.ma.tt/files/2009/02/p1000506-195x109.jpg\" width=\"195\" height=\"109\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9519/\" title=\"mcm_9519\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9519-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9520/\" title=\"mcm_9520\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9520-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/p1000505/\" title=\"p1000505\"><img src=\"http://s.ma.tt/files/2009/02/p1000505-195x109.jpg\" width=\"195\" height=\"109\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9521/\" title=\"mcm_9521\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9521-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9524/\" title=\"mcm_9524\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9524-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9526/\" title=\"mcm_9526\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9526-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9527/\" title=\"mcm_9527\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9527-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9529/\" title=\"mcm_9529\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9529-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9532/\" title=\"mcm_9532\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9532-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9533/\" title=\"mcm_9533\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9533-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9535/\" title=\"mcm_9535\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9535-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9536/\" title=\"mcm_9536\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9536-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9539/\" title=\"mcm_9539\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9539-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9540/\" title=\"mcm_9540\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9540-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9541/\" title=\"mcm_9541\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9541-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9542/\" title=\"mcm_9542\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9542-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9543/\" title=\"mcm_9543\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9543-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9544/\" title=\"mcm_9544\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9544-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9545/\" title=\"mcm_9545\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9545-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9546/\" title=\"mcm_9546\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9546-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9547/\" title=\"mcm_9547\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9547-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9548/\" title=\"mcm_9548\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9548-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9550/\" title=\"mcm_9550\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9550-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9551/\" title=\"mcm_9551\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9551-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9553/\" title=\"mcm_9553\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9553-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9555/\" title=\"mcm_9555\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9555-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9556/\" title=\"mcm_9556\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9556-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9558/\" title=\"mcm_9558\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9558-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9561/\" title=\"mcm_9561\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9561-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9566/\" title=\"mcm_9566\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9566-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9568/\" title=\"mcm_9568\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9568-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9570/\" title=\"mcm_9570\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9570-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9572/\" title=\"mcm_9572\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9572-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9573/\" title=\"mcm_9573\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9573-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9574/\" title=\"mcm_9574\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9574-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9578/\" title=\"mcm_9578\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9578-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9579/\" title=\"mcm_9579\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9579-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9581/\" title=\"mcm_9581\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9581-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9582/\" title=\"mcm_9582\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9582-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9583/\" title=\"mcm_9583\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9583-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9585/\" title=\"mcm_9585\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9585-195x128.jpg\" width=\"195\" height=\"128\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9587/\" title=\"mcm_9587\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9587-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9588/\" title=\"mcm_9588\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9588-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9589/\" title=\"mcm_9589\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9589-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9590/\" title=\"mcm_9590\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9590-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9591/\" title=\"mcm_9591\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9591-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/p1000542/\" title=\"p1000542\"><img src=\"http://s.ma.tt/files/2009/02/p1000542-195x109.jpg\" width=\"195\" height=\"109\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9596/\" title=\"mcm_9596\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9596-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9598/\" title=\"mcm_9598\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9598-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/p1000538/\" title=\"p1000538\"><img src=\"http://s.ma.tt/files/2009/02/p1000538-118x209.jpg\" width=\"118\" height=\"209\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9600/\" title=\"mcm_9600\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9600-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9601/\" title=\"mcm_9601\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9601-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9606/\" title=\"mcm_9606\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9606-195x130.jpg\" width=\"195\" height=\"130\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9607/\" title=\"mcm_9607\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9607-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9608/\" title=\"mcm_9608\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9608-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9609/\" title=\"mcm_9609\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9609-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9614/\" title=\"mcm_9614\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9614-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9615/\" title=\"mcm_9615\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9615-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9616/\" title=\"mcm_9616\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9616-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9617/\" title=\"mcm_9617\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9617-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9618/\" title=\"mcm_9618\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9618-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9619/\" title=\"mcm_9619\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9619-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9620/\" title=\"mcm_9620\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9620-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9621/\" title=\"mcm_9621\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9621-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9624/\" title=\"mcm_9624\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9624-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9626/\" title=\"mcm_9626\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9626-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9629/\" title=\"mcm_9629\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9629-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9630/\" title=\"mcm_9630\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9630-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9632/\" title=\"mcm_9632\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9632-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9633/\" title=\"mcm_9633\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9633-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9634/\" title=\"mcm_9634\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9634-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9638/\" title=\"mcm_9638\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9638-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9640/\" title=\"mcm_9640\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9640-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9651/\" title=\"mcm_9651\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9651-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9653/\" title=\"mcm_9653\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9653-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9656/\" title=\"mcm_9656\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9656-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9661/\" title=\"mcm_9661\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9661-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9664/\" title=\"mcm_9664\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9664-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9669/\" title=\"mcm_9669\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9669-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9674/\" title=\"mcm_9674\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9674-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9675/\" title=\"mcm_9675\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9675-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9676/\" title=\"mcm_9676\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9676-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2009/02/taj-mahal-agra/mcm_9677/\" title=\"mcm_9677\"><img src=\"http://s.ma.tt/files/2009/02/mcm_9677-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\";}i:27;a:7:{s:5:\"title\";s:24:\"Matt: Om’s India Posts\";s:4:\"guid\";s:21:\"http://ma.tt/?p=11874\";s:4:\"link\";s:37:\"http://ma.tt/2009/02/oms-india-posts/\";s:11:\"description\";s:293:\"<p>Om has been doing a bit of blogging from here in India: <a href=\"http://gigaom.com/2009/02/19/more-bars-in-more-places/\">More Bars in More Places</a> and <a href=\"http://gigaom.com/2009/02/19/what-the-taj-mahal-and-apple-have-in-common/\">What the Taj Mahal and Apple Have in Common</a>.</p>\";s:7:\"pubdate\";s:31:\"Fri, 20 Feb 2009 03:11:56 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:7:\"summary\";s:293:\"<p>Om has been doing a bit of blogging from here in India: <a href=\"http://gigaom.com/2009/02/19/more-bars-in-more-places/\">More Bars in More Places</a> and <a href=\"http://gigaom.com/2009/02/19/what-the-taj-mahal-and-apple-have-in-common/\">What the Taj Mahal and Apple Have in Common</a>.</p>\";}i:28;a:7:{s:5:\"title\";s:25:\"Matt: ReadWriteWeb France\";s:4:\"guid\";s:21:\"http://ma.tt/?p=11872\";s:4:\"link\";s:41:\"http://ma.tt/2009/02/readwriteweb-france/\";s:11:\"description\";s:215:\"<p><a href=\"http://www.readwriteweb.com/archives/readwriteweb_france_matt_mullenweg.php\">ReadWriteWeb France Catches Up with Matt Mullenweg</a>. The French version of RWW uses WordPress and is doing really well.</p>\";s:7:\"pubdate\";s:31:\"Fri, 20 Feb 2009 02:37:00 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:7:\"summary\";s:215:\"<p><a href=\"http://www.readwriteweb.com/archives/readwriteweb_france_matt_mullenweg.php\">ReadWriteWeb France Catches Up with Matt Mullenweg</a>. The French version of RWW uses WordPress and is doing really well.</p>\";}i:29;a:7:{s:5:\"title\";s:79:\"Weblog Tools Collection: Plugin Authors, Are you making the best of Readme.txt?\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=5206\";s:4:\"link\";s:105:\"http://weblogtoolscollection.com/archives/2009/02/19/plugin-authors-are-you-making-the-best-of-readmetxt/\";s:11:\"description\";s:3778:\"<p>I visit the <a href=\"http://wordpress.org/extend/plugins/\">WordPress Plugin Directory</a> a lot during my constant hunt for plugins for our release posts. If you&#8217;re a plugin author and you&#8217;re not hosting your plugin on the Repository then you&#8217;re definitely missing out a lot in getting your plugin out to all WordPress Users, especially now with the <a href=\"http://wordpress.org/development/2009/02/new-and-improved-plugins-directory-search/\">Plugin Directory search improved</a>. So, if you&#8217;re a plugin author and if you release your plugins as GPL, then do remember to <a href=\"http://wordpress.org/extend/plugins/add/\">add your plugin</a>.</p>\n<p>That being said, if you&#8217;re hosting your plugin there, then you will be required to add a <em>readme.txt</em> file in the folder of your plugin.</p>\n<p>To begin with, take a look at the <a href=\"http://wordpress.org/extend/plugins/about/readme.txt\">standard readme.txt file</a>.</p>\n<p>The readme.txt file contains the following sections:</p>\n<ul>\n<li>Plugin Name</li>\n<li>Description</li>\n<li>Installation</li>\n<li>Frequently Asked Questions</li>\n<li>Screenshots</li>\n<li>Other sections</li>\n</ul>\n<p>In my opinion, the most important of these are the first two sections since these are the first that a potential user sees. Completing all the sections is also useful since these can be searched.</p>\n<p>I&#8217;m going to focus this post on the <strong>Plugin Name</strong> section.</p>\n<pre>=== Plugin Name ===\nContributors: Ajay, Mark Ghosh\nDonate link: http://weblogtoolscollection.com/\nTags: comments, spam\nRequires at least: 2.0.2\nTested up to: 2.1\nStable tag: 4.3\n\nHere is a short description of the plugin.  This should be no more than 150 chars.  No markup here.</pre>\n<p>Another important section while adding your plugin is the header section in the plugin file itself. Here&#8217;s the section from my plugin <a href=\"http://ajaydsouza.com/wordpress/plugins/top-10/\">Top 10</a>.</p>\n<pre>/*\nPlugin Name: Top 10\nVersion:     1.1\nPlugin URI:  http://ajaydsouza.com/wordpress/plugins/top-10/\nDescription: Count visits per post and display the most popular posts based on the number of views.\nAuthor:      Ajay D\'Souza\nAuthor URI:  http://ajaydsouza.com/\n*/</pre>\n<p>And, while this isn&#8217;t part of the readme.txt, it also contributes towards the listing of your plugin. These both, in combination, are used to populate the details for each plugin as you can see below.</p>\n<p><img title=\"Plugin Details\" src=\"http://weblogtoolscollection.com/b2-img/2009/02/plugin-details.gif\" border=\"0\" alt=\"Plugin Details\" width=\"214\" height=\"255\" /></p>\n<p>The <strong>Author Homepage</strong> and <strong>Plugin Homepage</strong> are pulled from the plugin file, viz. <strong>Author URI</strong> and <strong>Plugin URI</strong> respectively. The version number is also pulled from the plugin file. The <strong>Requires WordPress Version</strong>, <strong>Compatible up to</strong> and <strong>Donate</strong> link are pulled from the readme.txt file.</p>\n<p>Hence, populating both the readme.txt file and the plugin file make your plugin complete.</p>\n<p>I&#8217;ve seen a lot of plugins which either miss out one of the three links above or just point them back to the repository. Some plugins have the same Author Homepage and Plugin Homepage. Needless to say, these aren&#8217;t making the most use of all the sections that are given to you.</p>\n<p>Are you a plugin author? Are you hosting your plugin on the directory? If so, why not?</p>\n<p>Are you ensuring that you are completely using all the sections in your plugin header section and the readme.txt? Do remember to run your readme.txt file through the <a href=\"http://wordpress.org/extend/plugins/about/validator/\">validator</a>.</p>\";s:7:\"pubdate\";s:31:\"Thu, 19 Feb 2009 16:56:30 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:3778:\"<p>I visit the <a href=\"http://wordpress.org/extend/plugins/\">WordPress Plugin Directory</a> a lot during my constant hunt for plugins for our release posts. If you&#8217;re a plugin author and you&#8217;re not hosting your plugin on the Repository then you&#8217;re definitely missing out a lot in getting your plugin out to all WordPress Users, especially now with the <a href=\"http://wordpress.org/development/2009/02/new-and-improved-plugins-directory-search/\">Plugin Directory search improved</a>. So, if you&#8217;re a plugin author and if you release your plugins as GPL, then do remember to <a href=\"http://wordpress.org/extend/plugins/add/\">add your plugin</a>.</p>\n<p>That being said, if you&#8217;re hosting your plugin there, then you will be required to add a <em>readme.txt</em> file in the folder of your plugin.</p>\n<p>To begin with, take a look at the <a href=\"http://wordpress.org/extend/plugins/about/readme.txt\">standard readme.txt file</a>.</p>\n<p>The readme.txt file contains the following sections:</p>\n<ul>\n<li>Plugin Name</li>\n<li>Description</li>\n<li>Installation</li>\n<li>Frequently Asked Questions</li>\n<li>Screenshots</li>\n<li>Other sections</li>\n</ul>\n<p>In my opinion, the most important of these are the first two sections since these are the first that a potential user sees. Completing all the sections is also useful since these can be searched.</p>\n<p>I&#8217;m going to focus this post on the <strong>Plugin Name</strong> section.</p>\n<pre>=== Plugin Name ===\nContributors: Ajay, Mark Ghosh\nDonate link: http://weblogtoolscollection.com/\nTags: comments, spam\nRequires at least: 2.0.2\nTested up to: 2.1\nStable tag: 4.3\n\nHere is a short description of the plugin.  This should be no more than 150 chars.  No markup here.</pre>\n<p>Another important section while adding your plugin is the header section in the plugin file itself. Here&#8217;s the section from my plugin <a href=\"http://ajaydsouza.com/wordpress/plugins/top-10/\">Top 10</a>.</p>\n<pre>/*\nPlugin Name: Top 10\nVersion:     1.1\nPlugin URI:  http://ajaydsouza.com/wordpress/plugins/top-10/\nDescription: Count visits per post and display the most popular posts based on the number of views.\nAuthor:      Ajay D\'Souza\nAuthor URI:  http://ajaydsouza.com/\n*/</pre>\n<p>And, while this isn&#8217;t part of the readme.txt, it also contributes towards the listing of your plugin. These both, in combination, are used to populate the details for each plugin as you can see below.</p>\n<p><img title=\"Plugin Details\" src=\"http://weblogtoolscollection.com/b2-img/2009/02/plugin-details.gif\" border=\"0\" alt=\"Plugin Details\" width=\"214\" height=\"255\" /></p>\n<p>The <strong>Author Homepage</strong> and <strong>Plugin Homepage</strong> are pulled from the plugin file, viz. <strong>Author URI</strong> and <strong>Plugin URI</strong> respectively. The version number is also pulled from the plugin file. The <strong>Requires WordPress Version</strong>, <strong>Compatible up to</strong> and <strong>Donate</strong> link are pulled from the readme.txt file.</p>\n<p>Hence, populating both the readme.txt file and the plugin file make your plugin complete.</p>\n<p>I&#8217;ve seen a lot of plugins which either miss out one of the three links above or just point them back to the repository. Some plugins have the same Author Homepage and Plugin Homepage. Needless to say, these aren&#8217;t making the most use of all the sections that are given to you.</p>\n<p>Are you a plugin author? Are you hosting your plugin on the directory? If so, why not?</p>\n<p>Are you ensuring that you are completely using all the sections in your plugin header section and the readme.txt? Do remember to run your readme.txt file through the <a href=\"http://wordpress.org/extend/plugins/about/validator/\">validator</a>.</p>\";}i:30;a:7:{s:5:\"title\";s:51:\"Dev Blog: New and Improved Plugins Directory Search\";s:4:\"guid\";s:39:\"http://wordpress.org/development/?p=544\";s:4:\"link\";s:83:\"http://wordpress.org/development/2009/02/new-and-improved-plugins-directory-search/\";s:11:\"description\";s:1054:\"<p>One of the biggest problems and most frequent complaints we&#8217;ve had with the <a href=\"http://wordpress.org/extend/plugins/\">WordPress.org Plugins Directory</a> is the horrible, horrible search results.</p>\n<p>No longer.  We&#8217;re now using <a href=\"http://www.sphinxsearch.com/\">Sphinx</a> (a &#8220;free open-source SQL full-text search engine&#8221;) to power search on the Plugins Directory both from the website and from within your blog&#8217;s admin (Plugins &rarr; Add New).</p>\n<p>It works much better.  There are a few oddities floating around (our fault not sphinx&#8217;s) that we&#8217;ll be cleaning up shortly, but we&#8217;re happy enough with it on the whole to start letting everyone else use it <img src=\"http://wordpress.org/development/wp-includes/images/smilies/icon_smile.gif\" alt=\":)\" class=\"wp-smiley\" /> </p>\n<p>Currently, the search only indexes the plugin&#8217;s title and description/installation/FAQ/etc. (from the plugin&#8217;s readme.txt file), but we&#8217;ll be adding things like authors and tags soon.</p>\";s:7:\"pubdate\";s:31:\"Thu, 19 Feb 2009 01:29:24 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:8:\"mdawaffe\";}s:7:\"summary\";s:1054:\"<p>One of the biggest problems and most frequent complaints we&#8217;ve had with the <a href=\"http://wordpress.org/extend/plugins/\">WordPress.org Plugins Directory</a> is the horrible, horrible search results.</p>\n<p>No longer.  We&#8217;re now using <a href=\"http://www.sphinxsearch.com/\">Sphinx</a> (a &#8220;free open-source SQL full-text search engine&#8221;) to power search on the Plugins Directory both from the website and from within your blog&#8217;s admin (Plugins &rarr; Add New).</p>\n<p>It works much better.  There are a few oddities floating around (our fault not sphinx&#8217;s) that we&#8217;ll be cleaning up shortly, but we&#8217;re happy enough with it on the whole to start letting everyone else use it <img src=\"http://wordpress.org/development/wp-includes/images/smilies/icon_smile.gif\" alt=\":)\" class=\"wp-smiley\" /> </p>\n<p>Currently, the search only indexes the plugin&#8217;s title and description/installation/FAQ/etc. (from the plugin&#8217;s readme.txt file), but we&#8217;ll be adding things like authors and tags soon.</p>\";}i:31;a:7:{s:5:\"title\";s:28:\"Alex King: Twitter Tools 1.6\";s:4:\"guid\";s:52:\"http://alexking.org/blog/2009/02/18/twitter-tools-16\";s:4:\"link\";s:52:\"http://alexking.org/blog/2009/02/18/twitter-tools-16\";s:11:\"description\";s:4938:\"<p>Yay, Twitter Tools has reached version 1.6!</p>\n<p>Twitter Tools is a <a href=\"http://wordpress.org/\" rel=\"external\">WordPress</a> plugin that allows you to do a two-way integration between your WordPress powered blog and <a href=\"http://twitter.com\" rel=\"external\">Twitter</a>. It has the following features:</p>\n<ul>\n<li>Download and archive your tweets from Twitter.</li>\n<li>Show your recent tweets in a sidebar widget.</li>\n<li>Create a blog post from each of your tweets (you can set the category, author, tags, etc.).</li>\n<li>Create a daily digest from your tweets.</li>\n<li>Create a weekly digest from your tweets.</li>\n<li>Create a tweet on Twitter when you post to your blog (optional on a per-post basis).</li>\n<li>Create tweets on Twitter from your blog sidebar and/or admin interface.</li>\n<li>Auto-link @replies and provide &#8220;in reply to&#8221; links.</li>\n<li>Auto-link hashtags.</li>\n<li>Ability to exclude @replies from sidebars, blog posts and digests.</li>\n<li>Supports URL shortening services via standard WordPress filter (read the README).</li>\n<li>Supports <a href=\"http://www.village-idiot.org/archives/2006/06/29/wp-chunk/\" rel=\"external\">WP Chunk</a> for URL shortening URLs in tweets when they are shown in your blog posts and/or sidebar.</li>\n<li>Thorough <a href=\"http://alexking.org/projects/wordpress/readme?project=twitter-tools\">README</a> with answers to frequently asked questions.</li>\n</ul>\n<p>Here are notable changes from the 1.5.x releases:</p>\n<ol>\n<li>Fixed the issue where posts via XML-RPC/AtomPub or scheduled posts would not get tweeted - these now use your default settings.</li>\n<li>Fixed issue where the per-post &#8220;send to Twitter&#8221; setting for future post was not honored properly.</li>\n<li>Fixed issues with digests - both daily and weekly should be working correctly now<sup><a href=\"http://alexking.org/blog/feed?cat=16#fn1234491030843n\" id=\"fn1234491030843\" class=\"footnote\">1</a></sup> The digest features are no longer listed as experimental.</li>\n<li>Changed the code that checks to create the Twitter data table so that it works properly with the new bulk plugin activation features.</li>\n<li>Added a new filter <code>tweet_blog_post_url</code> so that other plugins can hook in and run the URL of your blog post through an URL shortening service of your choosing before sending the full URL to Twitter (Twitter uses TinyURL by default).</li>\n<li>Fixed an issue that caused the &#8216;Test Login&#8217; functionality to report a failure with a correct username and password (though the regular functionality was unaffected).</li>\n<li>Changed how &#8220;replies&#8221; are determined. no longer using Twitter&#8217;s definition as many Twitter users <a href=\"http://alexking.org/blog/2009/02/14/twitter-tools-exclude-replies-feature-not-working\">thought differently</a> and considered this a bug.</li>\n<li>Allow anyone with &#8220;publish_posts&#8221; ability to post to Twitter from the admin area.</li>\n<li>Fixed several auto-linking edge cases.</li>\n<li>Bunch of little/under the hood stuff.</li>\n</ol>\n<p>I&#8217;m pleased to finally get these changes out. I know the 1.5.x versions lingered too long with some unfixed bugs. This plugin has gotten complex enough that the bugs are not always readily apparent.<sup><a href=\"http://alexking.org/blog/feed?cat=16#fn1234975089003n\" id=\"fn1234975089003\" class=\"footnote\">1</a></sup> <a href=\"http://crowdfavorite.com\">Crowd Favorite</a> has been (thankfully) keeping busy so we haven&#8217;t had the time to try to address these until recently. We had to spend quite a bit of time to track down some of these issues - hopefully they are all properly addressed now.<sup><a href=\"http://alexking.org/blog/feed?cat=16#fn1234991975940n\" id=\"fn1234991975940\" class=\"footnote\">2</a></sup></p>\n<p>The download and more information are available on my <a href=\"http://alexking.org/projects/wordpress\">WordPress Plugins page</a>.</p>\n<p>If you have any trouble with this, please open a thread in the <a href=\"http://wordpress.org/support/\" rel=\"external\">WP Support Forums</a> and <a href=\"http://alexking.org/contact\">e-mail</a> me a link to the thread.</p>\n<ol class=\"footnotes\">\n<li id=\"fn1234975089003n\">My <a href=\"http://alexking.org/blog/2008/11/16/twitter-tools-digest-problems\">call for help</a> a while back didn&#8217;t bring solutions - unfortunately. [<a href=\"http://alexking.org/blog/feed?cat=16#fn1234975089003\">back</a>]</li>\n<li id=\"fn1234991975940n\">This plugin is already pretty complicated, making it hard to test thoroughly. Another reason I&#8217;m hesitant to add additional features to it. [<a href=\"http://alexking.org/blog/feed?cat=16#fn1234991975940\">back</a>]</li>\n</ol>\n<p><a href=\"http://sharethis.com/item?&wp=2.2.3&amp;publisher=a1583af8-28eb-4210-97bd-2bb5c02bc265&amp;title=Twitter+Tools+1.6&amp;url=http%3A%2F%2Falexking.org%2Fblog%2F2009%2F02%2F18%2Ftwitter-tools-16\">ShareThis</a></p>\";s:7:\"pubdate\";s:31:\"Thu, 19 Feb 2009 00:36:12 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Alex\";}s:7:\"summary\";s:4938:\"<p>Yay, Twitter Tools has reached version 1.6!</p>\n<p>Twitter Tools is a <a href=\"http://wordpress.org/\" rel=\"external\">WordPress</a> plugin that allows you to do a two-way integration between your WordPress powered blog and <a href=\"http://twitter.com\" rel=\"external\">Twitter</a>. It has the following features:</p>\n<ul>\n<li>Download and archive your tweets from Twitter.</li>\n<li>Show your recent tweets in a sidebar widget.</li>\n<li>Create a blog post from each of your tweets (you can set the category, author, tags, etc.).</li>\n<li>Create a daily digest from your tweets.</li>\n<li>Create a weekly digest from your tweets.</li>\n<li>Create a tweet on Twitter when you post to your blog (optional on a per-post basis).</li>\n<li>Create tweets on Twitter from your blog sidebar and/or admin interface.</li>\n<li>Auto-link @replies and provide &#8220;in reply to&#8221; links.</li>\n<li>Auto-link hashtags.</li>\n<li>Ability to exclude @replies from sidebars, blog posts and digests.</li>\n<li>Supports URL shortening services via standard WordPress filter (read the README).</li>\n<li>Supports <a href=\"http://www.village-idiot.org/archives/2006/06/29/wp-chunk/\" rel=\"external\">WP Chunk</a> for URL shortening URLs in tweets when they are shown in your blog posts and/or sidebar.</li>\n<li>Thorough <a href=\"http://alexking.org/projects/wordpress/readme?project=twitter-tools\">README</a> with answers to frequently asked questions.</li>\n</ul>\n<p>Here are notable changes from the 1.5.x releases:</p>\n<ol>\n<li>Fixed the issue where posts via XML-RPC/AtomPub or scheduled posts would not get tweeted - these now use your default settings.</li>\n<li>Fixed issue where the per-post &#8220;send to Twitter&#8221; setting for future post was not honored properly.</li>\n<li>Fixed issues with digests - both daily and weekly should be working correctly now<sup><a href=\"http://alexking.org/blog/feed?cat=16#fn1234491030843n\" id=\"fn1234491030843\" class=\"footnote\">1</a></sup> The digest features are no longer listed as experimental.</li>\n<li>Changed the code that checks to create the Twitter data table so that it works properly with the new bulk plugin activation features.</li>\n<li>Added a new filter <code>tweet_blog_post_url</code> so that other plugins can hook in and run the URL of your blog post through an URL shortening service of your choosing before sending the full URL to Twitter (Twitter uses TinyURL by default).</li>\n<li>Fixed an issue that caused the &#8216;Test Login&#8217; functionality to report a failure with a correct username and password (though the regular functionality was unaffected).</li>\n<li>Changed how &#8220;replies&#8221; are determined. no longer using Twitter&#8217;s definition as many Twitter users <a href=\"http://alexking.org/blog/2009/02/14/twitter-tools-exclude-replies-feature-not-working\">thought differently</a> and considered this a bug.</li>\n<li>Allow anyone with &#8220;publish_posts&#8221; ability to post to Twitter from the admin area.</li>\n<li>Fixed several auto-linking edge cases.</li>\n<li>Bunch of little/under the hood stuff.</li>\n</ol>\n<p>I&#8217;m pleased to finally get these changes out. I know the 1.5.x versions lingered too long with some unfixed bugs. This plugin has gotten complex enough that the bugs are not always readily apparent.<sup><a href=\"http://alexking.org/blog/feed?cat=16#fn1234975089003n\" id=\"fn1234975089003\" class=\"footnote\">1</a></sup> <a href=\"http://crowdfavorite.com\">Crowd Favorite</a> has been (thankfully) keeping busy so we haven&#8217;t had the time to try to address these until recently. We had to spend quite a bit of time to track down some of these issues - hopefully they are all properly addressed now.<sup><a href=\"http://alexking.org/blog/feed?cat=16#fn1234991975940n\" id=\"fn1234991975940\" class=\"footnote\">2</a></sup></p>\n<p>The download and more information are available on my <a href=\"http://alexking.org/projects/wordpress\">WordPress Plugins page</a>.</p>\n<p>If you have any trouble with this, please open a thread in the <a href=\"http://wordpress.org/support/\" rel=\"external\">WP Support Forums</a> and <a href=\"http://alexking.org/contact\">e-mail</a> me a link to the thread.</p>\n<ol class=\"footnotes\">\n<li id=\"fn1234975089003n\">My <a href=\"http://alexking.org/blog/2008/11/16/twitter-tools-digest-problems\">call for help</a> a while back didn&#8217;t bring solutions - unfortunately. [<a href=\"http://alexking.org/blog/feed?cat=16#fn1234975089003\">back</a>]</li>\n<li id=\"fn1234991975940n\">This plugin is already pretty complicated, making it hard to test thoroughly. Another reason I&#8217;m hesitant to add additional features to it. [<a href=\"http://alexking.org/blog/feed?cat=16#fn1234991975940\">back</a>]</li>\n</ol>\n<p><a href=\"http://sharethis.com/item?&wp=2.2.3&amp;publisher=a1583af8-28eb-4210-97bd-2bb5c02bc265&amp;title=Twitter+Tools+1.6&amp;url=http%3A%2F%2Falexking.org%2Fblog%2F2009%2F02%2F18%2Ftwitter-tools-16\">ShareThis</a></p>\";}i:32;a:7:{s:5:\"title\";s:28:\"Matt: Embedding WP.com Video\";s:4:\"guid\";s:21:\"http://ma.tt/?p=11870\";s:4:\"link\";s:43:\"http://ma.tt/2009/02/embedding-wpcom-video/\";s:11:\"description\";s:237:\"<p><a href=\"http://www.baldheretic.com/2009/02/18/implementing-video\">Implementing WordPress.com Video</a> on a WordPress.org site. It&#8217;s easy, but I agree it would be nice if the video media embed popup made this more seamless.</p>\";s:7:\"pubdate\";s:31:\"Wed, 18 Feb 2009 23:55:40 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:7:\"summary\";s:237:\"<p><a href=\"http://www.baldheretic.com/2009/02/18/implementing-video\">Implementing WordPress.com Video</a> on a WordPress.org site. It&#8217;s easy, but I agree it would be nice if the video media embed popup made this more seamless.</p>\";}i:33;a:7:{s:5:\"title\";s:60:\"Weblog Tools Collection: WordPress Plugin Releases for 02/18\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=5203\";s:4:\"link\";s:88:\"http://weblogtoolscollection.com/archives/2009/02/18/wordpress-plugin-releases-for-0218/\";s:11:\"description\";s:4693:\"<h3>New Plugins</h3>\n<p><a href=\"http://scribu.net/wordpress/smarter-navigation\">Smarter Navigation</a></p>\n<p>Generate more specific previous / next post links based on referrer.</p>\n<p><a href=\"http://blogsessive.com/blogging-tools/wp-plugin-latest-posts-by-category-archive/\">Latest Posts by Category Archive</a></p>\n<p>It generates a list-based categorized archive of the latest blog posts.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/shoutsuite-mu/\">ShoutSuite MU</a></p>\n<p>Send blog title and url to ngeshout.com right away after post blog.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/voting-record/\">Voting Record</a></p>\n<p>Elected officials or citizens can record and display their votes or the votes of one or more elected officials they follow.</p>\n<p><a href=\"http://counsellingresource.com/features/2009/02/16/show-total-conversations/\">Greg&#8217;s Show Total Conversations</a></p>\n<p>This plugin displays the total number of threaded conversations contained within a post&#8217;s comments. Coders can call the function directly.</p>\n<p><a href=\"http://www.italyisfalling.com/autotitle-for-wordpress/\">Autotitle for Wordpress</a></p>\n<p>Generates a title upon publishing a post, if no title is given. Optionally works when editing posts as well. It is a must when posting in a hurry.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/recommended-reading-google-reader-shared/\">Recommended Reading: Google Reader Shared</a></p>\n<p>Recommended Reading pulls in your Google Reader shared items. Includes easy configuration and widget support.</p>\n<p><a href=\"http://www.tipsandtricks-hq.com/?p=768\">WordPress Simple Paypal Shopping Cart</a></p>\n<p>Very easy to use Simple Paypal Shopping Cart Plugin. Great for selling digital products online in one click.</p>\n<p><a href=\"http://omblogs.dk/myplugins/2009/02/commenttweets/\">CommentTweets</a></p>\n<p>When a reply is made to a comment, a twitter notification (@twittername) will be sent to the original comment author to notify him/her of the reply.</p>\n<p><a href=\"http://bavotasan.com/wordpress/free-wordpress-plugins/excerpt-and-content-word-limit-wordpress-plugin/\">Content and Excerpt Word Limit</a></p>\n<p>Allows users to limit the number or words that are displayed when they want the excerpt or content of a post to appear.</p>\n<p><a href=\"http://cochinoman.com/2009/02/16/wordpress-plugin-for-splash-screen/\">Splashscreen</a></p>\n<p>Display a splash screen before allowing visitor to see blog.</p>\n<h3>Updated Plugins</h3>\n<p><a href=\"http://ajaydsouza.com/wordpress/plugins/where-did-they-go-from-here/\">Where did they go from here?</a></p>\n<p>Have you seen Amazon.com’s product pages? They all have a “Readers who have bought this, also bought. So, why not implement this on your WordPress blog? This plugin will show “Readers who viewed this page, also viewed” links on your page.</p>\n<p><a href=\"http://blog.avirtualhome.com/wordpress-plugins/avh-amazon/\">AVH Amazon</a></p>\n<p>The AVH Amazon plugin gives you the ability to add multiple widgets which will display one or more random item(s) from your Amazon wishlist, baby registry and/or wedding registry. It also has the ability to show an item with its link, in posts and pages by use of shortcode.</p>\n<p><a href=\"http://omninoggin.com/wordpress-plugins/buy-sell-ads-wordpress-plugin/\">Buy Sell Ads</a></p>\n<p>A plugin to help you easily integrate your <a href=\"http://buysellads.com\">Buy Sell Ads</a> zones and includes anti-AdBlock meaures to help prevent AdBlock (and similar software) from blocking Buy Sell Ads advertisements.</p>\n<p><a href=\"http://alexking.org/projects/wordpress/readme?project=twitter-tools\">Twitter Tools</a></p>\n<p>This plugin that creates an integration between your WordPress blog and your Twitter account. It allows you to pull your tweets into your blog (as posts and digests) and create new tweets on blog posts and from within WordPress.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/magpierss-simplified/\">MagpieRSS Simplified</a></p>\n<p>MagpieRSS is already integrated with WordPress, this plugin will allow you to implement it easily within your theme.</p>\n<p><a href=\"http://pn.strübe.de/\">Post Notification</a></p>\n<p>With each new post an email is sent to every registered User in the Database. The email can be text or HTML.</p>\n<p><a href=\"http://horttcore.de/wordpress/contentboxes/\">Contentboxes</a></p>\n<p>This plugin will add some awesome cms functions to your site. Add posts to static pages on the fly. <em>Page not in English</em></p>\n<p><a href=\"http://blog.fleischer.hu/wordpress/authors/\">Authors Widget</a></p>\n<p>Authors Widget shows the list of the authors in the sidemenu.</p>\";s:7:\"pubdate\";s:31:\"Wed, 18 Feb 2009 19:20:01 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:4693:\"<h3>New Plugins</h3>\n<p><a href=\"http://scribu.net/wordpress/smarter-navigation\">Smarter Navigation</a></p>\n<p>Generate more specific previous / next post links based on referrer.</p>\n<p><a href=\"http://blogsessive.com/blogging-tools/wp-plugin-latest-posts-by-category-archive/\">Latest Posts by Category Archive</a></p>\n<p>It generates a list-based categorized archive of the latest blog posts.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/shoutsuite-mu/\">ShoutSuite MU</a></p>\n<p>Send blog title and url to ngeshout.com right away after post blog.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/voting-record/\">Voting Record</a></p>\n<p>Elected officials or citizens can record and display their votes or the votes of one or more elected officials they follow.</p>\n<p><a href=\"http://counsellingresource.com/features/2009/02/16/show-total-conversations/\">Greg&#8217;s Show Total Conversations</a></p>\n<p>This plugin displays the total number of threaded conversations contained within a post&#8217;s comments. Coders can call the function directly.</p>\n<p><a href=\"http://www.italyisfalling.com/autotitle-for-wordpress/\">Autotitle for Wordpress</a></p>\n<p>Generates a title upon publishing a post, if no title is given. Optionally works when editing posts as well. It is a must when posting in a hurry.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/recommended-reading-google-reader-shared/\">Recommended Reading: Google Reader Shared</a></p>\n<p>Recommended Reading pulls in your Google Reader shared items. Includes easy configuration and widget support.</p>\n<p><a href=\"http://www.tipsandtricks-hq.com/?p=768\">WordPress Simple Paypal Shopping Cart</a></p>\n<p>Very easy to use Simple Paypal Shopping Cart Plugin. Great for selling digital products online in one click.</p>\n<p><a href=\"http://omblogs.dk/myplugins/2009/02/commenttweets/\">CommentTweets</a></p>\n<p>When a reply is made to a comment, a twitter notification (@twittername) will be sent to the original comment author to notify him/her of the reply.</p>\n<p><a href=\"http://bavotasan.com/wordpress/free-wordpress-plugins/excerpt-and-content-word-limit-wordpress-plugin/\">Content and Excerpt Word Limit</a></p>\n<p>Allows users to limit the number or words that are displayed when they want the excerpt or content of a post to appear.</p>\n<p><a href=\"http://cochinoman.com/2009/02/16/wordpress-plugin-for-splash-screen/\">Splashscreen</a></p>\n<p>Display a splash screen before allowing visitor to see blog.</p>\n<h3>Updated Plugins</h3>\n<p><a href=\"http://ajaydsouza.com/wordpress/plugins/where-did-they-go-from-here/\">Where did they go from here?</a></p>\n<p>Have you seen Amazon.com’s product pages? They all have a “Readers who have bought this, also bought. So, why not implement this on your WordPress blog? This plugin will show “Readers who viewed this page, also viewed” links on your page.</p>\n<p><a href=\"http://blog.avirtualhome.com/wordpress-plugins/avh-amazon/\">AVH Amazon</a></p>\n<p>The AVH Amazon plugin gives you the ability to add multiple widgets which will display one or more random item(s) from your Amazon wishlist, baby registry and/or wedding registry. It also has the ability to show an item with its link, in posts and pages by use of shortcode.</p>\n<p><a href=\"http://omninoggin.com/wordpress-plugins/buy-sell-ads-wordpress-plugin/\">Buy Sell Ads</a></p>\n<p>A plugin to help you easily integrate your <a href=\"http://buysellads.com\">Buy Sell Ads</a> zones and includes anti-AdBlock meaures to help prevent AdBlock (and similar software) from blocking Buy Sell Ads advertisements.</p>\n<p><a href=\"http://alexking.org/projects/wordpress/readme?project=twitter-tools\">Twitter Tools</a></p>\n<p>This plugin that creates an integration between your WordPress blog and your Twitter account. It allows you to pull your tweets into your blog (as posts and digests) and create new tweets on blog posts and from within WordPress.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/magpierss-simplified/\">MagpieRSS Simplified</a></p>\n<p>MagpieRSS is already integrated with WordPress, this plugin will allow you to implement it easily within your theme.</p>\n<p><a href=\"http://pn.strübe.de/\">Post Notification</a></p>\n<p>With each new post an email is sent to every registered User in the Database. The email can be text or HTML.</p>\n<p><a href=\"http://horttcore.de/wordpress/contentboxes/\">Contentboxes</a></p>\n<p>This plugin will add some awesome cms functions to your site. Add posts to static pages on the fly. <em>Page not in English</em></p>\n<p><a href=\"http://blog.fleischer.hu/wordpress/authors/\">Authors Widget</a></p>\n<p>Authors Widget shows the list of the authors in the sidemenu.</p>\";}i:34;a:7:{s:5:\"title\";s:59:\"Alex King: WordCamp Denver - Overflow Tickets Now Available\";s:4:\"guid\";s:82:\"http://alexking.org/blog/2009/02/17/wordcamp-denver-overflow-tickets-now-available\";s:4:\"link\";s:82:\"http://alexking.org/blog/2009/02/17/wordcamp-denver-overflow-tickets-now-available\";s:11:\"description\";s:2918:\"<p>Well, we sold out all of the planned tickets for <a href=\"http://denver.wordcamp.org\" rel=\"external\">WordCamp Denver</a> way before we expected to. This is one of those good news/bad news things. We&#8217;re thrilled that so many people signed up early but we want everyone who wants to come to be able to attend. Also, we had to make some decisions about venue, ordering t-shirts, etc. and had to use some estimated numbers so we won&#8217;t be able to accomodate everyone - this time.</p>\n<p class=\"center\"><a href=\"http://denver.wordcamp.org/\"><img title=\"Attending WordCamp Denver\" src=\"http://denver.wordcamp.org/files/2008/10/attending-badge.png\" alt=\"I\'m Attending WordCamp Denver 2009\" width=\"125\" height=\"125\" /></a></p>\n<p>The good news is that we&#8217;ve talked with the folks at the venue, and have found a way to add some additional spots for people.</p>\n<p>There are, right now, <strong>8 Last Minute Tickets available</strong> that include a t-shirt and there are <strong>20 No T-Shirt tickets</strong> available that do not include a t-shirt (if there are no-shows, some of these folks might get a t-shirt - can&#8217;t promise it though).<sup><a href=\"http://alexking.org/blog/feed?cat=16#fn1234908145185n\" id=\"fn1234908145185\" class=\"footnote\">1</a></sup></p>\n<p>I think this will be it - I don&#8217;t think we can fit anyone else into the auditorium for the morning (combined) session. So if you want to come to the inaugural WordCamp Denver, I recommend <a href=\"http://wordcampdenver.eventbrite.com/\" rel=\"external\">signing up ASAP</a>.</p>\n<p>We are also looking for people that can record the sessions in HD. This video will likely be used on <a href=\"http://wordpress.tv\" rel=\"external\">WordPress.tv</a> and may be made available (with attribution) on other sites as well. We will need several volunteers for this so that we get good coverage of the morning sessions and both tracks of afternoon sessions.</p>\n<p>Take a look at the WordCamp Denver web site for an updated (though still fluid) <a href=\"http://denver.wordcamp.org/schedule/\" rel=\"external\">schedule</a> and <a href=\"http://denver.wordcamp.org/speakers/\" rel=\"external\">speaker</a> list. For folks coming in from out of town, there are lodging recommendations at the bottom of <a href=\"http://denver.wordcamp.org/venue/\" rel=\"external\">this page</a>.</p>\n<p>I look forward to seeing and meeting people there.</p>\n<ol class=\"footnotes\">\n<li id=\"fn1234908145185n\">Unfortunately, the t-shirt order was already placed with what we thought was the max capacity. [<a href=\"http://alexking.org/blog/feed?cat=16#fn1234908145185\">back</a>]</li>\n</ol>\n<p><a href=\"http://sharethis.com/item?&wp=2.2.3&amp;publisher=a1583af8-28eb-4210-97bd-2bb5c02bc265&amp;title=WordCamp+Denver+-+Overflow+Tickets+Now+Available&amp;url=http%3A%2F%2Falexking.org%2Fblog%2F2009%2F02%2F17%2Fwordcamp-denver-overflow-tickets-now-available\">ShareThis</a></p>\";s:7:\"pubdate\";s:31:\"Tue, 17 Feb 2009 22:21:48 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Alex\";}s:7:\"summary\";s:2918:\"<p>Well, we sold out all of the planned tickets for <a href=\"http://denver.wordcamp.org\" rel=\"external\">WordCamp Denver</a> way before we expected to. This is one of those good news/bad news things. We&#8217;re thrilled that so many people signed up early but we want everyone who wants to come to be able to attend. Also, we had to make some decisions about venue, ordering t-shirts, etc. and had to use some estimated numbers so we won&#8217;t be able to accomodate everyone - this time.</p>\n<p class=\"center\"><a href=\"http://denver.wordcamp.org/\"><img title=\"Attending WordCamp Denver\" src=\"http://denver.wordcamp.org/files/2008/10/attending-badge.png\" alt=\"I\'m Attending WordCamp Denver 2009\" width=\"125\" height=\"125\" /></a></p>\n<p>The good news is that we&#8217;ve talked with the folks at the venue, and have found a way to add some additional spots for people.</p>\n<p>There are, right now, <strong>8 Last Minute Tickets available</strong> that include a t-shirt and there are <strong>20 No T-Shirt tickets</strong> available that do not include a t-shirt (if there are no-shows, some of these folks might get a t-shirt - can&#8217;t promise it though).<sup><a href=\"http://alexking.org/blog/feed?cat=16#fn1234908145185n\" id=\"fn1234908145185\" class=\"footnote\">1</a></sup></p>\n<p>I think this will be it - I don&#8217;t think we can fit anyone else into the auditorium for the morning (combined) session. So if you want to come to the inaugural WordCamp Denver, I recommend <a href=\"http://wordcampdenver.eventbrite.com/\" rel=\"external\">signing up ASAP</a>.</p>\n<p>We are also looking for people that can record the sessions in HD. This video will likely be used on <a href=\"http://wordpress.tv\" rel=\"external\">WordPress.tv</a> and may be made available (with attribution) on other sites as well. We will need several volunteers for this so that we get good coverage of the morning sessions and both tracks of afternoon sessions.</p>\n<p>Take a look at the WordCamp Denver web site for an updated (though still fluid) <a href=\"http://denver.wordcamp.org/schedule/\" rel=\"external\">schedule</a> and <a href=\"http://denver.wordcamp.org/speakers/\" rel=\"external\">speaker</a> list. For folks coming in from out of town, there are lodging recommendations at the bottom of <a href=\"http://denver.wordcamp.org/venue/\" rel=\"external\">this page</a>.</p>\n<p>I look forward to seeing and meeting people there.</p>\n<ol class=\"footnotes\">\n<li id=\"fn1234908145185n\">Unfortunately, the t-shirt order was already placed with what we thought was the max capacity. [<a href=\"http://alexking.org/blog/feed?cat=16#fn1234908145185\">back</a>]</li>\n</ol>\n<p><a href=\"http://sharethis.com/item?&wp=2.2.3&amp;publisher=a1583af8-28eb-4210-97bd-2bb5c02bc265&amp;title=WordCamp+Denver+-+Overflow+Tickets+Now+Available&amp;url=http%3A%2F%2Falexking.org%2Fblog%2F2009%2F02%2F17%2Fwordcamp-denver-overflow-tickets-now-available\">ShareThis</a></p>\";}i:35;a:7:{s:5:\"title\";s:59:\"Weblog Tools Collection: WordPress Theme Releases for 02/17\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=5195\";s:4:\"link\";s:87:\"http://weblogtoolscollection.com/archives/2009/02/17/wordpress-theme-releases-for-0217/\";s:11:\"description\";s:1509:\"<p><a href=\"http://seedsforwealth.com/webdesign/black-dragon-free-wp-theme-make-your-adsense-breathe-fire.html\">Black Dragon</a></p>\n<p><a href=\"http://www.seedsforwealth.com/Blog/\"><img title=\"Black Dragon\" src=\"http://weblogtoolscollection.com/b2-img/2009/02/blackdragon.gif\" alt=\"Black Dragon\" width=\"139\" height=\"83\" /></a></p>\n<p>The Black Dragon free Wordpress theme was designed for the money making internet mogul. The layout allows plenty of media space while keeping your most important website real estate available for Black Dragons, which are your AdSense ads.</p>\n<p><a href=\"http://www.junglejar.com/2009/02/13/wordpress-template-graphii2/\">graphii 2</a></p>\n<p><a href=\"http://www.junglejar.com/templates/demos/graphii.2/\"><img title=\"graphii2\" src=\"http://weblogtoolscollection.com/b2-img/2009/02/graphii2.png\" alt=\"graphii2\" width=\"111\" height=\"83\" /></a></p>\n<p>Two / Three column gravatar ready theme with three widgetized sidebars and features sticky post section.</p>\n<p><a href=\"http://3oneseven.com/09/wordpress-theme-mojo/\">Mojo</a></p>\n<p><a href=\"http://wp2.3oneseven.com/index.php?wptheme=Mojo\"><img title=\"Mojo\" src=\"http://weblogtoolscollection.com/b2-img/2009/02/mojo.png\" alt=\"Mojo\" width=\"122\" height=\"83\" /></a></p>\n<p>The mojo WP theme includes an unique horizontal scrolling layout, eight recent posts and an options panel for the front area.</p>\n<p>Are you a WordPress theme author? <a href=\"http://weblogtoolscollection.com/submit-news/\">Submit your themes to us</a>.</p>\";s:7:\"pubdate\";s:31:\"Tue, 17 Feb 2009 20:46:11 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:1509:\"<p><a href=\"http://seedsforwealth.com/webdesign/black-dragon-free-wp-theme-make-your-adsense-breathe-fire.html\">Black Dragon</a></p>\n<p><a href=\"http://www.seedsforwealth.com/Blog/\"><img title=\"Black Dragon\" src=\"http://weblogtoolscollection.com/b2-img/2009/02/blackdragon.gif\" alt=\"Black Dragon\" width=\"139\" height=\"83\" /></a></p>\n<p>The Black Dragon free Wordpress theme was designed for the money making internet mogul. The layout allows plenty of media space while keeping your most important website real estate available for Black Dragons, which are your AdSense ads.</p>\n<p><a href=\"http://www.junglejar.com/2009/02/13/wordpress-template-graphii2/\">graphii 2</a></p>\n<p><a href=\"http://www.junglejar.com/templates/demos/graphii.2/\"><img title=\"graphii2\" src=\"http://weblogtoolscollection.com/b2-img/2009/02/graphii2.png\" alt=\"graphii2\" width=\"111\" height=\"83\" /></a></p>\n<p>Two / Three column gravatar ready theme with three widgetized sidebars and features sticky post section.</p>\n<p><a href=\"http://3oneseven.com/09/wordpress-theme-mojo/\">Mojo</a></p>\n<p><a href=\"http://wp2.3oneseven.com/index.php?wptheme=Mojo\"><img title=\"Mojo\" src=\"http://weblogtoolscollection.com/b2-img/2009/02/mojo.png\" alt=\"Mojo\" width=\"122\" height=\"83\" /></a></p>\n<p>The mojo WP theme includes an unique horizontal scrolling layout, eight recent posts and an options panel for the front area.</p>\n<p>Are you a WordPress theme author? <a href=\"http://weblogtoolscollection.com/submit-news/\">Submit your themes to us</a>.</p>\";}i:36;a:7:{s:5:\"title\";s:26:\"Ryan Boren: WordPress Bits\";s:4:\"guid\";s:23:\"http://boren.nu/?p=1668\";s:4:\"link\";s:51:\"http://boren.nu/archives/2009/02/17/wordpress-bits/\";s:11:\"description\";s:731:\"<p><a href=\"http://wordpress.org/development/2009/02/wordpress-271/\">2.7.1</a> is out, improving upon a solid 2.7 release.</p>\n<p>The next version of the iPhone app is <a href=\"http://iphone.wordpress.org/2009/02/17/looking-for-a-few-good-hardware-testers/\">almost out</a> and features comment moderation.</p>\n<p>2.8 is well underway.  So far there have been lots of <a href=\"http://wpdevel.wordpress.com/2009/02/06/script-loader-updates/\">script loading</a> and DB performance improvements.  The first cut of the theme installer is in, and the redesign of the Widgets admin UI is beginning.  Custom tag taxonomies now have some built-in admin UI,  and proper timezone and DST support is available if you are running PHP 5.</p>\";s:7:\"pubdate\";s:31:\"Tue, 17 Feb 2009 18:10:20 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ryan\";}s:7:\"summary\";s:731:\"<p><a href=\"http://wordpress.org/development/2009/02/wordpress-271/\">2.7.1</a> is out, improving upon a solid 2.7 release.</p>\n<p>The next version of the iPhone app is <a href=\"http://iphone.wordpress.org/2009/02/17/looking-for-a-few-good-hardware-testers/\">almost out</a> and features comment moderation.</p>\n<p>2.8 is well underway.  So far there have been lots of <a href=\"http://wpdevel.wordpress.com/2009/02/06/script-loader-updates/\">script loading</a> and DB performance improvements.  The first cut of the theme installer is in, and the redesign of the Widgets admin UI is beginning.  Custom tag taxonomies now have some built-in admin UI,  and proper timezone and DST support is available if you are running PHP 5.</p>\";}i:37;a:7:{s:5:\"title\";s:44:\"Donncha: The survivors guide to unemployment\";s:4:\"guid\";s:29:\"http://ocaoimh.ie/?p=89494495\";s:4:\"link\";s:65:\"http://ocaoimh.ie/2009/02/17/the-survivors-guide-to-unemployment/\";s:11:\"description\";s:2595:\"<p><img align=\"right\" src=\"http://ocaoimh.ie/wp-content/uploads/2009/02/jobless_cover-213x300.jpg\" alt=\"jobless\" title=\"jobless\" width=\"213\" height=\"300\" class=\"aligncenter size-full wp-image-89494498\" /> I like this. David Jones was recently laid off from his day job and decided to write a book about his experiences in the hope that it might help others in the same position. The book is called &#8220;Oh No: I’ve Lost My Job What Am I Going To Do?&#8221; and was written in just a few days.</p>\n<p>Last week he was on Newstalk talking about his book when he was contacted by <a href=\"http://www.brightspark-consulting.com\">Maryrose Lyons from Brightspark Consulting</a> who suggested that a website would really help his book. I&#8217;ll let <a href=\"http://www.ewritecork.com/blog/2009/02/creating-a-website-in-a-week-for-jobless-and-proud/\">Gordon continue</a>, he&#8217;s one of the team who built the site:</p>\n<blockquote><p>Maryrose gathered a team together consisting of <a href=\"http://twitter.com/rachearley\">Rachel Earle</a>y (Website  Graphic designer) , <a href=\"http://www.davymac.com/wordpress/test-01/\">David McDonald</a> (Book Graphic Designer), <a href=\"http://www.davidjduignan.com/\">David Duignan</a> (Photographer), <a href=\"http://www.persuadersonline.com/\">Alex Gibson</a> (Award winning Podcaster ) and myself to put the site together and make the functional stuff like Paypal work.</p></blockquote>\n<p>And so was born <a href=\"http://www.joblessandproud.com/\">Joblessandproud.com</a>. Today, for one day only, you can download David&#8217;s book for free. It&#8217;s only €4.99 anyway, a steal at that price.</p>\n<p>It also has a <a href=\"http://www.joblessandproud.com/blog/\">blog</a>, I&#8217;m glad to see powered by WordPress. I&#8217;m going to subscribe and see what David makes of this opportunity. It&#8217;s wonderful to see that WordPress is part of this venture.</p>\n<p><img src=\"http://ocaoimh.ie/?voyeur=1\" /></p><p><strong>Related Posts</strong><ul><li><a href=\"http://ocaoimh.ie/2004/09/29/macgyvers-guide-to-photography/\" rel=\"bookmark\" title=\"Permanent Link: MacGyver’s Guide to Photography\">MacGyver’s Guide to Photography</a></li><li><a href=\"http://ocaoimh.ie/2002/12/16/easy-guide-for-compo/\" rel=\"bookmark\" title=\"Permanent Link: Easy Guide For Composition - n &#8230;\">Easy Guide For Composition - n &#8230;</a></li><li><a href=\"http://ocaoimh.ie/2004/01/30/independent-consumer-guide-to-mortgages/\" rel=\"bookmark\" title=\"Permanent Link: Independent consumer guide to mortgages\">Independent consumer guide to mortgages</a></li></ul></p>\";s:7:\"pubdate\";s:31:\"Tue, 17 Feb 2009 15:28:31 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:7:\"Donncha\";}s:7:\"summary\";s:2595:\"<p><img align=\"right\" src=\"http://ocaoimh.ie/wp-content/uploads/2009/02/jobless_cover-213x300.jpg\" alt=\"jobless\" title=\"jobless\" width=\"213\" height=\"300\" class=\"aligncenter size-full wp-image-89494498\" /> I like this. David Jones was recently laid off from his day job and decided to write a book about his experiences in the hope that it might help others in the same position. The book is called &#8220;Oh No: I’ve Lost My Job What Am I Going To Do?&#8221; and was written in just a few days.</p>\n<p>Last week he was on Newstalk talking about his book when he was contacted by <a href=\"http://www.brightspark-consulting.com\">Maryrose Lyons from Brightspark Consulting</a> who suggested that a website would really help his book. I&#8217;ll let <a href=\"http://www.ewritecork.com/blog/2009/02/creating-a-website-in-a-week-for-jobless-and-proud/\">Gordon continue</a>, he&#8217;s one of the team who built the site:</p>\n<blockquote><p>Maryrose gathered a team together consisting of <a href=\"http://twitter.com/rachearley\">Rachel Earle</a>y (Website  Graphic designer) , <a href=\"http://www.davymac.com/wordpress/test-01/\">David McDonald</a> (Book Graphic Designer), <a href=\"http://www.davidjduignan.com/\">David Duignan</a> (Photographer), <a href=\"http://www.persuadersonline.com/\">Alex Gibson</a> (Award winning Podcaster ) and myself to put the site together and make the functional stuff like Paypal work.</p></blockquote>\n<p>And so was born <a href=\"http://www.joblessandproud.com/\">Joblessandproud.com</a>. Today, for one day only, you can download David&#8217;s book for free. It&#8217;s only €4.99 anyway, a steal at that price.</p>\n<p>It also has a <a href=\"http://www.joblessandproud.com/blog/\">blog</a>, I&#8217;m glad to see powered by WordPress. I&#8217;m going to subscribe and see what David makes of this opportunity. It&#8217;s wonderful to see that WordPress is part of this venture.</p>\n<p><img src=\"http://ocaoimh.ie/?voyeur=1\" /></p><p><strong>Related Posts</strong><ul><li><a href=\"http://ocaoimh.ie/2004/09/29/macgyvers-guide-to-photography/\" rel=\"bookmark\" title=\"Permanent Link: MacGyver’s Guide to Photography\">MacGyver’s Guide to Photography</a></li><li><a href=\"http://ocaoimh.ie/2002/12/16/easy-guide-for-compo/\" rel=\"bookmark\" title=\"Permanent Link: Easy Guide For Composition - n &#8230;\">Easy Guide For Composition - n &#8230;</a></li><li><a href=\"http://ocaoimh.ie/2004/01/30/independent-consumer-guide-to-mortgages/\" rel=\"bookmark\" title=\"Permanent Link: Independent consumer guide to mortgages\">Independent consumer guide to mortgages</a></li></ul></p>\";}i:38;a:7:{s:5:\"title\";s:36:\"Mark Jaquith: BarCamp/WordCamp Miami\";s:4:\"guid\";s:39:\"http://markjaquith.wordpress.com/?p=249\";s:4:\"link\";s:66:\"http://markjaquith.wordpress.com/2009/02/17/barcampwordcamp-miami/\";s:11:\"description\";s:1864:\"<div class=\"snap_preview\"><br /><p><img src=\"http://markjaquith.files.wordpress.com/2009/02/213003098.png?w=450&#038;h=137\" alt=\"BarCamp Miami\" title=\"BarCamp Miami\" width=\"450\" height=\"137\" class=\"aligncenter size-full wp-image-250\" /></p>\n<p>I&#8217;ll be in Miami on Sunday, February 22nd for <a href=\"http://wordcampmiami.com/\">BarCamp/WordCamp Miami</a>. If you&#8217;re in the area or are in town for the Future of Web Apps conference, you should stop by!</p>\n<p>What should I talk about?</p>\n<p><strong>Update:</strong> There has been a venue change for this event, so if you were planning on going, make sure you take note of <a href=\"http://barcampmiami.org/venue/\">the new location</a>!</p>\n  <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gocomments/markjaquith.wordpress.com/249/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/comments/markjaquith.wordpress.com/249/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godelicious/markjaquith.wordpress.com/249/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/delicious/markjaquith.wordpress.com/249/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gostumble/markjaquith.wordpress.com/249/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/stumble/markjaquith.wordpress.com/249/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godigg/markjaquith.wordpress.com/249/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/digg/markjaquith.wordpress.com/249/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/goreddit/markjaquith.wordpress.com/249/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/reddit/markjaquith.wordpress.com/249/\" /></a> <img alt=\"\" border=\"0\" src=\"http://stats.wordpress.com/b.gif?host=markjaquith.wordpress.com&blog=316&post=249&subd=markjaquith&ref=&feed=1\" /></div>\";s:7:\"pubdate\";s:31:\"Tue, 17 Feb 2009 09:26:24 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:12:\"Mark Jaquith\";}s:7:\"summary\";s:1864:\"<div class=\"snap_preview\"><br /><p><img src=\"http://markjaquith.files.wordpress.com/2009/02/213003098.png?w=450&#038;h=137\" alt=\"BarCamp Miami\" title=\"BarCamp Miami\" width=\"450\" height=\"137\" class=\"aligncenter size-full wp-image-250\" /></p>\n<p>I&#8217;ll be in Miami on Sunday, February 22nd for <a href=\"http://wordcampmiami.com/\">BarCamp/WordCamp Miami</a>. If you&#8217;re in the area or are in town for the Future of Web Apps conference, you should stop by!</p>\n<p>What should I talk about?</p>\n<p><strong>Update:</strong> There has been a venue change for this event, so if you were planning on going, make sure you take note of <a href=\"http://barcampmiami.org/venue/\">the new location</a>!</p>\n  <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gocomments/markjaquith.wordpress.com/249/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/comments/markjaquith.wordpress.com/249/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godelicious/markjaquith.wordpress.com/249/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/delicious/markjaquith.wordpress.com/249/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gostumble/markjaquith.wordpress.com/249/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/stumble/markjaquith.wordpress.com/249/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godigg/markjaquith.wordpress.com/249/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/digg/markjaquith.wordpress.com/249/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/goreddit/markjaquith.wordpress.com/249/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/reddit/markjaquith.wordpress.com/249/\" /></a> <img alt=\"\" border=\"0\" src=\"http://stats.wordpress.com/b.gif?host=markjaquith.wordpress.com&blog=316&post=249&subd=markjaquith&ref=&feed=1\" /></div>\";}i:39;a:7:{s:5:\"title\";s:30:\"Alex King: Twitter Tools 1.6b2\";s:4:\"guid\";s:54:\"http://alexking.org/blog/2009/02/16/twitter-tools-16b2\";s:4:\"link\";s:54:\"http://alexking.org/blog/2009/02/16/twitter-tools-16b2\";s:11:\"description\";s:1167:\"<p>After a couple of bug reports about scheduled posts still not working, we were able to identify and fix a nasty little bug that was causing the &#8220;notify Twitter about this post or not&#8221; setting to get stomped on a bit.</p>\n<p>We&#8217;ve fixed this, along with the <a href=\"http://alexking.org/blog/2009/02/14/twitter-tools-exclude-replies-feature-not-working\">&#8220;exclude replies&#8221; issues from the weekend</a>, and things are looking pretty good in our initial testing. We&#8217;d love to have some further testing help from you before 1.6 goes final.</p>\n<p>The download and more information are available on my <a href=\"http://alexking.org/projects/wordpress\">WordPress Plugins page</a>.</p>\n<p>If you have any trouble with this, please open a thread in the <a href=\"http://wordpress.org/support/\" rel=\"external\">WP Support Forums</a> and <a href=\"http://alexking.org/contact\">e-mail</a> me a link to the thread.</p>\n<p><a href=\"http://sharethis.com/item?&wp=2.2.3&amp;publisher=a1583af8-28eb-4210-97bd-2bb5c02bc265&amp;title=Twitter+Tools+1.6b2&amp;url=http%3A%2F%2Falexking.org%2Fblog%2F2009%2F02%2F16%2Ftwitter-tools-16b2\">ShareThis</a></p>\";s:7:\"pubdate\";s:31:\"Tue, 17 Feb 2009 00:22:05 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Alex\";}s:7:\"summary\";s:1167:\"<p>After a couple of bug reports about scheduled posts still not working, we were able to identify and fix a nasty little bug that was causing the &#8220;notify Twitter about this post or not&#8221; setting to get stomped on a bit.</p>\n<p>We&#8217;ve fixed this, along with the <a href=\"http://alexking.org/blog/2009/02/14/twitter-tools-exclude-replies-feature-not-working\">&#8220;exclude replies&#8221; issues from the weekend</a>, and things are looking pretty good in our initial testing. We&#8217;d love to have some further testing help from you before 1.6 goes final.</p>\n<p>The download and more information are available on my <a href=\"http://alexking.org/projects/wordpress\">WordPress Plugins page</a>.</p>\n<p>If you have any trouble with this, please open a thread in the <a href=\"http://wordpress.org/support/\" rel=\"external\">WP Support Forums</a> and <a href=\"http://alexking.org/contact\">e-mail</a> me a link to the thread.</p>\n<p><a href=\"http://sharethis.com/item?&wp=2.2.3&amp;publisher=a1583af8-28eb-4210-97bd-2bb5c02bc265&amp;title=Twitter+Tools+1.6b2&amp;url=http%3A%2F%2Falexking.org%2Fblog%2F2009%2F02%2F16%2Ftwitter-tools-16b2\">ShareThis</a></p>\";}i:40;a:7:{s:5:\"title\";s:60:\"Weblog Tools Collection: WordPress Plugin Releases for 02/16\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=5187\";s:4:\"link\";s:88:\"http://weblogtoolscollection.com/archives/2009/02/16/wordpress-plugin-releases-for-0216/\";s:11:\"description\";s:3783:\"<h3>New Plugins</h3>\n<p><a href=\"http://cesar.la/wbp\">WP Blogs&#8217; Planetarium</a></p>\n<p>Turns your WP into a blogs&#8217; planetarium.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/easy-vbox7/\">Easy VBOX7</a></p>\n<p>Easy way to insert videos from VBOX7.com right into your WordPress blog posts.</p>\n<p><a href=\"http://www.osexpert.net/wordpress-syntax-highlighter/\">Dojox Wordpress Syntax Highlighter</a></p>\n<p>Free syntax highlighter written in Java Script as Wordpress Plugin. <em>Page not in English</em></p>\n<p><a href=\"http://wordpress.org/extend/plugins/time-machine/\">Time Machine</a></p>\n<p>Time Machine list all public posts published in past on today date, including all years of blogging</p>\n<p><a href=\"http://omninoggin.com/wordpress-plugins/seo-no-duplicate-wordpress-plugin/\">SEO No Duplicate</a></p>\n<p>This plugin helps you manage your search engine duplicate content, by setting your post page&#8217;s canonical to the permalink.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/dropularrss/\">DropularRSS</a></p>\n<p>Pull in a photo stream from Dropular</p>\n<p><a href=\"http://wordpress.org/extend/plugins/fresh-from-friendfeed-and-twitter/\">Fresh From FriendFeed and Twitter</a></p>\n<p>Keeps your blog always fresh by regularly adding your most recent content from FriendFeed or Twitter. No external passwords required!</p>\n<p><a href=\"http://www.addinto.com/tools/wordpress.php\">AddInto</a></p>\n<p>Helps readers share, save, bookmark, and email your posts and pages.</p>\n<p><a href=\"http://www.artiss.co.uk/simple-wakoopa-list\">Simple TTIW List</a></p>\n<p>Simple TTIW List is a WordPress plugin that displays a list of the items that you are after, as provided by the TheThingsIWant.com website.</p>\n<h3>Updated Plugins</h3>\n<p><a href=\"http://ajaydsouza.com/wordpress/plugins/top-10/\">Top 10</a></p>\n<p>You can then display the page view count on individual posts and pages as well as display a list of most popular posts based on page views. Includes a sidebar widget to display the popular posts. And, all settings can be configured from within your WordPress Admin area itself!</p>\n<p><a href=\"http://omninoggin.com/wordpress-plugins/wp-greet-box-wordpress-plugin/\">WP Greet Box</a></p>\n<p>This plugin lets you show a different greeting message to your new visitors depending on their referrer url.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/wordpress-whois-search/\">Whois</a></p>\n<p>The plugin allows you to insert a tag into any WordPress post or page to generate a WHOIS search form for your users to get information on domain names with different TLDs.</p>\n<p><a href=\"http://www.thunderguy.com/semicolon/wordpress/seemore-wordpress-plugin/\">Seemore</a></p>\n<p>Change the (more&#8230;) link so that it jumps to the entire post, not just just the part after the (more&#8230;).</p>\n<p><a href=\"http://www.wikinvest.com/blogger/Wikinvest_stockquotes\">Wikinvest Stock Quotes</a></p>\n<p>Display in-line stock quotes on your blog.</p>\n<p><a href=\"http://themoneymakingwebsite.com/wp-directory-list/\">Wp-Directory-List</a></p>\n<p>Add a Business Directory or Directory of Links in different categories and pages.</p>\n<p><a href=\"http://bravenewcode.com/wptouch/\">WPtouch iPhone Theme</a></p>\n<p>WPtouch automatically transforms your WordPress blog into an iPhone application-style theme, complete with ajax loading articles and effects, when viewed from an iPhone or iPod touch.</p>\n<p><a href=\"http://bitsignals.com/2008/01/14/admin-msg-board/\">Admin Msg Board</a></p>\n<p>Adds a messaging system in your Wordpress admin area for bloggers to communicate. <em>Page in Spanish</em></p>\n<p><a href=\"http://tweetburn.com/tools/tweetroll/\">TweetRoll</a></p>\n<p>TweetRoll displays your Twitter details and the avatars of some of your friends.</p>\";s:7:\"pubdate\";s:31:\"Mon, 16 Feb 2009 19:24:14 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:3783:\"<h3>New Plugins</h3>\n<p><a href=\"http://cesar.la/wbp\">WP Blogs&#8217; Planetarium</a></p>\n<p>Turns your WP into a blogs&#8217; planetarium.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/easy-vbox7/\">Easy VBOX7</a></p>\n<p>Easy way to insert videos from VBOX7.com right into your WordPress blog posts.</p>\n<p><a href=\"http://www.osexpert.net/wordpress-syntax-highlighter/\">Dojox Wordpress Syntax Highlighter</a></p>\n<p>Free syntax highlighter written in Java Script as Wordpress Plugin. <em>Page not in English</em></p>\n<p><a href=\"http://wordpress.org/extend/plugins/time-machine/\">Time Machine</a></p>\n<p>Time Machine list all public posts published in past on today date, including all years of blogging</p>\n<p><a href=\"http://omninoggin.com/wordpress-plugins/seo-no-duplicate-wordpress-plugin/\">SEO No Duplicate</a></p>\n<p>This plugin helps you manage your search engine duplicate content, by setting your post page&#8217;s canonical to the permalink.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/dropularrss/\">DropularRSS</a></p>\n<p>Pull in a photo stream from Dropular</p>\n<p><a href=\"http://wordpress.org/extend/plugins/fresh-from-friendfeed-and-twitter/\">Fresh From FriendFeed and Twitter</a></p>\n<p>Keeps your blog always fresh by regularly adding your most recent content from FriendFeed or Twitter. No external passwords required!</p>\n<p><a href=\"http://www.addinto.com/tools/wordpress.php\">AddInto</a></p>\n<p>Helps readers share, save, bookmark, and email your posts and pages.</p>\n<p><a href=\"http://www.artiss.co.uk/simple-wakoopa-list\">Simple TTIW List</a></p>\n<p>Simple TTIW List is a WordPress plugin that displays a list of the items that you are after, as provided by the TheThingsIWant.com website.</p>\n<h3>Updated Plugins</h3>\n<p><a href=\"http://ajaydsouza.com/wordpress/plugins/top-10/\">Top 10</a></p>\n<p>You can then display the page view count on individual posts and pages as well as display a list of most popular posts based on page views. Includes a sidebar widget to display the popular posts. And, all settings can be configured from within your WordPress Admin area itself!</p>\n<p><a href=\"http://omninoggin.com/wordpress-plugins/wp-greet-box-wordpress-plugin/\">WP Greet Box</a></p>\n<p>This plugin lets you show a different greeting message to your new visitors depending on their referrer url.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/wordpress-whois-search/\">Whois</a></p>\n<p>The plugin allows you to insert a tag into any WordPress post or page to generate a WHOIS search form for your users to get information on domain names with different TLDs.</p>\n<p><a href=\"http://www.thunderguy.com/semicolon/wordpress/seemore-wordpress-plugin/\">Seemore</a></p>\n<p>Change the (more&#8230;) link so that it jumps to the entire post, not just just the part after the (more&#8230;).</p>\n<p><a href=\"http://www.wikinvest.com/blogger/Wikinvest_stockquotes\">Wikinvest Stock Quotes</a></p>\n<p>Display in-line stock quotes on your blog.</p>\n<p><a href=\"http://themoneymakingwebsite.com/wp-directory-list/\">Wp-Directory-List</a></p>\n<p>Add a Business Directory or Directory of Links in different categories and pages.</p>\n<p><a href=\"http://bravenewcode.com/wptouch/\">WPtouch iPhone Theme</a></p>\n<p>WPtouch automatically transforms your WordPress blog into an iPhone application-style theme, complete with ajax loading articles and effects, when viewed from an iPhone or iPod touch.</p>\n<p><a href=\"http://bitsignals.com/2008/01/14/admin-msg-board/\">Admin Msg Board</a></p>\n<p>Adds a messaging system in your Wordpress admin area for bloggers to communicate. <em>Page in Spanish</em></p>\n<p><a href=\"http://tweetburn.com/tools/tweetroll/\">TweetRoll</a></p>\n<p>TweetRoll displays your Twitter details and the avatars of some of your friends.</p>\";}i:41;a:7:{s:5:\"title\";s:46:\"Weblog Tools Collection: Plugin Review: Yawasp\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=5183\";s:4:\"link\";s:74:\"http://weblogtoolscollection.com/archives/2009/02/15/plugin-review-yawasp/\";s:11:\"description\";s:3375:\"<p>Who doesn&#8217;t hate spam? Ever since blogs became common place, one thing that we have to worry about is spammers. It is like the constant battle of good vs. evil with the good folks finding means to defend themselves and others and the bad ones finding better means to attack the innocent ones!</p>\n<p><a href=\"http://www.svenkubiak.de/yawasp-en/\">Yawasp (Yet Another WordPress Anti-Spam Plugin)</a> is one such plugin that uses an innovative approach to battle comment spam.</p>\n<h3>Description</h3>\n<p>Most anti-comment-spambot-plugins focus on user interaction, e.g. captcha or math comment spam protection. Yawasp focuses on handling comment-spam-protection within WordPress. It replaces the names of the comment form fields with random names, protecting your blog from spambots that aim at the default comment field names. Furthermore it adds a blank field, hidden from the user, that needs to be left empty. In addition, the random field names are changed every 24 hours, giving a spambot no chance to adapt to the comment form.</p>\n<h3>Features</h3>\n<ul>\n<li>Does not require JavaScript, Cookies or Sessions</li>\n<li>No extra field for user input (e.g. Captcha) required</li>\n<li>False-positives are nearly impossible</li>\n<li>No need to manage spam comments anymore</li>\n<li>Easy installation (automatic or manual)</li>\n</ul>\n<h3>Installation</h3>\n<p>The installation is more complicated than other plugins as it requires deal of manual intervention (in case the automatic editing fails). Upload the plugin and activate it.</p>\n<p>Make the necessary changes in your theme files if necessary and you&#8217;re good to go.</p>\n<p>The plugin will display the number of spambots blocked on the dashboard.</p>\n<p><img title=\"yawasp\" src=\"http://weblogtoolscollection.com/b2-img/2009/02/yawasp.png\" alt=\"yawasp\" width=\"510\" height=\"211\" /></p>\n<h3>Review</h3>\n<p>This plugin is another attempt to protect your blog from spam. However, I still don&#8217;t think that this is the first and last stop for protecting your blog.</p>\n<p>For one, it only attempts to stop automated spambots attacking your comment form.</p>\n<p>And it cannot protect you against manual comment spammers and trackback/pingback spam. Hence, you&#8217;d require another plugin like Akismet to form your secondary defense.</p>\n<p>I recommend using this plugin if you have been able to identify that your primary amount of spam is spambots attacking your site. By installing this plugin, you&#8217;ll notice that with these spambots blocked, you&#8217;ll be required to take a look at a much smaller amount of spam in your spam queue.</p>\n<p>What I would like to see is what spam is actually blocked by the plugin. The plugin does store which spambots are blocked over a 24 hour period, which works well. However, you won&#8217;t see any of the comments blocked.</p>\n<p>In case your visitors start to report being blocked, you&#8217;ll need to check your <em>comments.php</em> to see if the code is properly installed. I suggest making a few test comments as well getting a few friends to test it out. From my experience, a lot of commenters will just not bother informing you in case they face problems commenting on your site.</p>\n<p>So, which antispam plugins do you use? If you&#8217;re already using Yawasp, what has been your experience so far? What features would you like to see added?</p>\";s:7:\"pubdate\";s:31:\"Sun, 15 Feb 2009 18:20:09 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:3375:\"<p>Who doesn&#8217;t hate spam? Ever since blogs became common place, one thing that we have to worry about is spammers. It is like the constant battle of good vs. evil with the good folks finding means to defend themselves and others and the bad ones finding better means to attack the innocent ones!</p>\n<p><a href=\"http://www.svenkubiak.de/yawasp-en/\">Yawasp (Yet Another WordPress Anti-Spam Plugin)</a> is one such plugin that uses an innovative approach to battle comment spam.</p>\n<h3>Description</h3>\n<p>Most anti-comment-spambot-plugins focus on user interaction, e.g. captcha or math comment spam protection. Yawasp focuses on handling comment-spam-protection within WordPress. It replaces the names of the comment form fields with random names, protecting your blog from spambots that aim at the default comment field names. Furthermore it adds a blank field, hidden from the user, that needs to be left empty. In addition, the random field names are changed every 24 hours, giving a spambot no chance to adapt to the comment form.</p>\n<h3>Features</h3>\n<ul>\n<li>Does not require JavaScript, Cookies or Sessions</li>\n<li>No extra field for user input (e.g. Captcha) required</li>\n<li>False-positives are nearly impossible</li>\n<li>No need to manage spam comments anymore</li>\n<li>Easy installation (automatic or manual)</li>\n</ul>\n<h3>Installation</h3>\n<p>The installation is more complicated than other plugins as it requires deal of manual intervention (in case the automatic editing fails). Upload the plugin and activate it.</p>\n<p>Make the necessary changes in your theme files if necessary and you&#8217;re good to go.</p>\n<p>The plugin will display the number of spambots blocked on the dashboard.</p>\n<p><img title=\"yawasp\" src=\"http://weblogtoolscollection.com/b2-img/2009/02/yawasp.png\" alt=\"yawasp\" width=\"510\" height=\"211\" /></p>\n<h3>Review</h3>\n<p>This plugin is another attempt to protect your blog from spam. However, I still don&#8217;t think that this is the first and last stop for protecting your blog.</p>\n<p>For one, it only attempts to stop automated spambots attacking your comment form.</p>\n<p>And it cannot protect you against manual comment spammers and trackback/pingback spam. Hence, you&#8217;d require another plugin like Akismet to form your secondary defense.</p>\n<p>I recommend using this plugin if you have been able to identify that your primary amount of spam is spambots attacking your site. By installing this plugin, you&#8217;ll notice that with these spambots blocked, you&#8217;ll be required to take a look at a much smaller amount of spam in your spam queue.</p>\n<p>What I would like to see is what spam is actually blocked by the plugin. The plugin does store which spambots are blocked over a 24 hour period, which works well. However, you won&#8217;t see any of the comments blocked.</p>\n<p>In case your visitors start to report being blocked, you&#8217;ll need to check your <em>comments.php</em> to see if the code is properly installed. I suggest making a few test comments as well getting a few friends to test it out. From my experience, a lot of commenters will just not bother informing you in case they face problems commenting on your site.</p>\n<p>So, which antispam plugins do you use? If you&#8217;re already using Yawasp, what has been your experience so far? What features would you like to see added?</p>\";}i:42;a:7:{s:5:\"title\";s:77:\"Weblog Tools Collection: A Belated Welcome to the New Weblog Tools Collection\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=5177\";s:4:\"link\";s:106:\"http://weblogtoolscollection.com/archives/2009/02/14/a-belated-welcome-to-the-new-weblog-tools-collection/\";s:11:\"description\";s:2247:\"<p>It has been a week since we put this new design into production at Weblog Tools Collection. Though at first it was quite a change, the design is growing on me.</p>\n<p>A few things are still broken (find any?) and the internal code and the SQL queries that run the plugins are still being tweaked. We might end up re-writing a few of the plugins to make them more efficient and introduce caching. Our overall goal was to make the blog feel fresh and be able to highlight the various aspects of our community that helps generate and produce and news and the articles for this blog. Needless to say, we stuck to our basic tenets of minimal advertising and ease of use while sticking with a light (on the eyes and on the bandwidth) and minimalist theme.</p>\n<p>If you only read this blog in a news reader, I welcome you to <a href=\"http://weblogtoolscollection.com\">check it out</a> on a browser. A lot has changed and there are a lot of new features. Since themes and plugins form a large portion of what this blog is all about, there are theme and plugin news sections now on the front page. We also highlight the most visited posts of the day at the top of the blog. We have also added lists from <a href=\"http://jobs.wordpress.net\">WordPress Jobs</a>, <a href=\"http://weblogtoolscollection.com/news\">General WordPress News</a>, <a href=\"http://pressitfor.me\">PressItFor.me</a> and <a href=\"http://weblogtoolsvideos.com\">Weblog Tools Videos</a>. The single page design is cleaner with emphasis on the actual content of the article and the comment threading (which form the meat and potatoes of any blog). The advertising has been spread around and neatly tucked away to not be obtrusive and yet provide a good value to the advertiser. Regular visitors see fewer ads and never see AdSense ads.</p>\n<p>The <a href=\"http://www.wptavern.com/forum/themes-templates/188-weblogtoolscollection-com-new-design.html\">change has not gone unnoticed</a> and reactions have ranged from absolute distaste to glorious commendations, with the meter tilting towards the latter. The one browser bug with the search form is really bugging me (try visiting this blog in IE or in Safari) but overall I am pleased with the result.</p>\n<p>What are your impressions?</p>\";s:7:\"pubdate\";s:31:\"Sat, 14 Feb 2009 22:59:31 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:10:\"Mark Ghosh\";}s:7:\"summary\";s:2247:\"<p>It has been a week since we put this new design into production at Weblog Tools Collection. Though at first it was quite a change, the design is growing on me.</p>\n<p>A few things are still broken (find any?) and the internal code and the SQL queries that run the plugins are still being tweaked. We might end up re-writing a few of the plugins to make them more efficient and introduce caching. Our overall goal was to make the blog feel fresh and be able to highlight the various aspects of our community that helps generate and produce and news and the articles for this blog. Needless to say, we stuck to our basic tenets of minimal advertising and ease of use while sticking with a light (on the eyes and on the bandwidth) and minimalist theme.</p>\n<p>If you only read this blog in a news reader, I welcome you to <a href=\"http://weblogtoolscollection.com\">check it out</a> on a browser. A lot has changed and there are a lot of new features. Since themes and plugins form a large portion of what this blog is all about, there are theme and plugin news sections now on the front page. We also highlight the most visited posts of the day at the top of the blog. We have also added lists from <a href=\"http://jobs.wordpress.net\">WordPress Jobs</a>, <a href=\"http://weblogtoolscollection.com/news\">General WordPress News</a>, <a href=\"http://pressitfor.me\">PressItFor.me</a> and <a href=\"http://weblogtoolsvideos.com\">Weblog Tools Videos</a>. The single page design is cleaner with emphasis on the actual content of the article and the comment threading (which form the meat and potatoes of any blog). The advertising has been spread around and neatly tucked away to not be obtrusive and yet provide a good value to the advertiser. Regular visitors see fewer ads and never see AdSense ads.</p>\n<p>The <a href=\"http://www.wptavern.com/forum/themes-templates/188-weblogtoolscollection-com-new-design.html\">change has not gone unnoticed</a> and reactions have ranged from absolute distaste to glorious commendations, with the meter tilting towards the latter. The one browser bug with the search form is really bugging me (try visiting this blog in IE or in Safari) but overall I am pleased with the result.</p>\n<p>What are your impressions?</p>\";}i:43;a:7:{s:5:\"title\";s:66:\"Alex King: Twitter Tools Exclude Replies Feature “Not Working”\";s:4:\"guid\";s:85:\"http://alexking.org/blog/2009/02/14/twitter-tools-exclude-replies-feature-not-working\";s:4:\"link\";s:85:\"http://alexking.org/blog/2009/02/14/twitter-tools-exclude-replies-feature-not-working\";s:11:\"description\";s:2105:\"<p>I&#8217;ve seen a few reports of the &#8220;exclude replies&#8221; feature not working in the <a href=\"http://alexking.org/blog/2009/02/13/twitter-tools-16b1\">1.6b1 release</a>. This appears to be due to a change in the data returned by the Twitter API. The tweet data used to always include a message being &#8220;replied to&#8221; if the tweet started with @username. This is no longer the case.</p>\n<p>What appears to have happened is that Twitter has refined its concept of a reply (probably factoring in duration of time between your tweet and the tweet being replied to, etc.).</p>\n<p>While Twitter has made this conceptual refinement, the Twitter users don&#8217;t seem to have made the same mental adjustment. Twitter Tools used the data from the Twitter API - specifically the &#8220;in reply to&#8221; property - to determine if a tweet was a reply or not; then acted accordingly. So Twitter Tools is looking at the data and saying &#8220;Hmm, Twitter doesn&#8217;t think this is a reply&#8221; and the userbase is saying &#8220;Yes it is&#8221;.</p>\n<p>After thinking about this, I&#8217;ve decided to change Twitter Tools to reflect the behavior the Twitter user base is expecting. You can <a href=\"http://plugins.trac.wordpress.org/browser/twitter-tools/trunk/twitter-tools.php?rev=94637\" rel=\"external\">grab the new version from SVN</a> (see Download link at the bottom of the page) if you want this change immediately, or you can wait for the next release (probably sometime next week).</p>\n<h3>Feature Requests</h3>\n<p>I&#8217;m also getting a variety of feature requests for this plugin. These will likely not be added any time soon unless people are willing to fund the necessary development for them. Unfortunately I don&#8217;t have any free time to spend on building these right now.</p>\n<p><a href=\"http://sharethis.com/item?&wp=2.2.3&amp;publisher=a1583af8-28eb-4210-97bd-2bb5c02bc265&amp;title=Twitter+Tools+Exclude+Replies+Feature+%22Not+Working%22&amp;url=http%3A%2F%2Falexking.org%2Fblog%2F2009%2F02%2F14%2Ftwitter-tools-exclude-replies-feature-not-working\">ShareThis</a></p>\";s:7:\"pubdate\";s:31:\"Sat, 14 Feb 2009 21:06:38 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Alex\";}s:7:\"summary\";s:2105:\"<p>I&#8217;ve seen a few reports of the &#8220;exclude replies&#8221; feature not working in the <a href=\"http://alexking.org/blog/2009/02/13/twitter-tools-16b1\">1.6b1 release</a>. This appears to be due to a change in the data returned by the Twitter API. The tweet data used to always include a message being &#8220;replied to&#8221; if the tweet started with @username. This is no longer the case.</p>\n<p>What appears to have happened is that Twitter has refined its concept of a reply (probably factoring in duration of time between your tweet and the tweet being replied to, etc.).</p>\n<p>While Twitter has made this conceptual refinement, the Twitter users don&#8217;t seem to have made the same mental adjustment. Twitter Tools used the data from the Twitter API - specifically the &#8220;in reply to&#8221; property - to determine if a tweet was a reply or not; then acted accordingly. So Twitter Tools is looking at the data and saying &#8220;Hmm, Twitter doesn&#8217;t think this is a reply&#8221; and the userbase is saying &#8220;Yes it is&#8221;.</p>\n<p>After thinking about this, I&#8217;ve decided to change Twitter Tools to reflect the behavior the Twitter user base is expecting. You can <a href=\"http://plugins.trac.wordpress.org/browser/twitter-tools/trunk/twitter-tools.php?rev=94637\" rel=\"external\">grab the new version from SVN</a> (see Download link at the bottom of the page) if you want this change immediately, or you can wait for the next release (probably sometime next week).</p>\n<h3>Feature Requests</h3>\n<p>I&#8217;m also getting a variety of feature requests for this plugin. These will likely not be added any time soon unless people are willing to fund the necessary development for them. Unfortunately I don&#8217;t have any free time to spend on building these right now.</p>\n<p><a href=\"http://sharethis.com/item?&wp=2.2.3&amp;publisher=a1583af8-28eb-4210-97bd-2bb5c02bc265&amp;title=Twitter+Tools+Exclude+Replies+Feature+%22Not+Working%22&amp;url=http%3A%2F%2Falexking.org%2Fblog%2F2009%2F02%2F14%2Ftwitter-tools-exclude-replies-feature-not-working\">ShareThis</a></p>\";}i:44;a:7:{s:5:\"title\";s:78:\"Lorelle on WP: WordPress.com Maintenance Downtime on Sunday, February 15, 2009\";s:4:\"guid\";s:36:\"http://lorelle.wordpress.com/?p=3899\";s:4:\"link\";s:101:\"http://lorelle.wordpress.com/2009/02/14/wordpresscom-maintenance-downtime-on-sunday-february-15-2009/\";s:11:\"description\";s:6561:\"<div class=\"snap_preview\"><br /><p><a href=\"http://lorelle.wordpress.com/tag/wordpressdotcom/\" title=\"WordPressdotcom news and tips\"><img src=\"http://lorelle.files.wordpress.com/2007/04/wordpressdotcomnews.gif\" alt=\"WordPress.com News\" align=\"right\" /></a><a title=\"00 GMT\" href=\"http://en.forums.wordpress.com/topic/logged-out-at-215-at-2000-gmt\">WordPress.com warns that the free blog hosting service will be down for maintenance</a> starting Sunday, February 15, 2009, at 20:00 GMT (noon PST, 3PM EST) for maintenance and upgrade improvements. This should only be a few seconds to a couple minutes. This does not impact full version and self-hosted versions of WordPress. </p>\n<p>The maintenance probably involves upgrading to <a href=\"http://lorelle.wordpress.com/2009/02/11/wordpress-271-released/\" title=\"WordPress 2.7.1 Released\">WordPress 2.7.1</a>, server improvements, and possibly the <a href=\"http://lorelle.wordpress.com/2009/02/05/wordpress-news-lots-of-wordpress-releases-love-blogging-and-wordpress-contest-scott-wallick-akismet-news-permalinks-and-more/\" title=\"Lots of WordPress Releases, Love Blogging and WordPress Contest, Scott Wallick, Akismet News, Permalinks, and More\">reported news</a> of <a href=\"http://barry.wordpress.com/2009/02/04/winter-2008-photos/\" title=\"blog post featuring photographs, WordPress server guru, Barry Abrahamson let it leak\">some &#8220;cool gallery features&#8221;</a> that may add navigation links for image pages, and other small improvements. Do not expect any major changes to the interface or functionality. </p>\n<p><img src=\"http://lorelle.files.wordpress.com/2009/02/wpc-maintenance-warning.png\" alt=\"WordPress.com Maintenance Warning\" title=\"WordPress.com Maintenance Warning\" width=\"484\" height=\"106\" class=\"aligncenter size-full wp-image-3898\" /></p>\n<p>They warn that unsaved work with be lost and you may have to log in again once the system is restored. This means that if you are in the middle of blogging something, it will not be saved and auto-save will not kick in to backup your posts. </p>\n<p>I recommend that you save everything you are working on at least two hours before the maintenance down time begins, just in case. If you &#8220;need&#8221; to blog something, write it up in a text editor or (at the very worst) a word processor and save it there until you can copy and paste or paste using the Word quicktag button in the Visual Text Editor. This is a worst case scenario warning just to be safe. </p>\n<p>These maintenance &#8220;moments&#8221; are rare with WordPress.com. According to Barry in the comments below, expect WordPress.com to be back fully active in less than two minutes. </p>\n<p>While waiting for WordPress.com to come back online, consider checking out the <a href=\"http://en.blog.wordpress.com/2009/02/02/i-3-blogging-design-contest/\" title=\"I &lt;3 Blogging Design Contest\">I &lt;3 Blogging Design Contest</a> and entering your graphic design to define why you love blogging and WordPress. If your graphic design wins, it could be printed and sold on laptop and iPhone skins around the world through the Infectious store.</p>\n<p><img src=\"http://lorelle.files.wordpress.com/2006/08/sig.gif\" alt=\"\" /><br />\n<hr />\n<p><font size=\"-1\"><b>Site Search Tags:</b> <a href=\"http://lorelle.wordpress.com/index.php?s=WordPress.com\" rel=\"tag\">WordPress.com</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=WordPress\" rel=\"tag\">WordPress</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=WordPress.com+news\" rel=\"tag\">WordPress.com news</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=news\" rel=\"tag\">news</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=maintenance\" rel=\"tag\">maintenance</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpressdotcom\" rel=\"tag\">wordpressdotcom</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpressdotcom+news\" rel=\"tag\">wordpressdotcom news</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=upgrade\" rel=\"tag\">upgrade</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=WordPress+2.7.1\" rel=\"tag\">WordPress 2.7.1</a> </p>\n<p><a href=\"http://lorelle.wordpress.com/feed/\" title=\"Feed on Lorelle on WordPress\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/02/rss.png\" alt=\"Feed on Lorelle on WordPress\" /></a> <a href=\"http://lorelle.wordpress.com/feed/\" title=\"Feed on Lorelle on WordPress\">Subscribe</a>  <a href=\"http://feeds.feedburner.com/LorelleOnWordPress\" title=\"Feedburner Lorelle on WordPress Feed\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/04/feedburnericon.gif\" alt=\"Feedburner icon\" />Via Feedburner</a>  <a href=\"http://www.feedblitz.com/f/?Sub=182399\" title=\"Lorelle on WordPress - full site feed email subscription\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/03/email.gif\" alt=\"\" />Subscribe by Email</a> <a href=\"http://lorelle.wordpress.com/\" title=\"Visit Lorelle on WordPress\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2008/03/pointer.gif\" alt=\"\" />Visit</a><br /><a href=\"http://lorelle.wordpress.com/about/\" title=\"Copyright Protected by Brent and Lorelle VanFossen\">Copyright Lorelle VanFossen</a>, the author of <a href=\"http://lorelle.wordpress.com/books/blogging-tips/\" title=\"Blogging Tips Book By Lorelle VanFossen\"><em>Blogging Tips, What Bloggers Won\'t Tell You About Blogging</em></a>.</font></p>\nPosted in WordPress News, Wordpressdotcom  <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gocomments/lorelle.wordpress.com/3899/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/comments/lorelle.wordpress.com/3899/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godelicious/lorelle.wordpress.com/3899/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/delicious/lorelle.wordpress.com/3899/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gostumble/lorelle.wordpress.com/3899/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/stumble/lorelle.wordpress.com/3899/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godigg/lorelle.wordpress.com/3899/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/digg/lorelle.wordpress.com/3899/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/goreddit/lorelle.wordpress.com/3899/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/reddit/lorelle.wordpress.com/3899/\" /></a> <img alt=\"\" border=\"0\" src=\"http://stats.wordpress.com/b.gif?host=lorelle.wordpress.com&blog=72&post=3899&subd=lorelle&ref=&feed=1\" /></div>\";s:7:\"pubdate\";s:31:\"Sat, 14 Feb 2009 21:00:31 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:17:\"Lorelle VanFossen\";}s:7:\"summary\";s:6561:\"<div class=\"snap_preview\"><br /><p><a href=\"http://lorelle.wordpress.com/tag/wordpressdotcom/\" title=\"WordPressdotcom news and tips\"><img src=\"http://lorelle.files.wordpress.com/2007/04/wordpressdotcomnews.gif\" alt=\"WordPress.com News\" align=\"right\" /></a><a title=\"00 GMT\" href=\"http://en.forums.wordpress.com/topic/logged-out-at-215-at-2000-gmt\">WordPress.com warns that the free blog hosting service will be down for maintenance</a> starting Sunday, February 15, 2009, at 20:00 GMT (noon PST, 3PM EST) for maintenance and upgrade improvements. This should only be a few seconds to a couple minutes. This does not impact full version and self-hosted versions of WordPress. </p>\n<p>The maintenance probably involves upgrading to <a href=\"http://lorelle.wordpress.com/2009/02/11/wordpress-271-released/\" title=\"WordPress 2.7.1 Released\">WordPress 2.7.1</a>, server improvements, and possibly the <a href=\"http://lorelle.wordpress.com/2009/02/05/wordpress-news-lots-of-wordpress-releases-love-blogging-and-wordpress-contest-scott-wallick-akismet-news-permalinks-and-more/\" title=\"Lots of WordPress Releases, Love Blogging and WordPress Contest, Scott Wallick, Akismet News, Permalinks, and More\">reported news</a> of <a href=\"http://barry.wordpress.com/2009/02/04/winter-2008-photos/\" title=\"blog post featuring photographs, WordPress server guru, Barry Abrahamson let it leak\">some &#8220;cool gallery features&#8221;</a> that may add navigation links for image pages, and other small improvements. Do not expect any major changes to the interface or functionality. </p>\n<p><img src=\"http://lorelle.files.wordpress.com/2009/02/wpc-maintenance-warning.png\" alt=\"WordPress.com Maintenance Warning\" title=\"WordPress.com Maintenance Warning\" width=\"484\" height=\"106\" class=\"aligncenter size-full wp-image-3898\" /></p>\n<p>They warn that unsaved work with be lost and you may have to log in again once the system is restored. This means that if you are in the middle of blogging something, it will not be saved and auto-save will not kick in to backup your posts. </p>\n<p>I recommend that you save everything you are working on at least two hours before the maintenance down time begins, just in case. If you &#8220;need&#8221; to blog something, write it up in a text editor or (at the very worst) a word processor and save it there until you can copy and paste or paste using the Word quicktag button in the Visual Text Editor. This is a worst case scenario warning just to be safe. </p>\n<p>These maintenance &#8220;moments&#8221; are rare with WordPress.com. According to Barry in the comments below, expect WordPress.com to be back fully active in less than two minutes. </p>\n<p>While waiting for WordPress.com to come back online, consider checking out the <a href=\"http://en.blog.wordpress.com/2009/02/02/i-3-blogging-design-contest/\" title=\"I &lt;3 Blogging Design Contest\">I &lt;3 Blogging Design Contest</a> and entering your graphic design to define why you love blogging and WordPress. If your graphic design wins, it could be printed and sold on laptop and iPhone skins around the world through the Infectious store.</p>\n<p><img src=\"http://lorelle.files.wordpress.com/2006/08/sig.gif\" alt=\"\" /><br />\n<hr />\n<p><font size=\"-1\"><b>Site Search Tags:</b> <a href=\"http://lorelle.wordpress.com/index.php?s=WordPress.com\" rel=\"tag\">WordPress.com</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=WordPress\" rel=\"tag\">WordPress</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=WordPress.com+news\" rel=\"tag\">WordPress.com news</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=news\" rel=\"tag\">news</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=maintenance\" rel=\"tag\">maintenance</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpressdotcom\" rel=\"tag\">wordpressdotcom</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpressdotcom+news\" rel=\"tag\">wordpressdotcom news</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=upgrade\" rel=\"tag\">upgrade</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=WordPress+2.7.1\" rel=\"tag\">WordPress 2.7.1</a> </p>\n<p><a href=\"http://lorelle.wordpress.com/feed/\" title=\"Feed on Lorelle on WordPress\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/02/rss.png\" alt=\"Feed on Lorelle on WordPress\" /></a> <a href=\"http://lorelle.wordpress.com/feed/\" title=\"Feed on Lorelle on WordPress\">Subscribe</a>  <a href=\"http://feeds.feedburner.com/LorelleOnWordPress\" title=\"Feedburner Lorelle on WordPress Feed\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/04/feedburnericon.gif\" alt=\"Feedburner icon\" />Via Feedburner</a>  <a href=\"http://www.feedblitz.com/f/?Sub=182399\" title=\"Lorelle on WordPress - full site feed email subscription\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/03/email.gif\" alt=\"\" />Subscribe by Email</a> <a href=\"http://lorelle.wordpress.com/\" title=\"Visit Lorelle on WordPress\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2008/03/pointer.gif\" alt=\"\" />Visit</a><br /><a href=\"http://lorelle.wordpress.com/about/\" title=\"Copyright Protected by Brent and Lorelle VanFossen\">Copyright Lorelle VanFossen</a>, the author of <a href=\"http://lorelle.wordpress.com/books/blogging-tips/\" title=\"Blogging Tips Book By Lorelle VanFossen\"><em>Blogging Tips, What Bloggers Won\'t Tell You About Blogging</em></a>.</font></p>\nPosted in WordPress News, Wordpressdotcom  <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gocomments/lorelle.wordpress.com/3899/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/comments/lorelle.wordpress.com/3899/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godelicious/lorelle.wordpress.com/3899/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/delicious/lorelle.wordpress.com/3899/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gostumble/lorelle.wordpress.com/3899/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/stumble/lorelle.wordpress.com/3899/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godigg/lorelle.wordpress.com/3899/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/digg/lorelle.wordpress.com/3899/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/goreddit/lorelle.wordpress.com/3899/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/reddit/lorelle.wordpress.com/3899/\" /></a> <img alt=\"\" border=\"0\" src=\"http://stats.wordpress.com/b.gif?host=lorelle.wordpress.com&blog=72&post=3899&subd=lorelle&ref=&feed=1\" /></div>\";}i:45;a:7:{s:5:\"title\";s:60:\"Weblog Tools Collection: WordPress Plugin Releases for 02/13\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=5174\";s:4:\"link\";s:88:\"http://weblogtoolscollection.com/archives/2009/02/13/wordpress-plugin-releases-for-0213/\";s:11:\"description\";s:5737:\"<h3>New Plugins</h3>\n<p><a href=\"http://omninoggin.com/wordpress-plugins/buy-sell-ads-wordpress-plugin/\">Buy Sell Ads WordPress Plugin</a></p>\n<p>Easily integrate your <a href=\"http://buysellads.com\">Buy Sell Ads</a> zones and includes anti-AdBlock meaures to help prevent AdBlock (and similar software) from blocking Buy Sell Ads advertisements.</p>\n<p><a href=\"http://www.improvingtheweb.com/wordpress-plugins/track-mybloglog/\">Track MyBlogLog</a></p>\n<p>This plugin identifies and tracks MyBlogLog readers on your website. The plugin will store the user avatar, location, website, twitter, technorati, etc.. along with the last visit dates.</p>\n<p><a href=\"http://www.whypad.com/posts/supple-forms-a-wordpress-cms-plugin/566/\">Supple Forms</a></p>\n<p>Supple Forms is a CMS plugin for WordPress that lets you easily add a custom write panel or meta box to the Write Post/Write Page screen. It differs from other custom write panel plugins in that you can store your data in either WordPress Custom Fields or your own custom table that the plugin will create for you. Additionally, it provides a powerful HTML snippet tool that lets you format and insert your data into pages and posts with shortcodes, and without tweaking templates.</p>\n<p><a href=\"http://omninoggin.com/wordpress-posts/automatically-deal-with-duplicate-content-in-wordpress/\">SEO No Duplicate</a></p>\n<p>Automatically deal with duplicate content on your blog by following <a href=\"http://googlewebmastercentral.blogspot.com/2009/02/specify-your-canonical.html\">Google Webmaster Guidelines</a>.</p>\n<p><a href=\"http://denzeldesigns.com/2009/02/vimeo-sidebar-widget/\">Vimeo Sidebar Widget</a></p>\n<p>Enable administrator to embed a single vimeo video into widget sidebar of blog. Administrator able to select autoplay and continous looping of vimeo video.</p>\n<p><a href=\"http://counsellingresource.com/features/2009/01/27/threaded-comment-numbering-plugin-for-wordpress/\">Threaded Comment Numbering</a></p>\n<p>The plugin numbers comments accurately whether you choose to display them in ascending or descending date order, on multiple pages or on one long page, and with or without threading enabled. It also handles pingback and trackback numbering.</p>\n<p><a href=\"http://www.picturesurf.org/gallery/#get/wordpress\">Picturesurf Gallery</a></p>\n<p>Picturesurf Gallery is a free service that allows you to upload, link, and share photo galleries anywhere.</p>\n<p><a href=\"http://tech.kounoupaki.gr/?p=6\">Connect2site</a></p>\n<p>Allows you to display another&#8217;s subblog posts of a specific category.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/i-am-reading/\">I am reading</a></p>\n<p>Configurable book display in a sidebar widget. Book information is read from Amazon or Open Library and gets cached in database.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/wp-plugin-lister/\">WP Plugin Lister</a></p>\n<p>Outputs all of your active plugins via PHP for use in page templates &amp; more.</p>\n<p><a href=\"http://grandslambert.com/wordpress/login-configurator/\">Login Configurator</a></p>\n<p>Add features to control how your login form works including where the user is redirected when they log in.</p>\n<p><a href=\"http://wp.blueding.com/\">Blueding</a></p>\n<p>Blueding automatically adds to your content, suitable for mobiles, a link to download the content onto mobile via bluetooth.</p>\n<p><a href=\"http://gonahkar.com/wordpress-plugins/custom-fields-shortcode/\">Custom fields shortcode</a></p>\n<p>Use custom fields as shortcode in post content without edit your theme files.</p>\n<h3>Updated Plugins</h3>\n<p><a href=\"http://sgowtham.net/blog/2008/12/06/wordpress-plugin-to-keep-track-of-visitors/\">wp-visitors</a></p>\n<p>wp-visitors records information about every visitor (page load). Requested URL, Referring URL, IP address, Hostname and Browser along with Date/Time are recorded and displayed in a tabular fashion. Geographical resolution of IP address (it&#8217;s only approximate) is also included.</p>\n<p><a href=\"http://www.weinschenker.name/plugin-feed-reading-blogroll/\">Feed Reading Blogroll</a></p>\n<p>The plugin displays the freshness for all your bookmarks with a separately saved feed-url, i.e. the age of the most recent update at the bookmarked site. You can also order your bookmarks by the freshness/latest update.</p>\n<p><a href=\"http://blogsecurity.net/wpscan\">WordPress Security Scan</a></p>\n<p>WordPress scanner is a free online resource that blog administrators can use to provide a measure of their wordpress security level. It is BETA software and is continually being developed.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/sendfeed/\">SendFeed</a></p>\n<p>Allows WordPress bloggers to send email updates to a given email address any time an RSS feed is updated.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/lastunes/\">lasTunes</a></p>\n<p>Adds iTunes links to Last.fm user&#8217;s Recently Played Tracks feed and displays them.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/vidoopconnect/\">VidoopConnect</a></p>\n<p><a href=\"http://vidoopconnect.com/\">VidoopConnect</a> makes it easier than ever to sign up and login to your site by letting your visitors reuse their existing accounts from sites like Google, Yahoo, AOL, Facebook and MySpace, or any other OpenID provider.</p>\n<p><a href=\"http://www.francesco-castaldo.com/plugins-and-widgets/seo-blogroll/\">SEO Blogroll</a></p>\n<p>Lets you decide which blogroll links have the nofollow attribute. Don&#8217;t waste link juice!</p>\n<p><a href=\"http://alexking.org/projects/wordpress/readme?project=twitter-tools\">Twitter Tools</a></p>\n<p>Twitter Tools is a plugin that creates a complete integration between your WordPress blog and your Twitter account.</p>\";s:7:\"pubdate\";s:31:\"Fri, 13 Feb 2009 20:29:17 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:5737:\"<h3>New Plugins</h3>\n<p><a href=\"http://omninoggin.com/wordpress-plugins/buy-sell-ads-wordpress-plugin/\">Buy Sell Ads WordPress Plugin</a></p>\n<p>Easily integrate your <a href=\"http://buysellads.com\">Buy Sell Ads</a> zones and includes anti-AdBlock meaures to help prevent AdBlock (and similar software) from blocking Buy Sell Ads advertisements.</p>\n<p><a href=\"http://www.improvingtheweb.com/wordpress-plugins/track-mybloglog/\">Track MyBlogLog</a></p>\n<p>This plugin identifies and tracks MyBlogLog readers on your website. The plugin will store the user avatar, location, website, twitter, technorati, etc.. along with the last visit dates.</p>\n<p><a href=\"http://www.whypad.com/posts/supple-forms-a-wordpress-cms-plugin/566/\">Supple Forms</a></p>\n<p>Supple Forms is a CMS plugin for WordPress that lets you easily add a custom write panel or meta box to the Write Post/Write Page screen. It differs from other custom write panel plugins in that you can store your data in either WordPress Custom Fields or your own custom table that the plugin will create for you. Additionally, it provides a powerful HTML snippet tool that lets you format and insert your data into pages and posts with shortcodes, and without tweaking templates.</p>\n<p><a href=\"http://omninoggin.com/wordpress-posts/automatically-deal-with-duplicate-content-in-wordpress/\">SEO No Duplicate</a></p>\n<p>Automatically deal with duplicate content on your blog by following <a href=\"http://googlewebmastercentral.blogspot.com/2009/02/specify-your-canonical.html\">Google Webmaster Guidelines</a>.</p>\n<p><a href=\"http://denzeldesigns.com/2009/02/vimeo-sidebar-widget/\">Vimeo Sidebar Widget</a></p>\n<p>Enable administrator to embed a single vimeo video into widget sidebar of blog. Administrator able to select autoplay and continous looping of vimeo video.</p>\n<p><a href=\"http://counsellingresource.com/features/2009/01/27/threaded-comment-numbering-plugin-for-wordpress/\">Threaded Comment Numbering</a></p>\n<p>The plugin numbers comments accurately whether you choose to display them in ascending or descending date order, on multiple pages or on one long page, and with or without threading enabled. It also handles pingback and trackback numbering.</p>\n<p><a href=\"http://www.picturesurf.org/gallery/#get/wordpress\">Picturesurf Gallery</a></p>\n<p>Picturesurf Gallery is a free service that allows you to upload, link, and share photo galleries anywhere.</p>\n<p><a href=\"http://tech.kounoupaki.gr/?p=6\">Connect2site</a></p>\n<p>Allows you to display another&#8217;s subblog posts of a specific category.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/i-am-reading/\">I am reading</a></p>\n<p>Configurable book display in a sidebar widget. Book information is read from Amazon or Open Library and gets cached in database.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/wp-plugin-lister/\">WP Plugin Lister</a></p>\n<p>Outputs all of your active plugins via PHP for use in page templates &amp; more.</p>\n<p><a href=\"http://grandslambert.com/wordpress/login-configurator/\">Login Configurator</a></p>\n<p>Add features to control how your login form works including where the user is redirected when they log in.</p>\n<p><a href=\"http://wp.blueding.com/\">Blueding</a></p>\n<p>Blueding automatically adds to your content, suitable for mobiles, a link to download the content onto mobile via bluetooth.</p>\n<p><a href=\"http://gonahkar.com/wordpress-plugins/custom-fields-shortcode/\">Custom fields shortcode</a></p>\n<p>Use custom fields as shortcode in post content without edit your theme files.</p>\n<h3>Updated Plugins</h3>\n<p><a href=\"http://sgowtham.net/blog/2008/12/06/wordpress-plugin-to-keep-track-of-visitors/\">wp-visitors</a></p>\n<p>wp-visitors records information about every visitor (page load). Requested URL, Referring URL, IP address, Hostname and Browser along with Date/Time are recorded and displayed in a tabular fashion. Geographical resolution of IP address (it&#8217;s only approximate) is also included.</p>\n<p><a href=\"http://www.weinschenker.name/plugin-feed-reading-blogroll/\">Feed Reading Blogroll</a></p>\n<p>The plugin displays the freshness for all your bookmarks with a separately saved feed-url, i.e. the age of the most recent update at the bookmarked site. You can also order your bookmarks by the freshness/latest update.</p>\n<p><a href=\"http://blogsecurity.net/wpscan\">WordPress Security Scan</a></p>\n<p>WordPress scanner is a free online resource that blog administrators can use to provide a measure of their wordpress security level. It is BETA software and is continually being developed.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/sendfeed/\">SendFeed</a></p>\n<p>Allows WordPress bloggers to send email updates to a given email address any time an RSS feed is updated.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/lastunes/\">lasTunes</a></p>\n<p>Adds iTunes links to Last.fm user&#8217;s Recently Played Tracks feed and displays them.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/vidoopconnect/\">VidoopConnect</a></p>\n<p><a href=\"http://vidoopconnect.com/\">VidoopConnect</a> makes it easier than ever to sign up and login to your site by letting your visitors reuse their existing accounts from sites like Google, Yahoo, AOL, Facebook and MySpace, or any other OpenID provider.</p>\n<p><a href=\"http://www.francesco-castaldo.com/plugins-and-widgets/seo-blogroll/\">SEO Blogroll</a></p>\n<p>Lets you decide which blogroll links have the nofollow attribute. Don&#8217;t waste link juice!</p>\n<p><a href=\"http://alexking.org/projects/wordpress/readme?project=twitter-tools\">Twitter Tools</a></p>\n<p>Twitter Tools is a plugin that creates a complete integration between your WordPress blog and your Twitter account.</p>\";}i:46;a:7:{s:5:\"title\";s:30:\"Alex King: Twitter Tools 1.6b1\";s:4:\"guid\";s:54:\"http://alexking.org/blog/2009/02/13/twitter-tools-16b1\";s:4:\"link\";s:54:\"http://alexking.org/blog/2009/02/13/twitter-tools-16b1\";s:11:\"description\";s:2683:\"<p><a href=\"http://crowdfavorite.com\">We&#8217;ve</a> finally gotten a chance to do some cleanup and testing on a new version of Twitter Tools, and the new version is ready for public testing.</p>\n<p>Twitter Tools is a <a href=\"http://wordpress.org/\" rel=\"external\">WordPress</a> plugin that creates an integration between your WordPress blog and your Twitter account. It allows you to pull your tweets into your blog (as posts and digests) and create new tweets on blog posts and from within WordPress.</p>\n<p>Among other changes, this version has the following major revisions:</p>\n<ol>\n<li>Fixed the issue where posts via XML-RPC/AtomPub or scheduled posts would not get tweeted - these now use your default settings.</li>\n<li>Fixed issues with digests - both daily and weekly should be working correctly now<sup><a href=\"http://alexking.org/blog/feed?cat=16#fn1234491030843n\" id=\"fn1234491030843\" class=\"footnote\">1</a></sup> The digest features are no longer listed as experimental.</li>\n<li>Changed the code that checks to create the Twitter data table so that it works properly with the new bulk plugin activation features.</li>\n<li>Added a new filter <code>tweet_blog_post_url</code> so that other plugins can hook in and run the URL of your blog post through an URL shortening service of your choosing before sending the full URL to Twitter (which uses TinyURL by default).</li>\n<li>Fixed an issue that caused the &#8216;Test Login&#8217; functionality to report a failure with a correct username and password (though the regular functionality was unaffected).</li>\n<li>Fixed several auto-linking issues.</li>\n<li>Bunch of little/under the hood stuff.</li>\n</ol>\n<p>I&#8217;m calling this a beta release since it hasn&#8217;t had public testing, but it is the version I&#8217;d recommend using at this point. It should address commonly reported issues - I really hope it does.</p>\n<p>The download and more information are available on my <a href=\"http://alexking.org/projects/wordpress\">WordPress Plugins page</a>.</p>\n<p>If you have any trouble with this, please open a thread in the <a href=\"http://wordpress.org/support/\" rel=\"external\">WP Support Forums</a> and <a href=\"http://alexking.org/contact\">e-mail</a> me a link to the thread or post a link here.</p>\n<ol class=\"footnotes\">\n<li id=\"fn1234491030843n\">Though bug reports on these won&#8217;t shock me. [<a href=\"http://alexking.org/blog/feed?cat=16#fn1234491030843\">back</a>]</li>\n</ol>\n<p><a href=\"http://sharethis.com/item?&wp=2.2.3&amp;publisher=a1583af8-28eb-4210-97bd-2bb5c02bc265&amp;title=Twitter+Tools+1.6b1&amp;url=http%3A%2F%2Falexking.org%2Fblog%2F2009%2F02%2F13%2Ftwitter-tools-16b1\">ShareThis</a></p>\";s:7:\"pubdate\";s:31:\"Fri, 13 Feb 2009 18:37:54 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Alex\";}s:7:\"summary\";s:2683:\"<p><a href=\"http://crowdfavorite.com\">We&#8217;ve</a> finally gotten a chance to do some cleanup and testing on a new version of Twitter Tools, and the new version is ready for public testing.</p>\n<p>Twitter Tools is a <a href=\"http://wordpress.org/\" rel=\"external\">WordPress</a> plugin that creates an integration between your WordPress blog and your Twitter account. It allows you to pull your tweets into your blog (as posts and digests) and create new tweets on blog posts and from within WordPress.</p>\n<p>Among other changes, this version has the following major revisions:</p>\n<ol>\n<li>Fixed the issue where posts via XML-RPC/AtomPub or scheduled posts would not get tweeted - these now use your default settings.</li>\n<li>Fixed issues with digests - both daily and weekly should be working correctly now<sup><a href=\"http://alexking.org/blog/feed?cat=16#fn1234491030843n\" id=\"fn1234491030843\" class=\"footnote\">1</a></sup> The digest features are no longer listed as experimental.</li>\n<li>Changed the code that checks to create the Twitter data table so that it works properly with the new bulk plugin activation features.</li>\n<li>Added a new filter <code>tweet_blog_post_url</code> so that other plugins can hook in and run the URL of your blog post through an URL shortening service of your choosing before sending the full URL to Twitter (which uses TinyURL by default).</li>\n<li>Fixed an issue that caused the &#8216;Test Login&#8217; functionality to report a failure with a correct username and password (though the regular functionality was unaffected).</li>\n<li>Fixed several auto-linking issues.</li>\n<li>Bunch of little/under the hood stuff.</li>\n</ol>\n<p>I&#8217;m calling this a beta release since it hasn&#8217;t had public testing, but it is the version I&#8217;d recommend using at this point. It should address commonly reported issues - I really hope it does.</p>\n<p>The download and more information are available on my <a href=\"http://alexking.org/projects/wordpress\">WordPress Plugins page</a>.</p>\n<p>If you have any trouble with this, please open a thread in the <a href=\"http://wordpress.org/support/\" rel=\"external\">WP Support Forums</a> and <a href=\"http://alexking.org/contact\">e-mail</a> me a link to the thread or post a link here.</p>\n<ol class=\"footnotes\">\n<li id=\"fn1234491030843n\">Though bug reports on these won&#8217;t shock me. [<a href=\"http://alexking.org/blog/feed?cat=16#fn1234491030843\">back</a>]</li>\n</ol>\n<p><a href=\"http://sharethis.com/item?&wp=2.2.3&amp;publisher=a1583af8-28eb-4210-97bd-2bb5c02bc265&amp;title=Twitter+Tools+1.6b1&amp;url=http%3A%2F%2Falexking.org%2Fblog%2F2009%2F02%2F13%2Ftwitter-tools-16b1\">ShareThis</a></p>\";}i:47;a:7:{s:5:\"title\";s:65:\"Weblog Tools Collection: FeedBurner is Dead, Long Live Feedburner\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=5171\";s:4:\"link\";s:93:\"http://weblogtoolscollection.com/archives/2009/02/12/feedburner-is-dead-long-live-feedburner/\";s:11:\"description\";s:2751:\"<p>So for some reason that I can no longer remember, I had to log into FeedBurner to do <em>something.</em> I was greeted with an odd message that appeared to say that FeedBurner would cease to exist and I would have to migrate my account to Google. I have become <a href=\"http://weblogtoolscollection.com/archives/2009/01/31/et-tu-google-then-fail-net-safety/\">wary of attaching my Google account to my other important services after their recent gaffe</a> and was about to click &#8220;No Thanks&#8221; when I realized that the page was telling me that if I did not do it manually, they would be moved for me anyways. Since I had no choice, I went through the paces to move my FeedBurner services to Google.</p>\n<p>The move was mostly uneventful and I was told that while my feeds were being transferred, I could close the browser window and know that they would be safely transferred. There are <a href=\"http://www.centernetworks.com/feedburner-google-update\">some reported incidents of missing feeds and long transfer times</a>. Worthy of note is that <a href=\"http://feeds2.feedburner.com/weblogtoolscollection/UXMP\">our feed URI did change</a> but I vaguely remember reading that the old feed URI will continue to work and get redirected. Now I see a &#8220;Cool, you recently moved to a Google Account! Your feed stats might be low for a bit; they should return to former levels in about 72 hours.&#8221; when I log in to <a href=\"http://feedburner.google.com\">http://feedburner.google.com</a>. So our narcissistic numbers are a little off but we will live. I could not help but notice a tinge of sadness in the <a href=\"http://blogs.feedburner.com/feedburner/index.php\">last post on the FeedBurner Blog</a>. Here are <a href=\"https://www.google.com/support/feedburner/bin/answer.py?answer=126303\">some FAQ&#8217;s from Google on the transfer</a> and the <a href=\"http://adsenseforfeeds.blogspot.com/2008/12/now-available-moving-your-feedburner.html\">original blog post from Google announcing the move process</a> and essentially sounding the death knell on the original FeedBurner.</p>\n<p>The last date to get all your feeds transferred to the &#8220;new&#8221; version of FeedBurner is February 28th. I know I was not aware of that date and many of you may not be as well. I understand that if you fail to transfer your feeds, they will be transferred for you but I would rather do it myself, especially if the URI is about to change. <a href=\"http://www.dailyblogtips.com/time-to-switch-from-feedburner-to-google/\">Daniel transferred his feeds recently and goes into some details of the process</a>. He had very few problems to speak of as well.</p>\n<p>Did you know that this was going to happen? Did you remember to transfer your feeds?</p>\";s:7:\"pubdate\";s:31:\"Fri, 13 Feb 2009 01:12:09 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:10:\"Mark Ghosh\";}s:7:\"summary\";s:2751:\"<p>So for some reason that I can no longer remember, I had to log into FeedBurner to do <em>something.</em> I was greeted with an odd message that appeared to say that FeedBurner would cease to exist and I would have to migrate my account to Google. I have become <a href=\"http://weblogtoolscollection.com/archives/2009/01/31/et-tu-google-then-fail-net-safety/\">wary of attaching my Google account to my other important services after their recent gaffe</a> and was about to click &#8220;No Thanks&#8221; when I realized that the page was telling me that if I did not do it manually, they would be moved for me anyways. Since I had no choice, I went through the paces to move my FeedBurner services to Google.</p>\n<p>The move was mostly uneventful and I was told that while my feeds were being transferred, I could close the browser window and know that they would be safely transferred. There are <a href=\"http://www.centernetworks.com/feedburner-google-update\">some reported incidents of missing feeds and long transfer times</a>. Worthy of note is that <a href=\"http://feeds2.feedburner.com/weblogtoolscollection/UXMP\">our feed URI did change</a> but I vaguely remember reading that the old feed URI will continue to work and get redirected. Now I see a &#8220;Cool, you recently moved to a Google Account! Your feed stats might be low for a bit; they should return to former levels in about 72 hours.&#8221; when I log in to <a href=\"http://feedburner.google.com\">http://feedburner.google.com</a>. So our narcissistic numbers are a little off but we will live. I could not help but notice a tinge of sadness in the <a href=\"http://blogs.feedburner.com/feedburner/index.php\">last post on the FeedBurner Blog</a>. Here are <a href=\"https://www.google.com/support/feedburner/bin/answer.py?answer=126303\">some FAQ&#8217;s from Google on the transfer</a> and the <a href=\"http://adsenseforfeeds.blogspot.com/2008/12/now-available-moving-your-feedburner.html\">original blog post from Google announcing the move process</a> and essentially sounding the death knell on the original FeedBurner.</p>\n<p>The last date to get all your feeds transferred to the &#8220;new&#8221; version of FeedBurner is February 28th. I know I was not aware of that date and many of you may not be as well. I understand that if you fail to transfer your feeds, they will be transferred for you but I would rather do it myself, especially if the URI is about to change. <a href=\"http://www.dailyblogtips.com/time-to-switch-from-feedburner-to-google/\">Daniel transferred his feeds recently and goes into some details of the process</a>. He had very few problems to speak of as well.</p>\n<p>Did you know that this was going to happen? Did you remember to transfer your feeds?</p>\";}i:48;a:7:{s:5:\"title\";s:39:\"Lorelle on WP: WordPress 2.7.1 Released\";s:4:\"guid\";s:36:\"http://lorelle.wordpress.com/?p=3884\";s:4:\"link\";s:63:\"http://lorelle.wordpress.com/2009/02/11/wordpress-271-released/\";s:11:\"description\";s:7390:\"<div class=\"snap_preview\"><br /><p><a href=\"http://lorelle.wordpress.com/tag/wordpress-news/\" title=\"WordPress News\"><img src=\"http://lorelle.files.wordpress.com/2007/01/wpnews1.png\" alt=\"WordPress News\" align=\"right\" /></a><a href=\"http://wordpress.org/development/2009/02/wordpress-271/\" title=\"WordPress 2.7.1\">WordPress 2.7.1</a>, a maintenance release, is out. If you are using WordPress 2.7, take advantage of the automatic built-in upgrade. If you are not, then consider <a href=\"http://lorelle.wordpress.com/2008/12/11/wordpress-27-upgrade-tips/\" title=\"WordPress 2.7 Upgrade Tips « Lorelle on WordPress\">upgrading to WordPress 2.7</a>. Sixty-five files were modified with 68 bug and feature fixes and improvements. </p>\n<p>Some of the fixes and feature improvements include:</p>\n<ul>\n<li><a href=\"http://core.trac.wordpress.org/ticket/6489\" title=\"Revisions do not respect time zone offset\">Post and Page revisions do not respect time zone offset</a></li>\n<li><a href=\"http://core.trac.wordpress.org/ticket/8405\" title=\"WordPress produces invalid comment feeds\">Invalid comment feeds</a></li>\n<li><a href=\"http://core.trac.wordpress.org/ticket/8494\" title=\"XMLRPC returns category name instead of category description\">XMLRPC returns category name instead of category description</a></li>\n<li><a href=\"http://core.trac.wordpress.org/ticket/8548\" title=\"Theme preview fails when theme in subdirectory\">Theme preview fails when theme in subdirectory</a></li>\n<li><a href=\"http://core.trac.wordpress.org/ticket/8609\" title=\"Tag cloud order priority is broken\">Tag cloud order priority</a></li>\n<li><a href=\"http://core.trac.wordpress.org/ticket/8614\" title=\"With wp_list_categories child categories not excluded when parents are excluded\">Hierarchy issues with wp_list_categories</a></li>\n<li><a href=\"http://core.trac.wordpress.org/ticket/8626\" title=\"Namespace missing in Atoms-Comments Feed\">Namespace missing in Atoms-Comments Feed</a></li>\n<li><a href=\"http://core.trac.wordpress.org/ticket/8642\" title=\"Canonical redirect of feed URLs with suffixes is wrong\">Canonical redirect of feed URLs</a></li>\n<li><a href=\"http://core.trac.wordpress.org/ticket/8684\" title=\"Contributor level users can delete all spam\">Contributor level users could delete all spam</a></li>\n<li><a href=\"http://core.trac.wordpress.org/ticket/8694\" title=\"Word 2007 can\'t retrieve categories\">Allowing Word 2007 to retrieve categories</a></li>\n<li><a href=\"http://core.trac.wordpress.org/ticket/8700\">&#8220;Selected&#8221; argument doesn&#8217;t work for &#8220;none&#8221; and &#8220;all&#8221; options in wp_dropdown_categories template tag</a></li>\n<li><a href=\"http://core.trac.wordpress.org/ticket/8750\" title=\"\'Draft Saved\' current_time not reflecting timezone setting in the edit area\">Draft Saved current time doesn&#8217;t match timezone while editing</a></li>\n<li><a href=\"http://core.trac.wordpress.org/ticket/8771\" title=\"Distinguish between approved / unapproved comments in All Comments list for IE7\">IE7 bug fixed for approved and unapproved comments in All Comments list</a></li>\n<li><a href=\"http://core.trac.wordpress.org/ticket/8784\" title=\"Multiple categories in RSS feed broken in WordPress 2.7\">Multiple categories feeds repaired</a></li>\n<li><a href=\"http://core.trac.wordpress.org/ticket/8944\" title=\"MT import causes empty feed\">Empty feeds for MT imports</a></li>\n<li><a href=\"http://core.trac.wordpress.org/ticket/8978\" title=\"Drafts are published in the past\">Post drafts published in the past</a></li>\n</ul>\n<p>Some additional security measures were taken in this release to make protect it from future vulnerabilities as part of the ongoing work by WordPress to make it as safe and secure as possible. </p>\n<p>According to the <a href=\"http://wordpress.org/download/counter/\" title=\"Download Counter\">WordPress Download Counter</a>, WordPress 2.7 has been downloaded 1,872,184 times since <a href=\"http://wordpress.org/development/2008/12/coltrane/\" title=\"the official announcement\">December 10, 2008</a>.</p>\n<p><img src=\"http://lorelle.files.wordpress.com/2006/08/sig.gif\" alt=\"\" /><br />\n<hr />\n<p><font size=\"-1\"><b>Site Search Tags:</b> <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress\" rel=\"tag\">wordpress</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+2.7\" rel=\"tag\">wordpress 2.7</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+2.7.1\" rel=\"tag\">wordpress 2.7.1</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+version\" rel=\"tag\">wordpress version</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+released\" rel=\"tag\">wordpress released</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+update\" rel=\"tag\">wordpress update</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+upgrade\" rel=\"tag\">wordpress upgrade</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+news\" rel=\"tag\">wordpress news</a> </p>\n<p><a href=\"http://lorelle.wordpress.com/feed/\" title=\"Feed on Lorelle on WordPress\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/02/rss.png\" alt=\"Feed on Lorelle on WordPress\" /></a> <a href=\"http://lorelle.wordpress.com/feed/\" title=\"Feed on Lorelle on WordPress\">Subscribe</a>  <a href=\"http://feeds.feedburner.com/LorelleOnWordPress\" title=\"Feedburner Lorelle on WordPress Feed\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/04/feedburnericon.gif\" alt=\"Feedburner icon\" />Via Feedburner</a>  <a href=\"http://www.feedblitz.com/f/?Sub=182399\" title=\"Lorelle on WordPress - full site feed email subscription\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/03/email.gif\" alt=\"\" />Subscribe by Email</a> <a href=\"http://lorelle.wordpress.com/\" title=\"Visit Lorelle on WordPress\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2008/03/pointer.gif\" alt=\"\" />Visit</a><br /><a href=\"http://lorelle.wordpress.com/about/\" title=\"Copyright Protected by Brent and Lorelle VanFossen\">Copyright Lorelle VanFossen</a>, the author of <a href=\"http://lorelle.wordpress.com/books/blogging-tips/\" title=\"Blogging Tips Book By Lorelle VanFossen\"><em>Blogging Tips, What Bloggers Won\'t Tell You About Blogging</em></a>.</font></p>\nPosted in WordPress News  <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gocomments/lorelle.wordpress.com/3884/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/comments/lorelle.wordpress.com/3884/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godelicious/lorelle.wordpress.com/3884/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/delicious/lorelle.wordpress.com/3884/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gostumble/lorelle.wordpress.com/3884/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/stumble/lorelle.wordpress.com/3884/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godigg/lorelle.wordpress.com/3884/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/digg/lorelle.wordpress.com/3884/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/goreddit/lorelle.wordpress.com/3884/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/reddit/lorelle.wordpress.com/3884/\" /></a> <img alt=\"\" border=\"0\" src=\"http://stats.wordpress.com/b.gif?host=lorelle.wordpress.com&blog=72&post=3884&subd=lorelle&ref=&feed=1\" /></div>\";s:7:\"pubdate\";s:31:\"Wed, 11 Feb 2009 20:52:24 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:17:\"Lorelle VanFossen\";}s:7:\"summary\";s:7390:\"<div class=\"snap_preview\"><br /><p><a href=\"http://lorelle.wordpress.com/tag/wordpress-news/\" title=\"WordPress News\"><img src=\"http://lorelle.files.wordpress.com/2007/01/wpnews1.png\" alt=\"WordPress News\" align=\"right\" /></a><a href=\"http://wordpress.org/development/2009/02/wordpress-271/\" title=\"WordPress 2.7.1\">WordPress 2.7.1</a>, a maintenance release, is out. If you are using WordPress 2.7, take advantage of the automatic built-in upgrade. If you are not, then consider <a href=\"http://lorelle.wordpress.com/2008/12/11/wordpress-27-upgrade-tips/\" title=\"WordPress 2.7 Upgrade Tips « Lorelle on WordPress\">upgrading to WordPress 2.7</a>. Sixty-five files were modified with 68 bug and feature fixes and improvements. </p>\n<p>Some of the fixes and feature improvements include:</p>\n<ul>\n<li><a href=\"http://core.trac.wordpress.org/ticket/6489\" title=\"Revisions do not respect time zone offset\">Post and Page revisions do not respect time zone offset</a></li>\n<li><a href=\"http://core.trac.wordpress.org/ticket/8405\" title=\"WordPress produces invalid comment feeds\">Invalid comment feeds</a></li>\n<li><a href=\"http://core.trac.wordpress.org/ticket/8494\" title=\"XMLRPC returns category name instead of category description\">XMLRPC returns category name instead of category description</a></li>\n<li><a href=\"http://core.trac.wordpress.org/ticket/8548\" title=\"Theme preview fails when theme in subdirectory\">Theme preview fails when theme in subdirectory</a></li>\n<li><a href=\"http://core.trac.wordpress.org/ticket/8609\" title=\"Tag cloud order priority is broken\">Tag cloud order priority</a></li>\n<li><a href=\"http://core.trac.wordpress.org/ticket/8614\" title=\"With wp_list_categories child categories not excluded when parents are excluded\">Hierarchy issues with wp_list_categories</a></li>\n<li><a href=\"http://core.trac.wordpress.org/ticket/8626\" title=\"Namespace missing in Atoms-Comments Feed\">Namespace missing in Atoms-Comments Feed</a></li>\n<li><a href=\"http://core.trac.wordpress.org/ticket/8642\" title=\"Canonical redirect of feed URLs with suffixes is wrong\">Canonical redirect of feed URLs</a></li>\n<li><a href=\"http://core.trac.wordpress.org/ticket/8684\" title=\"Contributor level users can delete all spam\">Contributor level users could delete all spam</a></li>\n<li><a href=\"http://core.trac.wordpress.org/ticket/8694\" title=\"Word 2007 can\'t retrieve categories\">Allowing Word 2007 to retrieve categories</a></li>\n<li><a href=\"http://core.trac.wordpress.org/ticket/8700\">&#8220;Selected&#8221; argument doesn&#8217;t work for &#8220;none&#8221; and &#8220;all&#8221; options in wp_dropdown_categories template tag</a></li>\n<li><a href=\"http://core.trac.wordpress.org/ticket/8750\" title=\"\'Draft Saved\' current_time not reflecting timezone setting in the edit area\">Draft Saved current time doesn&#8217;t match timezone while editing</a></li>\n<li><a href=\"http://core.trac.wordpress.org/ticket/8771\" title=\"Distinguish between approved / unapproved comments in All Comments list for IE7\">IE7 bug fixed for approved and unapproved comments in All Comments list</a></li>\n<li><a href=\"http://core.trac.wordpress.org/ticket/8784\" title=\"Multiple categories in RSS feed broken in WordPress 2.7\">Multiple categories feeds repaired</a></li>\n<li><a href=\"http://core.trac.wordpress.org/ticket/8944\" title=\"MT import causes empty feed\">Empty feeds for MT imports</a></li>\n<li><a href=\"http://core.trac.wordpress.org/ticket/8978\" title=\"Drafts are published in the past\">Post drafts published in the past</a></li>\n</ul>\n<p>Some additional security measures were taken in this release to make protect it from future vulnerabilities as part of the ongoing work by WordPress to make it as safe and secure as possible. </p>\n<p>According to the <a href=\"http://wordpress.org/download/counter/\" title=\"Download Counter\">WordPress Download Counter</a>, WordPress 2.7 has been downloaded 1,872,184 times since <a href=\"http://wordpress.org/development/2008/12/coltrane/\" title=\"the official announcement\">December 10, 2008</a>.</p>\n<p><img src=\"http://lorelle.files.wordpress.com/2006/08/sig.gif\" alt=\"\" /><br />\n<hr />\n<p><font size=\"-1\"><b>Site Search Tags:</b> <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress\" rel=\"tag\">wordpress</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+2.7\" rel=\"tag\">wordpress 2.7</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+2.7.1\" rel=\"tag\">wordpress 2.7.1</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+version\" rel=\"tag\">wordpress version</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+released\" rel=\"tag\">wordpress released</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+update\" rel=\"tag\">wordpress update</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+upgrade\" rel=\"tag\">wordpress upgrade</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+news\" rel=\"tag\">wordpress news</a> </p>\n<p><a href=\"http://lorelle.wordpress.com/feed/\" title=\"Feed on Lorelle on WordPress\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/02/rss.png\" alt=\"Feed on Lorelle on WordPress\" /></a> <a href=\"http://lorelle.wordpress.com/feed/\" title=\"Feed on Lorelle on WordPress\">Subscribe</a>  <a href=\"http://feeds.feedburner.com/LorelleOnWordPress\" title=\"Feedburner Lorelle on WordPress Feed\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/04/feedburnericon.gif\" alt=\"Feedburner icon\" />Via Feedburner</a>  <a href=\"http://www.feedblitz.com/f/?Sub=182399\" title=\"Lorelle on WordPress - full site feed email subscription\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/03/email.gif\" alt=\"\" />Subscribe by Email</a> <a href=\"http://lorelle.wordpress.com/\" title=\"Visit Lorelle on WordPress\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2008/03/pointer.gif\" alt=\"\" />Visit</a><br /><a href=\"http://lorelle.wordpress.com/about/\" title=\"Copyright Protected by Brent and Lorelle VanFossen\">Copyright Lorelle VanFossen</a>, the author of <a href=\"http://lorelle.wordpress.com/books/blogging-tips/\" title=\"Blogging Tips Book By Lorelle VanFossen\"><em>Blogging Tips, What Bloggers Won\'t Tell You About Blogging</em></a>.</font></p>\nPosted in WordPress News  <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gocomments/lorelle.wordpress.com/3884/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/comments/lorelle.wordpress.com/3884/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godelicious/lorelle.wordpress.com/3884/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/delicious/lorelle.wordpress.com/3884/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gostumble/lorelle.wordpress.com/3884/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/stumble/lorelle.wordpress.com/3884/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godigg/lorelle.wordpress.com/3884/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/digg/lorelle.wordpress.com/3884/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/goreddit/lorelle.wordpress.com/3884/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/reddit/lorelle.wordpress.com/3884/\" /></a> <img alt=\"\" border=\"0\" src=\"http://stats.wordpress.com/b.gif?host=lorelle.wordpress.com&blog=72&post=3884&subd=lorelle&ref=&feed=1\" /></div>\";}i:49;a:7:{s:5:\"title\";s:59:\"Weblog Tools Collection: WordPress Theme Releases for 02/11\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=5167\";s:4:\"link\";s:87:\"http://weblogtoolscollection.com/archives/2009/02/11/wordpress-theme-releases-for-0211/\";s:11:\"description\";s:1561:\"<p><strong>Compositio [removed, premium theme sponsored]<br />\n</strong></p>\n<p><img title=\"compositio\" src=\"http://weblogtoolscollection.com/b2-img/2009/02/compositio.png\" border=\"0\" alt=\"compositio\" width=\"196\" height=\"114\" /></p>\n<p>Compositio is a two column theme, made to for those who want to put their content at the front with a unique light blue design. Random square shapes are the defining graphics of this theme. They are used throughout the background, bringing a special rhythm to the theme.</p>\n<p><a href=\"http://www.acosmin.com/free-wordpress-theme-i-can-watch-movies/\"><strong>I Can Watch Movies</strong></a></p>\n<p><a href=\"http://www.acosmin.com/wptest/?theme=i_can_watch_movies\"><img title=\"ICanWatchMovies\" src=\"http://weblogtoolscollection.com/b2-img/2009/02/icanwatchmovies.gif\" border=\"0\" alt=\"ICanWatchMovies\" width=\"191\" height=\"114\" /></a></p>\n<p>Single column, widget ready theme with SIFR for main title and headings.</p>\n<p><a href=\"http://snailbird.com/?p=612\"><strong>Sheep in a Field</strong></a></p>\n<p><a href=\"http://demo.snailbird.com/index.php?wptheme=Sheepfield\"><img title=\"Sheepfield\" src=\"http://weblogtoolscollection.com/b2-img/2009/02/sheepfield.jpg\" border=\"0\" alt=\"Sheepfield\" width=\"127\" height=\"114\" /></a></p>\n<p>Three-column design, featuring a few sheep, some birds, and a little springtime to cheer you up from the Winter blues. You don’t have to be part of the flock to use this theme.</p>\n<p>Theme developer? Come <a href=\"http://weblogtoolscollection.com/submit-news/\">submit your themes</a> to us.</p>\";s:7:\"pubdate\";s:31:\"Wed, 11 Feb 2009 20:14:56 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:1561:\"<p><strong>Compositio [removed, premium theme sponsored]<br />\n</strong></p>\n<p><img title=\"compositio\" src=\"http://weblogtoolscollection.com/b2-img/2009/02/compositio.png\" border=\"0\" alt=\"compositio\" width=\"196\" height=\"114\" /></p>\n<p>Compositio is a two column theme, made to for those who want to put their content at the front with a unique light blue design. Random square shapes are the defining graphics of this theme. They are used throughout the background, bringing a special rhythm to the theme.</p>\n<p><a href=\"http://www.acosmin.com/free-wordpress-theme-i-can-watch-movies/\"><strong>I Can Watch Movies</strong></a></p>\n<p><a href=\"http://www.acosmin.com/wptest/?theme=i_can_watch_movies\"><img title=\"ICanWatchMovies\" src=\"http://weblogtoolscollection.com/b2-img/2009/02/icanwatchmovies.gif\" border=\"0\" alt=\"ICanWatchMovies\" width=\"191\" height=\"114\" /></a></p>\n<p>Single column, widget ready theme with SIFR for main title and headings.</p>\n<p><a href=\"http://snailbird.com/?p=612\"><strong>Sheep in a Field</strong></a></p>\n<p><a href=\"http://demo.snailbird.com/index.php?wptheme=Sheepfield\"><img title=\"Sheepfield\" src=\"http://weblogtoolscollection.com/b2-img/2009/02/sheepfield.jpg\" border=\"0\" alt=\"Sheepfield\" width=\"127\" height=\"114\" /></a></p>\n<p>Three-column design, featuring a few sheep, some birds, and a little springtime to cheer you up from the Winter blues. You don’t have to be part of the flock to use this theme.</p>\n<p>Theme developer? Come <a href=\"http://weblogtoolscollection.com/submit-news/\">submit your themes</a> to us.</p>\";}}s:7:\"channel\";a:5:{s:5:\"title\";s:16:\"WordPress Planet\";s:4:\"link\";s:28:\"http://planet.wordpress.org/\";s:8:\"language\";s:2:\"en\";s:11:\"description\";s:47:\"WordPress Planet - http://planet.wordpress.org/\";s:7:\"tagline\";s:47:\"WordPress Planet - http://planet.wordpress.org/\";}s:9:\"textinput\";a:0:{}s:5:\"image\";a:0:{}s:9:\"feed_type\";s:3:\"RSS\";s:12:\"feed_version\";s:3:\"2.0\";s:5:\"stack\";a:0:{}s:9:\"inchannel\";b:0;s:6:\"initem\";b:0;s:9:\"incontent\";b:0;s:11:\"intextinput\";b:0;s:7:\"inimage\";b:0;s:13:\"current_field\";s:0:\"\";s:17:\"current_namespace\";b:0;s:19:\"_CONTENT_CONSTRUCTS\";a:6:{i:0;s:7:\"content\";i:1;s:7:\"summary\";i:2;s:4:\"info\";i:3;s:5:\"title\";i:4;s:7:\"tagline\";i:5;s:9:\"copyright\";}}','no'),(120,0,'rss_867bd5c64f85878d03a060509cd2f92c_ts','1236130597','no'),(124,0,'category_children','a:0:{}','yes'),(125,0,'rewrite_rules','a:71:{s:12:\"robots\\.txt$\";s:18:\"index.php?robots=1\";s:14:\".*wp-atom.php$\";s:19:\"index.php?feed=atom\";s:13:\".*wp-rdf.php$\";s:18:\"index.php?feed=rdf\";s:13:\".*wp-rss.php$\";s:18:\"index.php?feed=rss\";s:14:\".*wp-rss2.php$\";s:19:\"index.php?feed=rss2\";s:14:\".*wp-feed.php$\";s:19:\"index.php?feed=feed\";s:22:\".*wp-commentsrss2.php$\";s:34:\"index.php?feed=rss2&withcomments=1\";s:32:\"feed/(feed|rdf|rss|rss2|atom)/?$\";s:27:\"index.php?&feed=$matches[1]\";s:27:\"(feed|rdf|rss|rss2|atom)/?$\";s:27:\"index.php?&feed=$matches[1]\";s:20:\"page/?([0-9]{1,})/?$\";s:28:\"index.php?&paged=$matches[1]\";s:41:\"comments/feed/(feed|rdf|rss|rss2|atom)/?$\";s:42:\"index.php?&feed=$matches[1]&withcomments=1\";s:36:\"comments/(feed|rdf|rss|rss2|atom)/?$\";s:42:\"index.php?&feed=$matches[1]&withcomments=1\";s:29:\"comments/page/?([0-9]{1,})/?$\";s:28:\"index.php?&paged=$matches[1]\";s:44:\"search/(.+)/feed/(feed|rdf|rss|rss2|atom)/?$\";s:40:\"index.php?s=$matches[1]&feed=$matches[2]\";s:39:\"search/(.+)/(feed|rdf|rss|rss2|atom)/?$\";s:40:\"index.php?s=$matches[1]&feed=$matches[2]\";s:32:\"search/(.+)/page/?([0-9]{1,})/?$\";s:41:\"index.php?s=$matches[1]&paged=$matches[2]\";s:14:\"search/(.+)/?$\";s:23:\"index.php?s=$matches[1]\";s:47:\"category/(.+?)/feed/(feed|rdf|rss|rss2|atom)/?$\";s:52:\"index.php?category_name=$matches[1]&feed=$matches[2]\";s:42:\"category/(.+?)/(feed|rdf|rss|rss2|atom)/?$\";s:52:\"index.php?category_name=$matches[1]&feed=$matches[2]\";s:35:\"category/(.+?)/page/?([0-9]{1,})/?$\";s:53:\"index.php?category_name=$matches[1]&paged=$matches[2]\";s:17:\"category/(.+?)/?$\";s:35:\"index.php?category_name=$matches[1]\";s:42:\"tag/(.+?)/feed/(feed|rdf|rss|rss2|atom)/?$\";s:42:\"index.php?tag=$matches[1]&feed=$matches[2]\";s:37:\"tag/(.+?)/(feed|rdf|rss|rss2|atom)/?$\";s:42:\"index.php?tag=$matches[1]&feed=$matches[2]\";s:30:\"tag/(.+?)/page/?([0-9]{1,})/?$\";s:43:\"index.php?tag=$matches[1]&paged=$matches[2]\";s:12:\"tag/(.+?)/?$\";s:25:\"index.php?tag=$matches[1]\";s:47:\"author/([^/]+)/feed/(feed|rdf|rss|rss2|atom)/?$\";s:50:\"index.php?author_name=$matches[1]&feed=$matches[2]\";s:42:\"author/([^/]+)/(feed|rdf|rss|rss2|atom)/?$\";s:50:\"index.php?author_name=$matches[1]&feed=$matches[2]\";s:35:\"author/([^/]+)/page/?([0-9]{1,})/?$\";s:51:\"index.php?author_name=$matches[1]&paged=$matches[2]\";s:17:\"author/([^/]+)/?$\";s:33:\"index.php?author_name=$matches[1]\";s:69:\"([0-9]{4})/([0-9]{1,2})/([0-9]{1,2})/feed/(feed|rdf|rss|rss2|atom)/?$\";s:80:\"index.php?year=$matches[1]&monthnum=$matches[2]&day=$matches[3]&feed=$matches[4]\";s:64:\"([0-9]{4})/([0-9]{1,2})/([0-9]{1,2})/(feed|rdf|rss|rss2|atom)/?$\";s:80:\"index.php?year=$matches[1]&monthnum=$matches[2]&day=$matches[3]&feed=$matches[4]\";s:57:\"([0-9]{4})/([0-9]{1,2})/([0-9]{1,2})/page/?([0-9]{1,})/?$\";s:81:\"index.php?year=$matches[1]&monthnum=$matches[2]&day=$matches[3]&paged=$matches[4]\";s:39:\"([0-9]{4})/([0-9]{1,2})/([0-9]{1,2})/?$\";s:63:\"index.php?year=$matches[1]&monthnum=$matches[2]&day=$matches[3]\";s:56:\"([0-9]{4})/([0-9]{1,2})/feed/(feed|rdf|rss|rss2|atom)/?$\";s:64:\"index.php?year=$matches[1]&monthnum=$matches[2]&feed=$matches[3]\";s:51:\"([0-9]{4})/([0-9]{1,2})/(feed|rdf|rss|rss2|atom)/?$\";s:64:\"index.php?year=$matches[1]&monthnum=$matches[2]&feed=$matches[3]\";s:44:\"([0-9]{4})/([0-9]{1,2})/page/?([0-9]{1,})/?$\";s:65:\"index.php?year=$matches[1]&monthnum=$matches[2]&paged=$matches[3]\";s:26:\"([0-9]{4})/([0-9]{1,2})/?$\";s:47:\"index.php?year=$matches[1]&monthnum=$matches[2]\";s:43:\"([0-9]{4})/feed/(feed|rdf|rss|rss2|atom)/?$\";s:43:\"index.php?year=$matches[1]&feed=$matches[2]\";s:38:\"([0-9]{4})/(feed|rdf|rss|rss2|atom)/?$\";s:43:\"index.php?year=$matches[1]&feed=$matches[2]\";s:31:\"([0-9]{4})/page/?([0-9]{1,})/?$\";s:44:\"index.php?year=$matches[1]&paged=$matches[2]\";s:13:\"([0-9]{4})/?$\";s:26:\"index.php?year=$matches[1]\";s:58:\"[0-9]{4}/[0-9]{1,2}/[0-9]{1,2}/[^/]+/attachment/([^/]+)/?$\";s:32:\"index.php?attachment=$matches[1]\";s:68:\"[0-9]{4}/[0-9]{1,2}/[0-9]{1,2}/[^/]+/attachment/([^/]+)/trackback/?$\";s:37:\"index.php?attachment=$matches[1]&tb=1\";s:88:\"[0-9]{4}/[0-9]{1,2}/[0-9]{1,2}/[^/]+/attachment/([^/]+)/feed/(feed|rdf|rss|rss2|atom)/?$\";s:49:\"index.php?attachment=$matches[1]&feed=$matches[2]\";s:83:\"[0-9]{4}/[0-9]{1,2}/[0-9]{1,2}/[^/]+/attachment/([^/]+)/(feed|rdf|rss|rss2|atom)/?$\";s:49:\"index.php?attachment=$matches[1]&feed=$matches[2]\";s:83:\"[0-9]{4}/[0-9]{1,2}/[0-9]{1,2}/[^/]+/attachment/([^/]+)/comment-page-([0-9]{1,})/?$\";s:50:\"index.php?attachment=$matches[1]&cpage=$matches[2]\";s:57:\"([0-9]{4})/([0-9]{1,2})/([0-9]{1,2})/([^/]+)/trackback/?$\";s:85:\"index.php?year=$matches[1]&monthnum=$matches[2]&day=$matches[3]&name=$matches[4]&tb=1\";s:77:\"([0-9]{4})/([0-9]{1,2})/([0-9]{1,2})/([^/]+)/feed/(feed|rdf|rss|rss2|atom)/?$\";s:97:\"index.php?year=$matches[1]&monthnum=$matches[2]&day=$matches[3]&name=$matches[4]&feed=$matches[5]\";s:72:\"([0-9]{4})/([0-9]{1,2})/([0-9]{1,2})/([^/]+)/(feed|rdf|rss|rss2|atom)/?$\";s:97:\"index.php?year=$matches[1]&monthnum=$matches[2]&day=$matches[3]&name=$matches[4]&feed=$matches[5]\";s:65:\"([0-9]{4})/([0-9]{1,2})/([0-9]{1,2})/([^/]+)/page/?([0-9]{1,})/?$\";s:98:\"index.php?year=$matches[1]&monthnum=$matches[2]&day=$matches[3]&name=$matches[4]&paged=$matches[5]\";s:72:\"([0-9]{4})/([0-9]{1,2})/([0-9]{1,2})/([^/]+)/comment-page-([0-9]{1,})/?$\";s:98:\"index.php?year=$matches[1]&monthnum=$matches[2]&day=$matches[3]&name=$matches[4]&cpage=$matches[5]\";s:57:\"([0-9]{4})/([0-9]{1,2})/([0-9]{1,2})/([^/]+)(/[0-9]+)?/?$\";s:97:\"index.php?year=$matches[1]&monthnum=$matches[2]&day=$matches[3]&name=$matches[4]&page=$matches[5]\";s:47:\"[0-9]{4}/[0-9]{1,2}/[0-9]{1,2}/[^/]+/([^/]+)/?$\";s:32:\"index.php?attachment=$matches[1]\";s:57:\"[0-9]{4}/[0-9]{1,2}/[0-9]{1,2}/[^/]+/([^/]+)/trackback/?$\";s:37:\"index.php?attachment=$matches[1]&tb=1\";s:77:\"[0-9]{4}/[0-9]{1,2}/[0-9]{1,2}/[^/]+/([^/]+)/feed/(feed|rdf|rss|rss2|atom)/?$\";s:49:\"index.php?attachment=$matches[1]&feed=$matches[2]\";s:72:\"[0-9]{4}/[0-9]{1,2}/[0-9]{1,2}/[^/]+/([^/]+)/(feed|rdf|rss|rss2|atom)/?$\";s:49:\"index.php?attachment=$matches[1]&feed=$matches[2]\";s:72:\"[0-9]{4}/[0-9]{1,2}/[0-9]{1,2}/[^/]+/([^/]+)/comment-page-([0-9]{1,})/?$\";s:50:\"index.php?attachment=$matches[1]&cpage=$matches[2]\";s:64:\"([0-9]{4})/([0-9]{1,2})/([0-9]{1,2})/comment-page-([0-9]{1,})/?$\";s:81:\"index.php?year=$matches[1]&monthnum=$matches[2]&day=$matches[3]&cpage=$matches[4]\";s:51:\"([0-9]{4})/([0-9]{1,2})/comment-page-([0-9]{1,})/?$\";s:65:\"index.php?year=$matches[1]&monthnum=$matches[2]&cpage=$matches[3]\";s:38:\"([0-9]{4})/comment-page-([0-9]{1,})/?$\";s:44:\"index.php?year=$matches[1]&cpage=$matches[2]\";s:25:\".+?/attachment/([^/]+)/?$\";s:32:\"index.php?attachment=$matches[1]\";s:35:\".+?/attachment/([^/]+)/trackback/?$\";s:37:\"index.php?attachment=$matches[1]&tb=1\";s:55:\".+?/attachment/([^/]+)/feed/(feed|rdf|rss|rss2|atom)/?$\";s:49:\"index.php?attachment=$matches[1]&feed=$matches[2]\";s:50:\".+?/attachment/([^/]+)/(feed|rdf|rss|rss2|atom)/?$\";s:49:\"index.php?attachment=$matches[1]&feed=$matches[2]\";s:50:\".+?/attachment/([^/]+)/comment-page-([0-9]{1,})/?$\";s:50:\"index.php?attachment=$matches[1]&cpage=$matches[2]\";s:18:\"(.+?)/trackback/?$\";s:35:\"index.php?pagename=$matches[1]&tb=1\";s:38:\"(.+?)/feed/(feed|rdf|rss|rss2|atom)/?$\";s:47:\"index.php?pagename=$matches[1]&feed=$matches[2]\";s:33:\"(.+?)/(feed|rdf|rss|rss2|atom)/?$\";s:47:\"index.php?pagename=$matches[1]&feed=$matches[2]\";s:26:\"(.+?)/page/?([0-9]{1,})/?$\";s:48:\"index.php?pagename=$matches[1]&paged=$matches[2]\";s:33:\"(.+?)/comment-page-([0-9]{1,})/?$\";s:48:\"index.php?pagename=$matches[1]&cpage=$matches[2]\";s:18:\"(.+?)(/[0-9]+)?/?$\";s:47:\"index.php?pagename=$matches[1]&page=$matches[2]\";}','yes'),(126,0,'update_core','O:8:\"stdClass\":3:{s:7:\"updates\";a:1:{i:0;O:8:\"stdClass\":5:{s:8:\"response\";s:6:\"latest\";s:3:\"url\";s:30:\"http://wordpress.org/download/\";s:7:\"package\";s:40:\"http://wordpress.org/wordpress-2.7.1.zip\";s:7:\"current\";s:5:\"2.7.1\";s:6:\"locale\";s:5:\"en_US\";}}s:12:\"last_checked\";i:1236113231;s:15:\"version_checked\";s:5:\"2.7.1\";}','yes');
/*!40000 ALTER TABLE `wp_options` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `wp_postmeta`
--

DROP TABLE IF EXISTS `wp_postmeta`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `wp_postmeta` (
  `meta_id` bigint(20) NOT NULL auto_increment,
  `post_id` bigint(20) NOT NULL default '0',
  `meta_key` varchar(255) default NULL,
  `meta_value` longtext,
  PRIMARY KEY  (`meta_id`),
  KEY `post_id` (`post_id`),
  KEY `meta_key` (`meta_key`)
) ENGINE=MyISAM AUTO_INCREMENT=5 DEFAULT CHARSET=utf8;
SET character_set_client = @saved_cs_client;

--
-- Dumping data for table `wp_postmeta`
--

LOCK TABLES `wp_postmeta` WRITE;
/*!40000 ALTER TABLE `wp_postmeta` DISABLE KEYS */;
INSERT INTO `wp_postmeta` VALUES (1,1,'_edit_lock','1233057168'),(2,1,'_edit_last','1');
/*!40000 ALTER TABLE `wp_postmeta` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `wp_posts`
--

DROP TABLE IF EXISTS `wp_posts`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `wp_posts` (
  `ID` bigint(20) unsigned NOT NULL auto_increment,
  `post_author` bigint(20) NOT NULL default '0',
  `post_date` datetime NOT NULL default '0000-00-00 00:00:00',
  `post_date_gmt` datetime NOT NULL default '0000-00-00 00:00:00',
  `post_content` longtext NOT NULL,
  `post_title` text NOT NULL,
  `post_category` int(4) NOT NULL default '0',
  `post_excerpt` text NOT NULL,
  `post_status` varchar(20) NOT NULL default 'publish',
  `comment_status` varchar(20) NOT NULL default 'open',
  `ping_status` varchar(20) NOT NULL default 'open',
  `post_password` varchar(20) NOT NULL default '',
  `post_name` varchar(200) NOT NULL default '',
  `to_ping` text NOT NULL,
  `pinged` text NOT NULL,
  `post_modified` datetime NOT NULL default '0000-00-00 00:00:00',
  `post_modified_gmt` datetime NOT NULL default '0000-00-00 00:00:00',
  `post_content_filtered` text NOT NULL,
  `post_parent` bigint(20) NOT NULL default '0',
  `guid` varchar(255) NOT NULL default '',
  `menu_order` int(11) NOT NULL default '0',
  `post_type` varchar(20) NOT NULL default 'post',
  `post_mime_type` varchar(100) NOT NULL default '',
  `comment_count` bigint(20) NOT NULL default '0',
  PRIMARY KEY  (`ID`),
  KEY `post_name` (`post_name`),
  KEY `type_status_date` (`post_type`,`post_status`,`post_date`,`ID`),
  KEY `post_parent` (`post_parent`)
) ENGINE=MyISAM AUTO_INCREMENT=6 DEFAULT CHARSET=utf8;
SET character_set_client = @saved_cs_client;

--
-- Dumping data for table `wp_posts`
--

LOCK TABLES `wp_posts` WRITE;
/*!40000 ALTER TABLE `wp_posts` DISABLE KEYS */;
INSERT INTO `wp_posts` VALUES (1,1,'2008-12-10 20:07:08','2008-12-11 03:07:08','Well, I was going to start on a somewhat different note, but I had the BBC news on in the background this evening (Monday 26 Jan) when what appeared to be a senior official from the MOD (Ministry of Defence)  started explaining that yes, there have been violations of British airspace recently by UFOs, (here he explained that we don\'t know if they\'re from Moscow or Mars ..)  and the British Defense Force has fired at them on a number of occasions. (Unsuccessfully so far, the news reader assured me).  This  stopped me  in my tracks and wondered if I was hearing things.\r\n\r\nBecause I had only half been watching I\'m not sure if this was the repeat of a statement made a while ago or a current one, but that was a first for me, a top-brass Military Man (or at least a well-dressed MOD spokesman) stating that yes, they were currently dealing with UFO\'s (whether made of Marshmallows or from Moscow or Mars, it was still a first.) I shook as  much dust out of my ears as I could in case the statement was repeated but it wasn\'t.\r\n\r\nA few weeks ago there was a news story about a wind turbine that had been damaged, alongside reports of UFO sightings. The original news story gave possible explanations of the damage being done by ice being flung off another of the turbines, or even a frozen block of urine falling out of a plane, but these seem to have been dismissed.\r\n\r\nThe Telegraph have a write-up saying that <a title=\"Turbine Debris Sent to German Forensic Scientists\" href=\"http://www.telegraph.co.uk/news/newstopics/howaboutthat/4211158/UFO-turbine-debris-sent-to-German-forensic-scientists.html\" target=\"_blank\"> \"Debris from a destroyed wind turbine which reports have claimed was hit by a UFO has been sent for forensic analysis in Germany. \"</a> and \"Hundreds of local witnesses claimed to have seen bright flashing spheres in the skies above the turbine, and many are convinced the damage was caused by a flying saucer.\"\r\n\r\nI sent a text to my brother who is on holiday in Egypt, telling him of the MOD admitting to firing at UFOs, and got the reply: \"Shame, they probably just came by to refuel...\" which warranted the reply: \"True... it was actually British Gas who were firing at them...\"\r\n\r\nThe UFO controversy has taken on a whole new dimension since Britain\'s Ministry of Defense released files on UFO sightings to the National Archives at Kew. These date back to the 1970s and include witness accounts and the government\'s response, and are part of a four-year project to make all UFO documents available to the public via the archives at Kew. CNN <a title=\"CNN UFO\" href=\"http://edition.cnn.com/2008/WORLD/europe/05/14/britain.ufos/index.html\" target=\"_blank\">covered this in May last year.</a>\r\n\r\nIf you want to find out more about close encounters over Gatwick Airport, alien abductions, stray satellites - and what the UK Government thought of it all - then this is the place to be -  <a title=\"Kew\" href=\"http://www.nationalarchives.gov.uk/ufos/\" target=\"_blank\">UFOs at The National Archives at Kew.</a> Anybody interested in digging through this archive may want to start with Dr David Clarke’s background guide to the files  <a title=\"Highlights\" href=\"http://www.nationalarchives.gov.uk/ufos/pdfs/oct-2008-highlights-guide.pdf?WT.download=highlights-guide\" target=\"_blank\">a synopsis of the highlights in PDF form.</a>\r\n\r\nEven Obama doesn\'t seem to have avoided the UFO factor according to a video clip of CNN broadcasting from the inaugration which has images of a UFO over Obama\'s inaugration, passing the Washington Memorial at a time when no planes were allowed over the area. Is this a hoax or is this real?\r\nI think it looks like a turbo-charged pigeon, but it is somewhat strange.\r\n\r\n<object width=\"425\" height=\"344\"><param name=\"movie\" value=\"http://www.youtube.com/v/EFu6XJ3yChI&hl=en&fs=1\"></param><param name=\"allowFullScreen\" value=\"true\"></param><param name=\"allowscriptaccess\" value=\"always\"></param><embed src=\"http://www.youtube.com/v/EFu6XJ3yChI&hl=en&fs=1\" type=\"application/x-shockwave-flash\" allowscriptaccess=\"always\" allowfullscreen=\"true\" width=\"425\" height=\"344\"></embed></object>\r\n\r\nWell, I started with the BBC news on in the background now I feel as if I may be in a strange other-worldly dream of UFO\'s... I\'ll finish this when I wake up, but...\r\n... Its All Out There ...','From Moscow or Mars to Obama\'s Striped Stars',0,'..there have been violations of British airspace recently by UFOs, and the British Defense Force has fired at them on a number of occasions...','publish','open','open','','hello-world','','','2009-01-27 04:48:40','2009-01-27 11:48:40','',0,'http://www.rainbowzebra.net/wildwideweblog/?p=1',0,'post','',0),(2,1,'2008-12-10 20:07:08','2008-12-11 03:07:08','This is an example of a WordPress page, you could edit this to put information about yourself or your site so readers know where you are coming from. You can create as many pages like this one or sub-pages as you like and manage all of your content inside of WordPress.','About',0,'','publish','open','open','','about','','','2008-12-10 20:07:08','2008-12-11 03:07:08','',0,'http://www.rainbowzebra.net/wildwideweblog/?page_id=2',0,'page','',0),(3,1,'2009-01-27 04:44:15','2009-01-27 11:44:15','Well, I was going to start on a somewhat different note, but I had the BBC news on in the background this evening (Monday 26 Jan) when what appeared to be a senior official from the MOD (Ministry of Defence)  started explaining that yes, there have been violations of British airspace recently by UFOs, (here he explained that we don\'t know if they\'re from Moscow or Mars ..)  and the British Defense Force has fired at them on a number of occasions. (Unsuccessfully so far, the news reader assured me).  This  stopped me  in my tracks and wondered if I was hearing things.\r\n\r\nBecause I had only half been watching I\'m not sure if this was the repeat of a statement made a while ago or a current one, but that was a first for me, a top-brass Military Man (or at least a well-dressed MOD spokesman) stating that yes, they were currently dealing with UFO\'s (whether made of Marshmallows or from Moscow or Mars, it was still a first.) I shook as  much dust out of my ears as I could in case the statement was repeated but it wasn\'t.\r\n\r\nA few weeks ago there was a news story about a wind turbine that had been damaged, alongside reports of UFO sightings. The original news story gave possible explanations of the damage being done by ice being flung off another of the turbines, or even a frozen block of urine falling out of a plane, but these seem to have been dismissed.\r\n\r\nThe Telegraph have a write-up saying that <a title=\"Turbine Debris Sent to German Forensic Scientists\" href=\"http://www.telegraph.co.uk/news/newstopics/howaboutthat/4211158/UFO-turbine-debris-sent-to-German-forensic-scientists.html\" target=\"_blank\"> \"Debris from a destroyed wind turbine which reports have claimed was hit by a UFO has been sent for forensic analysis in Germany. \"</a> and \"Hundreds of local witnesses claimed to have seen bright flashing spheres in the skies above the turbine, and many are convinced the damage was caused by a flying saucer.\"\r\n\r\nI sent a text to my brother who is on holiday in Egypt, telling him of the MOD admitting to firing at UFOs, and got the reply: \"Shame, they probably just came by to refuel...\" which warranted the reply: \"True... it was actually British Gas who were firing at them...\"\r\n\r\nThe UFO controversy has taken on a whole new dimension since Britain\'s Ministry of Defense released files on UFO sightings to the National Archives at Kew. These date back to the 1970s and include witness accounts and the government\'s response, and are part of a four-year project to make all UFO documents available to the public via the archives at Kew. CNN <a title=\"CNN UFO\" href=\"http://edition.cnn.com/2008/WORLD/europe/05/14/britain.ufos/index.html\" target=\"_blank\">covered this in May last year.</a>\r\n\r\nIf you want to find out more about close encounters over Gatwick Airport, alien abductions, stray satellites - and what the UK Government thought of it all - then this is the place to be -  <a title=\"Kew\" href=\"http://www.nationalarchives.gov.uk/ufos/\" target=\"_blank\">UFOs at The National Archives at Kew.</a> Anybody interested in digging through this archive may want to start with Dr David Clarke’s background guide to the files  <a title=\"Highlights\" href=\"http://www.nationalarchives.gov.uk/ufos/pdfs/oct-2008-highlights-guide.pdf?WT.download=highlights-guide\" target=\"_blank\">a synopsis of the highlights in PDF form.</a>\r\n\r\nEven Obama doesn\'t seem to have avoided the UFO factor according to a video clip of CNN broadcasting from the inaugration which has images of a UFO over Obama\'s inaugration, passing the Washington Memorial at a time when no planes were allowed over the area. Is this a hoax or is this real?\r\nI think it looks like a turbo-charged pigeon, but it is somewhat strange.\r\n\r\n<object width=\"425\" height=\"344\"><param name=\"movie\" value=\"http://www.youtube.com/v/EFu6XJ3yChI&hl=en&fs=1\"></param><param name=\"allowFullScreen\" value=\"true\"></param><param name=\"allowscriptaccess\" value=\"always\"></param><embed src=\"http://www.youtube.com/v/EFu6XJ3yChI&hl=en&fs=1\" type=\"application/x-shockwave-flash\" allowscriptaccess=\"always\" allowfullscreen=\"true\" width=\"425\" height=\"344\"></embed></object>\r\n\r\nWell, I started with the BBC news on in the background now I feel as if I may be in a strange other-worldly dream of UFO\'s... I\'ll finish this when I wake up, but...\r\n... Its All Out There ...','From Moscow or Mars to Obama\'s Striped Stars',0,'..there have been violations of British airspace recently by UFOs, and the British Defense Force has fired at them on a number of occasions...','inherit','open','closed','','1-autosave','','','2009-01-27 04:44:15','2009-01-27 11:44:15','',1,'http://www.rainbowzebra.net/wildwideweblog/?p=3',0,'revision','',0),(4,1,'2008-12-10 20:07:08','2008-12-11 03:07:08','Welcome to WordPress. This is your first post. Edit or delete it, then start blogging!','Hello world!',0,'','inherit','open','closed','','1-revision','','','2008-12-10 20:07:08','2008-12-11 03:07:08','',1,'http://www.rainbowzebra.net/wildwideweblog/?p=4',0,'revision','',0),(5,1,'2009-01-27 04:43:59','2009-01-27 11:43:59','Well, I was going to start on a somewhat different note, but I had the BBC news on in the background this evening (Monday 26 Jan) when what appeared to be a senior official from the MOD (Ministry of Defence)  started explaining that yes, there have been violations of British airspace recently by UFOs, (here he explained that we don\'t know if they\'re from Moscow or Mars ..)  and the British Defense Force has fired at them on a number of occasions. (Unsuccessfully so far, the news reader assured me).  This  stopped me  in my tracks and wondered if I was hearing things.\r\n\r\nBecause I had only half been watching I\'m not sure if this was the repeat of a statement made a while ago or a current one, but that was a first for me, a top-brass Military Man (or at least a well-dressed MOD spokesman) stating that yes, they were currently dealing with UFO\'s (whether made of Marshmallows or from Moscow or Mars, it was still a first.) I shook as  much dust out of my ears as I could in case the statement was repeated but it wasn\'t.\r\n\r\nA few weeks ago there was a news story about a wind turbine that had been damaged, alongside reports of UFO sightings. The original news story gave possible explanations of the damage being done by ice being flung off another of the turbines, or even a frozen block of urine falling out of a plane, but these seem to have been dismissed.\r\n\r\nThe Telegraph have a write-up saying that <a title=\"Turbine Debris Sent to German Forensic Scientists\" href=\"http://www.telegraph.co.uk/news/newstopics/howaboutthat/4211158/UFO-turbine-debris-sent-to-German-forensic-scientists.html\" target=\"_blank\"> \"Debris from a destroyed wind turbine which reports have claimed was hit by a UFO has been sent for forensic analysis in Germany. \"</a> and \"Hundreds of local witnesses claimed to have seen bright flashing spheres in the skies above the turbine, and many are convinced the damage was caused by a flying saucer.\"\r\n\r\nI sent a text to my brother who is on holiday in Egypt, telling him of the MOD admitting to firing at UFOs, and got the reply: \"Shame, they probably just came by to refuel...\" which warranted the reply: \"True... it was actually British Gas who were firing at them...\"\r\n\r\nThe UFO controversy has taken on a whole new dimension since Britain\'s Ministry of Defense released files on UFO sightings to the National Archives at Kew. These date back to the 1970s and include witness accounts and the government\'s response, and are part of a four-year project to make all UFO documents available to the public via the archives at Kew. CNN <a title=\"CNN UFO\" href=\"http://edition.cnn.com/2008/WORLD/europe/05/14/britain.ufos/index.html\" target=\"_blank\">covered this in May last year.</a>\r\n\r\nIf you want to find out more about close encounters over Gatwick Airport, alien abductions, stray satellites - and what the UK Government thought of it all - then this is the place to be -  <a title=\"Kew\" href=\"http://www.nationalarchives.gov.uk/ufos/\" target=\"_blank\">UFOs at The National Archives at Kew.</a> Anybody interested in digging through this archive may want to start with Dr David Clarke’s background guide to the files  <a title=\"Highlights\" href=\"http://www.nationalarchives.gov.uk/ufos/pdfs/oct-2008-highlights-guide.pdf?WT.download=highlights-guide\" target=\"_blank\">a synopsis of the highlights in PDF form.</a>\r\n\r\nEven Obama doesn\'t seem to have avoided the UFO factor according to a video clip of CNN broadcasting from the inaugration which has images of a UFO over Obama\'s inaugration, passing the Washington Memorial at a time when no planes were allowed over the area. Is this a hoax or is this real?\r\nI think it looks like a turbo-charged pigeon, but it is somewhat strange.\r\n\r\n<object width=\"425\" height=\"344\"><param name=\"movie\" value=\"http://www.youtube.com/v/EFu6XJ3yChI&hl=en&fs=1\"></param><param name=\"allowFullScreen\" value=\"true\"></param><param name=\"allowscriptaccess\" value=\"always\"></param><embed src=\"http://www.youtube.com/v/EFu6XJ3yChI&hl=en&fs=1\" type=\"application/x-shockwave-flash\" allowscriptaccess=\"always\" allowfullscreen=\"true\" width=\"425\" height=\"344\"></embed></object>\r\n\r\nWell, I started with the BBC news on in the background now I feel as if I may be in a strange other-worldly dream of UFO\'s... I\'ll finish this when I wake up, but...\r\n... Its All Out There ...','From Moscow or Mars to Obama\'s Striped Stars',0,'..there have been violations of British airspace recently by UFOs, and the British Defense Force has fired at them on a number of occasions...','inherit','open','closed','','1-revision-2','','','2009-01-27 04:43:59','2009-01-27 11:43:59','',1,'http://www.rainbowzebra.net/wildwideweblog/?p=5',0,'revision','',0);
/*!40000 ALTER TABLE `wp_posts` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `wp_term_relationships`
--

DROP TABLE IF EXISTS `wp_term_relationships`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `wp_term_relationships` (
  `object_id` bigint(20) NOT NULL default '0',
  `term_taxonomy_id` bigint(20) NOT NULL default '0',
  `term_order` int(11) NOT NULL default '0',
  PRIMARY KEY  (`object_id`,`term_taxonomy_id`),
  KEY `term_taxonomy_id` (`term_taxonomy_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;
SET character_set_client = @saved_cs_client;

--
-- Dumping data for table `wp_term_relationships`
--

LOCK TABLES `wp_term_relationships` WRITE;
/*!40000 ALTER TABLE `wp_term_relationships` DISABLE KEYS */;
INSERT INTO `wp_term_relationships` VALUES (1,2,0),(2,2,0),(3,2,0),(4,2,0),(5,2,0),(6,2,0),(7,2,0),(3,1,0),(4,1,0),(5,1,0),(1,3,0);
/*!40000 ALTER TABLE `wp_term_relationships` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `wp_term_taxonomy`
--

DROP TABLE IF EXISTS `wp_term_taxonomy`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `wp_term_taxonomy` (
  `term_taxonomy_id` bigint(20) NOT NULL auto_increment,
  `term_id` bigint(20) NOT NULL default '0',
  `taxonomy` varchar(32) NOT NULL default '',
  `description` longtext NOT NULL,
  `parent` bigint(20) NOT NULL default '0',
  `count` bigint(20) NOT NULL default '0',
  PRIMARY KEY  (`term_taxonomy_id`),
  UNIQUE KEY `term_id_taxonomy` (`term_id`,`taxonomy`)
) ENGINE=MyISAM AUTO_INCREMENT=4 DEFAULT CHARSET=utf8;
SET character_set_client = @saved_cs_client;

--
-- Dumping data for table `wp_term_taxonomy`
--

LOCK TABLES `wp_term_taxonomy` WRITE;
/*!40000 ALTER TABLE `wp_term_taxonomy` DISABLE KEYS */;
INSERT INTO `wp_term_taxonomy` VALUES (1,1,'category','',0,0),(2,2,'link_category','',0,7),(3,3,'category','',0,1);
/*!40000 ALTER TABLE `wp_term_taxonomy` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `wp_terms`
--

DROP TABLE IF EXISTS `wp_terms`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `wp_terms` (
  `term_id` bigint(20) NOT NULL auto_increment,
  `name` varchar(200) NOT NULL default '',
  `slug` varchar(200) NOT NULL default '',
  `term_group` bigint(10) NOT NULL default '0',
  PRIMARY KEY  (`term_id`),
  UNIQUE KEY `slug` (`slug`),
  KEY `name` (`name`)
) ENGINE=MyISAM AUTO_INCREMENT=4 DEFAULT CHARSET=utf8;
SET character_set_client = @saved_cs_client;

--
-- Dumping data for table `wp_terms`
--

LOCK TABLES `wp_terms` WRITE;
/*!40000 ALTER TABLE `wp_terms` DISABLE KEYS */;
INSERT INTO `wp_terms` VALUES (1,'Uncategorized','uncategorized',0),(2,'Blogroll','blogroll',0),(3,'UFOs','ufos',0);
/*!40000 ALTER TABLE `wp_terms` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `wp_usermeta`
--

DROP TABLE IF EXISTS `wp_usermeta`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `wp_usermeta` (
  `umeta_id` bigint(20) NOT NULL auto_increment,
  `user_id` bigint(20) NOT NULL default '0',
  `meta_key` varchar(255) default NULL,
  `meta_value` longtext,
  PRIMARY KEY  (`umeta_id`),
  KEY `user_id` (`user_id`),
  KEY `meta_key` (`meta_key`)
) ENGINE=MyISAM AUTO_INCREMENT=9 DEFAULT CHARSET=utf8;
SET character_set_client = @saved_cs_client;

--
-- Dumping data for table `wp_usermeta`
--

LOCK TABLES `wp_usermeta` WRITE;
/*!40000 ALTER TABLE `wp_usermeta` DISABLE KEYS */;
INSERT INTO `wp_usermeta` VALUES (1,1,'nickname','Muizing1'),(2,1,'rich_editing','true'),(3,1,'comment_shortcuts','false'),(4,1,'admin_color','fresh'),(5,1,'wp_capabilities','a:1:{s:13:\"administrator\";b:1;}'),(6,1,'wp_user_level','10'),(7,1,'wp_usersettings','editor=html'),(8,1,'wp_usersettingstime','1233056402');
/*!40000 ALTER TABLE `wp_usermeta` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `wp_users`
--

DROP TABLE IF EXISTS `wp_users`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `wp_users` (
  `ID` bigint(20) unsigned NOT NULL auto_increment,
  `user_login` varchar(60) NOT NULL default '',
  `user_pass` varchar(64) NOT NULL default '',
  `user_nicename` varchar(50) NOT NULL default '',
  `user_email` varchar(100) NOT NULL default '',
  `user_url` varchar(100) NOT NULL default '',
  `user_registered` datetime NOT NULL default '0000-00-00 00:00:00',
  `user_activation_key` varchar(60) NOT NULL default '',
  `user_status` int(11) NOT NULL default '0',
  `display_name` varchar(250) NOT NULL default '',
  PRIMARY KEY  (`ID`),
  KEY `user_login_key` (`user_login`),
  KEY `user_nicename` (`user_nicename`)
) ENGINE=MyISAM AUTO_INCREMENT=2 DEFAULT CHARSET=utf8;
SET character_set_client = @saved_cs_client;

--
-- Dumping data for table `wp_users`
--

LOCK TABLES `wp_users` WRITE;
/*!40000 ALTER TABLE `wp_users` DISABLE KEYS */;
INSERT INTO `wp_users` VALUES (1,'Muizing1','$P$BGheW9HAnBBXkpmCBH6XBTzweC2Peh/','Muizing1','webmaster@rainbowzebra.com','http://','2008-12-11 03:07:08','',0,'Muizing1');
/*!40000 ALTER TABLE `wp_users` ENABLE KEYS */;
UNLOCK TABLES;
/*!40103 SET TIME_ZONE=@OLD_TIME_ZONE */;

/*!40101 SET SQL_MODE=@OLD_SQL_MODE */;
/*!40014 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS */;
/*!40014 SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS */;
/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
/*!40101 SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS */;
/*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;
/*!40111 SET SQL_NOTES=@OLD_SQL_NOTES */;

-- Dump completed on 2009-03-04  2:03:15
